<?php

return array(
	'menu-top-bar-resolution' => '959',
	'tribe-events-join-text' => 'Join',
	'full-width-header' => 'false',
	'header-layout' => 'logo-text-menu',
	'related-portfolios-title' => 'RELATED PROJECTS',
	'related-posts-title' => 'RELATED STORIES',
	'top-bar-layout' => 'social-text',
	'enable-header-search' => 'true',
	'single-portfolio-images-wth' => '0',
	'page-images-wth' => '1.25',
	'portfolio-loop-images-wth' => '1.3',
	'post-small-images-wth' => '1.3',
	'post-loop-images-wth' => '1.3',
	'single-post-images-wth' => '0',
	'fmap-zoom' => '14',
	'fmap-marker' => 'true',
	'fmap-popup' => 'false',
	'lcolumn-text-color' => '#ff5400',
	'site-layout-type' => 'full',
	'javascript_move_bottom' => '1',
	'enable-featured-posts' => '',
	'default-body-layout' => 'full',
	'primary-font-face' => 'Raleway',
	'primary-font-weight' => 'normal',
	'primary-font-size' => '14',
	'primary-font-lheight' => '20',
	'primary-font-color' => '#767676',
	'secondary-font-face' => 'Droid Serif',
	'secondary-font-weight' => 'normal',
	'secondary-font-size' => '13',
	'secondary-font-lheight' => '18',
	'secondary-font-color' => '#777777',
	'footer-sidebars-font-face' => 'Raleway',
	'footer-sidebars-font-weight' => 'normal',
	'footer-sidebars-font-size' => '13',
	'footer-sidebars-font-lheight' => '20',
	'footer-sidebars-font-color' => '#AFAFAF',
	'footer-sidebars-titles-face' => 'Raleway',
	'footer-sidebars-titles-weight' => '300',
	'footer-sidebars-titles-size' => '14',
	'footer-sidebars-titles-lheight' => '16',
	'footer-sidebars-titles-color' => '#ffffff',
	'sub-footer-face' => 'Raleway',
	'sub-footer-weight' => '300',
	'sub-footer-size' => '12',
	'sub-footer-lheight' => '14',
	'sub-footer-color' => '#898989',
	'em-face' => 'Raleway',
	'em-weight' => 'italic',
	'em-size' => '14',
	'em-lheight' => '18',
	'em-color' => '#898989',
	'logo-face' => 'Raleway',
	'logo-weight' => '600',
	'logo-size' => '20',
	'logo-lheight' => '40',
	'logo-color' => '#F0542D',
	'menu-font-face' => 'Raleway',
	'menu-font-weight' => '600',
	'menu-font-size' => '13',
	'menu-font-lheight' => '30',
	'menu-font-color' => '#000000',
	'h1-face' => 'Raleway',
	'h1-size' => '36',
	'h1-lheight' => '42',
	'h1-weight' => 'bold',
	'h1-color' => '#4A4F55',
	'h2-face' => 'Raleway',
	'h2-size' => '26',
	'h2-lheight' => '30',
	'h2-weight' => '800',
	'h2-color' => '#364352',
	'h3-face' => 'Raleway',
	'h3-size' => '24',
	'h3-lheight' => '30',
	'h3-weight' => 'normal',
	'h3-color' => '#4A4F55',
	'h4-face' => 'Raleway',
	'h4-size' => '20',
	'h4-lheight' => '26',
	'h4-weight' => '300',
	'h4-color' => '#4A4F55',
	'h5-face' => 'Raleway',
	'h5-size' => '12',
	'h5-lheight' => '14',
	'h5-weight' => '600',
	'h5-color' => '#242323',
	'h6-face' => 'Arial',
	'h6-size' => '10',
	'h6-lheight' => '11',
	'h6-weight' => 'bold',
	'h6-color' => '#6A6A6A',
	'show_scroll_to_top' => 'false',
	'footer-sidebars' => '8',
	'footer-sidebars-1-width' => 'cell-1-4',
	'footer-sidebars-2-width' => 'cell-1-4',
	'footer-sidebars-3-width' => 'cell-1-4',
	'footer-sidebars-4-width' => 'cell-1-4',
	'footer-sidebars-5-width' => 'cell-1-4',
	'footer-sidebars-6-width' => 'cell-1-4',
	'footer-sidebars-7-width' => 'cell-1-4',
	'footer-sidebars-1-last' => 'false',
	'footer-sidebars-2-last' => 'false',
	'footer-sidebars-3-last' => 'false',
	'footer-sidebars-4-last' => 'true',
	'footer-sidebars-5-last' => 'false',
	'footer-sidebars-6-last' => 'false',
	'footer-sidebars-7-last' => 'false',
	'header-sidebars' => '3',
	'header-sidebars-1-width' => 'cell-1-3',
	'header-sidebars-2-width' => 'cell-1-3',
	'header-sidebars-3-width' => 'cell-1-3',
	'header-sidebars-4-width' => 'full',
	'header-sidebars-5-width' => 'full',
	'header-sidebars-6-width' => 'full',
	'header-sidebars-1-last' => 'false',
	'header-sidebars-2-last' => 'false',
	'header-sidebars-3-last' => 'true',
	'header-sidebars-4-last' => 'false',
	'header-sidebars-5-last' => 'false',
	'header-sidebars-6-last' => 'false',
	'has-header-slider' => '',
	'has-header-sidebars' => 'false',
	'has-footer-sidebars' => 'true',
	'has-fullwidth-slider' => '1',
	'header-slider-position' => 'static',
	'header-slider-pausetime' => '6438',
	'header-slider-animationtime' => '934',
	'header-slider-effect' => 'makalu',
	'header-slider-direction' => 'none',
	'header-slider-prevtext' => 'Previous',
	'header-slider-nexttext' => 'Next',
	'header-slider-captionopacity' => '1',
	'header-slider-easing' => 'easeInOutQuint',
	'header-slider-waveduration' => '300',
	'header-slider-wavetype' => 'B2T',
	'header-slider-subslideduration' => '0',
	'header-slider-visiblegrid' => '1',
	'header-slider-gridcolor' => '#cccccc',
	'header-slider-rows' => '4',
	'header-slider-cols' => '6',
	'header-slider-captiontime' => '659',
	'header-slider-resizing' => 'none',
	'post-thumbnail-width' => '250',
	'post-thumbnail-height' => '200',
	'fullimage-height' => '560',
	'accent-color-1' => '#F0542D',
	'accent-color-2' => '#364352',
	'accent-color-3' => '#7C8A8D',
	'accent-color-4' => '#D8D8D8',
	'accent-color-5' => '#ffffff',
	'accent-color-6' => '#2B2F34',
	'header-helper-style' => 'light',
	'slider-helper-style' => 'light',
	'body-helper-style' => 'light',
	'footer-helper-style' => 'light',
	'css_link_color' => '#F0542D',
	'css_link_visited_color' => '#142e91',
	'css_link_hover_color' => '#5C6268',
	'css_header_link_color' => '#4e89a5',
	'css_header_link_visited_color' => '#4e89a5',
	'css_header_link_hover_color' => '#4e89a5',
	'css_footer_link_color' => '#F0542D',
	'css_footer_link_visited_color' => '#F0542D',
	'css_footer_link_hover_color' => '#fff',
	'css_tophead_background' => 'rgba(0, 0, 0, 0)',
	'css_tophead_background_repeat' => 'no-repeat',
	'css_tophead_background_picture' => '',
	'css_tophead_background_position' => 'center top',
	'css_tophead_color' => '#c1c1c1',
	'css-tophead-link-color' => '#D4D7D7',
	'css-tophead-link-hover-color' => '#ffffff',
	'css_tophead_current_link_color' => 'EA5178',
	'subfooter-background-color' => '#ffffff',
	'subfooter-background-repeat' => 'repeat',
	'subfooter-background-picture' => '',
	'subfooter-background-attachment' => 'scroll',
	'subfooter-background-position' => 'center top',
	'events-after-sidebars-2-background-color' => '',
	'events-after-sidebars-2-background-repeat' => 'no-repeat',
	'events-after-sidebars-2-background-image' => '',
	'events-after-sidebars-2-background-attachment' => 'fixed',
	'events-after-sidebars-2-background-position' => 'center top',
	'events-after-sidebars-2-background-size' => 'auto',
	'css_credits_color' => '#555555',
	'footer-background-color' => '#34373C',
	'footer-background-opacity' => '1',
	'footer-background-repeat' => 'no-repeat',
	'footer-background-picture' => '',
	'footer-background-position' => 'center bottom',
	'footer-background-attachment' => 'scroll',
	'css_header_sidebars_title_color' => '#000',
	'body-background-color' => '#EDEDED',
	'body-background-repeat' => 'repeat',
	'body-background-image' => '',
	'body-background-position' => 'center top',
	'body-background-attachment' => 'fixed',
	'header-background-color' => '#ffffff',
	'header-background-opacity' => '1',
	'header-background-repeat' => 'no-repeat',
	'header-background-picture' => '',
	'header-background-position' => 'center top',
	'header-background-attachment' => 'fixed',
	'top-nav-background-color' => '#7C8A8D',
	'top-nav-background-opacity' => '1',
	'top-nav-background-repeat' => 'no-repeat',
	'top-nav-background-picture' => '',
	'top-nav-background-position' => 'center top',
	'top-nav-background-attachment' => 'fixed',
	'slider-background-color' => '#ffffff',
	'slider-background-repeat' => 'repeat-x',
	'slider-background-picture' => '',
	'slider-background-position' => 'center top',
	'slider-background-attachment' => 'scroll',
	'main-background' => '#ffffff',
	'main-background-opacity' => '1',
	'main-background-repeat' => 'no-repeat',
	'main-background-picture' => '',
	'main-background-position' => 'center top',
	'main-background-attachment' => 'fixed',
	'css_hide_fnav_background_repeat' => 'no-repeat',
	'css_hide_fnav_background_picture' => '',
	'css_hive_fnav_background_position' => 'center center',
	'css_button_color' => '#eeeeee',
	'css_button_hover_color' => '#eeeeee',
	'left-sidebar-width' => '25',
	'right-sidebar-width' => '25',
	'sidebar-margin-top' => '0',
	'content-width' => '940',
	'custom_css' => '.screens .linkarea img{
	box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.10);
	transition: all .3s ease;
	border-radius: 2px;
}

.screens .linkarea img:hover {
	box-shadow: 0px 2px 20px 0px rgba(0,0,0,0.16);
	margin-top: -10px;
}
.page-id-10091 #style-switcher{
display: none;
}


body.sticky-header-type-over.sticky-header.wpv-not-scrolled header.main-header.layout-standard .second-row, body.sticky-header-type-over.sticky-header.wpv-not-scrolled header.main-header.layout-logo-text-menu .second-row{
  border-top-color: rgba(237, 237, 237, 0.2)
}





/* Welcome page only! */

.w-header {
	text-align: center;
}
.w-header .grid-1-6{
	display: inline-block;
	float: none;
}
.w-header h3{
	margin: 0px;
	font-weight: 600;
}
.w-header p{
	margin-top: 0.5em
}
.w-header .sep{
	opacity: 0.2;
}



.page-id-10091 h2{
    font-size: 3em;
    line-height: 1em;
    font-weight: 100;
    color: #7C8A8D;
    margin-bottom: 10px;
}

.big-text {
	font-size: 1.3em;
    line-height: 1.2em;
    font-weight: 100
}

.plugin-logos img{
	padding: 0px 20px;
    display: inline-block;
}


.more-testimonials{
	border: solid 1px #EDEDED;
	text-align: center;
	padding: 20px 30px;
	border: 1px solid #D9D9D9;
}
.more-testimonials h3{
    margin-bottom: 9px;
    margin-top: 6px;
}
.more-testimonials p{
	margin-top: 0px;
}
.dark-bg h2{
	color: #fff !important;
}

@media (max-width: 958px){
.twitter-button{
	margin-bottom: 20px;
}
.w-header .extended-content {
	left: 0px !important;
	right: 0px !important;
}
}



',
	'custom_js' => '',
	'image_small_width' => '50',
	'image_small_height' => '50',
	'image_medium_width' => '640',
	'image_medium_height' => '150',
	'image_large_width' => '400',
	'image_large_height' => '400',
	'video_width' => '877',
	'video_height' => '640',
	'feedback-link' => '',
	'show-fb' => '',
	'fb-link' => '',
	'show-twitter' => '',
	'twitter-link' => '',
	'show-youtube' => '',
	'youtube-link' => '',
	'show-flickr' => '',
	'flickr-link' => '',
	'show-phone-top' => '1',
	'header-text-main' => '[icon name=\"theme-envelope-open\" style=\"\" color=\"accent4\" size=\"32\" ]
<p>WANT AN APPROXIMATE PRICE?<br/>
<a href=\"/contact-us/\"><strong>GET A FREE QUOTE »</strong></a></p>
',
	'custom-header-logo' => 'https://construction.vamtam.com/wp-content/uploads/2014/12/logo.png',
	'splash-screen-logo' => 'https://construction.vamtam.com/wp-content/uploads/2014/12/load-icon.png',
	'css_logo_margin_bottom' => '0',
	'css_logo_margin_top' => '10',
	'css_menu_color' => '#afd2ea',
	'css_menu_background' => '#F6F6F6',
	'css_menu_hover_color' => '#F0542D',
	'css_menu_hover_background' => '#3f3f3f',
	'css_submenu_color' => '#000000',
	'css_submenu_background' => '#000000',
	'css_submenu_hover_color' => '#F0542D',
	'css_submenu_hover_background' => '#ffffff',
	'css_postformat_opacity_n' => '0.2',
	'css_postformat_opacity_h' => '0.5',
	'header-height' => '140',
	'stage-height' => '189',
	'header-slider-height' => '382',
	'favicon_url' => 'https://construction.vamtam.com/wp-content/uploads/2014/12/favicon.png',
	'meta_posted_in' => 'false',
	'meta_posted_on' => 'true',
	'meta_comment_count' => 'true',
	'last-active-skin' => 'Orange',
	'fixed-header' => '',
	'share-post-twitter' => 'true',
	'share-post-facebook' => 'true',
	'share-page-twitter' => '',
	'share-page-facebook' => '',
	'share-portfolio-twitter' => 'true',
	'share-portfolio-facebook' => 'true',
	'share-lightbox-twitter' => '',
	'share-lightbox-facebook' => '',
	'header-sidebars-7-width' => 'full',
	'header-sidebars-7-last' => 'false',
	'header-sidebars-8-width' => 'full',
	'header-sidebars-8-last' => 'false',
	'header-sidebars-9-width' => 'full',
	'header-sidebars-9-last' => '',
	'header-sidebars-10-width' => 'full',
	'header-sidebars-10-last' => '',
	'header-sidebars-11-width' => 'full',
	'header-sidebars-11-last' => '',
	'header-sidebars-12-width' => 'full',
	'header-sidebars-12-last' => '',
	'footer-sidebars-8-width' => 'cell-1-4',
	'footer-sidebars-8-last' => 'true',
	'footer-sidebars-9-width' => 'full',
	'footer-sidebars-9-last' => '',
	'footer-sidebars-10-width' => 'full',
	'footer-sidebars-10-last' => '',
	'footer-sidebars-11-width' => 'full',
	'footer-sidebars-11-last' => '',
	'footer-sidebars-12-width' => 'full',
	'footer-sidebars-12-last' => '',
	'show_flickr' => '1',
	'show_youtube' => '1',
	'show_twitter' => '1',
	'fbb-link' => '#',
	'show_fb' => '1',
	'show_rss_button' => '',
	'title_background_color' => '',
	'credits' => '<p style=\"text-align:center; padding: 10px 0px;\">
© 2015 <a href=\"#\">Construction Renovation Theme</a> – Made with pasion!',
	'analytics_key' => '',
	'custom-sidebars' => 'wpv_sidebar-Widgets ,wpv_sidebar-Blog page,wpv_sidebar-Team Area,wpv_sidebar-woo shop home',
	'header-slider-pauseonhover' => '',
	'feedback-type' => 'none',
	'has-page-header' => '1',
	'single-featured-image-position' => 'sideimage',
	'page_title_background_color' => '',
	'page_title_background_image' => 'http://makalu.vamtam.com/wp-content/uploads/2012/02/interior-design-black-living-room-on-white-up.jpg',
	'page_title_background_repeat' => 'no-repeat',
	'disable-lazy-load' => '',
	'css_body_background' => '#ffffff',
	'css_body_background_picture' => '',
	'css_body_background_repeat' => 'no-repeat',
	'css_body_background_attachment' => 'fixed',
	'css_body_background_position' => 'center bottom',
	'show-feedback' => '1',
	'content-background' => '#ffffff',
	'linkedin-link' => '',
	'default-header-slider' => 'layerslider-1',
	'css_header_background' => 'transparent',
	'css_header_background_opacity' => '0.15',
	'css_header_background_picture' => '',
	'css_header_background_repeat' => 'repeat',
	'css_header_background_position' => 'left top',
	'css_slider_background' => 'transparent',
	'css_slider_background_picture' => '',
	'css_slider_background_repeat' => 'no-repeat',
	'css_slider_background_position' => 'center center',
	'css_main_content_background' => '#ffffff',
	'css_main_content_opacity' => '0.95',
	'css_main_content_background_picture' => '',
	'css_main_content_background_repeat' => 'no-repeat',
	'css_main_content_background_position' => 'center center',
	'css_footer_background' => '#050505',
	'css_footer_opacity' => '0.9',
	'css_footer_background_picture' => '',
	'css_footer_background_repeat' => 'repeat-x',
	'css_footer_background_attachment' => 'fixed',
	'css_footer_background_position' => 'center center',
	'css_credits_background' => 'transparent',
	'css_credits_background_picture' => '',
	'css_credits_background_repeat' => 'no-repeat',
	'css_credits_background_position' => 'center top',
	'css_footer_color' => '#bfbfbf',
	'css_footer_sidebars_title_color' => '#bdbdbd',
	'css_footer_font_size' => '11',
	'enable-feedback-sidebar' => '1',
	'css_content_background' => '#ffffff',
	'css_content_opacity' => '0.5',
	'css_content_background_picture' => '',
	'css_content_background_repeat' => 'no-repeat',
	'css_content_background_position' => 'left center',
	'hide-post-author' => '1',
	'show_linkedin' => '1',
	'header-background-image' => '',
	'slider-background-image' => 'http://makalu.demo.ltf8.com/wp-content/uploads/2012/11/slider-bg.png',
	'title-background-image' => '',
	'title-background-color' => 'transparent',
	'title-background-position' => 'center top',
	'title-background-attachment' => 'fixed',
	'title-background-repeat' => 'no-repeat',
	'events-listing-title-background-image' => '',
	'events-listing-title-background-color' => '#4f4f4f',
	'events-listing-title-background-position' => 'center top',
	'events-listing-title-background-attachment' => 'fixed',
	'events-listing-title-background-repeat' => 'no-repeat',
	'events-listing-title-background-size' => 'auto',
	'mobile-top-bar-resolution' => '959',
	'main-background-image' => '',
	'main-background-color' => '#ffffff',
	'footer-background-image' => 'https://construction.vamtam.com//wp-content/uploads/2014/12/footer-bg.jpg',
	'subfooter-background-image' => '',
	'content-background-attachment' => 'fixed',
	'pagination-type' => 'load-more',
	'accent-color' => '#4E89A5',
	'accent-color-7' => '#EDEDED',
	'accent-color-8' => '#ffffff',
	'accent-override-1' => '#17f700',
	'accent-override-2' => '#00938b',
	'accent-override-3' => '#05008f',
	'accent-override-4' => '#690070',
	'accent-override-5' => '#832500',
	'accent-override-6' => '',
	'accent-override-7' => '',
	'accent-override-8' => '',
	'additional-font-1-color' => '#898989',
	'additional-font-1-face' => 'Lato',
	'additional-font-1-lheight' => '36',
	'additional-font-1-size' => '30',
	'additional-font-1-weight' => 'bold',
	'additional-font-2-color' => '#F8E71C',
	'additional-font-2-face' => 'Raleway',
	'additional-font-2-lheight' => '48',
	'additional-font-2-size' => '46',
	'additional-font-2-weight' => '600',
	'body-background' => 'cover',
	'body-background-opacity' => '0',
	'body-background-size' => 'auto',
	'body-helper-classic' => '',
	'content-background-color' => '#ff0000',
	'content-background-image' => '',
	'content-background-opacity-attachment' => 'scroll',
	'content-background-opacity-color' => '',
	'content-background-opacity-image' => '',
	'content-background-opacity-position' => 'left center',
	'content-background-opacity-repeat' => 'no-repeat',
	'content-background-position' => 'center bottom',
	'content-background-repeat' => 'repeat',
	'crop-featured-image' => '1',
	'css-cache-timestamp' => '1672867661',
	'css_accordion_background_bottom' => 'transparent',
	'css_accordion_background_top' => '#78ff64',
	'css_accordion_border_color' => 'transparent',
	'css_accordion_color' => '#898989',
	'css_accordion_pane_opacity' => '1',
	'css_button_radius' => '0',
	'css_footer_link_border_color' => '#e7e7e7',
	'css_footer_link_hover_border_color' => '#f2612c',
	'css_header_link_border_color' => '#999999',
	'css_header_link_hover_border_color' => '#00c758',
	'css_input_text_background' => '#fcfcfc',
	'css_input_text_color' => '#999999',
	'css_input_text_focus_background' => '#fafafa',
	'css_input_text_focus_color' => '#444444',
	'css_link_border_color' => '#FF6F18',
	'css_link_hover_border_color' => '#FF6F18',
	'css_link_underline' => '',
	'css_tab_active_background_bottom' => '#f8f8f8',
	'css_tab_active_background_top' => '#d5d5d5',
	'css_tab_active_color' => '#ececec',
	'css_tab_background' => '#ececec',
	'css_tab_border_color' => 'transparent',
	'css_tab_color' => '#777777',
	'css_toggle_content_background' => '#5bff04',
	'css_toggle_content_color' => '#9d9d9d',
	'css_toggle_title_background' => '#24ff32',
	'css_toggle_title_color' => '#3f4955',
	'custom-header-logo2x' => 'https://construction.vamtam.com/wp-content/uploads/2014/01/Logo@2x.png',
	'enable-breadcrumbs' => 'false',
	'enable-fmap' => 'true',
	'enable_box_layout' => '1',
	'envato-api-key' => '',
	'envato-license-key' => '',
	'envato-username' => '',
	'external-fonts' => 'a:1:{s:6:"gfonts";s:101:"https://fonts.googleapis.com/css?family=Raleway:bold,800,normal,300,600,italic|Lato:bold&subset=latin";}',
	'fmap-address' => 'London',
	'fmap-background-attachment' => 'scroll',
	'fmap-background-color' => '',
	'fmap-background-image' => 'http://david-goliath.demo.ltf8.com/wp-content/uploads/2013/07/map_bottom.jpg',
	'fmap-background-opacity' => '',
	'fmap-background-position' => 'left center',
	'fmap-background-repeat' => 'no-repeat',
	'fmap-background-size' => 'auto',
	'fmap-color' => 'accent1',
	'fmap-controls' => '',
	'fmap-html' => 'London, UK 10, <br/> Firs Avenue, Muswell Hill,<br/>  London, <br/> N10 3LY Tel: 02 562-958',
	'fmap-invert-lightness' => 'true',
	'fmap-invert_lightness' => '',
	'fmap-latitude' => '',
	'fmap-longitude' => '',
	'fmap-maptype' => 'ROADMAP',
	'fmap-scrollwheel' => 'false',
	'footer-background-size' => 'auto',
	'footer-divider-image' => '',
	'footer-helper-classic' => '',
	'footer-phone' => '',
	'footer-phone-color' => 'accent8',
	'footer-phone-olor' => 'accent1',
	'footer-sidebars-1-empty' => 'false',
	'footer-sidebars-2-empty' => 'false',
	'footer-sidebars-3-empty' => 'false',
	'footer-sidebars-4-empty' => 'false',
	'footer-sidebars-5-empty' => 'false',
	'footer-sidebars-6-empty' => 'false',
	'force-menu-background' => '',
	'full-width-slider' => '1',
	'header-background-size' => 'auto',
	'header-helper-classic' => '',
	'header-sidebars-1-empty' => 'false',
	'header-sidebars-2-empty' => 'false',
	'header-sidebars-3-empty' => 'false',
	'header-sidebars-4-empty' => 'false',
	'header-sidebars-5-empty' => 'false',
	'header-sidebars-6-empty' => 'false',
	'header-slider-button-thumbnails' => '',
	'header-slider-captionqueue' => '1',
	'header-slider-function-height' => '-1',
	'helper-color' => '#dcf9ff',
	'helper-color-2' => '#ff98f3',
	'helper-color-3' => '#ffc238',
	'htmlslide-thumbnail' => 'http://makalu.vamtam.com/wp-content/uploads/2012/07/logo.png',
	'is-responsive' => 'true',
	'left_sidebar_width' => '150',
	'main-background-size' => 'auto',
	'menu-widget-active-background-color' => '#e9e9e9',
	'menu-widget-background-color' => '#f7f7f7',
	'menu-widget-color' => '#cfcfcf',
	'page-header-height' => '125',
	'portfolio-all-items' => 'https://construction.vamtam.com/portfolio-layouts/masonry-style/',
	'portfolio-crop-featured-image' => '1',
	'portfolio-fullimage-height' => '500',
	'portfolio-slider-resizing' => 'none',
	'post-all-items' => 'https://construction.vamtam.com/blog/blog-layout-1/',
	'right_sidebar_width' => '299',
	'secondary-background-attachment' => '',
	'secondary-background-color' => '',
	'secondary-background-image' => '',
	'secondary-background-position' => '',
	'secondary-background-repeat' => '',
	'share-lightbox-googleplus' => '',
	'share-lightbox-pinterest' => '',
	'share-page-googleplus' => '',
	'share-page-pinterest' => '',
	'share-portfolio-googleplus' => 'true',
	'share-portfolio-pinterest' => 'true',
	'share-post-googleplus' => 'true',
	'share-post-pinterest' => 'true',
	'show-left-column' => '1',
	'show-related-portfolios' => 'true',
	'slider-background-opacity' => '0',
	'slider-background-size' => 'auto',
	'slider-helper-classic' => '',
	'slider-title' => 'LATEST DEALS',
	'sub-header' => '',
	'subfooter-background' => 'auto',
	'subfooter-background-opacity' => '0',
	'subfooter-background-size' => 'auto',
	'theme_installed_version' => '23',
	'title-background' => 'cover',
	'title-background-opacity' => '0',
	'title-background-size' => 'cover',
	'use-load-more' => '1',
	'header-slider-nomobile' => 'true',
	'additional-font-3-color' => '#a9b9d6',
	'additional-font-3-face' => 'Arial',
	'additional-font-3-lheight' => '10',
	'additional-font-3-size' => '10',
	'additional-font-3-weight' => '300',
	'lawyers-attorneys_vamtam_theme_activated' => '1',
	'fmap-text-close' => 'Close',
	'fmap-text-open' => '[icon name=theme-map color=accent1 size=15] Мap',
	'layerslider_activated' => '1',
	'main-menu-hover-background' => 'transparent',
	'main-menu-sticky-color' => '#ffffff',
	'middle-header-content' => '',
	'page-images-crop' => 'false',
	'portfolio-loop-images-crop' => 'true',
	'post-loop-images-crop' => 'true',
	'post-small-images-crop' => 'true',
	'share-lightbox-gplus' => '',
	'share-page-gplus' => '',
	'share-portfolio-gplus' => '',
	'share-post-gplus' => '',
	'share-product-facebook' => '',
	'share-product-googleplus' => '',
	'share-product-gplus' => '',
	'share-product-pinterest' => '',
	'share-product-twitter' => '',
	'show-post-author' => 'false',
	'show-related-posts' => 'true',
	'single-portfolio-images-crop' => 'false',
	'single-post-images-crop' => 'false',
	'site-max-width' => '1140',
	'sticky-header' => 'true',
	'sub-header-background-color' => '#ffffff',
	'sub-header-background-image' => '',
	'sub-header-background-repeat' => 'repeat-x',
	'sub-header-background-size' => 'auto',
	'portfolio-slug' => 'projects',
	'google-fonts-subsets' => 'latin',
	'auto-repair_vamtam_theme_activated' => '1',
	'construction_vamtam_theme_activated' => '1',
	'css_tophead_link_color' => '#EA5178',
	'css_tophead_link_hover_color' => '#898989',
	'css-tophead-text-color' => '#CCD0D0',
	'custom-font-families' => '',
	'custom-header-logo-transparent' => 'https://construction.vamtam.com/wp-content/uploads/2015/04/logo-trans.png',
	'david-goliath_vamtam_theme_activated' => '1',
	'do-biz_vamtam_theme_activated' => '1',
	'envato-license-key-old' => '',
	'events-after-details-content' => '',
	'events-after-sidebars-2-background-opacity' => '0',
	'events-after-sidebars-2-content' => '[text_divider type="double"]


Upcoming Events


[/text_divider]

[wpv_tribe_events layout="multiple" style="dark" count="4" columns="4" ongoing="" cat=""] [/wpv_tribe_events] 
[push h="40"]',
	'fitness-wellness_vamtam_theme_activated' => '1',
	'footer-sidebars-7-empty' => 'false',
	'footer-sidebars-8-empty' => 'false',
	'header-logo-type' => 'image',
	'header-name-left-bottom' => 'Smith',
	'header-name-left-top' => 'MICHAEL',
	'header-name-right-bottom' => 'Bellucci ',
	'header-name-right-top' => 'ASHLEY',
	'header-sidebars-7-empty' => 'false',
	'header-sidebars-8-empty' => 'false',
	'header-text-right' => '[icon name=\"theme-call-end\" style=\"\" color=\"accent4\" size=\"32\" ]
<p>CALL US NOW: <br/>
<a href=\"/contact-us/\"><strong>715.387.5006</strong></a></p>
',
	'health-center_vamtam_theme_activated' => '1',
	'honeymoon_vamtam_theme_activated' => '1',
	'last-theme-version' => '1',
	'main-menu-layout' => 'standard',
	'mobile-search-in-header' => 'true',
	'mobile-top-bar' => '',
	'page-title-background-attachment' => 'scroll',
	'page-title-background-color' => '#ffffff',
	'page-title-background-image' => '',
	'page-title-background-repeat' => 'no-repeat',
	'page-title-background-size' => 'auto',
	'phone-num-top' => 'test ',
	'previous-portfolio-slug' => 'projects',
	'sermons_category_children' => 'a:0:{}',
	'share-tribe-facebook' => 'true',
	'share-tribe-googleplus' => 'true',
	'share-tribe-pinterest' => 'true',
	'share-tribe-twitter' => 'true',
	'subfooter-center' => '&nbsp;&nbsp;',
	'subfooter-left' => '© 2023  <a href=\"/\">Construction Renovation Theme</a> by <a href=\"https://vamtam.com/\" target=\"_blank\">VamTam Themes</a>',
	'subfooter-right' => 'Proudly powered by <a href=\"https://wordpress.org/\" target=\"_blank\">WordPress</a>',
	'system-status-opt-out' => 'false',
	'theme-loop-images-wth' => '1.3',
	'theme-single-images-wth' => '1.3',
	'theme-update-notice-dismissed' => '1',
	'top-bar-social' => '[{\"icon-name\":\"theme-facebook\",\"icon-text\":\"facebook\",\"icon-link\":\"#\"},{\"icon-name\":\"twitter\",\"icon-text\":\"twitter\",\"icon-link\":\"\"},{\"icon-name\":\"linkedin\",\"icon-text\":\"\",\"icon-link\":\"\"},{\"icon-name\":\"googleplus\",\"icon-text\":\"\",\"icon-link\":\"\"},{\"icon-name\":\"flickr\",\"icon-text\":\"\",\"icon-link\":\"\"},{\"icon-name\":\"pinterest1\",\"icon-text\":\"\",\"icon-link\":\"\"},{\"icon-name\":\"dribbble1\",\"icon-text\":\"\",\"icon-link\":\"\"}]',
	'top-bar-social-dribbble' => '',
	'top-bar-social-fb' => '#',
	'top-bar-social-flickr' => '',
	'top-bar-social-gplus' => '',
	'top-bar-social-instagram' => '',
	'top-bar-social-lead' => 'Stay connected:',
	'top-bar-social-linkedin' => '#',
	'top-bar-social-pinterest' => '',
	'top-bar-social-twitter' => '#',
	'top-bar-social-vimeo' => '',
	'top-bar-social-youtube' => '',
	'top-bar-text' => 'Mon – Sat:  7.00 – 18.00  ·  Sunday:  Closed  ·  Emergency:  24hr / 7days',
	'top-nav-background-image' => '',
	'top-nav-background-size' => 'auto',
	'custom-js' => '',
);
