#wpv-config /* custom.css */
#wpv-config .info { background:#fafcfc; }
#wpv-config .borderTop { border-top: 1px solid #eee;}
#wpv-config .append-0 {padding-right:20px;}
#wpv-config 
#wpv-config /* typography.css */
#wpv-config h1, #wpv-config h2, #wpv-config h3, #wpv-config h4, #wpv-config h5, #wpv-config h6 {font-weight:normal;color:#111;}
#wpv-config h1 {font-size:2.6em;line-height:1;margin-bottom:0.5em;}
#wpv-config h2 {font-size:1.9em;margin-bottom:0.75em;}
#wpv-config h3 {font-size:1.4em;line-height:1;margin-bottom:1em;}
#wpv-config h4 {font-size:1.1em;line-height:1.25;margin-bottom:1.25em;}
#wpv-config h5 {font-size:1em;font-weight:bold;margin-bottom:1.5em;}
#wpv-config h6 {font-size:1em;font-weight:bold;}
#wpv-config h1 img, #wpv-config h2 img, #wpv-config h3 img, #wpv-config h4 img, #wpv-config h5 img, #wpv-config h6 img {margin:0;}
#wpv-config p {margin:0 0 1.5em;line-height:1.65em;}
#wpv-config p img.left {float:left;margin:1.5em 1.5em 1.5em 0;padding:0;}
#wpv-config p img.right {float:right;margin:1.5em 0 1.5em 1.5em;}
#wpv-config a:focus, #wpv-config a:hover {color:#000;}
#wpv-config a {color:#009;text-decoration:underline;}
#wpv-config blockquote {margin:1.5em;color:#666;font-style:italic;}
#wpv-config strong {font-weight:bold;}
#wpv-config em, #wpv-config dfn {font-style:italic;}
#wpv-config dfn {font-weight:bold;}
#wpv-config sup, #wpv-config sub {line-height:0;}
#wpv-config abbr, #wpv-config acronym {border-bottom:1px dotted #666;}
#wpv-config address {margin:0 0 1.5em;font-style:italic;}
#wpv-config del {color:#666;}
#wpv-config pre {margin:1.5em 0;white-space:pre;}
#wpv-config pre, #wpv-config code, #wpv-config tt {font:13px 'andale mono', #wpv-config 'lucida console', #wpv-config monospace;line-height:1.5;}
#wpv-config li ul, #wpv-config li ol {margin:0 1.5em;}
#wpv-config ul, #wpv-config ol {margin:0 1.5em 1.5em 3.5em;}
#wpv-config ul {list-style-type:disc;}
#wpv-config ol {list-style-type:decimal;}
#wpv-config ol.alpha {list-style:upper-alpha;}
#wpv-config dl {margin:0 0 1.5em 0;}
#wpv-config dl dt {font-weight:bold;}
#wpv-config dd {margin-left:1.5em;}
#wpv-config table {margin-bottom:1.4em;width:100%;}
#wpv-config th {font-weight:bold;}
#wpv-config thead th {background:#c3d9ff;}
#wpv-config th, #wpv-config td, #wpv-config caption {padding:4px 10px 4px 5px;}
#wpv-config tr.even td {background:#e5ecf9;}
#wpv-config tfoot {font-style:italic;}
#wpv-config caption {background:#eee;}
#wpv-config .small {font-size:.85em;margin-bottom:1.875em;line-height:1.875em;}
#wpv-config .large {font-size:1.2em;line-height:2.5em;margin-bottom:1.25em;}
#wpv-config .hide {display:none;}
#wpv-config .quiet {color:#666;}
#wpv-config .loud {color:#000;}
#wpv-config .highlight {background:#ff0;}
#wpv-config .added {background:#060;color:#fff;}
#wpv-config .removed {background:#900;color:#fff;}
#wpv-config .first {margin-left:0;padding-left:0;}
#wpv-config .last {margin-right:0;padding-right:0;}
#wpv-config .top {margin-top:0;padding-top:0;}
#wpv-config .bottom {margin-bottom:0;padding-bottom:0;}
#wpv-config .center {text-align:center;}
#wpv-config 
#wpv-config /* grid.css */
#wpv-config .container {width:790px;margin:0 auto;}
#wpv-config .showgrid {background:url(src/grid.png);}
#wpv-config .column, #wpv-config div.span-1, #wpv-config div.span-2, #wpv-config div.span-3, #wpv-config div.span-4, #wpv-config div.span-5, #wpv-config div.span-6, #wpv-config div.span-7, #wpv-config div.span-8, #wpv-config div.span-9, #wpv-config div.span-10, #wpv-config div.span-11, #wpv-config div.span-12, #wpv-config div.span-13, #wpv-config div.span-14, #wpv-config div.span-15, #wpv-config div.span-16, #wpv-config div.span-17, #wpv-config div.span-18, #wpv-config div.span-19, #wpv-config div.span-20, #wpv-config div.span-21, #wpv-config div.span-22, #wpv-config div.span-23, #wpv-config div.span-24 {float:left;margin-right:10px;}
#wpv-config .last, #wpv-config div.last {margin-right:0;}
#wpv-config .span-1 {width:30px;}
#wpv-config .span-2 {width:70px;}
#wpv-config .span-3 {width:110px;}
#wpv-config .span-4 {width:150px;}
#wpv-config .span-5 {width:190px;}
#wpv-config .span-6 {width:230px;}
#wpv-config .span-7 {width:270px;}
#wpv-config .span-8 {width:310px;}
#wpv-config .span-9 {width:350px;}
#wpv-config .span-10 {width:390px;}
#wpv-config .span-11 {width:430px;}
#wpv-config .span-12 {width:470px;}
#wpv-config .span-13 {width:510px;}
#wpv-config .span-14 {width:550px;}
#wpv-config .span-15 {width:590px;}
#wpv-config .span-16 {width:630px;}
#wpv-config .span-17 {width:670px;}
#wpv-config .span-18 {width:710px;}
#wpv-config .span-19 {width:750px;}
#wpv-config .span-20 {width:790px;}
#wpv-config .span-21 {width:830px;}
#wpv-config .span-22 {width:870px;}
#wpv-config .span-23 {width:910px;}
#wpv-config .span-24, #wpv-config div.span-24 {width:950px;margin:0;}
#wpv-config 
#wpv-config input.span-1, #wpv-config textarea.span-1, #wpv-config input.span-2, #wpv-config textarea.span-2, #wpv-config input.span-3, #wpv-config textarea.span-3, #wpv-config input.span-4, #wpv-config textarea.span-4, #wpv-config input.span-5, #wpv-config textarea.span-5, #wpv-config input.span-6, #wpv-config textarea.span-6, #wpv-config input.span-7, #wpv-config textarea.span-7, #wpv-config input.span-8, #wpv-config textarea.span-8, #wpv-config input.span-9, #wpv-config textarea.span-9, #wpv-config input.span-10, #wpv-config textarea.span-10, #wpv-config input.span-11, #wpv-config textarea.span-11, #wpv-config input.span-12, #wpv-config textarea.span-12, #wpv-config input.span-13, #wpv-config textarea.span-13, #wpv-config input.span-14, #wpv-config textarea.span-14, #wpv-config input.span-15, #wpv-config textarea.span-15, #wpv-config input.span-16, #wpv-config textarea.span-16, #wpv-config input.span-17, #wpv-config textarea.span-17, #wpv-config input.span-18, #wpv-config textarea.span-18, #wpv-config input.span-19, #wpv-config textarea.span-19, #wpv-config input.span-20, #wpv-config textarea.span-20, #wpv-config input.span-21, #wpv-config textarea.span-21, #wpv-config input.span-22, #wpv-config textarea.span-22, #wpv-config input.span-23, #wpv-config textarea.span-23, #wpv-config input.span-24, #wpv-config textarea.span-24 {border-left-width:1px!important;border-right-width:1px!important;padding-left:5px!important;padding-right:5px!important;}
#wpv-config input.span-1, #wpv-config textarea.span-1 {width:18px!important;}
#wpv-config input.span-2, #wpv-config textarea.span-2 {width:58px!important;}
#wpv-config input.span-3, #wpv-config textarea.span-3 {width:98px!important;}
#wpv-config input.span-4, #wpv-config textarea.span-4 {width:138px!important;}
#wpv-config input.span-5, #wpv-config textarea.span-5 {width:178px!important;}
#wpv-config input.span-6, #wpv-config textarea.span-6 {width:218px!important;}
#wpv-config input.span-7, #wpv-config textarea.span-7 {width:258px!important;}
#wpv-config input.span-8, #wpv-config textarea.span-8 {width:298px!important;}
#wpv-config input.span-9, #wpv-config textarea.span-9 {width:338px!important;}
#wpv-config input.span-10, #wpv-config textarea.span-10 {width:378px!important;}
#wpv-config input.span-11, #wpv-config textarea.span-11 {width:418px!important;}
#wpv-config input.span-12, #wpv-config textarea.span-12 {width:458px!important;}
#wpv-config input.span-13, #wpv-config textarea.span-13 {width:498px!important;}
#wpv-config input.span-14, #wpv-config textarea.span-14 {width:538px!important;}
#wpv-config input.span-15, #wpv-config textarea.span-15 {width:578px!important;}
#wpv-config input.span-16, #wpv-config textarea.span-16 {width:618px!important;}
#wpv-config input.span-17, #wpv-config textarea.span-17 {width:658px!important;}
#wpv-config input.span-18, #wpv-config textarea.span-18 {width:698px!important;}
#wpv-config input.span-19, #wpv-config textarea.span-19 {width:738px!important;}
#wpv-config input.span-20, #wpv-config textarea.span-20 {width:778px!important;}
#wpv-config input.span-21, #wpv-config textarea.span-21 {width:818px!important;}
#wpv-config input.span-22, #wpv-config textarea.span-22 {width:858px!important;}
#wpv-config input.span-23, #wpv-config textarea.span-23 {width:898px!important;}
#wpv-config input.span-24, #wpv-config textarea.span-24 {width:938px!important;}
#wpv-config .append-1 {padding-right:40px;}
#wpv-config .append-2 {padding-right:80px;}
#wpv-config .append-3 {padding-right:120px;}
#wpv-config .append-4 {padding-right:160px;}
#wpv-config .append-5 {padding-right:200px;}
#wpv-config .append-6 {padding-right:240px;}
#wpv-config .append-7 {padding-right:280px;}
#wpv-config .append-8 {padding-right:320px;}
#wpv-config .append-9 {padding-right:360px;}
#wpv-config .append-10 {padding-right:400px;}
#wpv-config .append-11 {padding-right:440px;}
#wpv-config .append-12 {padding-right:480px;}
#wpv-config .append-13 {padding-right:520px;}
#wpv-config .append-14 {padding-right:560px;}
#wpv-config .append-15 {padding-right:600px;}
#wpv-config .append-16 {padding-right:640px;}
#wpv-config .append-17 {padding-right:680px;}
#wpv-config .append-18 {padding-right:720px;}
#wpv-config .append-19 {padding-right:760px;}
#wpv-config .append-20 {padding-right:800px;}
#wpv-config .append-21 {padding-right:840px;}
#wpv-config .append-22 {padding-right:880px;}
#wpv-config .append-23 {padding-right:920px;}
#wpv-config .prepend-1 {padding-left:40px;}
#wpv-config .prepend-2 {padding-left:80px;}
#wpv-config .prepend-3 {padding-left:120px;}
#wpv-config .prepend-4 {padding-left:160px;}
#wpv-config .prepend-5 {padding-left:200px;}
#wpv-config .prepend-6 {padding-left:240px;}
#wpv-config .prepend-7 {padding-left:280px;}
#wpv-config .prepend-8 {padding-left:320px;}
#wpv-config .prepend-9 {padding-left:360px;}
#wpv-config .prepend-10 {padding-left:400px;}
#wpv-config .prepend-11 {padding-left:440px;}
#wpv-config .prepend-12 {padding-left:480px;}
#wpv-config .prepend-13 {padding-left:520px;}
#wpv-config .prepend-14 {padding-left:560px;}
#wpv-config .prepend-15 {padding-left:600px;}
#wpv-config .prepend-16 {padding-left:640px;}
#wpv-config .prepend-17 {padding-left:680px;}
#wpv-config .prepend-18 {padding-left:720px;}
#wpv-config .prepend-19 {padding-left:760px;}
#wpv-config .prepend-20 {padding-left:800px;}
#wpv-config .prepend-21 {padding-left:840px;}
#wpv-config .prepend-22 {padding-left:880px;}
#wpv-config .prepend-23 {padding-left:920px;}
#wpv-config div.border {padding-right:4px;margin-right:5px;border-right:1px solid #eee;}
#wpv-config div.colborder {padding-right:24px;margin-right:25px;border-right:1px solid #eee;}
#wpv-config div.colborderTop {border-top:1px solid #eee;}
#wpv-config .pull-1 {margin-left:-40px;}
#wpv-config .pull-2 {margin-left:-80px;}
#wpv-config .pull-3 {margin-left:-120px;}
#wpv-config .pull-4 {margin-left:-160px;}
#wpv-config .pull-5 {margin-left:-200px;}
#wpv-config .pull-6 {margin-left:-240px;}
#wpv-config .pull-7 {margin-left:-280px;}
#wpv-config .pull-8 {margin-left:-320px;}
#wpv-config .pull-9 {margin-left:-360px;}
#wpv-config .pull-10 {margin-left:-400px;}
#wpv-config .pull-11 {margin-left:-440px;}
#wpv-config .pull-12 {margin-left:-480px;}
#wpv-config .pull-13 {margin-left:-520px;}
#wpv-config .pull-14 {margin-left:-560px;}
#wpv-config .pull-15 {margin-left:-600px;}
#wpv-config .pull-16 {margin-left:-640px;}
#wpv-config .pull-17 {margin-left:-680px;}
#wpv-config .pull-18 {margin-left:-720px;}
#wpv-config .pull-19 {margin-left:-760px;}
#wpv-config .pull-20 {margin-left:-800px;}
#wpv-config .pull-21 {margin-left:-840px;}
#wpv-config .pull-22 {margin-left:-880px;}
#wpv-config .pull-23 {margin-left:-920px;}
#wpv-config .pull-24 {margin-left:-960px;}
#wpv-config .pull-1, #wpv-config .pull-2, #wpv-config .pull-3, #wpv-config .pull-4, #wpv-config .pull-5, #wpv-config .pull-6, #wpv-config .pull-7, #wpv-config .pull-8, #wpv-config .pull-9, #wpv-config .pull-10, #wpv-config .pull-11, #wpv-config .pull-12, #wpv-config .pull-13, #wpv-config .pull-14, #wpv-config .pull-15, #wpv-config .pull-16, #wpv-config .pull-17, #wpv-config .pull-18, #wpv-config .pull-19, #wpv-config .pull-20, #wpv-config .pull-21, #wpv-config .pull-22, #wpv-config .pull-23, #wpv-config .pull-24 {float:left;position:relative;}
#wpv-config .push-1 {margin:0 -40px 1.5em 40px;}
#wpv-config .push-2 {margin:0 -80px 1.5em 80px;}
#wpv-config .push-3 {margin:0 -120px 1.5em 120px;}
#wpv-config .push-4 {margin:0 -160px 1.5em 160px;}
#wpv-config .push-5 {margin:0 -200px 1.5em 200px;}
#wpv-config .push-6 {margin:0 -240px 1.5em 240px;}
#wpv-config .push-7 {margin:0 -280px 1.5em 280px;}
#wpv-config .push-8 {margin:0 -320px 1.5em 320px;}
#wpv-config .push-9 {margin:0 -360px 1.5em 360px;}
#wpv-config .push-10 {margin:0 -400px 1.5em 400px;}
#wpv-config .push-11 {margin:0 -440px 1.5em 440px;}
#wpv-config .push-12 {margin:0 -480px 1.5em 480px;}
#wpv-config .push-13 {margin:0 -520px 1.5em 520px;}
#wpv-config .push-14 {margin:0 -560px 1.5em 560px;}
#wpv-config .push-15 {margin:0 -600px 1.5em 600px;}
#wpv-config .push-16 {margin:0 -640px 1.5em 640px;}
#wpv-config .push-17 {margin:0 -680px 1.5em 680px;}
#wpv-config .push-18 {margin:0 -720px 1.5em 720px;}
#wpv-config .push-19 {margin:0 -760px 1.5em 760px;}
#wpv-config .push-20 {margin:0 -800px 1.5em 800px;}
#wpv-config .push-21 {margin:0 -840px 1.5em 840px;}
#wpv-config .push-22 {margin:0 -880px 1.5em 880px;}
#wpv-config .push-23 {margin:0 -920px 1.5em 920px;}
#wpv-config .push-24 {margin:0 -960px 1.5em 960px;}
#wpv-config .push-1, #wpv-config .push-2, #wpv-config .push-3, #wpv-config .push-4, #wpv-config .push-5, #wpv-config .push-6, #wpv-config .push-7, #wpv-config .push-8, #wpv-config .push-9, #wpv-config .push-10, #wpv-config .push-11, #wpv-config .push-12, #wpv-config .push-13, #wpv-config .push-14, #wpv-config .push-15, #wpv-config .push-16, #wpv-config .push-17, #wpv-config .push-18, #wpv-config .push-19, #wpv-config .push-20, #wpv-config .push-21, #wpv-config .push-22, #wpv-config .push-23, #wpv-config .push-24 {float:right;position:relative;}
#wpv-config .prepend-top {margin-top:1.5em;}
#wpv-config .append-bottom {margin-bottom:1.5em;}
#wpv-config .box {padding:1.5em;margin-bottom:1.5em;background:#E5ECF9;}
#wpv-config hr {background:#ddd;color:#ddd;clear:both;float:none;width:100%;height:.1em;margin:0 0 1.45em;border:none;}
#wpv-config hr.space {background:#fff;color:#fff;}
#wpv-config .clearfix:after, #wpv-config .container:after {content:"\0020";display:block;height:0;clear:both;visibility:hidden;overflow:hidden;}
#wpv-config .clearfix, #wpv-config .container {display:block;}
#wpv-config .clear {clear:both;}