		/***********************************************
		 *        DO NOT EDIT all.css MANUALLY         *
		 *                                             *
		 *   this is an automatically generated file   *
		 ***********************************************/



@-webkit-keyframes breathe {
  from {
    opacity: 1;
  }
  to {
    opacity: .4;
  }
}
@keyframes breathe {
  from {
    opacity: 1;
  }
  to {
    opacity: .4;
  }
}
.wpv-splash-screen {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background: #ffffff;
  z-index: 99999;
}
.wpv-splash-screen .wpv-splash-screen-logo {
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  -webkit-animation: breathe 1s alternate infinite cubic-bezier(.5522847498,0,.44771525,1);
  animation: breathe 1s alternate infinite cubic-bezier(.5522847498,0,.44771525,1);
}
@font-face {
  font-family: 'icomoon';
  src: url(../vamtam/assets/fonts/icons/icons.eot);
  src: url(../vamtam/assets/fonts/icons/icons.eot?#iefix) format('embedded-opentype'), url(../vamtam/assets/fonts/icons/icons.ttf) format('truetype');
  font-weight: normal;
  font-style: normal;
}
@font-face {
  font-family: 'theme';
  src: url(../wpv_theme/assets/fonts/icons/theme-icons.eot);
  src: url(../wpv_theme/assets/fonts/icons/theme-icons.eot?#iefix) format('embedded-opentype'), url(../wpv_theme/assets/fonts/icons/theme-icons.ttf) format('truetype');
  font-weight: normal;
  font-style: normal;
}
.icon,
.icon-a:after,
.icon-b:before {
  font-family: 'icomoon' !important;
  font-weight: normal !important;
  font-style: normal !important;
  display: inline-block;
  min-width: 1em;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
.theme.icon,
.theme.icon-a:after,
.theme.icon-b:before {
  font-family: 'theme' !important;
}
.custom.icon,
.custom.icon-a:after,
.custom.icon-b:before {
  font-family: 'vamtam-custom-icons' !important;
}
.icon-b:before,
.icon-a:after {
  content: " " attr(data-icon) " ";
}
.icon-b.size-small:before,
.icon-a.size-small:after,
.icon.size-small {
  font-size: 16px;
}
.icon-b.size-medium:before,
.icon-a.size-medium:after,
.icon.size-medium {
  font-size: 24px;
}
.icon-b.size-large:before,
.icon-a.size-large:after,
.icon.size-large {
  font-size: 32px;
}
.icon-b.icon-a:before {
  content: " " attr(data-iconb) " ";
}
.icon-b.icon-a:after {
  content: " " attr(data-icona) " ";
}
.icon-b:before {
  padding-right: .5em;
}
.icon-a:before {
  padding-left: .5em;
}
html,
body,
div,
span,
object,
iframe,
h1,
h2,
h3,
h4,
h5,
h6,
p,
blockquote,
pre,
abbr,
address,
cite,
code,
del,
dfn,
em,
img,
ins,
kbd,
q,
samp,
small,
strong,
sub,
sup,
var,
b,
i,
dl,
dt,
dd,
ol,
ul,
li,
fieldset,
form,
label,
legend,
table,
caption,
tbody,
tfoot,
thead,
tr,
th,
td,
article,
aside,
canvas,
details,
figcaption,
figure,
footer,
header,
hgroup,
menu,
nav,
section,
summary,
time,
mark,
audio,
video {
  margin: 0;
  padding: 0;
  border: 0;
  font-size: 100%;
  font: inherit;
  vertical-align: baseline;
}
html,
body {
  overflow-x: hidden;
  -webkit-tap-highlight-color: rgba(0,0,0,0);
  -webkit-text-size-adjust: 100%;
  -webkit-overflow-scrolling: touch;
}
body {
  overflow: hidden;
}
article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
menu,
nav,
section {
  display: block;
}
blockquote,
q {
  quotes: none;
}
blockquote:after,
q:before,
q:after {
  content: "";
  content: none;
}
ins {
  color: #364352;
  text-decoration: none;
}
mark {
  background-color: #ff9;
  color: #000;
  font-style: italic;
  font-weight: bold;
}
del {
  text-decoration: line-through;
}
abbr[title],
dfn[title] {
  border-bottom: 1px dotted;
  cursor: help;
}
table {
  border-collapse: collapse;
  border-spacing: 0;
}
hr {
  display: block;
  height: 1px;
  border: 0;
  border-top: 1px solid #ccc;
  margin: 1em 0;
  padding: 0;
}
input,
select {
  vertical-align: middle;
}
body {
  font: 13px/1.231 sans-serif;
  *font-size: small;
}
select,
input,
textarea,
button {
  font: 99% sans-serif;
}
pre,
code,
kbd,
samp {
  font-family: monospace, sans-serif;
}
:disabled {
  cursor: not-allowed;
}
a:hover,
a:active {
  outline: none;
}
nav ul,
nav li {
  margin: 0;
  list-style: none;
  list-style-image: none;
}
small {
  font-size: 85%;
}
b,
strong,
th {
  font-weight: bold;
}
td {
  vertical-align: top;
}
sub,
sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
}
sup {
  top: -0.5em;
}
sub {
  bottom: -0.25em;
}
pre {
  white-space: pre;
  white-space: pre-wrap;
  word-wrap: break-word;
  padding: 15px;
}
textarea {
  overflow: auto;
}
input[type="radio"] {
  vertical-align: text-bottom;
}
input[type="checkbox"] {
  vertical-align: middle;
}
label,
input[type="button"],
input[type="submit"],
input[type="image"],
button {
  cursor: pointer;
}
button,
input,
select,
textarea {
  margin: 0;
  box-shadow: none;
  border-radius: 0;
}
button {
  padding: 0;
}
button,
input[type="button"],
input[type="submit"] {
  -webkit-appearance: none;
  background-image: none;
}
button {
  width: auto;
  overflow: visible;
}
select,
input,
textarea {
  color: #444;
}
.ir {
  display: block;
  text-indent: -999em;
  overflow: hidden;
  background-repeat: no-repeat;
  text-align: left;
  direction: ltr;
}
.hidden {
  display: none;
  visibility: hidden;
}
.screen-reader-text,
.visuallyhidden {
  border: 0;
  clip: rect(0 0 0 0);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px;
}
.visuallyhidden.focusable:active,
.visuallyhidden.focusable:focus {
  clip: auto;
  height: auto;
  margin: 0;
  overflow: visible;
  position: static;
  width: auto;
}
.invisible {
  visibility: hidden;
}
html.no-js .nojs-hide {
  display: none;
}
.disable-hover {
  pointer-events: none;
}
.clearboth {
  clear: both;
}
.row,
.clearfix {
  clear: both;
}
.row:before,
.row:after,
.clearfix:before,
.clearfix:after {
  content: " ";
  display: table;
}
.row:after,
.clearfix:after {
  clear: both;
}
.row .row {
  margin-left: -15px;
  margin-right: -15px;
}
.grid-1-1,
.grid-1-2,
.grid-1-3,
.grid-1-4,
.grid-1-5,
.grid-1-6,
.grid-2-3,
.grid-2-5,
.grid-3-4,
.grid-3-5,
.grid-4-5,
.grid-5-6 {
  position: relative;
  padding: 0;
  float: left;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  display: block;
  padding: 0 15px;
}
.grid-1-1 {
  width: 100%;
}
.grid-1-2 {
  width: 50%;
}
.grid-1-3 {
  width: 33.33333333%;
}
.grid-1-4 {
  width: 25%;
}
.grid-1-5 {
  width: 20%;
}
.grid-1-6 {
  width: 16.66666666%;
}
.grid-2-3 {
  width: 66.66666666%;
}
.grid-2-5 {
  width: 40%;
}
.grid-3-4 {
  width: 75%;
}
.grid-3-5 {
  width: 60%;
}
.grid-4-5 {
  width: 80%;
}
.grid-5-6 {
  width: 83.33333333%;
}
img.lazy,
.loading {
  background: url(../wpv_theme/assets/images/loader.gif) center center no-repeat;
  background-image: url(../wpv_theme/assets/images/loader.gif), url(../wpv_theme/assets/images/loader_bg.png);
  background-position: center center, center center;
  background-color: #ffffff;
}
img.loaded,
img.lazy.no-animation,
.loading.no-animation {
  background-image: none;
}
.wide .limit-wrapper,
.boxed .boxed-layout {
  width: 1140px;
  max-width: 1140px;
}
.boxed #header-slider-container .ls-container,
.boxed #header-slider-container .rev_slider_wrapper,
.boxed .limit-wrapper .ls-container,
.boxed .limit-wrapper .rev_slider_wrapper {
  max-width: 1140px;
}
.boxed #header-slider-container .rev_slider_wrapper {
  left: 0 !important;
}
.boxed #header-slider-container .rev_slider_wrapper .tp-leftarrow.default {
  left: 30px !important;
}
.boxed #header-slider-container .rev_slider_wrapper .tp-rightarrow.default {
  right: 30px !important;
}
body.full article .ls-container {
  max-width: 100%;
}
html.touch .fixed-header-box {
  -webkit-transform: translate3d(0,0,0);
}
.vamtam-cubeportfolio.cbp-slider-edge.vamtam-cube-narrow .cbp-nav {
  display: none;
}
.vamtam-cubeportfolio.cbp-slider-edge.vamtam-cube-narrow .cbp-wrapper {
  position: relative;
  margin: auto;
}
.vamtam-cubeportfolio.cbp-slider-edge .cbp-nav-next,
.vamtam-cubeportfolio.cbp-slider-edge .cbp-nav-prev {
  display: block;
  margin-top: -26px;
  border-radius: 0px;
  top: 50%;
  transition: all .3s;
  opacity: 0.8;
  text-align: center;
}
.vamtam-cubeportfolio.cbp-slider-edge .cbp-nav-next:hover,
.vamtam-cubeportfolio.cbp-slider-edge .cbp-nav-prev:hover {
  opacity: 1;
}
.vamtam-cubeportfolio.cbp-slider-edge .cbp-nav-next:after,
.vamtam-cubeportfolio.cbp-slider-edge .cbp-nav-prev:after {
  display: block;
  font: 25px/25px theme;
  width: 25px;
  height: 25px;
  line-height: 25px;
  padding: 10px;
  background: #364352;
  color: #EDEDED;
  box-sizing: content-box;
}
.vamtam-cubeportfolio.cbp-slider-edge .cbp-nav-prev {
  right: auto;
  left: 20px;
}
.vamtam-cubeportfolio.cbp-slider-edge .cbp-nav-prev:after {
  font-family: theme;
  content: "\e607";
}
.vamtam-cubeportfolio.cbp-slider-edge .cbp-nav-next {
  right: 20px;
}
.vamtam-cubeportfolio.cbp-slider-edge .cbp-nav-next:after {
  font-family: theme;
  content: "\e606";
}
.vamtam-cubeportfolio .cbp-slider-inline .cbp-slider-controls {
  right: 10px;
  top: 10px;
}
.vamtam-cubeportfolio .cbp-slider-inline .cbp-slider-prev,
.vamtam-cubeportfolio .cbp-slider-inline .cbp-slider-next {
  width: 32px;
  height: 32px;
  text-align: center;
  transition: all .3s;
  color: #ffffff;
  background: transparent;
}
.vamtam-cubeportfolio .cbp-slider-inline .cbp-slider-prev:after,
.vamtam-cubeportfolio .cbp-slider-inline .cbp-slider-next:after {
  font-size: 32px;
  line-height: 32px;
  width: 32px;
  height: 32px;
  font-style: normal;
  background: none;
  font-family: theme;
}
.vamtam-cubeportfolio .cbp-slider-inline .cbp-slider-prev:hover,
.vamtam-cubeportfolio .cbp-slider-inline .cbp-slider-next:hover {
  opacity: 1;
  color: #F0542D;
}
.vamtam-cubeportfolio .cbp-slider-inline .cbp-slider-prev:after {
  content: "\e607";
}
.vamtam-cubeportfolio .cbp-slider-inline .cbp-slider-next:after {
  content: "\e606";
}
.vamtam-cubeportfolio + .thumbnails .cbp-pagination-item {
  border: solid 1px #ffffff;
  transition: all .3s ease-out;
  margin-top: 0;
  margin-right: 0;
  display: block;
}
.vamtam-cubeportfolio + .thumbnails .cbp-pagination-item:after {
  background: rgba(255,255,255,0.5);
}
.vamtam-cubeportfolio + .thumbnails .cbp-pagination-active .cbp-pagination-item,
.vamtam-cubeportfolio + .thumbnails .cbp-pagination-item:hover {
  border-color: #F0542D;
}
.vamtam-cubeportfolio + .thumbnails .cbp-pagination-active .cbp-pagination-item:after,
.vamtam-cubeportfolio + .thumbnails .cbp-pagination-item:hover:after {
  background: transparent;
}
.cbp-popup-close:after {
  content: "\e0bb";
}
.cbp-popup-next:after {
  content: "\e606";
}
.cbp-popup-prev:after {
  content: "\e607";
}
body .cbp-popup-ready.cbp-popup-lightbox .cbp-popup-next,
body .cbp-popup-ready.cbp-popup-lightbox .cbp-popup-prev,
body .cbp-popup-ready.cbp-popup-lightbox .cbp-popup-close {
  text-align: center;
  background: none;
  width: 70px;
  height: 70px;
}
body .cbp-popup-ready.cbp-popup-lightbox .cbp-popup-next:after,
body .cbp-popup-ready.cbp-popup-lightbox .cbp-popup-prev:after,
body .cbp-popup-ready.cbp-popup-lightbox .cbp-popup-close:after {
  transition: all .3s ease;
  font-family: 'theme';
  font-size: 50px;
  vertical-align: middle;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  display: block;
  width: 50px;
  height: 50px;
  line-height: 50px;
  padding: 10px;
  border-radius: 1000%;
  border: none;
  color: #ffffff;
}
body .cbp-popup-ready.cbp-popup-lightbox .cbp-popup-next:hover:after,
body .cbp-popup-ready.cbp-popup-lightbox .cbp-popup-prev:hover:after,
body .cbp-popup-ready.cbp-popup-lightbox .cbp-popup-close:hover:after {
  color: #F0542D;
}
html,
body,
th,
td,
p {
  color: #767676;
}
.accent-1 {
  color: #F0542D;
}
.accent-2 {
  color: #364352;
}
.accent-3 {
  color: #7C8A8D;
}
.accent-4 {
  color: #D8D8D8;
}
.accent-5 {
  color: #ffffff;
}
.accent-6 {
  color: #2B2F34;
}
.accent-7 {
  color: #EDEDED;
}
.accent-8 {
  color: #ffffff;
}
.hover-accent-1:hover {
  color: #F0542D;
}
.hover-accent-2:hover {
  color: #364352;
}
.hover-accent-3:hover {
  color: #7C8A8D;
}
.hover-accent-4:hover {
  color: #D8D8D8;
}
.hover-accent-5:hover {
  color: #ffffff;
}
.hover-accent-6:hover {
  color: #2B2F34;
}
.hover-accent-7:hover {
  color: #EDEDED;
}
.hover-accent-8:hover {
  color: #ffffff;
}
*,
p,
.main-container {
  font: normal 14px/20px "Raleway";
}
.page-header .desc,
.page-header .desc a,
em {
  font: italic 14px/18px "Raleway";
  color: #898989;
}
h1,
h1 a,
h1 a:visited {
  color: #4A4F55;
}
h1,
h1 a {
  font: bold 36px/42px "Raleway";
}
footer.main-footer h1 a {
  font: bold 36px/42px "Raleway";
}
h1 em {
  font: italic 36px/42px "Raleway";
  color: #4A4F55;
}
h2,
h2 a,
h2 a:visited {
  color: #364352;
}
h2,
h2 a {
  font: 800 26px/30px "Raleway";
}
footer.main-footer h2 a {
  font: 800 26px/30px "Raleway";
}
h2 em {
  font: italic 26px/30px "Raleway";
  color: #364352;
}
h3,
h3 a,
h3 a:visited {
  color: #4A4F55;
}
h3,
h3 a {
  font: normal 24px/30px "Raleway";
}
footer.main-footer h3 a {
  font: normal 24px/30px "Raleway";
}
h3 em {
  font: italic 24px/30px "Raleway";
  color: #4A4F55;
}
h4,
h4 a,
h4 a:visited {
  color: #4A4F55;
}
h4,
h4 a {
  font: 300 20px/26px "Raleway";
}
footer.main-footer h4 a {
  font: 300 20px/26px "Raleway";
}
h4 em {
  font: italic 20px/26px "Raleway";
  color: #4A4F55;
}
h5,
h5 a,
h5 a:visited {
  color: #242323;
}
h5,
h5 a {
  font: 600 12px/14px "Raleway";
}
footer.main-footer h5 a {
  font: 600 12px/14px "Raleway";
}
h5 em {
  font: italic 12px/14px "Raleway";
  color: #242323;
}
h6,
h6 a,
h6 a:visited {
  color: #6A6A6A;
}
h6,
h6 a {
  font: bold 10px/11px "Arial";
}
footer.main-footer h6 a {
  font: bold 10px/11px "Arial";
}
h6 em {
  font: italic 10px/11px "Raleway";
  color: #6A6A6A;
}
small {
  color: #e2e2e2;
  font-size: 11px !important;
}
a {
  text-decoration: none;
  color: #F0542D;
  transition: color .3s;
}
a .icon.shortcode.use-hover {
  transition: all .3s ease;
}
a:hover {
  text-decoration: none;
  color: #5C6268;
}
a:hover .icon.shortcode.use-hover {
  color: #364352;
}
p {
  margin: 1em 0;
}
p:empty {
  display: none;
}
h1,
h2,
h3,
h4,
h5,
h6 {
  margin-top: 0.6em;
  margin-bottom: 0.6em;
}
.vamtam-font-style-1 {
  font: bold 30px/36px "Lato";
  padding-bottom: 10px;
}
.vamtam-font-style-1.with-color {
  color: #898989;
}
.vamtam-font-style-2 {
  font: 600 46px/48px "Raleway";
}
.vamtam-font-style-2.with-color {
  color: #F8E71C;
}
.socialcount {
  list-style: none;
  padding-left: 0;
  margin: 0 0 .6em 0;
  overflow: hidden;
}
.socialcount-large {
  line-height: normal;
}
.socialcount :link,
.socialcount :visited {
  color: inherit;
}
.socialcount > li {
  display: inline-block;
  *display: inline;
  zoom: 1;
  position: relative;
  vertical-align: top;
  min-width: 80px;
  min-height: 30px;
  text-align: center;
  white-space: nowrap;
  *margin-right: 4px;
}
.socialcount-small > li {
  min-width: 0;
}
.socialcount-large > li {
  float: left;
  margin: 0 .6em .6em 0;
  min-width: 105px;
}
.socialcount > li > a {
  display: block;
  padding: 0 5px;
  text-decoration: none;
  color: inherit;
}
.socialcount-small > li > a {
  padding-left: 8px;
  padding-right: 8px;
}
.socialcount-large > li > a {
  padding: 12px 5px 8px;
}
.socialcount .count {
  color: inherit;
  position: relative;
  display: inline-block;
  *display: inline;
  zoom: 1;
  text-align: center;
  margin-left: 6px;
}
.socialcount-large .count {
  display: block;
  width: 100%;
  margin-left: 0;
  padding-top: 10px;
}
.socialcount-small .count {
  margin-left: 0;
}
.socialcount .socialcount-button {
  display: none;
  width: 100%;
  position: absolute;
  left: 0;
  top: 5px;
  text-align: center;
  pointer-events: none;
  line-height: 100%;
}
.socialcount .socialcount-button iframe {
  pointer-events: auto;
}
.socialcount-large .socialcount-button {
  top: auto;
  bottom: 2px;
}
.socialcount.grade-a.activate-on-hover > li.hover.loaded .count,
.socialcount.grade-a.activate-on-click > li.hover.loaded .count {
  text-indent: -999px;
}
.socialcount.grade-a.activate-on-hover > li.hover.loaded .socialcount-button,
.socialcount.grade-a.activate-on-click > li.hover.loaded .socialcount-button {
  display: block;
}
.socialcount.grade-a.activate-on-hover > li.hover.loaded > a,
.socialcount.grade-a.activate-on-click > li.hover.loaded > a {
  cursor: default;
}
.socialcount-small.grade-a.activate-on-hover > li.hover.loaded > a,
.socialcount-small.grade-a.activate-on-click > li.hover.loaded > a,
.socialcount.grade-a.activate-on-hover > li.hover.loaded .socialcount-button iframe,
.socialcount.grade-a.activate-on-click > li.hover.loaded .socialcount-button iframe {
  cursor: pointer;
}
.socialcount.like.de_DE > .facebook {
  min-width: 90px;
}
.socialcount.recommend .facebook {
  min-width: 120px;
}
.socialcount-small.recommend .facebook {
  min-width: 0;
}
.socialcount-large.recommend .facebook {
  min-width: 105px;
}
.socialcount .facebook iframe {
  height: 21px;
  width: 90px;
}
.socialcount.de_DE .facebook iframe {
  width: 83px;
}
.socialcount.fr_FR .facebook iframe {
  width: 98px;
}
.socialcount.like .facebook iframe {
  width: 48px;
}
.socialcount.like.de_DE .facebook iframe {
  width: 83px;
}
.socialcount.like.fr_FR .facebook iframe {
  width: 57px;
}
.socialcount .pinterest {
  display: none;
}
.socialcount.js .pinterest {
  display: inline-block;
  *display: inline;
  zoom: 1;
}
.socialcount .pinterest .socialcount-button {
  bottom: 0;
  pointer-events: auto;
}
.socialcount-large .pinterest .socialcount-button {
  bottom: 10px;
}
.socialcount > .pinterest:hover {
  cursor: pointer;
}
.socialcount-small .pinterest .count {
  text-indent: -999px;
}
.socialcount .loading {
  position: absolute;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
  z-index: 3;
  background-color: #aaa;
  background-color: rgba(170,170,170,0.7);
  color: #000;
  text-transform: uppercase;
  font-size: .75em;
  text-align: center;
  border-radius: 5px;
}
.socialcount-large .loading {
  padding-top: 30%;
}
.socialcount .loading .dot {
  display: inline-block;
  width: 6px;
  height: 6px;
  margin: 0 3px;
  background: #fff;
  opacity: 0;
  border-radius: 50%;
  -webkit-animation: socialCountLoadingFade .6s infinite;
  -moz-animation: socialCountLoadingFade .6s infinite;
  animation: socialCountLoadingFade .6s infinite;
}
.socialcount .loading .dot:nth-child(1) {
  -webkit-animation-delay: 0s;
  -moz-animation-delay: 0s;
  animation-delay: 0s;
}
.socialcount .loading .dot:nth-child(2) {
  -webkit-animation-delay: .05s;
  -moz-animation-delay: .05s;
  animation-delay: .05s;
}
.socialcount .loading .dot:nth-child(3) {
  -webkit-animation-delay: .1s;
  -moz-animation-delay: .1s;
  animation-delay: .1s;
}
@-webkit-keyframes socialCountLoadingFade {
  0% {
    opacity: 0;
  }
  50% {
    opacity: 0.8;
  }
  100% {
    opacity: 0;
  }
}
@-moz-keyframes socialCountLoadingFade {
  0% {
    opacity: 0;
  }
  50% {
    opacity: 0.8;
  }
  100% {
    opacity: 0;
  }
}
@keyframes socialCountLoadingFade {
  0% {
    opacity: 0;
  }
  50% {
    opacity: 0.8;
  }
  100% {
    opacity: 0;
  }
}
.socialcount {
  margin-top: 30px;
  color: #2B2F34;
}
.socialcount > li {
  background-color: #EDEDED;
  min-height: 0;
}
.socialcount > li > a {
  line-height: 2.2em;
  transition: color .3s ease-out;
}
.socialcount > li > a:hover {
  color: #5C6268;
}
.socialcount > li,
.socialcount > li > a:focus,
.socialcount .sc-loading {
  border-radius: 1px;
}
@keyframes flash {
  0%,
  50%,
  100% {
    opacity: 1;
  }
  25%,
  75% {
    opacity: 0;
  }
}
@keyframes wiggle {
  0% {
    transform: skewX(9deg);
  }
  10% {
    transform: skewX(-8deg);
  }
  20% {
    transform: skewX(7deg);
  }
  30% {
    transform: skewX(-6deg);
  }
  40% {
    transform: skewX(5deg);
  }
  50% {
    transform: skewX(-4deg);
  }
  60% {
    transform: skewX(3deg);
  }
  70% {
    transform: skewX(-2deg);
  }
  80% {
    transform: skewX(1deg);
  }
  90% {
    transform: skewX(0deg);
  }
  100% {
    transform: skewX(0deg);
  }
}
.animated {
  -webkit-animation-fill-mode: both;
  animation-timing-fill-mode: both;
  -webkit-animation-duration: 1s;
  animation-duration: 1s;
  -webkit-animation-iteration-count: infinite;
  animation-iteration-count: infinite;
}
.animated.flash {
  -webkit-animation-name: flash;
  animation-name: flash;
}
.animated.wiggle {
  -webkit-animation-name: wiggle;
  animation-name: wiggle;
  -webkit-animation-timing-function: ease-in;
  animation-timing-function: ease-in;
}
.animated.dialog-message {
  animation-iteration-count: 1;
}
.submit-button-style {
  font-size: 1em;
  font-weight: normal;
  display: inline-block;
  text-align: center;
  cursor: pointer;
  position: relative;
  z-index: 0;
  vertical-align: middle;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
  text-decoration: none;
  text-shadow: none;
  line-height: 1.15em;
  border-widht: 2px;
  padding: 0;
  text-align: center !important;
  background: #F0542D;
  color: #ffffff;
  padding: 0.8em 1.6em;
}
.submit-button-style,
.submit-button-style span {
  transition: color .3s ease, border .3s ease, background .3s ease;
}
.submit-button-style span {
  display: inline-block;
  font-size: 1em;
  line-height: inherit;
  padding: .3em .4em;
  margin: 0 0;
  vertical-align: baseline;
}
.submit-button-style span.icon {
  font-size: 100%;
  vertical-align: bottom !important;
}
.submit-button-style span.icon.shortcode.inverted-colors {
  font-size: 100%;
  box-shadow: 0 1px 1px rgba(0,0,0,0.1) inset, 0 1px 1px rgba(255,255,255,0.2);
  text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}
.submit-button-style span.icon:first-child,
.submit-button-style span.icon:last-child {
  vertical-align: top;
  background: none;
}
.submit-button-style span.icon:first-child {
  padding: .5em 0 .5em .8em !important;
}
.submit-button-style span.icon:last-child {
  padding: .5em .8em .5em 0 !important;
}
.submit-button-style span.btext {
  position: relative;
  font-weight: 500;
  vertical-align: middle;
  padding: 0.7em 1.2em;
  letter-spacing: 1px;
}
.submit-button-style:hover,
.submit-button-style:hover span {
  text-decoration: none;
}
.submit-button-style span {
  color: #ffffff;
}
.submit-button-style:hover,
.submit-button-style:focus,
.submit-button-style:active {
  background: #7C8A8D;
}
.submit-button-style:hover,
.submit-button-style:hover span,
.submit-button-style:focus,
.submit-button-style:focus span,
.submit-button-style:active,
.submit-button-style:active span {
  color: #ffffff;
}
.button,
.vamtam-button,
input[type=button],
input[type=submit] {
  font-size: 1em;
  font-weight: normal;
  display: inline-block;
  text-align: center;
  cursor: pointer;
  position: relative;
  z-index: 0;
  vertical-align: middle;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
  text-decoration: none;
  text-shadow: none;
  line-height: 1.15em;
  border-widht: 2px;
  padding: 0;
  text-align: center !important;
  background: #F0542D;
  color: #ffffff;
  padding: 0.8em 1.6em;
}
.button,
.button span,
.vamtam-button,
.vamtam-button span,
input[type=button],
input[type=button] span,
input[type=submit],
input[type=submit] span {
  transition: color .3s ease, border .3s ease, background .3s ease;
}
.button span,
.vamtam-button span,
input[type=button] span,
input[type=submit] span {
  display: inline-block;
  font-size: 1em;
  line-height: inherit;
  padding: .3em .4em;
  margin: 0 0;
  vertical-align: baseline;
}
.button span.icon,
.vamtam-button span.icon,
input[type=button] span.icon,
input[type=submit] span.icon {
  font-size: 100%;
  vertical-align: bottom !important;
}
.button span.icon.shortcode.inverted-colors,
.vamtam-button span.icon.shortcode.inverted-colors,
input[type=button] span.icon.shortcode.inverted-colors,
input[type=submit] span.icon.shortcode.inverted-colors {
  font-size: 100%;
  box-shadow: 0 1px 1px rgba(0,0,0,0.1) inset, 0 1px 1px rgba(255,255,255,0.2);
  text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}
.button span.icon:first-child,
.button span.icon:last-child,
.vamtam-button span.icon:first-child,
.vamtam-button span.icon:last-child,
input[type=button] span.icon:first-child,
input[type=button] span.icon:last-child,
input[type=submit] span.icon:first-child,
input[type=submit] span.icon:last-child {
  vertical-align: top;
  background: none;
}
.button span.icon:first-child,
.vamtam-button span.icon:first-child,
input[type=button] span.icon:first-child,
input[type=submit] span.icon:first-child {
  padding: .5em 0 .5em .8em !important;
}
.button span.icon:last-child,
.vamtam-button span.icon:last-child,
input[type=button] span.icon:last-child,
input[type=submit] span.icon:last-child {
  padding: .5em .8em .5em 0 !important;
}
.button span.btext,
.vamtam-button span.btext,
input[type=button] span.btext,
input[type=submit] span.btext {
  position: relative;
  font-weight: 500;
  vertical-align: middle;
  padding: 0.7em 1.2em;
  letter-spacing: 1px;
}
.button:hover,
.button:hover span,
.vamtam-button:hover,
.vamtam-button:hover span,
input[type=button]:hover,
input[type=button]:hover span,
input[type=submit]:hover,
input[type=submit]:hover span {
  text-decoration: none;
}
.button span,
.vamtam-button span,
input[type=button] span,
input[type=submit] span {
  color: #ffffff;
}
.button:hover,
.button:focus,
.button:active,
.vamtam-button:hover,
.vamtam-button:focus,
.vamtam-button:active,
input[type=button]:hover,
input[type=button]:focus,
input[type=button]:active,
input[type=submit]:hover,
input[type=submit]:focus,
input[type=submit]:active {
  background: #7C8A8D;
}
.button:hover,
.button:hover span,
.button:focus,
.button:focus span,
.button:active,
.button:active span,
.vamtam-button:hover,
.vamtam-button:hover span,
.vamtam-button:focus,
.vamtam-button:focus span,
.vamtam-button:active,
.vamtam-button:active span,
input[type=button]:hover,
input[type=button]:hover span,
input[type=button]:focus,
input[type=button]:focus span,
input[type=button]:active,
input[type=button]:active span,
input[type=submit]:hover,
input[type=submit]:hover span,
input[type=submit]:focus,
input[type=submit]:focus span,
input[type=submit]:active,
input[type=submit]:active span {
  color: #ffffff;
}
.button,
.button.accent1,
.button.accent2,
.button.accent3,
.button.accent4,
.button.accent5,
.button.accent6,
.button.accent7,
.button.accent8,
.vamtam-button,
.vamtam-button.accent1,
.vamtam-button.accent2,
.vamtam-button.accent3,
.vamtam-button.accent4,
.vamtam-button.accent5,
.vamtam-button.accent6,
.vamtam-button.accent7,
.vamtam-button.accent8 {
  font-size: 1em;
  font-weight: normal;
  display: inline-block;
  text-align: center;
  cursor: pointer;
  position: relative;
  z-index: 0;
  vertical-align: middle;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
  text-decoration: none;
  text-shadow: none;
  line-height: 1.15em;
  border-widht: 2px;
  padding: 0;
  text-align: center !important;
}
.button,
.button span,
.button.accent1,
.button.accent1 span,
.button.accent2,
.button.accent2 span,
.button.accent3,
.button.accent3 span,
.button.accent4,
.button.accent4 span,
.button.accent5,
.button.accent5 span,
.button.accent6,
.button.accent6 span,
.button.accent7,
.button.accent7 span,
.button.accent8,
.button.accent8 span,
.vamtam-button,
.vamtam-button span,
.vamtam-button.accent1,
.vamtam-button.accent1 span,
.vamtam-button.accent2,
.vamtam-button.accent2 span,
.vamtam-button.accent3,
.vamtam-button.accent3 span,
.vamtam-button.accent4,
.vamtam-button.accent4 span,
.vamtam-button.accent5,
.vamtam-button.accent5 span,
.vamtam-button.accent6,
.vamtam-button.accent6 span,
.vamtam-button.accent7,
.vamtam-button.accent7 span,
.vamtam-button.accent8,
.vamtam-button.accent8 span {
  transition: color .3s ease, border .3s ease, background .3s ease;
}
.button span,
.button.accent1 span,
.button.accent2 span,
.button.accent3 span,
.button.accent4 span,
.button.accent5 span,
.button.accent6 span,
.button.accent7 span,
.button.accent8 span,
.vamtam-button span,
.vamtam-button.accent1 span,
.vamtam-button.accent2 span,
.vamtam-button.accent3 span,
.vamtam-button.accent4 span,
.vamtam-button.accent5 span,
.vamtam-button.accent6 span,
.vamtam-button.accent7 span,
.vamtam-button.accent8 span {
  display: inline-block;
  font-size: 1em;
  line-height: inherit;
  padding: .3em .4em;
  margin: 0 0;
  vertical-align: baseline;
}
.button span.icon,
.button.accent1 span.icon,
.button.accent2 span.icon,
.button.accent3 span.icon,
.button.accent4 span.icon,
.button.accent5 span.icon,
.button.accent6 span.icon,
.button.accent7 span.icon,
.button.accent8 span.icon,
.vamtam-button span.icon,
.vamtam-button.accent1 span.icon,
.vamtam-button.accent2 span.icon,
.vamtam-button.accent3 span.icon,
.vamtam-button.accent4 span.icon,
.vamtam-button.accent5 span.icon,
.vamtam-button.accent6 span.icon,
.vamtam-button.accent7 span.icon,
.vamtam-button.accent8 span.icon {
  font-size: 100%;
  vertical-align: bottom !important;
}
.button span.icon.shortcode.inverted-colors,
.button.accent1 span.icon.shortcode.inverted-colors,
.button.accent2 span.icon.shortcode.inverted-colors,
.button.accent3 span.icon.shortcode.inverted-colors,
.button.accent4 span.icon.shortcode.inverted-colors,
.button.accent5 span.icon.shortcode.inverted-colors,
.button.accent6 span.icon.shortcode.inverted-colors,
.button.accent7 span.icon.shortcode.inverted-colors,
.button.accent8 span.icon.shortcode.inverted-colors,
.vamtam-button span.icon.shortcode.inverted-colors,
.vamtam-button.accent1 span.icon.shortcode.inverted-colors,
.vamtam-button.accent2 span.icon.shortcode.inverted-colors,
.vamtam-button.accent3 span.icon.shortcode.inverted-colors,
.vamtam-button.accent4 span.icon.shortcode.inverted-colors,
.vamtam-button.accent5 span.icon.shortcode.inverted-colors,
.vamtam-button.accent6 span.icon.shortcode.inverted-colors,
.vamtam-button.accent7 span.icon.shortcode.inverted-colors,
.vamtam-button.accent8 span.icon.shortcode.inverted-colors {
  font-size: 100%;
  box-shadow: 0 1px 1px rgba(0,0,0,0.1) inset, 0 1px 1px rgba(255,255,255,0.2);
  text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}
.button span.icon:first-child,
.button span.icon:last-child,
.button.accent1 span.icon:first-child,
.button.accent1 span.icon:last-child,
.button.accent2 span.icon:first-child,
.button.accent2 span.icon:last-child,
.button.accent3 span.icon:first-child,
.button.accent3 span.icon:last-child,
.button.accent4 span.icon:first-child,
.button.accent4 span.icon:last-child,
.button.accent5 span.icon:first-child,
.button.accent5 span.icon:last-child,
.button.accent6 span.icon:first-child,
.button.accent6 span.icon:last-child,
.button.accent7 span.icon:first-child,
.button.accent7 span.icon:last-child,
.button.accent8 span.icon:first-child,
.button.accent8 span.icon:last-child,
.vamtam-button span.icon:first-child,
.vamtam-button span.icon:last-child,
.vamtam-button.accent1 span.icon:first-child,
.vamtam-button.accent1 span.icon:last-child,
.vamtam-button.accent2 span.icon:first-child,
.vamtam-button.accent2 span.icon:last-child,
.vamtam-button.accent3 span.icon:first-child,
.vamtam-button.accent3 span.icon:last-child,
.vamtam-button.accent4 span.icon:first-child,
.vamtam-button.accent4 span.icon:last-child,
.vamtam-button.accent5 span.icon:first-child,
.vamtam-button.accent5 span.icon:last-child,
.vamtam-button.accent6 span.icon:first-child,
.vamtam-button.accent6 span.icon:last-child,
.vamtam-button.accent7 span.icon:first-child,
.vamtam-button.accent7 span.icon:last-child,
.vamtam-button.accent8 span.icon:first-child,
.vamtam-button.accent8 span.icon:last-child {
  vertical-align: top;
  background: none;
}
.button span.icon:first-child,
.button.accent1 span.icon:first-child,
.button.accent2 span.icon:first-child,
.button.accent3 span.icon:first-child,
.button.accent4 span.icon:first-child,
.button.accent5 span.icon:first-child,
.button.accent6 span.icon:first-child,
.button.accent7 span.icon:first-child,
.button.accent8 span.icon:first-child,
.vamtam-button span.icon:first-child,
.vamtam-button.accent1 span.icon:first-child,
.vamtam-button.accent2 span.icon:first-child,
.vamtam-button.accent3 span.icon:first-child,
.vamtam-button.accent4 span.icon:first-child,
.vamtam-button.accent5 span.icon:first-child,
.vamtam-button.accent6 span.icon:first-child,
.vamtam-button.accent7 span.icon:first-child,
.vamtam-button.accent8 span.icon:first-child {
  padding: .5em 0 .5em .8em !important;
}
.button span.icon:last-child,
.button.accent1 span.icon:last-child,
.button.accent2 span.icon:last-child,
.button.accent3 span.icon:last-child,
.button.accent4 span.icon:last-child,
.button.accent5 span.icon:last-child,
.button.accent6 span.icon:last-child,
.button.accent7 span.icon:last-child,
.button.accent8 span.icon:last-child,
.vamtam-button span.icon:last-child,
.vamtam-button.accent1 span.icon:last-child,
.vamtam-button.accent2 span.icon:last-child,
.vamtam-button.accent3 span.icon:last-child,
.vamtam-button.accent4 span.icon:last-child,
.vamtam-button.accent5 span.icon:last-child,
.vamtam-button.accent6 span.icon:last-child,
.vamtam-button.accent7 span.icon:last-child,
.vamtam-button.accent8 span.icon:last-child {
  padding: .5em .8em .5em 0 !important;
}
.button span.btext,
.button.accent1 span.btext,
.button.accent2 span.btext,
.button.accent3 span.btext,
.button.accent4 span.btext,
.button.accent5 span.btext,
.button.accent6 span.btext,
.button.accent7 span.btext,
.button.accent8 span.btext,
.vamtam-button span.btext,
.vamtam-button.accent1 span.btext,
.vamtam-button.accent2 span.btext,
.vamtam-button.accent3 span.btext,
.vamtam-button.accent4 span.btext,
.vamtam-button.accent5 span.btext,
.vamtam-button.accent6 span.btext,
.vamtam-button.accent7 span.btext,
.vamtam-button.accent8 span.btext {
  position: relative;
  font-weight: 500;
  vertical-align: middle;
  padding: 0.7em 1.2em;
  letter-spacing: 1px;
}
.button:hover,
.button:hover span,
.button.accent1:hover,
.button.accent1:hover span,
.button.accent2:hover,
.button.accent2:hover span,
.button.accent3:hover,
.button.accent3:hover span,
.button.accent4:hover,
.button.accent4:hover span,
.button.accent5:hover,
.button.accent5:hover span,
.button.accent6:hover,
.button.accent6:hover span,
.button.accent7:hover,
.button.accent7:hover span,
.button.accent8:hover,
.button.accent8:hover span,
.vamtam-button:hover,
.vamtam-button:hover span,
.vamtam-button.accent1:hover,
.vamtam-button.accent1:hover span,
.vamtam-button.accent2:hover,
.vamtam-button.accent2:hover span,
.vamtam-button.accent3:hover,
.vamtam-button.accent3:hover span,
.vamtam-button.accent4:hover,
.vamtam-button.accent4:hover span,
.vamtam-button.accent5:hover,
.vamtam-button.accent5:hover span,
.vamtam-button.accent6:hover,
.vamtam-button.accent6:hover span,
.vamtam-button.accent7:hover,
.vamtam-button.accent7:hover span,
.vamtam-button.accent8:hover,
.vamtam-button.accent8:hover span {
  text-decoration: none;
}
.button.button-border,
.button.button-style-3,
.button.accent1.button-border,
.button.accent1.button-style-3,
.button.accent2.button-border,
.button.accent2.button-style-3,
.button.accent3.button-border,
.button.accent3.button-style-3,
.button.accent4.button-border,
.button.accent4.button-style-3,
.button.accent5.button-border,
.button.accent5.button-style-3,
.button.accent6.button-border,
.button.accent6.button-style-3,
.button.accent7.button-border,
.button.accent7.button-style-3,
.button.accent8.button-border,
.button.accent8.button-style-3,
.vamtam-button.button-border,
.vamtam-button.button-style-3,
.vamtam-button.accent1.button-border,
.vamtam-button.accent1.button-style-3,
.vamtam-button.accent2.button-border,
.vamtam-button.accent2.button-style-3,
.vamtam-button.accent3.button-border,
.vamtam-button.accent3.button-style-3,
.vamtam-button.accent4.button-border,
.vamtam-button.accent4.button-style-3,
.vamtam-button.accent5.button-border,
.vamtam-button.accent5.button-style-3,
.vamtam-button.accent6.button-border,
.vamtam-button.accent6.button-style-3,
.vamtam-button.accent7.button-border,
.vamtam-button.accent7.button-style-3,
.vamtam-button.accent8.button-border,
.vamtam-button.accent8.button-style-3 {
  background: transparent;
  box-shadow: none;
  font-style: normal;
  overflow: hidden;
}
.button.button-border:hover span.btext,
.button.accent1.button-border:hover span.btext,
.button.accent2.button-border:hover span.btext,
.button.accent3.button-border:hover span.btext,
.button.accent4.button-border:hover span.btext,
.button.accent5.button-border:hover span.btext,
.button.accent6.button-border:hover span.btext,
.button.accent7.button-border:hover span.btext,
.button.accent8.button-border:hover span.btext,
.vamtam-button.button-border:hover span.btext,
.vamtam-button.accent1.button-border:hover span.btext,
.vamtam-button.accent2.button-border:hover span.btext,
.vamtam-button.accent3.button-border:hover span.btext,
.vamtam-button.accent4.button-border:hover span.btext,
.vamtam-button.accent5.button-border:hover span.btext,
.vamtam-button.accent6.button-border:hover span.btext,
.vamtam-button.accent7.button-border:hover span.btext,
.vamtam-button.accent8.button-border:hover span.btext {
  position: relative;
  display: inline-block;
  -webkit-transition: -webkit-transform 0.3s;
  -moz-transition: -moz-transform 0.3s;
  transition: transform 0.3s;
  -webkit-transform: translateY(-100%);
  -ms-transform: translateY(-100%);
  transform: translateY(-100%);
}
.button.button-border:hover span.btext:before,
.button.accent1.button-border:hover span.btext:before,
.button.accent2.button-border:hover span.btext:before,
.button.accent3.button-border:hover span.btext:before,
.button.accent4.button-border:hover span.btext:before,
.button.accent5.button-border:hover span.btext:before,
.button.accent6.button-border:hover span.btext:before,
.button.accent7.button-border:hover span.btext:before,
.button.accent8.button-border:hover span.btext:before,
.vamtam-button.button-border:hover span.btext:before,
.vamtam-button.accent1.button-border:hover span.btext:before,
.vamtam-button.accent2.button-border:hover span.btext:before,
.vamtam-button.accent3.button-border:hover span.btext:before,
.vamtam-button.accent4.button-border:hover span.btext:before,
.vamtam-button.accent5.button-border:hover span.btext:before,
.vamtam-button.accent6.button-border:hover span.btext:before,
.vamtam-button.accent7.button-border:hover span.btext:before,
.vamtam-button.accent8.button-border:hover span.btext:before {
  position: absolute;
  content: attr(data-text);
  font-weight: 700;
  -webkit-transform: translate3d(0,0,0);
  -ms-transform: translate3d(0,0,0);
  transform: translate3d(0,0,0);
  top: 100%;
  left: 0px;
  height: 100%;
  width: 100%;
  padding-top: 0.8em;
  line-height: 1.2em;
}
.button.button-border span.btext,
.button.accent1.button-border span.btext,
.button.accent2.button-border span.btext,
.button.accent3.button-border span.btext,
.button.accent4.button-border span.btext,
.button.accent5.button-border span.btext,
.button.accent6.button-border span.btext,
.button.accent7.button-border span.btext,
.button.accent8.button-border span.btext,
.vamtam-button.button-border span.btext,
.vamtam-button.accent1.button-border span.btext,
.vamtam-button.accent2.button-border span.btext,
.vamtam-button.accent3.button-border span.btext,
.vamtam-button.accent4.button-border span.btext,
.vamtam-button.accent5.button-border span.btext,
.vamtam-button.accent6.button-border span.btext,
.vamtam-button.accent7.button-border span.btext,
.vamtam-button.accent8.button-border span.btext {
  padding: .8em 2em !important;
  font-weight: 600 !important;
  line-height: 1.2em;
}
.button.button-style-3 span.icon,
.button.accent1.button-style-3 span.icon,
.button.accent2.button-style-3 span.icon,
.button.accent3.button-style-3 span.icon,
.button.accent4.button-style-3 span.icon,
.button.accent5.button-style-3 span.icon,
.button.accent6.button-style-3 span.icon,
.button.accent7.button-style-3 span.icon,
.button.accent8.button-style-3 span.icon,
.vamtam-button.button-style-3 span.icon,
.vamtam-button.accent1.button-style-3 span.icon,
.vamtam-button.accent2.button-style-3 span.icon,
.vamtam-button.accent3.button-style-3 span.icon,
.vamtam-button.accent4.button-style-3 span.icon,
.vamtam-button.accent5.button-style-3 span.icon,
.vamtam-button.accent6.button-style-3 span.icon,
.vamtam-button.accent7.button-style-3 span.icon,
.vamtam-button.accent8.button-style-3 span.icon {
  padding: 0.7em 0.8em !important;
  vertical-align: middle !important;
}
.button.button-style-3 span.icon:first-child,
.button.accent1.button-style-3 span.icon:first-child,
.button.accent2.button-style-3 span.icon:first-child,
.button.accent3.button-style-3 span.icon:first-child,
.button.accent4.button-style-3 span.icon:first-child,
.button.accent5.button-style-3 span.icon:first-child,
.button.accent6.button-style-3 span.icon:first-child,
.button.accent7.button-style-3 span.icon:first-child,
.button.accent8.button-style-3 span.icon:first-child,
.vamtam-button.button-style-3 span.icon:first-child,
.vamtam-button.accent1.button-style-3 span.icon:first-child,
.vamtam-button.accent2.button-style-3 span.icon:first-child,
.vamtam-button.accent3.button-style-3 span.icon:first-child,
.vamtam-button.accent4.button-style-3 span.icon:first-child,
.vamtam-button.accent5.button-style-3 span.icon:first-child,
.vamtam-button.accent6.button-style-3 span.icon:first-child,
.vamtam-button.accent7.button-style-3 span.icon:first-child,
.vamtam-button.accent8.button-style-3 span.icon:first-child {
  border-right: solid 1px;
}
.button.accent1,
.vamtam-button.accent1 {
  background: #F0542D;
  color: #ffffff;
}
.button.accent1 span,
.vamtam-button.accent1 span {
  color: #ffffff;
}
.button.accent1.button-border,
.vamtam-button.accent1.button-border {
  border: 2px solid #F0542D;
}
.button.accent1.button-border:hover span,
.button.accent1.button-border span,
.vamtam-button.accent1.button-border:hover span,
.vamtam-button.accent1.button-border span {
  color: #F0542D !important;
}
.button.accent1.button-style-3,
.vamtam-button.accent1.button-style-3 {
  border: none;
  background: #F0542D;
  padding: 0px !important;
}
.button.accent1.button-style-3 span,
.vamtam-button.accent1.button-style-3 span {
  color: #ffffff;
}
.button.accent1.button-style-3 span.icon,
.vamtam-button.accent1.button-style-3 span.icon {
  padding: 0.5em 0.8em !important;
}
.button.accent1.button-style-3 span.icon:first-child,
.vamtam-button.accent1.button-style-3 span.icon:first-child {
  border-right: solid 1px;
  border-color: #ffffff;
}
.button.accent1.button-style-3 span.icon:last-child,
.vamtam-button.accent1.button-style-3 span.icon:last-child {
  border-left: solid 1px;
  border-color: #ffffff;
}
.button,
.button.accent2,
.vamtam-button,
.vamtam-button.accent2 {
  background: #364352;
  color: #f5f6f8;
}
.button span,
.button.accent2 span,
.vamtam-button span,
.vamtam-button.accent2 span {
  color: #f5f6f8;
}
.button.button-border,
.button.accent2.button-border,
.vamtam-button.button-border,
.vamtam-button.accent2.button-border {
  border: 2px solid #364352;
}
.button.button-border:hover span,
.button.button-border span,
.button.accent2.button-border:hover span,
.button.accent2.button-border span,
.vamtam-button.button-border:hover span,
.vamtam-button.button-border span,
.vamtam-button.accent2.button-border:hover span,
.vamtam-button.accent2.button-border span {
  color: #364352 !important;
}
.button.button-style-3,
.button.accent2.button-style-3,
.vamtam-button.button-style-3,
.vamtam-button.accent2.button-style-3 {
  border: none;
  background: #364352;
  padding: 0px !important;
}
.button.button-style-3 span,
.button.accent2.button-style-3 span,
.vamtam-button.button-style-3 span,
.vamtam-button.accent2.button-style-3 span {
  color: #f5f6f8;
}
.button.button-style-3 span.icon,
.button.accent2.button-style-3 span.icon,
.vamtam-button.button-style-3 span.icon,
.vamtam-button.accent2.button-style-3 span.icon {
  padding: 0.5em 0.8em !important;
}
.button.button-style-3 span.icon:first-child,
.button.accent2.button-style-3 span.icon:first-child,
.vamtam-button.button-style-3 span.icon:first-child,
.vamtam-button.accent2.button-style-3 span.icon:first-child {
  border-right: solid 1px;
  border-color: #f5f6f8;
}
.button.button-style-3 span.icon:last-child,
.button.accent2.button-style-3 span.icon:last-child,
.vamtam-button.button-style-3 span.icon:last-child,
.vamtam-button.accent2.button-style-3 span.icon:last-child {
  border-left: solid 1px;
  border-color: #f5f6f8;
}
.button.accent3,
.vamtam-button.accent3 {
  background: #7C8A8D;
  color: #ffffff;
}
.button.accent3 span,
.vamtam-button.accent3 span {
  color: #ffffff;
}
.button.accent3.button-border,
.vamtam-button.accent3.button-border {
  border: 2px solid #7C8A8D;
}
.button.accent3.button-border:hover span,
.button.accent3.button-border span,
.vamtam-button.accent3.button-border:hover span,
.vamtam-button.accent3.button-border span {
  color: #7C8A8D !important;
}
.button.accent3.button-style-3,
.vamtam-button.accent3.button-style-3 {
  border: none;
  background: #7C8A8D;
  padding: 0px !important;
}
.button.accent3.button-style-3 span,
.vamtam-button.accent3.button-style-3 span {
  color: #ffffff;
}
.button.accent3.button-style-3 span.icon,
.vamtam-button.accent3.button-style-3 span.icon {
  padding: 0.5em 0.8em !important;
}
.button.accent3.button-style-3 span.icon:first-child,
.vamtam-button.accent3.button-style-3 span.icon:first-child {
  border-right: solid 1px;
  border-color: #ffffff;
}
.button.accent3.button-style-3 span.icon:last-child,
.vamtam-button.accent3.button-style-3 span.icon:last-child {
  border-left: solid 1px;
  border-color: #ffffff;
}
.button.accent4,
.vamtam-button.accent4 {
  background: #D8D8D8;
  color: #262626;
}
.button.accent4 span,
.vamtam-button.accent4 span {
  color: #262626;
}
.button.accent4.button-border,
.vamtam-button.accent4.button-border {
  border: 2px solid #D8D8D8;
}
.button.accent4.button-border:hover span,
.button.accent4.button-border span,
.vamtam-button.accent4.button-border:hover span,
.vamtam-button.accent4.button-border span {
  color: #D8D8D8 !important;
}
.button.accent4.button-style-3,
.vamtam-button.accent4.button-style-3 {
  border: none;
  background: #D8D8D8;
  padding: 0px !important;
}
.button.accent4.button-style-3 span,
.vamtam-button.accent4.button-style-3 span {
  color: #262626;
}
.button.accent4.button-style-3 span.icon,
.vamtam-button.accent4.button-style-3 span.icon {
  padding: 0.5em 0.8em !important;
}
.button.accent4.button-style-3 span.icon:first-child,
.vamtam-button.accent4.button-style-3 span.icon:first-child {
  border-right: solid 1px;
  border-color: #262626;
}
.button.accent4.button-style-3 span.icon:last-child,
.vamtam-button.accent4.button-style-3 span.icon:last-child {
  border-left: solid 1px;
  border-color: #262626;
}
.button.accent5,
.vamtam-button.accent5 {
  background: #ffffff;
  color: #4d4d4d;
}
.button.accent5 span,
.vamtam-button.accent5 span {
  color: #4d4d4d;
}
.button.accent5.button-border,
.vamtam-button.accent5.button-border {
  border: 2px solid #ffffff;
}
.button.accent5.button-border:hover span,
.button.accent5.button-border span,
.vamtam-button.accent5.button-border:hover span,
.vamtam-button.accent5.button-border span {
  color: #ffffff !important;
}
.button.accent5.button-style-3,
.vamtam-button.accent5.button-style-3 {
  border: none;
  background: #ffffff;
  padding: 0px !important;
}
.button.accent5.button-style-3 span,
.vamtam-button.accent5.button-style-3 span {
  color: #4d4d4d;
}
.button.accent5.button-style-3 span.icon,
.vamtam-button.accent5.button-style-3 span.icon {
  padding: 0.5em 0.8em !important;
}
.button.accent5.button-style-3 span.icon:first-child,
.vamtam-button.accent5.button-style-3 span.icon:first-child {
  border-right: solid 1px;
  border-color: #4d4d4d;
}
.button.accent5.button-style-3 span.icon:last-child,
.vamtam-button.accent5.button-style-3 span.icon:last-child {
  border-left: solid 1px;
  border-color: #4d4d4d;
}
.button.accent6,
.vamtam-button.accent6 {
  background: #2B2F34;
  color: #dfe2e5;
}
.button.accent6 span,
.vamtam-button.accent6 span {
  color: #dfe2e5;
}
.button.accent6.button-border,
.vamtam-button.accent6.button-border {
  border: 2px solid #2B2F34;
}
.button.accent6.button-border:hover span,
.button.accent6.button-border span,
.vamtam-button.accent6.button-border:hover span,
.vamtam-button.accent6.button-border span {
  color: #2B2F34 !important;
}
.button.accent6.button-style-3,
.vamtam-button.accent6.button-style-3 {
  border: none;
  background: #2B2F34;
  padding: 0px !important;
}
.button.accent6.button-style-3 span,
.vamtam-button.accent6.button-style-3 span {
  color: #dfe2e5;
}
.button.accent6.button-style-3 span.icon,
.vamtam-button.accent6.button-style-3 span.icon {
  padding: 0.5em 0.8em !important;
}
.button.accent6.button-style-3 span.icon:first-child,
.vamtam-button.accent6.button-style-3 span.icon:first-child {
  border-right: solid 1px;
  border-color: #dfe2e5;
}
.button.accent6.button-style-3 span.icon:last-child,
.vamtam-button.accent6.button-style-3 span.icon:last-child {
  border-left: solid 1px;
  border-color: #dfe2e5;
}
.button.accent7,
.vamtam-button.accent7 {
  background: #EDEDED;
  color: #3b3b3b;
}
.button.accent7 span,
.vamtam-button.accent7 span {
  color: #3b3b3b;
}
.button.accent7.button-border,
.vamtam-button.accent7.button-border {
  border: 2px solid #EDEDED;
}
.button.accent7.button-border:hover span,
.button.accent7.button-border span,
.vamtam-button.accent7.button-border:hover span,
.vamtam-button.accent7.button-border span {
  color: #EDEDED !important;
}
.button.accent7.button-style-3,
.vamtam-button.accent7.button-style-3 {
  border: none;
  background: #EDEDED;
  padding: 0px !important;
}
.button.accent7.button-style-3 span,
.vamtam-button.accent7.button-style-3 span {
  color: #3b3b3b;
}
.button.accent7.button-style-3 span.icon,
.vamtam-button.accent7.button-style-3 span.icon {
  padding: 0.5em 0.8em !important;
}
.button.accent7.button-style-3 span.icon:first-child,
.vamtam-button.accent7.button-style-3 span.icon:first-child {
  border-right: solid 1px;
  border-color: #3b3b3b;
}
.button.accent7.button-style-3 span.icon:last-child,
.vamtam-button.accent7.button-style-3 span.icon:last-child {
  border-left: solid 1px;
  border-color: #3b3b3b;
}
.button.accent8,
.vamtam-button.accent8 {
  background: #ffffff;
  color: #4d4d4d;
}
.button.accent8 span,
.vamtam-button.accent8 span {
  color: #4d4d4d;
}
.button.accent8.button-border,
.vamtam-button.accent8.button-border {
  border: 2px solid #ffffff;
}
.button.accent8.button-border:hover span,
.button.accent8.button-border span,
.vamtam-button.accent8.button-border:hover span,
.vamtam-button.accent8.button-border span {
  color: #ffffff !important;
}
.button.accent8.button-style-3,
.vamtam-button.accent8.button-style-3 {
  border: none;
  background: #ffffff;
  padding: 0px !important;
}
.button.accent8.button-style-3 span,
.vamtam-button.accent8.button-style-3 span {
  color: #4d4d4d;
}
.button.accent8.button-style-3 span.icon,
.vamtam-button.accent8.button-style-3 span.icon {
  padding: 0.5em 0.8em !important;
}
.button.accent8.button-style-3 span.icon:first-child,
.vamtam-button.accent8.button-style-3 span.icon:first-child {
  border-right: solid 1px;
  border-color: #4d4d4d;
}
.button.accent8.button-style-3 span.icon:last-child,
.vamtam-button.accent8.button-style-3 span.icon:last-child {
  border-left: solid 1px;
  border-color: #4d4d4d;
}
.button:hover,
.button:focus,
.button:active,
.button.hover-accent1:hover,
.button.hover-accent1:focus,
.button.hover-accent1:active,
.vamtam-button:hover,
.vamtam-button:focus,
.vamtam-button:active,
.vamtam-button.hover-accent1:hover,
.vamtam-button.hover-accent1:focus,
.vamtam-button.hover-accent1:active {
  background: #F0542D;
}
.button:hover,
.button:hover span,
.button:focus,
.button:focus span,
.button:active,
.button:active span,
.button.hover-accent1:hover,
.button.hover-accent1:hover span,
.button.hover-accent1:focus,
.button.hover-accent1:focus span,
.button.hover-accent1:active,
.button.hover-accent1:active span,
.vamtam-button:hover,
.vamtam-button:hover span,
.vamtam-button:focus,
.vamtam-button:focus span,
.vamtam-button:active,
.vamtam-button:active span,
.vamtam-button.hover-accent1:hover,
.vamtam-button.hover-accent1:hover span,
.vamtam-button.hover-accent1:focus,
.vamtam-button.hover-accent1:focus span,
.vamtam-button.hover-accent1:active,
.vamtam-button.hover-accent1:active span {
  color: #ffffff;
}
.button.button-border:after,
.button.button-style-3:after,
.button.hover-accent1.button-border:after,
.button.hover-accent1.button-style-3:after,
.vamtam-button.button-border:after,
.vamtam-button.button-style-3:after,
.vamtam-button.hover-accent1.button-border:after,
.vamtam-button.hover-accent1.button-style-3:after {
  content: '';
  position: absolute;
  z-index: -1;
  width: 100%;
  height: 0;
  bottom: 0;
  left: 0;
  background: #F0542D;
  transition: all 0.3s;
}
.button.button-border:hover:after,
.button.button-style-3:hover:after,
.button.hover-accent1.button-border:hover:after,
.button.hover-accent1.button-style-3:hover:after,
.vamtam-button.button-border:hover:after,
.vamtam-button.button-style-3:hover:after,
.vamtam-button.hover-accent1.button-border:hover:after,
.vamtam-button.hover-accent1.button-style-3:hover:after {
  height: 100%;
}
.button.button-border:hover,
.button.button-border:hover span,
.button.button-style-3:hover,
.button.button-style-3:hover span,
.button.hover-accent1.button-border:hover,
.button.hover-accent1.button-border:hover span,
.button.hover-accent1.button-style-3:hover,
.button.hover-accent1.button-style-3:hover span,
.vamtam-button.button-border:hover,
.vamtam-button.button-border:hover span,
.vamtam-button.button-style-3:hover,
.vamtam-button.button-style-3:hover span,
.vamtam-button.hover-accent1.button-border:hover,
.vamtam-button.hover-accent1.button-border:hover span,
.vamtam-button.hover-accent1.button-style-3:hover,
.vamtam-button.hover-accent1.button-style-3:hover span {
  border-color: #F0542D;
}
.button.button-style-3:hover span,
.button.hover-accent1.button-style-3:hover span,
.vamtam-button.button-style-3:hover span,
.vamtam-button.hover-accent1.button-style-3:hover span {
  color: #ffffff;
}
.button.button-style-3:hover span.icon,
.button.hover-accent1.button-style-3:hover span.icon,
.vamtam-button.button-style-3:hover span.icon,
.vamtam-button.hover-accent1.button-style-3:hover span.icon {
  border-color: #ffffff;
}
.button.button-style-3:hover span.icon:first-child,
.button.hover-accent1.button-style-3:hover span.icon:first-child,
.vamtam-button.button-style-3:hover span.icon:first-child,
.vamtam-button.hover-accent1.button-style-3:hover span.icon:first-child {
  color: #ffffff !important;
}
.button.button-style-3:hover span.icon:last-child,
.button.hover-accent1.button-style-3:hover span.icon:last-child,
.vamtam-button.button-style-3:hover span.icon:last-child,
.vamtam-button.hover-accent1.button-style-3:hover span.icon:last-child {
  color: #ffffff !important;
}
.button.button-border:hover,
.button.button-border:focus,
.button.hover-accent1.button-border:hover,
.button.hover-accent1.button-border:focus,
.vamtam-button.button-border:hover,
.vamtam-button.button-border:focus,
.vamtam-button.hover-accent1.button-border:hover,
.vamtam-button.hover-accent1.button-border:focus {
  background: none;
}
.button.button-border:hover span,
.button.button-border:focus span,
.button.hover-accent1.button-border:hover span,
.button.hover-accent1.button-border:focus span,
.vamtam-button.button-border:hover span,
.vamtam-button.button-border:focus span,
.vamtam-button.hover-accent1.button-border:hover span,
.vamtam-button.hover-accent1.button-border:focus span {
  color: #F0542D;
}
.button.button-border:hover span.btext:before,
.button.button-border:focus span.btext:before,
.button.hover-accent1.button-border:hover span.btext:before,
.button.hover-accent1.button-border:focus span.btext:before,
.vamtam-button.button-border:hover span.btext:before,
.vamtam-button.button-border:focus span.btext:before,
.vamtam-button.hover-accent1.button-border:hover span.btext:before,
.vamtam-button.hover-accent1.button-border:focus span.btext:before {
  color: #ffffff;
  background: #F0542D;
}
.button.button-border:hover span.icon,
.button.button-border:focus span.icon,
.button.hover-accent1.button-border:hover span.icon,
.button.hover-accent1.button-border:focus span.icon,
.vamtam-button.button-border:hover span.icon,
.vamtam-button.button-border:focus span.icon,
.vamtam-button.hover-accent1.button-border:hover span.icon,
.vamtam-button.hover-accent1.button-border:focus span.icon {
  color: #ffffff !important;
}
.button.hover-accent2:hover,
.button.hover-accent2:focus,
.button.hover-accent2:active,
.vamtam-button.hover-accent2:hover,
.vamtam-button.hover-accent2:focus,
.vamtam-button.hover-accent2:active {
  background: #364352;
}
.button.hover-accent2:hover,
.button.hover-accent2:hover span,
.button.hover-accent2:focus,
.button.hover-accent2:focus span,
.button.hover-accent2:active,
.button.hover-accent2:active span,
.vamtam-button.hover-accent2:hover,
.vamtam-button.hover-accent2:hover span,
.vamtam-button.hover-accent2:focus,
.vamtam-button.hover-accent2:focus span,
.vamtam-button.hover-accent2:active,
.vamtam-button.hover-accent2:active span {
  color: #b7c3d0;
}
.button.hover-accent2.button-border:after,
.button.hover-accent2.button-style-3:after,
.vamtam-button.hover-accent2.button-border:after,
.vamtam-button.hover-accent2.button-style-3:after {
  content: '';
  position: absolute;
  z-index: -1;
  width: 100%;
  height: 0;
  bottom: 0;
  left: 0;
  background: #364352;
  transition: all 0.3s;
}
.button.hover-accent2.button-border:hover:after,
.button.hover-accent2.button-style-3:hover:after,
.vamtam-button.hover-accent2.button-border:hover:after,
.vamtam-button.hover-accent2.button-style-3:hover:after {
  height: 100%;
}
.button.hover-accent2.button-border:hover,
.button.hover-accent2.button-border:hover span,
.button.hover-accent2.button-style-3:hover,
.button.hover-accent2.button-style-3:hover span,
.vamtam-button.hover-accent2.button-border:hover,
.vamtam-button.hover-accent2.button-border:hover span,
.vamtam-button.hover-accent2.button-style-3:hover,
.vamtam-button.hover-accent2.button-style-3:hover span {
  border-color: #364352;
}
.button.hover-accent2.button-style-3:hover span,
.vamtam-button.hover-accent2.button-style-3:hover span {
  color: #ffffff;
}
.button.hover-accent2.button-style-3:hover span.icon,
.vamtam-button.hover-accent2.button-style-3:hover span.icon {
  border-color: #b7c3d0;
}
.button.hover-accent2.button-style-3:hover span.icon:first-child,
.vamtam-button.hover-accent2.button-style-3:hover span.icon:first-child {
  color: #ffffff !important;
}
.button.hover-accent2.button-style-3:hover span.icon:last-child,
.vamtam-button.hover-accent2.button-style-3:hover span.icon:last-child {
  color: #ffffff !important;
}
.button.hover-accent2.button-border:hover,
.button.hover-accent2.button-border:focus,
.vamtam-button.hover-accent2.button-border:hover,
.vamtam-button.hover-accent2.button-border:focus {
  background: none;
}
.button.hover-accent2.button-border:hover span,
.button.hover-accent2.button-border:focus span,
.vamtam-button.hover-accent2.button-border:hover span,
.vamtam-button.hover-accent2.button-border:focus span {
  color: #364352;
}
.button.hover-accent2.button-border:hover span.btext:before,
.button.hover-accent2.button-border:focus span.btext:before,
.vamtam-button.hover-accent2.button-border:hover span.btext:before,
.vamtam-button.hover-accent2.button-border:focus span.btext:before {
  color: #ffffff;
  background: #364352;
}
.button.hover-accent2.button-border:hover span.icon,
.button.hover-accent2.button-border:focus span.icon,
.vamtam-button.hover-accent2.button-border:hover span.icon,
.vamtam-button.hover-accent2.button-border:focus span.icon {
  color: #ffffff !important;
}
.button.hover-accent3:hover,
.button.hover-accent3:focus,
.button.hover-accent3:active,
.vamtam-button.hover-accent3:hover,
.vamtam-button.hover-accent3:focus,
.vamtam-button.hover-accent3:active {
  background: #7C8A8D;
}
.button.hover-accent3:hover,
.button.hover-accent3:hover span,
.button.hover-accent3:focus,
.button.hover-accent3:focus span,
.button.hover-accent3:active,
.button.hover-accent3:active span,
.vamtam-button.hover-accent3:hover,
.vamtam-button.hover-accent3:hover span,
.vamtam-button.hover-accent3:focus,
.vamtam-button.hover-accent3:focus span,
.vamtam-button.hover-accent3:active,
.vamtam-button.hover-accent3:active span {
  color: #ffffff;
}
.button.hover-accent3.button-border:after,
.button.hover-accent3.button-style-3:after,
.vamtam-button.hover-accent3.button-border:after,
.vamtam-button.hover-accent3.button-style-3:after {
  content: '';
  position: absolute;
  z-index: -1;
  width: 100%;
  height: 0;
  bottom: 0;
  left: 0;
  background: #7C8A8D;
  transition: all 0.3s;
}
.button.hover-accent3.button-border:hover:after,
.button.hover-accent3.button-style-3:hover:after,
.vamtam-button.hover-accent3.button-border:hover:after,
.vamtam-button.hover-accent3.button-style-3:hover:after {
  height: 100%;
}
.button.hover-accent3.button-border:hover,
.button.hover-accent3.button-border:hover span,
.button.hover-accent3.button-style-3:hover,
.button.hover-accent3.button-style-3:hover span,
.vamtam-button.hover-accent3.button-border:hover,
.vamtam-button.hover-accent3.button-border:hover span,
.vamtam-button.hover-accent3.button-style-3:hover,
.vamtam-button.hover-accent3.button-style-3:hover span {
  border-color: #7C8A8D;
}
.button.hover-accent3.button-style-3:hover span,
.vamtam-button.hover-accent3.button-style-3:hover span {
  color: #ffffff;
}
.button.hover-accent3.button-style-3:hover span.icon,
.vamtam-button.hover-accent3.button-style-3:hover span.icon {
  border-color: #ffffff;
}
.button.hover-accent3.button-style-3:hover span.icon:first-child,
.vamtam-button.hover-accent3.button-style-3:hover span.icon:first-child {
  color: #ffffff !important;
}
.button.hover-accent3.button-style-3:hover span.icon:last-child,
.vamtam-button.hover-accent3.button-style-3:hover span.icon:last-child {
  color: #ffffff !important;
}
.button.hover-accent3.button-border:hover,
.button.hover-accent3.button-border:focus,
.vamtam-button.hover-accent3.button-border:hover,
.vamtam-button.hover-accent3.button-border:focus {
  background: none;
}
.button.hover-accent3.button-border:hover span,
.button.hover-accent3.button-border:focus span,
.vamtam-button.hover-accent3.button-border:hover span,
.vamtam-button.hover-accent3.button-border:focus span {
  color: #7C8A8D;
}
.button.hover-accent3.button-border:hover span.btext:before,
.button.hover-accent3.button-border:focus span.btext:before,
.vamtam-button.hover-accent3.button-border:hover span.btext:before,
.vamtam-button.hover-accent3.button-border:focus span.btext:before {
  color: #ffffff;
  background: #7C8A8D;
}
.button.hover-accent3.button-border:hover span.icon,
.button.hover-accent3.button-border:focus span.icon,
.vamtam-button.hover-accent3.button-border:hover span.icon,
.vamtam-button.hover-accent3.button-border:focus span.icon {
  color: #ffffff !important;
}
.button.hover-accent4:hover,
.button.hover-accent4:focus,
.button.hover-accent4:active,
.vamtam-button.hover-accent4:hover,
.vamtam-button.hover-accent4:focus,
.vamtam-button.hover-accent4:active {
  background: #D8D8D8;
}
.button.hover-accent4:hover,
.button.hover-accent4:hover span,
.button.hover-accent4:focus,
.button.hover-accent4:focus span,
.button.hover-accent4:active,
.button.hover-accent4:active span,
.vamtam-button.hover-accent4:hover,
.vamtam-button.hover-accent4:hover span,
.vamtam-button.hover-accent4:focus,
.vamtam-button.hover-accent4:focus span,
.vamtam-button.hover-accent4:active,
.vamtam-button.hover-accent4:active span {
  color: #595959;
}
.button.hover-accent4.button-border:after,
.button.hover-accent4.button-style-3:after,
.vamtam-button.hover-accent4.button-border:after,
.vamtam-button.hover-accent4.button-style-3:after {
  content: '';
  position: absolute;
  z-index: -1;
  width: 100%;
  height: 0;
  bottom: 0;
  left: 0;
  background: #D8D8D8;
  transition: all 0.3s;
}
.button.hover-accent4.button-border:hover:after,
.button.hover-accent4.button-style-3:hover:after,
.vamtam-button.hover-accent4.button-border:hover:after,
.vamtam-button.hover-accent4.button-style-3:hover:after {
  height: 100%;
}
.button.hover-accent4.button-border:hover,
.button.hover-accent4.button-border:hover span,
.button.hover-accent4.button-style-3:hover,
.button.hover-accent4.button-style-3:hover span,
.vamtam-button.hover-accent4.button-border:hover,
.vamtam-button.hover-accent4.button-border:hover span,
.vamtam-button.hover-accent4.button-style-3:hover,
.vamtam-button.hover-accent4.button-style-3:hover span {
  border-color: #D8D8D8;
}
.button.hover-accent4.button-style-3:hover span,
.vamtam-button.hover-accent4.button-style-3:hover span {
  color: #ffffff;
}
.button.hover-accent4.button-style-3:hover span.icon,
.vamtam-button.hover-accent4.button-style-3:hover span.icon {
  border-color: #595959;
}
.button.hover-accent4.button-style-3:hover span.icon:first-child,
.vamtam-button.hover-accent4.button-style-3:hover span.icon:first-child {
  color: #ffffff !important;
}
.button.hover-accent4.button-style-3:hover span.icon:last-child,
.vamtam-button.hover-accent4.button-style-3:hover span.icon:last-child {
  color: #ffffff !important;
}
.button.hover-accent4.button-border:hover,
.button.hover-accent4.button-border:focus,
.vamtam-button.hover-accent4.button-border:hover,
.vamtam-button.hover-accent4.button-border:focus {
  background: none;
}
.button.hover-accent4.button-border:hover span,
.button.hover-accent4.button-border:focus span,
.vamtam-button.hover-accent4.button-border:hover span,
.vamtam-button.hover-accent4.button-border:focus span {
  color: #D8D8D8;
}
.button.hover-accent4.button-border:hover span.btext:before,
.button.hover-accent4.button-border:focus span.btext:before,
.vamtam-button.hover-accent4.button-border:hover span.btext:before,
.vamtam-button.hover-accent4.button-border:focus span.btext:before {
  color: #ffffff;
  background: #D8D8D8;
}
.button.hover-accent4.button-border:hover span.icon,
.button.hover-accent4.button-border:focus span.icon,
.vamtam-button.hover-accent4.button-border:hover span.icon,
.vamtam-button.hover-accent4.button-border:focus span.icon {
  color: #ffffff !important;
}
.button.hover-accent5:hover,
.button.hover-accent5:focus,
.button.hover-accent5:active,
.vamtam-button.hover-accent5:hover,
.vamtam-button.hover-accent5:focus,
.vamtam-button.hover-accent5:active {
  background: #ffffff;
}
.button.hover-accent5:hover,
.button.hover-accent5:hover span,
.button.hover-accent5:focus,
.button.hover-accent5:focus span,
.button.hover-accent5:active,
.button.hover-accent5:active span,
.vamtam-button.hover-accent5:hover,
.vamtam-button.hover-accent5:hover span,
.vamtam-button.hover-accent5:focus,
.vamtam-button.hover-accent5:focus span,
.vamtam-button.hover-accent5:active,
.vamtam-button.hover-accent5:active span {
  color: #808080;
}
.button.hover-accent5.button-border:after,
.button.hover-accent5.button-style-3:after,
.vamtam-button.hover-accent5.button-border:after,
.vamtam-button.hover-accent5.button-style-3:after {
  content: '';
  position: absolute;
  z-index: -1;
  width: 100%;
  height: 0;
  bottom: 0;
  left: 0;
  background: #ffffff;
  transition: all 0.3s;
}
.button.hover-accent5.button-border:hover:after,
.button.hover-accent5.button-style-3:hover:after,
.vamtam-button.hover-accent5.button-border:hover:after,
.vamtam-button.hover-accent5.button-style-3:hover:after {
  height: 100%;
}
.button.hover-accent5.button-border:hover,
.button.hover-accent5.button-border:hover span,
.button.hover-accent5.button-style-3:hover,
.button.hover-accent5.button-style-3:hover span,
.vamtam-button.hover-accent5.button-border:hover,
.vamtam-button.hover-accent5.button-border:hover span,
.vamtam-button.hover-accent5.button-style-3:hover,
.vamtam-button.hover-accent5.button-style-3:hover span {
  border-color: #ffffff;
}
.button.hover-accent5.button-style-3:hover span,
.vamtam-button.hover-accent5.button-style-3:hover span {
  color: #ffffff;
}
.button.hover-accent5.button-style-3:hover span.icon,
.vamtam-button.hover-accent5.button-style-3:hover span.icon {
  border-color: #808080;
}
.button.hover-accent5.button-style-3:hover span.icon:first-child,
.vamtam-button.hover-accent5.button-style-3:hover span.icon:first-child {
  color: #ffffff !important;
}
.button.hover-accent5.button-style-3:hover span.icon:last-child,
.vamtam-button.hover-accent5.button-style-3:hover span.icon:last-child {
  color: #ffffff !important;
}
.button.hover-accent5.button-border:hover,
.button.hover-accent5.button-border:focus,
.vamtam-button.hover-accent5.button-border:hover,
.vamtam-button.hover-accent5.button-border:focus {
  background: none;
}
.button.hover-accent5.button-border:hover span,
.button.hover-accent5.button-border:focus span,
.vamtam-button.hover-accent5.button-border:hover span,
.vamtam-button.hover-accent5.button-border:focus span {
  color: #ffffff;
}
.button.hover-accent5.button-border:hover span.btext:before,
.button.hover-accent5.button-border:focus span.btext:before,
.vamtam-button.hover-accent5.button-border:hover span.btext:before,
.vamtam-button.hover-accent5.button-border:focus span.btext:before {
  color: #ffffff;
  background: #ffffff;
}
.button.hover-accent5.button-border:hover span.icon,
.button.hover-accent5.button-border:focus span.icon,
.vamtam-button.hover-accent5.button-border:hover span.icon,
.vamtam-button.hover-accent5.button-border:focus span.icon {
  color: #ffffff !important;
}
.button.hover-accent6:hover,
.button.hover-accent6:focus,
.button.hover-accent6:active,
.vamtam-button.hover-accent6:hover,
.vamtam-button.hover-accent6:focus,
.vamtam-button.hover-accent6:active {
  background: #2B2F34;
}
.button.hover-accent6:hover,
.button.hover-accent6:hover span,
.button.hover-accent6:focus,
.button.hover-accent6:focus span,
.button.hover-accent6:active,
.button.hover-accent6:active span,
.vamtam-button.hover-accent6:hover,
.vamtam-button.hover-accent6:hover span,
.vamtam-button.hover-accent6:focus,
.vamtam-button.hover-accent6:focus span,
.vamtam-button.hover-accent6:active,
.vamtam-button.hover-accent6:active span {
  color: #a7aeb7;
}
.button.hover-accent6.button-border:after,
.button.hover-accent6.button-style-3:after,
.vamtam-button.hover-accent6.button-border:after,
.vamtam-button.hover-accent6.button-style-3:after {
  content: '';
  position: absolute;
  z-index: -1;
  width: 100%;
  height: 0;
  bottom: 0;
  left: 0;
  background: #2B2F34;
  transition: all 0.3s;
}
.button.hover-accent6.button-border:hover:after,
.button.hover-accent6.button-style-3:hover:after,
.vamtam-button.hover-accent6.button-border:hover:after,
.vamtam-button.hover-accent6.button-style-3:hover:after {
  height: 100%;
}
.button.hover-accent6.button-border:hover,
.button.hover-accent6.button-border:hover span,
.button.hover-accent6.button-style-3:hover,
.button.hover-accent6.button-style-3:hover span,
.vamtam-button.hover-accent6.button-border:hover,
.vamtam-button.hover-accent6.button-border:hover span,
.vamtam-button.hover-accent6.button-style-3:hover,
.vamtam-button.hover-accent6.button-style-3:hover span {
  border-color: #2B2F34;
}
.button.hover-accent6.button-style-3:hover span,
.vamtam-button.hover-accent6.button-style-3:hover span {
  color: #ffffff;
}
.button.hover-accent6.button-style-3:hover span.icon,
.vamtam-button.hover-accent6.button-style-3:hover span.icon {
  border-color: #a7aeb7;
}
.button.hover-accent6.button-style-3:hover span.icon:first-child,
.vamtam-button.hover-accent6.button-style-3:hover span.icon:first-child {
  color: #ffffff !important;
}
.button.hover-accent6.button-style-3:hover span.icon:last-child,
.vamtam-button.hover-accent6.button-style-3:hover span.icon:last-child {
  color: #ffffff !important;
}
.button.hover-accent6.button-border:hover,
.button.hover-accent6.button-border:focus,
.vamtam-button.hover-accent6.button-border:hover,
.vamtam-button.hover-accent6.button-border:focus {
  background: none;
}
.button.hover-accent6.button-border:hover span,
.button.hover-accent6.button-border:focus span,
.vamtam-button.hover-accent6.button-border:hover span,
.vamtam-button.hover-accent6.button-border:focus span {
  color: #2B2F34;
}
.button.hover-accent6.button-border:hover span.btext:before,
.button.hover-accent6.button-border:focus span.btext:before,
.vamtam-button.hover-accent6.button-border:hover span.btext:before,
.vamtam-button.hover-accent6.button-border:focus span.btext:before {
  color: #ffffff;
  background: #2B2F34;
}
.button.hover-accent6.button-border:hover span.icon,
.button.hover-accent6.button-border:focus span.icon,
.vamtam-button.hover-accent6.button-border:hover span.icon,
.vamtam-button.hover-accent6.button-border:focus span.icon {
  color: #ffffff !important;
}
.button.hover-accent7:hover,
.button.hover-accent7:focus,
.button.hover-accent7:active,
.vamtam-button.hover-accent7:hover,
.vamtam-button.hover-accent7:focus,
.vamtam-button.hover-accent7:active {
  background: #EDEDED;
}
.button.hover-accent7:hover,
.button.hover-accent7:hover span,
.button.hover-accent7:focus,
.button.hover-accent7:focus span,
.button.hover-accent7:active,
.button.hover-accent7:active span,
.vamtam-button.hover-accent7:hover,
.vamtam-button.hover-accent7:hover span,
.vamtam-button.hover-accent7:focus,
.vamtam-button.hover-accent7:focus span,
.vamtam-button.hover-accent7:active,
.vamtam-button.hover-accent7:active span {
  color: #6e6e6e;
}
.button.hover-accent7.button-border:after,
.button.hover-accent7.button-style-3:after,
.vamtam-button.hover-accent7.button-border:after,
.vamtam-button.hover-accent7.button-style-3:after {
  content: '';
  position: absolute;
  z-index: -1;
  width: 100%;
  height: 0;
  bottom: 0;
  left: 0;
  background: #EDEDED;
  transition: all 0.3s;
}
.button.hover-accent7.button-border:hover:after,
.button.hover-accent7.button-style-3:hover:after,
.vamtam-button.hover-accent7.button-border:hover:after,
.vamtam-button.hover-accent7.button-style-3:hover:after {
  height: 100%;
}
.button.hover-accent7.button-border:hover,
.button.hover-accent7.button-border:hover span,
.button.hover-accent7.button-style-3:hover,
.button.hover-accent7.button-style-3:hover span,
.vamtam-button.hover-accent7.button-border:hover,
.vamtam-button.hover-accent7.button-border:hover span,
.vamtam-button.hover-accent7.button-style-3:hover,
.vamtam-button.hover-accent7.button-style-3:hover span {
  border-color: #EDEDED;
}
.button.hover-accent7.button-style-3:hover span,
.vamtam-button.hover-accent7.button-style-3:hover span {
  color: #ffffff;
}
.button.hover-accent7.button-style-3:hover span.icon,
.vamtam-button.hover-accent7.button-style-3:hover span.icon {
  border-color: #6e6e6e;
}
.button.hover-accent7.button-style-3:hover span.icon:first-child,
.vamtam-button.hover-accent7.button-style-3:hover span.icon:first-child {
  color: #ffffff !important;
}
.button.hover-accent7.button-style-3:hover span.icon:last-child,
.vamtam-button.hover-accent7.button-style-3:hover span.icon:last-child {
  color: #ffffff !important;
}
.button.hover-accent7.button-border:hover,
.button.hover-accent7.button-border:focus,
.vamtam-button.hover-accent7.button-border:hover,
.vamtam-button.hover-accent7.button-border:focus {
  background: none;
}
.button.hover-accent7.button-border:hover span,
.button.hover-accent7.button-border:focus span,
.vamtam-button.hover-accent7.button-border:hover span,
.vamtam-button.hover-accent7.button-border:focus span {
  color: #EDEDED;
}
.button.hover-accent7.button-border:hover span.btext:before,
.button.hover-accent7.button-border:focus span.btext:before,
.vamtam-button.hover-accent7.button-border:hover span.btext:before,
.vamtam-button.hover-accent7.button-border:focus span.btext:before {
  color: #ffffff;
  background: #EDEDED;
}
.button.hover-accent7.button-border:hover span.icon,
.button.hover-accent7.button-border:focus span.icon,
.vamtam-button.hover-accent7.button-border:hover span.icon,
.vamtam-button.hover-accent7.button-border:focus span.icon {
  color: #ffffff !important;
}
.button.hover-accent8:hover,
.button.hover-accent8:focus,
.button.hover-accent8:active,
.vamtam-button.hover-accent8:hover,
.vamtam-button.hover-accent8:focus,
.vamtam-button.hover-accent8:active {
  background: #ffffff;
}
.button.hover-accent8:hover,
.button.hover-accent8:hover span,
.button.hover-accent8:focus,
.button.hover-accent8:focus span,
.button.hover-accent8:active,
.button.hover-accent8:active span,
.vamtam-button.hover-accent8:hover,
.vamtam-button.hover-accent8:hover span,
.vamtam-button.hover-accent8:focus,
.vamtam-button.hover-accent8:focus span,
.vamtam-button.hover-accent8:active,
.vamtam-button.hover-accent8:active span {
  color: #808080;
}
.button.hover-accent8.button-border:after,
.button.hover-accent8.button-style-3:after,
.vamtam-button.hover-accent8.button-border:after,
.vamtam-button.hover-accent8.button-style-3:after {
  content: '';
  position: absolute;
  z-index: -1;
  width: 100%;
  height: 0;
  bottom: 0;
  left: 0;
  background: #ffffff;
  transition: all 0.3s;
}
.button.hover-accent8.button-border:hover:after,
.button.hover-accent8.button-style-3:hover:after,
.vamtam-button.hover-accent8.button-border:hover:after,
.vamtam-button.hover-accent8.button-style-3:hover:after {
  height: 100%;
}
.button.hover-accent8.button-border:hover,
.button.hover-accent8.button-border:hover span,
.button.hover-accent8.button-style-3:hover,
.button.hover-accent8.button-style-3:hover span,
.vamtam-button.hover-accent8.button-border:hover,
.vamtam-button.hover-accent8.button-border:hover span,
.vamtam-button.hover-accent8.button-style-3:hover,
.vamtam-button.hover-accent8.button-style-3:hover span {
  border-color: #ffffff;
}
.button.hover-accent8.button-style-3:hover span,
.vamtam-button.hover-accent8.button-style-3:hover span {
  color: #ffffff;
}
.button.hover-accent8.button-style-3:hover span.icon,
.vamtam-button.hover-accent8.button-style-3:hover span.icon {
  border-color: #808080;
}
.button.hover-accent8.button-style-3:hover span.icon:first-child,
.vamtam-button.hover-accent8.button-style-3:hover span.icon:first-child {
  color: #ffffff !important;
}
.button.hover-accent8.button-style-3:hover span.icon:last-child,
.vamtam-button.hover-accent8.button-style-3:hover span.icon:last-child {
  color: #ffffff !important;
}
.button.hover-accent8.button-border:hover,
.button.hover-accent8.button-border:focus,
.vamtam-button.hover-accent8.button-border:hover,
.vamtam-button.hover-accent8.button-border:focus {
  background: none;
}
.button.hover-accent8.button-border:hover span,
.button.hover-accent8.button-border:focus span,
.vamtam-button.hover-accent8.button-border:hover span,
.vamtam-button.hover-accent8.button-border:focus span {
  color: #ffffff;
}
.button.hover-accent8.button-border:hover span.btext:before,
.button.hover-accent8.button-border:focus span.btext:before,
.vamtam-button.hover-accent8.button-border:hover span.btext:before,
.vamtam-button.hover-accent8.button-border:focus span.btext:before {
  color: #ffffff;
  background: #ffffff;
}
.button.hover-accent8.button-border:hover span.icon,
.button.hover-accent8.button-border:focus span.icon,
.vamtam-button.hover-accent8.button-border:hover span.icon,
.vamtam-button.hover-accent8.button-border:focus span.icon {
  color: #ffffff !important;
}
.button,
a.button,
.vamtam-button {
  font-size: 1em;
  font-weight: normal;
  display: inline-block;
  text-align: center;
  cursor: pointer;
  position: relative;
  z-index: 0;
  vertical-align: middle;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
  text-decoration: none;
  text-shadow: none;
  line-height: 1.15em;
  border-widht: 2px;
  padding: 0;
  text-align: center !important;
}
.button,
.button span,
a.button,
a.button span,
.vamtam-button,
.vamtam-button span {
  transition: color .3s ease, border .3s ease, background .3s ease;
}
.button span,
a.button span,
.vamtam-button span {
  display: inline-block;
  font-size: 1em;
  line-height: inherit;
  padding: .3em .4em;
  margin: 0 0;
  vertical-align: baseline;
}
.button span.icon,
a.button span.icon,
.vamtam-button span.icon {
  font-size: 100%;
  vertical-align: bottom !important;
}
.button span.icon.shortcode.inverted-colors,
a.button span.icon.shortcode.inverted-colors,
.vamtam-button span.icon.shortcode.inverted-colors {
  font-size: 100%;
  box-shadow: 0 1px 1px rgba(0,0,0,0.1) inset, 0 1px 1px rgba(255,255,255,0.2);
  text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}
.button span.icon:first-child,
.button span.icon:last-child,
a.button span.icon:first-child,
a.button span.icon:last-child,
.vamtam-button span.icon:first-child,
.vamtam-button span.icon:last-child {
  vertical-align: top;
  background: none;
}
.button span.icon:first-child,
a.button span.icon:first-child,
.vamtam-button span.icon:first-child {
  padding: .5em 0 .5em .8em !important;
}
.button span.icon:last-child,
a.button span.icon:last-child,
.vamtam-button span.icon:last-child {
  padding: .5em .8em .5em 0 !important;
}
.button span.btext,
a.button span.btext,
.vamtam-button span.btext {
  position: relative;
  font-weight: 500;
  vertical-align: middle;
  padding: 0.7em 1.2em;
  letter-spacing: 1px;
}
.button:hover,
.button:hover span,
a.button:hover,
a.button:hover span,
.vamtam-button:hover,
.vamtam-button:hover span {
  text-decoration: none;
}
.button.full,
a.button.full,
.vamtam-button.full {
  width: auto;
  float: none;
  display: block;
}
#comments-list,
#trackbacks-list {
  margin-bottom: 0px;
}
.respond-box {
  position: relative;
  margin: 10px 0 0;
  padding: 0;
  border-top: 0;
  background: #EDEDED;
}
.respond-box-title.sep-text {
  position: relative;
  padding: 30px 0 0 0;
  width: auto;
  height: 0;
}
.respond-box-title.sep-text .sep-text-before,
.respond-box-title.sep-text .sep-text-after {
  width: 50%;
  vertical-align: bottom;
}
.comments-wrapper {
  clear: both;
  border: solid 1px #EDEDED;
  margin-top: 20px;
}
.comments-wrapper:first-child {
  border: solid 1px #EDEDED;
  margin-top: 20px;
}
.comments-wrapper .sep-text {
  z-index: 2;
  margin-top: 20px;
  margin-bottom: 0px;
  padding-bottom: 20px;
  border-bottom: solid 1px #EDEDED;
}
.comments-wrapper .sep-text .sep-text-before,
.comments-wrapper .sep-text .sep-text-after,
.comments-wrapper .sep-text .sep-text-line {
  display: none;
}
.comments-wrapper .sep-text .content {
  padding: 0 10px;
}
.comments-wrapper .sep-text .content h5,
.comments-wrapper .sep-text .content h5 a {
  font: normal 24px/30px "Raleway";
}
.comments-wrapper .sep-text .content a:hover {
  text-decoration: none;
}
.comments-wrapper .sep-text .sep-text-more {
  padding-right: 20px;
  padding-left: 0px;
}
.comments-wrapper .sep-text .sep-text-more a.icon-b {
  font-size: 12px;
}
.comments-wrapper .sep-text .sep-text-more a.icon-b:before {
  color: #7C8A8D !important;
}
.comments-wrapper .children > li {
  margin-left: 0;
  padding-left: 0;
}
.comments-wrapper label {
  font-size: 12px !important;
}
.comments ol {
  margin: 0px;
}
.comments li {
  position: relative;
  min-height: 70px;
  border-bottom: solid 1px #EDEDED;
  padding: 15px;
}
.comments li.has-children {
  padding-bottom: 0;
}
.comments ol li {
  clear: both;
  margin-top: -1px;
  list-style: none;
}
.comments > ol > li:first-child {
  margin-top: 0px;
}
.comments .children {
  border-top: 0;
  margin: 0px;
}
.comments .children li {
  clear: both;
  margin-left: 80px;
  padding-left: 10px;
}
.comments .children li:last-child {
  padding-bottom: 15px;
  border-bottom: none;
}
.comments .avatar {
  max-width: 70px !important;
  max-height: 70px;
  background-color: #EDEDED;
}
.comments .comment-author {
  position: absolute;
  top: 0;
  bottom: 0;
  padding: 10px;
  min-height: 70px;
  width: 70px;
}
.comments .bypostauthor {
  position: relative;
  z-index: 1;
  transition: .3s;
}
.comments .bypostauthor:hover {
  background: #f5f5f5;
}
.comments .bypostauthor:hover .comment-author:after {
  border-right-color: #ffffff;
}
.comments .comment-author-link {
  display: inline;
}
.comments .comment-time {
  display: inline;
  font-size: 10px !important;
}
.comments .comment-time:before {
  margin: auto 5px;
  content: " | ";
}
.comments .comment-content {
  position: relative;
  margin-left: 100px;
  min-height: 50px;
}
.comments .comment-content:hover h6.comment-reply-link {
  display: block;
}
.comments .comment-meta {
  margin-top: -3px;
  margin-bottom: 6px;
}
.comments .comment-meta > .comment-author-link {
  font: 300 20px/26px "Raleway";
}
.comments h6.comment-reply-link {
  position: absolute;
  top: 0px;
  right: 0px;
  display: none;
  padding: 0 0 0 5px;
}
.comments h6.comment-reply-link a {
  margin: 0 0 0 5px;
  color: #F0542D;
  font-size: 12px;
}
.comments h6.comment-reply-link a:hover {
  color: #5C6268;
}
.comments h6.comment-reply-link:before {
  position: relative;
  top: 5px;
  color: #7C8A8D;
  content: "\e03a";
  font-size: 18px;
  font-family: theme;
  line-height: 18px;
}
.comments #reply-title {
  margin-bottom: 0px !important;
}
.comments #cancel-comment-reply-link {
  position: relative;
}
.comments .comment-notes {
  margin-bottom: 14px;
}
#commentform {
  position: relative;
  padding-bottom: 10px;
}
#commentform:after {
  display: block;
  clear: both;
  content: "";
}
#commentform .form-input {
  float: left;
  margin-bottom: 10px;
  width: 100%;
  background: none;
}
#commentform .form-input input {
  width: 100%;
  font-size: 14px;
  padding: 10px;
  box-shadow: none !important;
  font-weight: 200;
  transition: all .2s ease;
  border: solid 1px rgba(43,47,52,0.1);
  margin-top: 5px;
}
#commentform .form-input input:hover {
  -moz-box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05) !important;
  box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05) !important;
  border: solid 1px rgba(0,0,0,0.2);
}
#commentform .comment-form-comment textarea {
  width: 100%;
  height: 160px;
  font-size: 14px;
  padding: 10px;
  box-shadow: none !important;
  font-weight: 200;
  transition: all .2s ease;
  border: solid 1px rgba(43,47,52,0.1);
  margin-top: 5px;
}
#commentform .comment-form-comment textarea:hover {
  -moz-box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05) !important;
  box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05) !important;
  border: solid 1px rgba(0,0,0,0.2);
}
#commentform .form-submit {
  bottom: 0;
  height: auto;
  float: none;
  margin: 0px 0px 0px 20px;
}
#commentform #submit {
  font-size: 1em;
  font-weight: normal;
  display: inline-block;
  text-align: center;
  cursor: pointer;
  position: relative;
  z-index: 0;
  vertical-align: middle;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
  text-decoration: none;
  text-shadow: none;
  line-height: 1.15em;
  border-widht: 2px;
  padding: 0;
  text-align: center !important;
  background: #F0542D;
  color: #ffffff;
  padding: 0.8em 1.6em;
  color: #F0542D;
  padding: 0.9em 1.5em;
  border: 2px solid #F0542D;
  background: transparent;
}
#commentform #submit,
#commentform #submit span {
  transition: color .3s ease, border .3s ease, background .3s ease;
}
#commentform #submit span {
  display: inline-block;
  font-size: 1em;
  line-height: inherit;
  padding: .3em .4em;
  margin: 0 0;
  vertical-align: baseline;
}
#commentform #submit span.icon {
  font-size: 100%;
  vertical-align: bottom !important;
}
#commentform #submit span.icon.shortcode.inverted-colors {
  font-size: 100%;
  box-shadow: 0 1px 1px rgba(0,0,0,0.1) inset, 0 1px 1px rgba(255,255,255,0.2);
  text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}
#commentform #submit span.icon:first-child,
#commentform #submit span.icon:last-child {
  vertical-align: top;
  background: none;
}
#commentform #submit span.icon:first-child {
  padding: .5em 0 .5em .8em !important;
}
#commentform #submit span.icon:last-child {
  padding: .5em .8em .5em 0 !important;
}
#commentform #submit span.btext {
  position: relative;
  font-weight: 500;
  vertical-align: middle;
  padding: 0.7em 1.2em;
  letter-spacing: 1px;
}
#commentform #submit:hover,
#commentform #submit:hover span {
  text-decoration: none;
}
#commentform #submit span {
  color: #ffffff;
}
#commentform #submit:hover,
#commentform #submit:focus,
#commentform #submit:active {
  background: #7C8A8D;
}
#commentform #submit:hover,
#commentform #submit:hover span,
#commentform #submit:focus,
#commentform #submit:focus span,
#commentform #submit:active,
#commentform #submit:active span {
  color: #ffffff;
}
#commentform #submit:before {
  position: absolute;
  top: 50%;
  left: 0;
  content: "\e025";
  font-family: theme;
}
#commentform #submit:hover {
  background: #F0542D;
  color: #ffffff;
}
#commentform input[type="checkbox"] {
  vertical-align: middle;
}
#respond {
  padding: 10px;
}
.respond-box {
  background: none;
  margin-bottom: 0px;
  margin-top: 0px;
}
.respond-box .respond-box-title.sep-text {
  margin: 0px;
  height: auto;
  padding: 20px;
}
.respond-box .respond-box-title.sep-text .content {
  font: normal 24px/30px "Raleway";
  padding: 0 1em;
}
.respond-box .respond-box-title.sep-text .sep-text-line {
  border-top-width: 0;
  border-bottom: 0;
}
.comment-meta {
  color: #ffffff;
  font-size: 13px;
}
.comment-author {
  line-height: 1em !important;
}
.comment-author span {
  float: left;
  margin-top: 3px;
}
#cancel-comment-reply-link,
h6.comment-reply-link,
.comment-edit-link,
.comment-notes {
  font-size: 12px !important;
}
.comment-content {
  line-height: 1.4em;
}
body.page-template-guestbook-php #commentform .form-input {
  background: none;
}
body.page-template-guestbook-php #commentform .form-input.grid-1-2 {
  width: 50%;
}
body.page-template-guestbook-php #commentform .form-input.grid-1-1 {
  width: auto;
}
body.page-template-guestbook-php #commentform .comment-notes {
  float: right;
}
body.page-template-guestbook-php #commentform textarea {
  height: auto;
}
body.page-template-guestbook-php #commentform .form-submit {
  float: left;
  margin-right: 0;
  margin-left: 0;
  width: 100%;
  text-align: center;
}
body.page-template-guestbook-php #commentform #submit {
  font-size: 1em;
  font-weight: normal;
  display: inline-block;
  text-align: center;
  cursor: pointer;
  position: relative;
  z-index: 0;
  vertical-align: middle;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
  text-decoration: none;
  text-shadow: none;
  line-height: 1.15em;
  border-widht: 2px;
  padding: 0;
  text-align: center !important;
  background: #F0542D;
  color: #ffffff;
  padding: 0.8em 1.6em;
  color: #F0542D;
  padding: 0.9em 1.5em;
  border: 2px solid #F0542D;
  background: transparent;
}
body.page-template-guestbook-php #commentform #submit,
body.page-template-guestbook-php #commentform #submit span {
  transition: color .3s ease, border .3s ease, background .3s ease;
}
body.page-template-guestbook-php #commentform #submit span {
  display: inline-block;
  font-size: 1em;
  line-height: inherit;
  padding: .3em .4em;
  margin: 0 0;
  vertical-align: baseline;
}
body.page-template-guestbook-php #commentform #submit span.icon {
  font-size: 100%;
  vertical-align: bottom !important;
}
body.page-template-guestbook-php #commentform #submit span.icon.shortcode.inverted-colors {
  font-size: 100%;
  box-shadow: 0 1px 1px rgba(0,0,0,0.1) inset, 0 1px 1px rgba(255,255,255,0.2);
  text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}
body.page-template-guestbook-php #commentform #submit span.icon:first-child,
body.page-template-guestbook-php #commentform #submit span.icon:last-child {
  vertical-align: top;
  background: none;
}
body.page-template-guestbook-php #commentform #submit span.icon:first-child {
  padding: .5em 0 .5em .8em !important;
}
body.page-template-guestbook-php #commentform #submit span.icon:last-child {
  padding: .5em .8em .5em 0 !important;
}
body.page-template-guestbook-php #commentform #submit span.btext {
  position: relative;
  font-weight: 500;
  vertical-align: middle;
  padding: 0.7em 1.2em;
  letter-spacing: 1px;
}
body.page-template-guestbook-php #commentform #submit:hover,
body.page-template-guestbook-php #commentform #submit:hover span {
  text-decoration: none;
}
body.page-template-guestbook-php #commentform #submit span {
  color: #ffffff;
}
body.page-template-guestbook-php #commentform #submit:hover,
body.page-template-guestbook-php #commentform #submit:focus,
body.page-template-guestbook-php #commentform #submit:active {
  background: #7C8A8D;
}
body.page-template-guestbook-php #commentform #submit:hover,
body.page-template-guestbook-php #commentform #submit:hover span,
body.page-template-guestbook-php #commentform #submit:focus,
body.page-template-guestbook-php #commentform #submit:focus span,
body.page-template-guestbook-php #commentform #submit:active,
body.page-template-guestbook-php #commentform #submit:active span {
  color: #ffffff;
}
body.page-template-guestbook-php #commentform #submit:hover {
  background: #F0542D;
  color: #ffffff;
}
body.page-template-guestbook-php .comments .bypostauthor:hover {
  background: transparent;
}
body.page-template-guestbook-php .respond-box {
  margin-top: 0;
  margin-bottom: 60px;
  border: 0;
  background: #ffffff;
  box-shadow: 0 1px 3px 1px #EDEDED;
  -moz-box-shadow: 0px 1px 4px 2px rgba(43,47,52,0.1) !important;
  box-shadow: 0px 1px 4px 2px rgba(43,47,52,0.1) !important;
}
body.page-template-guestbook-php .respond-box,
body.page-template-guestbook-php .respond-box p {
  color: #2B2F34;
}
body.page-template-guestbook-php .respond-box a {
  color: #F0542D;
}
body.page-template-guestbook-php .comments-title {
  text-align: center;
  text-transform: uppercase;
  margin-bottom: 30px;
}
body.page-template-guestbook-php .comments-title a {
  color: #2B2F34;
}
body.page-template-guestbook-php .comment-time {
  text-transform: uppercase;
  display: block;
}
body.page-template-guestbook-php .comment-time:before {
  display: none;
}
body.page-template-guestbook-php .comments .content {
  font-size: 23px;
  color: #7C8A8D;
}
body.page-template-guestbook-php .comments .comment {
  clear: none;
  padding: 0 15px;
  margin: 20px 0;
  border-bottom: 0;
}
body.page-template-guestbook-php .comments .comment > .cbp-item-wrapper > .sep-text {
  margin: 0;
}
body.page-template-guestbook-php .comments .comment > .cbp-item-wrapper > .sep-text .sep-text-before,
body.page-template-guestbook-php .comments .comment > .cbp-item-wrapper > .sep-text .sep-text-after {
  vertical-align: top;
  padding-bottom: 5px;
}
body.page-template-guestbook-php .comments .comment .comment-inner {
  padding: 20px;
  border: 1px solid #EDEDED;
  border-top: 0;
  margin-top: -9px;
  text-align: center;
}
body.page-template-guestbook-php .comments .comment .comment-inner .comment-header {
  font-size: 24px;
  margin: 1em 0 1em 0;
}
#bbpress-forums p.bbp-topic-meta img.avatar,
#bbpress-forums ul.bbp-reply-revision-log img.avatar,
#bbpress-forums ul.bbp-topic-revision-log img.avatar,
#bbpress-forums div.bbp-template-notice img.avatar,
#bbpress-forums .widget_display_topics img.avatar,
#bbpress-forums .widget_display_replies img.avatar,
#bbpress-forums p.bbp-topic-meta img.avatar {
  display: inline-block;
  margin-bottom: 0 !important;
}
#bbpress-forums p.bbp-topic-meta img.avatar.avatar-14,
#bbpress-forums ul.bbp-reply-revision-log img.avatar.avatar-14,
#bbpress-forums ul.bbp-topic-revision-log img.avatar.avatar-14,
#bbpress-forums div.bbp-template-notice img.avatar.avatar-14,
#bbpress-forums .widget_display_topics img.avatar.avatar-14,
#bbpress-forums .widget_display_replies img.avatar.avatar-14,
#bbpress-forums p.bbp-topic-meta img.avatar.avatar-14 {
  display: none !important;
}
#bbpress-forums .bbp-topic-started-by img {
  display: none !important;
}
#bbpress-forums #bbp_search {
  width: 200px;
  margin-right: 10px;
}
#bbpress-forums #bbp-search-form {
  margin-bottom: 10px;
}
#bbpress-forums .bbp-forum-title {
  font: normal 24px/30px "Raleway";
}
#bbpress-forums .bbp-forum-info .bbp-forum-content,
#bbpress-forums p.bbp-topic-meta {
  font: normal 14px/20px "Raleway";
}
#bbpress-forums .bbp-breadcrumb p {
  margin: 0;
}
#bbpress-forums #subscription-toggle {
  float: right;
}
.tt_event_hours {
  margin: 0 -15px;
}
.tt_event_hours li {
  border-left-color: #F0542D;
  margin-left: 15px;
  margin-right: 15px;
}
.csscalc .tt_event_hours li {
  width: -webkit-calc(33.33333% - 30px);
  width: calc(33.33333% - 30px);
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.tt_event_hours li.event_hours_right {
  margin-right: 15px;
}
.timetable .row_gray {
  background: #EDEDED;
}
.fixed-header-box {
  position: relative;
  z-index: 10;
  margin: 0 auto;
  max-width: 1140px;
  transition: box-shadow .3s ease, background-color .3s ease, transform .3s ease-out;
  box-shadow: 0 2px 2px 0 rgba(0,0,0,0.04);
  will-change: transform;
}
body.full .fixed-header-box {
  max-width: none;
}
body.wpv-not-scrolled.sticky-header-type-half-over .fixed-header-box {
  border: none;
}
body.sticky-header-type-half-over.sticky-header.wpv-not-scrolled .fixed-header-box,
body.sticky-header-type-over.sticky-header.wpv-not-scrolled .fixed-header-box {
  box-shadow: none;
}
html.touch body.fixed-layout .fixed-header-box {
  top: .5px;
  z-index: 50000000000000;
}
html.touch body.fixed-layout.mfp-zoom-out-cur .fixed-header-box {
  z-index: 50;
}
.fixed-header-box .logo-wrapper {
  display: table-cell;
  vertical-align: middle;
  text-align: center;
}
.fixed-header-box .logo-wrapper .logo {
  text-decoration: none !important;
  line-height: 1;
  display: block;
  position: relative;
}
.fixed-header-box .logo-wrapper .logo img {
  clear: both;
  padding: 0;
  border: 0 !important;
  vertical-align: bottom;
}
.fixed-header-box .logo-wrapper .logo.text-logo {
  font: 600 20px/40px "Raleway";
  line-height: 30px;
}
.fixed-header-box .logo-wrapper .logo.text-logo,
.fixed-header-box .logo-wrapper .logo.text-logo:hover {
  color: #F0542D;
}
.ie9 .fixed-header-box .logo-wrapper .logo img {
  position: relative;
  z-index: 3;
}
.fixed-header-box .logo-wrapper .logo-tagline {
  font: bold 10px/11px "Arial";
  display: block;
  padding-top: 5px;
  color: #2B2F34;
}
.header-content-wrapper {
  background-repeat: no-repeat;
  background-position: center top;
  background-attachment: scroll;
  background-color: #ffffff;
  -webkit-background-size: auto;
  -moz-background-size: auto;
  background-size: auto;
  margin-top: 0;
  transition: background .3s ease;
}
body.sticky-header-type-over.sticky-header.wpv-not-scrolled .header-content-wrapper {
  background-color: rgba(255,255,255,0);
}
body.sticky-header-type-half-over.sticky-header.wpv-not-scrolled .header-content-wrapper.second-row {
  background: rgba(54,67,82,0.2);
}
header.main-header {
  transition: background .3s ease;
  padding: 0;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
body.sticky-header.wpv-scrolled header.main-header,
body:not(.sticky-header-type-half-over):not(.sticky-header) header.main-header,
body.sticky-header-type-half-over header.main-header .first-row {
  background-repeat: no-repeat;
  background-position: center top;
  background-attachment: scroll;
  background-color: #ffffff;
  -webkit-background-size: auto;
  -moz-background-size: auto;
  background-size: auto;
}
body.sticky-header.wpv-scrolled header.main-header.layout-standard .second-row,
body.sticky-header.wpv-scrolled header.main-header.layout-logo-text-menu .second-row,
body:not(.sticky-header-type-half-over):not(.sticky-header) header.main-header.layout-standard .second-row,
body:not(.sticky-header-type-half-over):not(.sticky-header) header.main-header.layout-logo-text-menu .second-row,
body.sticky-header-type-half-over header.main-header .first-row.layout-standard .second-row,
body.sticky-header-type-half-over header.main-header .first-row.layout-logo-text-menu .second-row {
  background-repeat: repeat-x;
  background-position: center top;
  background-attachment: scroll;
  background-color: #ffffff;
  -webkit-background-size: auto;
  -moz-background-size: auto;
  background-size: auto;
}
body:not(.sticky-header-type-over) header.main-header.layout-standard .second-row,
body:not(.sticky-header-type-over) header.main-header.layout-logo-text-menu .second-row {
  background-repeat: repeat-x;
  background-position: center top;
  background-attachment: scroll;
  background-color: #ffffff;
  -webkit-background-size: auto;
  -moz-background-size: auto;
  background-size: auto;
}
body.sticky-header-type-over.sticky-header.wpv-not-scrolled header.main-header.layout-standard .second-row,
body.sticky-header-type-over.sticky-header.wpv-not-scrolled header.main-header.layout-logo-text-menu .second-row {
  border-top-color: rgba(237,237,237,0.002);
}
header.main-header .header-padding {
  padding: 0 60px;
  box-sizing: border-box;
}
header.main-header .header-padding.limit-wrapper {
  max-width: 1260px;
}
header.main-header .first-row {
  display: table;
  width: 100%;
  height: 91px;
  box-sizing: border-box;
}
body.boxed header.main-header .first-row {
  box-sizing: border-box;
}
header.main-header .first-row .alternative-logo {
  position: absolute;
  top: 0;
  left: 0;
  opacity: 0;
}
body.sticky-header-type-over.sticky-header.wpv-not-scrolled header.main-header .first-row .normal-logo {
  opacity: 0;
}
body.sticky-header-type-over.sticky-header.wpv-not-scrolled header.main-header .first-row .alternative-logo {
  opacity: 1;
}
header.main-header .second-row {
  clear: both;
  min-height: 49px;
  width: 100%;
  border-top: solid 1px rgba(43,47,52,0.1);
}
header.main-header .second-row .second-row-columns {
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  position: relative;
  display: table;
  width: 100%;
}
header.main-header .header-left {
  display: table-cell;
  padding: 0;
  min-width: 160px;
  vertical-align: middle;
  white-space: nowrap;
}
header.main-header .header-center {
  display: table-cell;
  width: 100%;
  vertical-align: middle;
  text-align: center;
  filter: none;
  padding: 0px;
  vertical-align: bottom;
}
header.main-header .header-center:after {
  display: block;
  clear: both;
  content: "";
}
header.main-header .header-center #megaMenu #megaMenuToggle {
  position: relative;
  padding-right: 30px;
}
header.main-header .header-center #megaMenu #megaMenuToggle .megaMenuToggle-icon {
  position: absolute;
  top: 50%;
  right: 10px;
  margin-top: 4px;
}
header.main-header .header-right {
  position: relative;
  display: table-cell;
  padding: 0;
  vertical-align: middle;
  text-align: right;
}
body.sticky-header-type-over.sticky-header.wpv-not-scrolled header.main-header .vamtam-cart-dropdown-link .icon,
body.sticky-header-type-half-over.sticky-header.wpv-not-scrolled header.main-header .vamtam-cart-dropdown-link .icon {
  color: #ffffff !important;
}
body.sticky-header-type-over.sticky-header.wpv-not-scrolled header.main-header .vamtam-cart-dropdown-link .products.cart-emtpy,
body.sticky-header-type-half-over.sticky-header.wpv-not-scrolled header.main-header .vamtam-cart-dropdown-link .products.cart-emtpy {
  background: #ffffff !important;
  color: #808080 !important;
}
header.main-header #header-text {
  padding: 10px 0;
  white-space: nowrap;
  transition: color .3s;
  font-size: 11px;
}
header.main-header #header-text h4 {
  margin: 0;
  line-height: 10px;
}
header.main-header #header-text h4 a {
  font-size: 16px;
  font-weight: 600;
  color: #F0542D;
}
header.main-header #header-text h4 a:hover {
  color: #7C8A8D;
}
body.sticky-header-type-over.sticky-header.wpv-not-scrolled header.main-header #header-text,
body.sticky-header-type-over.sticky-header.wpv-not-scrolled header.main-header #header-text p,
body.sticky-header-type-over.sticky-header.wpv-not-scrolled header.main-header #header-text .icon {
  color: #ffffff !important;
}
header.main-header button.header-search {
  border: 0;
  background: none;
  color: #D8D8D8;
  font-size: 20px;
}
body.sticky-header-type-over.sticky-header.wpv-not-scrolled header.main-header button.header-search,
body.sticky-header-type-half-over.sticky-header.wpv-not-scrolled header.main-header button.header-search {
  color: #ffffff;
}
header.main-header button.header-search:active {
  -webkit-transform: translate(0,3px);
  -ms-transform: translate(0,3px);
  transform: translate(0,3px);
}
header.main-header button.header-search:hover {
  color: #F0542D;
}
header.main-header .search-wrapper:not(:last-child) {
  padding-right: 10px;
}
body.wpv-not-scrolled:not(.sticky-header-type-over) header.main-header {
  border: 0;
}
header.main-header.layout-standard .logo {
  height: auto;
  display: inline-block;
}
header.main-header.layout-standard .first-row.header-padding {
  box-sizing: border-box;
}
header.main-header.layout-standard .header-center:not(:first-child):last-child {
  padding-right: 160px;
}
body.header-cart-visible header.main-header.layout-standard .header-center:not(:first-child) {
  padding-right: 70px;
}
body.header-cart-visible header.main-header.layout-standard .header-center.first-child {
  padding-right: 90px;
}
header.main-header.layout-standard body.sticky-header-type-half-over.sticky-header.wpv-not-scrolled #header-text,
header.main-header.layout-standard body.sticky-header-type-half-over.sticky-header.wpv-not-scrolled #header-text .icon {
  color: inherit !important;
}
header.main-header.layout-logo-menu .header-contents {
  display: table;
}
header.main-header.layout-logo-menu .first-row {
  display: table-cell;
  width: auto;
  height: auto;
  background: transparent;
  vertical-align: middle;
  transition: border-radius .3s;
}
body.sticky-header-type-half-over.sticky-header.wpv-not-scrolled header.main-header.layout-logo-menu .first-row,
body.sticky-header-type-over.sticky-header.wpv-not-scrolled header.main-header.layout-logo-menu .first-row {
  border-radius: 5px 0 0 5px;
}
header.main-header.layout-logo-menu .first-row .logo-wrapper {
  display: block;
  min-height: 140px;
  position: relative;
  text-align: left;
}
header.main-header.layout-logo-menu .first-row .logo-wrapper.loaded img {
  transition: all .3s ease;
}
header.main-header.layout-logo-menu .first-row .logo-wrapper.scrolled {
  min-height: 0;
}
header.main-header.layout-logo-menu .first-row .logo-wrapper:not( .scrolled ).with-text-logo {
  display: flex;
  flex-direction: column;
  justify-content: center;
}
header.main-header.layout-logo-menu .first-row .logo-tagline {
  display: none;
}
header.main-header.layout-logo-menu .second-row {
  display: table-cell;
  width: 100%;
  background: transparent;
  vertical-align: middle;
  text-align: right;
}
header.main-header.layout-logo-menu .second-row #menus {
  padding: 9.5px 0;
  margin-right: -12px;
}
header.main-header.layout-logo-menu .second-row.has-search {
  padding-right: 5px;
}
header.main-header.layout-logo-menu .search-wrapper,
header.main-header.layout-logo-menu #header-text {
  display: table-cell;
  vertical-align: middle;
  padding-left: 5px;
}
body.sticky-header-type-over.sticky-header header.main-header.layout-logo-menu .search-wrapper:last-child,
body.sticky-header-type-over.sticky-header header.main-header.layout-logo-menu #header-text:last-child {
  padding-right: 2px;
}
header.main-header.layout-logo-text-menu .first-row > .first-row-wrapper {
  height: 91px;
}
header.main-header.layout-logo-text-menu .first-row .first-row-right-inner {
  display: table;
  width: 100%;
}
header.main-header.layout-logo-text-menu .first-row #header-text,
header.main-header.layout-logo-text-menu .first-row .first-row-left,
header.main-header.layout-logo-text-menu .first-row .first-row-right {
  display: table-cell;
  vertical-align: middle;
}
header.main-header.layout-logo-text-menu .first-row .first-row-left,
header.main-header.layout-logo-text-menu .first-row .first-row-right {
  height: 91px;
}
header.main-header.layout-logo-text-menu .first-row .first-row-right {
  width: 100%;
  text-align: right;
}
header.main-header.layout-logo-text-menu .first-row #header-text {
  padding: 0;
  width: 100%;
  padding: 10px 0 10px 40px;
  box-sizing: border-box;
  text-align: right;
  margin-left: auto;
  display: flex;
  justify-content: flex-end;
}
header.main-header.layout-logo-text-menu .first-row #header-text > div:first-child:not(:last-child) {
  margin-right: 30px;
}
header.main-header.layout-logo-text-menu .first-row #header-text p {
  display: inline-block;
  padding-left: 10px;
  text-align: left;
  font-size: 1em;
}
header.main-header.layout-logo-text-menu .first-row #header-text p strong {
  font-weight: 500;
  font-size: 1.2em;
}
header.main-header.layout-logo-text-menu .second-row #main-menu .menu {
  text-align: left;
}
header.main-header.layout-logo-text-menu .second-row .header-center {
  padding-right: 0;
  padding-left: 0;
}
body.header-cart-visible header.main-header.layout-logo-text-menu .second-row .header-center {
  padding-right: 60px;
}
header.main-header.layout-logo-text-menu .second-row .search-wrapper {
  display: table-cell;
  vertical-align: middle;
  padding-left: 10px;
}
#top-nav-sidebar .widget {
  display: inline-block;
  margin: 0 30px 0 0;
  vertical-align: middle;
}
#top-nav-sidebar .widget:last-child {
  margin-right: 0;
}
#top-nav-sidebar .widget-title {
  display: none;
}
#top-nav-sidebar .wpv_icon_link .content {
  display: none !important;
}
.header-middle {
  position: relative;
  z-index: 10;
  margin-bottom: 0;
}
.header-middle > h4 {
  padding: 20px 0 0;
}
body.boxed .header-middle > .limit-wrapper > .row,
body.boxed .header-middle > .row {
  margin: 0;
}
#header-sidebars {
  position: relative;
  z-index: 5;
  padding: 5px 0 0;
}
#header-sidebars > .row > aside.cell-1-2 {
  position: relative;
  padding: 0;
  float: left;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  display: block;
  padding: 0 15px;
  width: 50%;
}
#header-sidebars > .row > aside.cell-1-3 {
  position: relative;
  padding: 0;
  float: left;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  display: block;
  padding: 0 15px;
  width: 33.33333333%;
}
#header-sidebars > .row > aside.cell-1-4 {
  position: relative;
  padding: 0;
  float: left;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  display: block;
  padding: 0 15px;
  width: 25%;
}
#header-sidebars > .row > aside.cell-1-5 {
  position: relative;
  padding: 0;
  float: left;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  display: block;
  padding: 0 15px;
  width: 20%;
}
#header-sidebars > .row > aside.cell-1-6 {
  position: relative;
  padding: 0;
  float: left;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  display: block;
  padding: 0 15px;
  width: 16.66666666%;
}
#header-sidebars > .row > aside.cell-2-3 {
  position: relative;
  padding: 0;
  float: left;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  display: block;
  padding: 0 15px;
  width: 66.66666666%;
}
#header-sidebars > .row > aside.cell-2-5 {
  position: relative;
  padding: 0;
  float: left;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  display: block;
  padding: 0 15px;
  width: 40%;
}
#header-sidebars > .row > aside.cell-3-4 {
  position: relative;
  padding: 0;
  float: left;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  display: block;
  padding: 0 15px;
  width: 75%;
}
#header-sidebars > .row > aside.cell-3-5 {
  position: relative;
  padding: 0;
  float: left;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  display: block;
  padding: 0 15px;
  width: 60%;
}
#header-sidebars > .row > aside.cell-4-5 {
  position: relative;
  padding: 0;
  float: left;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  display: block;
  padding: 0 15px;
  width: 80%;
}
#header-sidebars > .row > aside.cell-5-6 {
  position: relative;
  padding: 0;
  float: left;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  display: block;
  padding: 0 15px;
  width: 83.33333333%;
}
#header-sidebars > .row > aside.last {
  margin: 0;
}
#wpv-overlay-search {
  margin: auto;
  max-width: 550px;
  font-size: 50px;
}
#wpv-overlay-search input[type="text"] {
  width: 475px;
  height: 60px;
  max-width: calc(100% - 100px);
  border: 0;
  border-bottom: 1px solid #ffffff;
  background: transparent;
  color: #ffffff;
  margin-bottom: 0;
}
#wpv-overlay-search input[type="text"]::-webkit-input-placeholder {
  color: #ffffff;
}
#wpv-overlay-search input[type="text"]:-ms-input-placeholder {
  color: #ffffff;
}
#wpv-overlay-search input[type="text"]::placeholder {
  color: #ffffff;
}
#wpv-overlay-search button[type="submit"] {
  width: 60px;
  height: 60px;
  border: 0;
  background: none;
  color: #ffffff;
  vertical-align: bottom;
  padding: 0;
}
body > #wpv-overlay-search {
  display: none;
}
.meta-header {
  background-repeat: no-repeat;
  background-position: center top;
  background-attachment: scroll;
  background-color: #ffffff;
  -webkit-background-size: auto;
  -moz-background-size: auto;
  background-size: auto;
  padding-bottom: 0.035px;
}
.meta-header > .limit-wrapper {
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
body.bosed .meta-header > .limit-wrapper {
  padding: 0;
}
.has-breadcrumbs .meta-header > .limit-wrapper,
.has-share-menu .meta-header > .limit-wrapper {
  min-height: 30px;
}
body.events-archive .meta-header {
  background-repeat: no-repeat;
  background-position: center top;
  background-attachment: fixed;
  background-color: #4f4f4f;
  -webkit-background-size: auto;
  -moz-background-size: auto;
  background-size: auto;
}
body.events-archive .meta-header h1 {
  color: #ffffff;
}
.page-header .page-header-content {
  width: 100%;
  text-align: left;
  position: relative;
}
.page-header h1 {
  padding: 0 !important;
  width: 100%;
  margin: 0;
  text-align: center;
  position: relative;
  color: #4d4d4d;
}
.page-header .title {
  padding: 90px 0 40px 0;
  display: inline-block;
}
.page-header .desc {
  display: block;
  font: normal 14px Arial;
  text-align: center;
  margin-top: 10px;
}
.page-header.has-buttons h1 .title {
  padding-bottom: 10px;
}
.page-header .post-siblings {
  display: table;
  margin: 0 auto 20px auto;
}
.page-header .post-siblings a span.icon {
  color: #e0e0e0;
  font-size: 22px;
}
.page-header .post-siblings a span.icon:hover {
  background: none;
  color: #F0542D;
}
.page-header .post-siblings a[rel="prev"] span.icon,
.page-header .post-siblings a[rel="next"] span.icon {
  font-size: 25px;
}
.page-header .all-items,
.page-header a[rel="prev"],
.page-header a[rel="next"],
.page-header .portfolio-slider-prev,
.page-header .portfolio-slider-next,
.page-header .portfolio-slider-close {
  display: table-cell;
  vertical-align: middle;
  text-align: center;
  padding: 10px 5px;
}
.page-header .all-items b,
.page-header a[rel="prev"] b,
.page-header a[rel="next"] b,
.page-header .portfolio-slider-prev b,
.page-header .portfolio-slider-next b,
.page-header .portfolio-slider-close b {
  display: none;
}
.page-header .all-items .icon,
.page-header a[rel="prev"] .icon,
.page-header a[rel="next"] .icon,
.page-header .portfolio-slider-prev .icon,
.page-header .portfolio-slider-next .icon,
.page-header .portfolio-slider-close .icon {
  font-size: 18px;
  line-height: normal;
  text-align: center;
  padding: 5px;
  background: transparent;
  color: #4A4F55;
  border-radius: 3px;
  background-clip: padding-box;
  content: "0";
}
.page-header .all-items .icon:hover,
.page-header a[rel="prev"] .icon:hover,
.page-header a[rel="next"] .icon:hover,
.page-header .portfolio-slider-prev .icon:hover,
.page-header .portfolio-slider-next .icon:hover,
.page-header .portfolio-slider-close .icon:hover {
  background: #4A4F55;
  color: #364352;
}
.page-header .all-items.loading,
.page-header a[rel="prev"].loading,
.page-header a[rel="next"].loading,
.page-header .portfolio-slider-prev.loading,
.page-header .portfolio-slider-next.loading,
.page-header .portfolio-slider-close.loading {
  background: none;
}
.page-header .all-items.loading .icon,
.page-header a[rel="prev"].loading .icon,
.page-header a[rel="next"].loading .icon,
.page-header .portfolio-slider-prev.loading .icon,
.page-header .portfolio-slider-next.loading .icon,
.page-header .portfolio-slider-close.loading .icon {
  background: url(../wpv_theme/assets/images/loader.gif) center center no-repeat;
  background-image: url(../wpv_theme/assets/images/loader.gif), url(../wpv_theme/assets/images/loader_bg.png);
  background-position: center center, center center;
  color: transparent !important;
}
#header-breadcrumbs {
  text-align: left;
  margin-top: 0;
  padding: 10px 0 0 60px;
  color: #ffffff;
}
#header-breadcrumbs a {
  color: #F0542D;
}
#header-breadcrumbs:after {
  content: "";
  width: 70px;
  border-bottom: 1px solid #EDEDED;
  position: absolute;
  top: 34px;
  left: 60px;
  height: 1px;
}
#menus {
  position: relative;
  z-index: 210;
  min-height: 31px;
}
#main-menu .menu {
  position: relative;
  min-height: 31px;
  font-size: 0;
}
#main-menu .menu .menu-item {
  position: relative;
  list-style: none;
  cursor: pointer;
}
#main-menu .menu .menu-item:hover > .sub-menu-wrapper > .sub-menu {
  display: block;
  box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.12);
  border-radius: 0;
}
#main-menu .menu .menu-item a {
  display: block;
  text-decoration: none;
  padding: .3em .6em;
  transition: color .4s;
}
#main-menu .menu .menu-item a strong {
  font-weight: normal;
}
#main-menu .menu .menu-item.home > a {
  width: 16px;
  text-align: left;
  text-indent: -6000px;
  position: relative;
}
#main-menu .menu .menu-item.home > a:before {
  position: absolute;
  top: 4px;
  left: 5px;
  z-index: 5;
  width: 16px;
  height: 16px;
  content: "\e003";
  text-indent: 0 !important;
  font-size: 16px;
  font-family: icomoon;
}
#main-menu .menu .sub-menu {
  position: absolute;
  top: 0;
  z-index: 200;
  display: none;
  margin: 0 auto auto 0;
  width: 190px;
  text-align: left;
  background: #ffffff;
  padding: 0;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
#main-menu .menu .sub-menu.invert-position {
  left: auto;
  right: 0;
}
#main-menu .menu .sub-menu .menu-item {
  padding: 0;
  transition: all .4s;
}
#main-menu .menu .sub-menu .menu-item > a {
  padding: 13px 13px;
  color: #000000;
  font: 600 "Raleway" 11px;
  text-transform: none;
  transition: all .3s;
  border: none;
}
#main-menu .menu .sub-menu .menu-item:last-child {
  padding-bottom: 0;
}
#main-menu .menu .sub-menu .menu-item.current-menu-parent,
#main-menu .menu .sub-menu .menu-item.current-menu-item,
#main-menu .menu .sub-menu .menu-item.current-menu-ancestor,
#main-menu .menu .sub-menu .menu-item.current-menu-ancestor,
#main-menu .menu .sub-menu .menu-item:hover {
  background: #F6F6F6;
  border-radius: 0px;
}
#main-menu .menu .sub-menu .menu-item.current-menu-parent > a,
#main-menu .menu .sub-menu .menu-item.current-menu-item > a,
#main-menu .menu .sub-menu .menu-item.current-menu-ancestor > a,
#main-menu .menu .sub-menu .menu-item.current-menu-ancestor > a,
#main-menu .menu .sub-menu .menu-item:hover > a {
  text-decoration: none;
  color: #F0542D;
  border-left-color: #F0542D;
  border-bottom-color: #EDEDED;
  padding: 13px;
}
body.sticky-header-type-over.sticky-header.wpv-not-scrolled #main-menu .menu > .menu-item:not(.current-menu-parent):not(.current-menu-item):not(.current-menu-ancestor):not(.current-menu-ancestor):not(:hover) > a,
body.sticky-header-type-over.sticky-header.wpv-not-scrolled #main-menu .menu > .menu-item:not(.current-menu-parent):not(.current-menu-item):not(.current-menu-ancestor):not(.current-menu-ancestor):not(:hover) > a:visited,
body.sticky-header-type-half-over.sticky-header.wpv-not-scrolled .layout-standard #main-menu .menu > .menu-item:not(.current-menu-parent):not(.current-menu-item):not(.current-menu-ancestor):not(.current-menu-ancestor):not(:hover) > a,
body.sticky-header-type-half-over.sticky-header.wpv-not-scrolled .layout-standard #main-menu .menu > .menu-item:not(.current-menu-parent):not(.current-menu-item):not(.current-menu-ancestor):not(.current-menu-ancestor):not(:hover) > a:visited,
body.sticky-header-type-half-over.sticky-header.wpv-not-scrolled .layout-logo-text-menu #main-menu .menu > .menu-item:not(.current-menu-parent):not(.current-menu-item):not(.current-menu-ancestor):not(.current-menu-ancestor):not(:hover) > a,
body.sticky-header-type-half-over.sticky-header.wpv-not-scrolled .layout-logo-text-menu #main-menu .menu > .menu-item:not(.current-menu-parent):not(.current-menu-item):not(.current-menu-ancestor):not(.current-menu-ancestor):not(:hover) > a:visited {
  color: #ffffff;
}
#main-menu .menu > .menu-item {
  padding: 3px 15px 0 15px;
  background: url("data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7");
  display: inline-block;
}
#main-menu .menu > .menu-item > a,
#main-menu .menu > .menu-item > a:visited {
  color: #000000;
  font: 600 13px/16px "Raleway";
  border-bottom: solid 3px transparent;
  padding: 1em 0;
  letter-spacing: 0.05em;
  transition-duration: .3s;
  transition-property: color, border-bottom-color;
}
#main-menu .menu > .menu-item.current-menu-parent > a,
#main-menu .menu > .menu-item.current-menu-item > a,
#main-menu .menu > .menu-item.current-menu-ancestor > a,
#main-menu .menu > .menu-item.current-menu-ancestor > a,
#main-menu .menu > .menu-item:hover > a {
  background-color: transparent;
  color: #F0542D;
  text-decoration: none;
  border-bottom: solid 3px #F0542D;
  padding-bottom: 1em;
}
#main-menu .menu > .menu-item:hover > .sub-menu-wrapper {
  padding-top: 14px;
  position: absolute;
  top: 100%;
  left: 10%;
  width: 100%;
  z-index: 10000;
}
#main-menu .menu > .menu-item:hover > .sub-menu-wrapper > .sub-menu {
  top: 0;
}
#main-menu .menu > .menu-item > .sub-menu-wrapper > .sub-menu {
  left: 0;
  margin: 0 auto auto 0;
  transition: all .3s;
}
#main-menu .menu > .menu-item > .sub-menu-wrapper > .sub-menu .menu-item-has-children > a:after {
  position: absolute;
  top: 50%;
  top: calc(48%);
  right: 10px;
  line-height: 0;
  font-size: 12px;
}
#main-menu .menu > .menu-item > .sub-menu-wrapper > .sub-menu .sub-menu {
  left: 100%;
  top: 0px;
}
#main-menu .menu > .menu-item > .sub-menu-wrapper > .sub-menu .sub-menu.invert-position {
  left: auto;
  right: 100%;
}
#top-nav-wrapper {
  position: relative;
  z-index: 6666;
  background: #ffffff;
  border: none;
}
.top-nav strong {
  font-size: inherit;
  font-weight: inherit;
  color: #2B2F34;
  font-weight: 700;
}
.top-nav {
  background-repeat: no-repeat;
  background-position: center top;
  background-attachment: scroll;
  background-color: #7c8a8d;
  -webkit-background-size: auto;
  -moz-background-size: auto;
  background-size: auto;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  margin: 0 auto;
  white-space: nowrap;
}
.top-nav,
.top-nav p {
  color: #CCD0D0;
}
.top-nav,
.top-nav p,
.top-nav div,
.top-nav li,
.top-nav a {
  font-size: 12px;
}
.top-nav > .top-nav-inner > .row {
  padding: 7px 0;
}
.top-nav > .top-nav-inner > .row > .row > div {
  vertical-align: top;
}
.top-nav .grid-1-2 {
  min-height: 1px;
}
.top-nav .grid-1-2:last-child {
  text-align: right;
}
.top-nav .menu-wrapper {
  position: relative;
  height: 17px;
}
.top-nav a {
  color: #D4D7D7;
}
.top-nav a:hover {
  color: #ffffff;
}
.top-nav a:hover .icon {
  color: #ffffff !important;
}
.top-nav ul > li.current_page_item > a,
.top-nav ul > li.current-menu-item > a,
.top-nav ul > li.current-menu-parent > a,
.top-nav ul > li.current-menu-ancestor > a {
  color: #ffffff;
}
.top-nav .menu,
.top-nav .menu li {
  display: inline-block;
  margin: 0;
  padding: 0;
}
.top-nav .menu {
  height: 20px;
  margin: 0 -15px;
}
.top-nav .menu > li.menu-item-has-children a:first-child {
  position: relative;
}
.top-nav .menu > li.menu-item-has-children:hover {
  height: 45px;
}
.top-nav .menu > li.menu-item-has-children:hover > .sub-menu {
  display: block;
}
.top-nav .menu > li > a {
  padding: 0 13px;
}
.top-nav .menu > li a {
  font-size: 11px;
  line-height: 1.6em;
}
.top-nav .menu li {
  position: relative;
}
.top-nav .menu li .sub-menu {
  position: absolute;
  top: 30px;
  display: none;
  margin: 0 auto auto 0;
  width: 190px;
  text-align: left;
  box-shadow: 0 2px 4px 2px rgba(0,0,0,0.09);
  background: #ffffff;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.top-nav .menu li .sub-menu.invert-position {
  left: auto;
  right: 0;
}
.top-nav .menu li .sub-menu .sub-menu.invert-position {
  right: 100%;
}
.top-nav .menu li .sub-menu .menu-item {
  display: block;
}
.top-nav .menu li .sub-menu .menu-item > a {
  display: block;
  padding: 11px 13px;
  color: #000000;
  border-bottom: 1px solid #EDEDED;
}
.top-nav .menu li .sub-menu .menu-item:last-child {
  padding-bottom: 0;
}
.top-nav .menu li .sub-menu .menu-item.current-menu-parent,
.top-nav .menu li .sub-menu .menu-item.current-menu-item,
.top-nav .menu li .sub-menu .menu-item.current-menu-ancestor,
.top-nav .menu li .sub-menu .menu-item.current-menu-ancestor,
.top-nav .menu li .sub-menu .menu-item:hover {
  background: #F6F6F6;
  transition: all .4s;
  border-radius: 1px;
}
.top-nav .menu li .sub-menu .menu-item.current-menu-parent > a,
.top-nav .menu li .sub-menu .menu-item.current-menu-item > a,
.top-nav .menu li .sub-menu .menu-item.current-menu-ancestor > a,
.top-nav .menu li .sub-menu .menu-item.current-menu-ancestor > a,
.top-nav .menu li .sub-menu .menu-item:hover > a {
  text-decoration: none;
  color: #F0542D;
  border-bottom-color: #F0542D;
  transition: all .4s;
}
#top-nav-social > a {
  display: inline-block;
  width: 1.65em;
  height: 1.65em;
  text-align: center;
  vertical-align: middle;
  border: none;
  border-radius: 0;
  font-size: 15px;
  margin: 0px;
}
#top-nav-social > a,
#top-nav-social > a .icon {
  line-height: 1.65em;
}
#top-nav-social > a:hover {
  background: #ffffff;
  border-color: none;
}
#top-nav-social > a:hover .icon.shortcode.use-hover {
  color: #F0542D !important;
}
#top-nav-text .icon.shortcode {
  vertical-align: middle;
}
header.main-header .sub-menu {
  display: none;
}
.mp-menu,
#mp-menu-trigger {
  display: none;
}
body.full-bg-slider #mp-pusher,
body.full-bg-slider #mp-scroller,
body.full-bg-slider #page {
  height: 100%;
}
::selection {
  color: #ffffff;
  background: #F0542D;
}
.vamtam-add-shadow {
  box-shadow: 0 1px 3px 1px #EDEDED;
  padding-bottom: 0px !important;
}
html {
  background-repeat: repeat;
  background-position: center top;
  background-attachment: fixed;
  background-color: #EDEDED;
  -webkit-background-size: auto;
  -moz-background-size: auto;
  background-size: auto;
}
#wpadminbar {
  position: fixed;
}
.shortcode-preview #wpadminbar {
  top: -28px !important;
  overflow: hidden;
}
.wpv-main {
  background-repeat: no-repeat;
  background-position: center top;
  background-attachment: fixed;
  background-color: #ffffff;
  -webkit-background-size: auto;
  -moz-background-size: auto;
  background-size: auto;
}
.wpv-main.layout-left-right article,
.wpv-main.layout-left-only article,
.wpv-main.layout-right-only article {
  position: relative;
  float: left;
}
.wpv-main.layout-left-right article > .page-content,
.wpv-main.layout-left-only article > .page-content,
.wpv-main.layout-right-only article > .page-content {
  position: relative;
  z-index: 1;
}
body:not(.page-vertical-padding-none):not(.page-vertical-padding-bottom-only) #sub-header.has-background + .wpv-main {
  padding-top: 40px;
}
.limit-wrapper {
  z-index: 555;
  display: block;
  float: none;
  margin: auto;
  min-width: 290px;
  min-height: 100%;
  max-width: 1140px;
  width: auto;
  -ms-zoom: 1;
}
.limit-wrapper > div {
  position: relative;
}
#page {
  position: relative;
  margin-right: auto;
  margin-left: auto;
  min-width: 1140px;
  max-width: 1140px;
  width: auto;
  height: 100%;
}
#page .full {
  max-width: 100%;
}
body.responsive-layout #page {
  min-width: 290px;
}
.no-boxshadow #page {
  box-sizing: border-box;
  border-right: 1px solid #EDEDED;
  border-left: 1px solid #EDEDED;
}
body.full #page {
  max-width: none;
  border: none;
  box-shadow: none;
}
body.fast-slider #page {
  border: none;
  box-shadow: none;
}
#page .boxed-layout {
  position: relative;
  z-index: 0;
  margin: auto;
  max-width: 1140px;
  width: 100%;
}
#page .boxed-layout #main-content {
  position: relative;
}
body.full #page {
  overflow: hidden;
  max-width: 100%;
}
body.full #page .boxed-layout {
  max-width: 100%;
}
.single-product.layout-right-only .right {
  padding-top: 0;
}
.share-btns {
  margin: 0;
  text-align: center;
}
.page-wrapper {
  position: relative;
}
.no-header-sidebars.no-page-header .page-wrapper {
  padding-top: 60px;
}
body.page-vertical-padding-bottom-only.no-header-sidebars.no-page-header .page-wrapper,
body.page-vertical-padding-none.no-header-sidebars.no-page-header .page-wrapper {
  padding-top: 0.035px;
}
.page-wrapper > aside.left {
  padding-right: 20px;
  width: 25%;
}
body.boxed .page-wrapper > aside.left {
  padding-left: 60px;
}
.page-wrapper > aside.right {
  margin-left: 20px;
  padding-left: 20px;
  width: 25%;
}
body.boxed .page-wrapper > aside.right {
  padding-right: 60px;
}
.page-wrapper > aside.left,
.page-wrapper > aside.right {
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  float: left;
  margin: 0 !important;
  min-height: 1px;
}
.page-wrapper > aside.left section.widget a,
.page-wrapper > aside.right section.widget a {
  color: #F0542D;
  transition: all .2s ease;
}
.page-wrapper > aside.left section.widget a:hover,
.page-wrapper > aside.right section.widget a:hover {
  color: #2B2F34;
  border-color: #EDEDED;
}
.page-wrapper > div,
.page-wrapper > article {
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  margin-top: -1px;
  padding: 1px 0 45px 0;
}
body.page-vertical-padding-top-only .page-wrapper > div,
body.page-vertical-padding-none .page-wrapper > div,
body.page-vertical-padding-top-only .page-wrapper > article,
body.page-vertical-padding-none .page-wrapper > article {
  padding-bottom: 0.035px;
}
body.vamtam-limit-wrapper.boxed .page-wrapper > div,
body.vamtam-limit-wrapper.boxed .page-wrapper > article {
  padding-left: 60px;
  padding-right: 60px;
}
body.full .page-wrapper > div.left-only,
body.full .page-wrapper > div.left-right,
body.full .page-wrapper > article.left-only,
body.full .page-wrapper > article.left-right {
  padding-left: 60px;
}
body.full .page-wrapper > div.right-only,
body.full .page-wrapper > div.left-right,
body.full .page-wrapper > article.right-only,
body.full .page-wrapper > article.left-right {
  padding-right: 60px;
}
.page-wrapper > div.right-only,
.page-wrapper > article.right-only {
  width: 75%;
}
body.wide .page-wrapper > div.right-only,
body.wide .page-wrapper > article.right-only {
  padding-left: 0;
}
.page-wrapper > div.left-only,
.page-wrapper > article.left-only {
  width: 75%;
}
body.wide .page-wrapper > div.left-only,
body.wide .page-wrapper > article.left-only {
  padding-right: 0;
}
.page-wrapper > div.left-right,
.page-wrapper > article.left-right {
  width: 50%;
  background: #ffffff;
}
body.page-template-page-blank-php .page-wrapper > div,
body.page-template-page-blank-php .page-wrapper > article {
  padding-bottom: 0;
}
body.no-page-header.no-breadcrumbs #sub-header.layout-left-only .meta-header .meta-header-inside,
body.no-page-header.no-breadcrumbs #sub-header.layout-left-right .meta-header .meta-header-inside {
  padding: 0;
}
body.no-page-header.no-breadcrumbs #header-sidebars {
  padding-top: 55px;
}
.fl {
  float: left;
}
.fr {
  float: right;
}
.boxed-layout img {
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  display: block;
  max-width: 100%;
  height: auto;
}
.ie9 .boxed-layout img {
  display: inline-block;
}
.boxed-layout iframe,
.boxed-layout object,
.boxed-layout embed {
  display: block;
  max-width: 100%;
}
.google_map img,
.slider-shortcode img,
.wpv-wrapper img {
  max-width: none;
}
.wpv-video-frame iframe {
  display: block;
  margin: auto;
  max-width: 100%;
}
iframe[src*="soundcloud.com"] {
  max-width: 100%;
}
code,
kbd,
pre,
samp {
  -webkit-hyphens: none;
  -moz-hyphens: none;
  hyphens: none;
  font-size: 14px;
  font-family: monospace, serif;
  -ms-hyphens: none;
}
pre,
.wire-pad {
  position: relative;
  z-index: 1;
  margin-bottom: 8px;
  padding: 20px;
}
pre {
  border: 1px solid #EDEDED;
  background: #ffffff;
  font-size: 14px;
  line-height: 1.5em;
}
.toggle pre {
  padding: 0 !important;
  border: none;
}
code {
  padding: 0;
}
.mejs-container,
.mejs-embed,
.mejs-embed body,
.mejs-container .mejs-controls {
  background: #F0542D !important;
}
.mejs-controls .mejs-time-rail .mejs-time-loaded {
  background: #21759b;
}
.mejs-controls .mejs-time-rail .mejs-time-current {
  background: #d54e21;
}
.page-content .share-btns {
  padding-top: 0;
  padding-left: 0;
}
.page-content .share-btns .sep-3 {
  margin-top: 20px;
}
.error-message {
  clear: both;
  -webkit-transition: opacity .2s linear .7s !important;
  transition: opacity .2s linear .7s !important;
  position: absolute;
  top: 0;
  left: 100% !important;
  z-index: 100000;
  display: block;
  overflow: visible;
  margin-top: -13px;
  margin-left: 2px;
  padding: 0.5em;
  height: 16px;
  background: none repeat scroll 0 0 #D94729 !important;
  box-shadow: 0 0 0 1px #D94729 inset;
  color: #ffffff;
  white-space: nowrap;
  line-height: 16px;
}
.error-message:before,
.error-message:after {
  content: " ";
  display: table;
}
.error-message:after {
  clear: both;
}
.error-message:before,
.error-message:after {
  content: " ";
  display: table;
}
.error-message:after {
  clear: both;
}
.error-message:before {
  position: absolute;
  top: 50%;
  left: 0;
  margin-top: -6px;
  margin-left: -8px;
  width: 0;
  height: 0;
  border-width: 6px 6px 6px 0;
  border-style: inset solid inset none;
  border-color: transparent #D94729 transparent transparent;
  content: "";
}
.author-info-box {
  margin-bottom: 20px;
  padding-bottom: 20px;
  border-bottom: 1px solid #EDEDED;
}
.author-info-box .author-avatar {
  float: left;
}
.author-info-box .author-description {
  overflow: hidden;
  padding-left: 20px;
}
.author-info-box .author-description > h4 {
  margin-top: 0;
}
.author-info-box + .no-posts-by-author {
  padding-top: 40px;
  text-align: center;
}
.vamtam-column-border {
  border-radius: 10px;
  border: 15px solid #D8D8D8;
}
.vamtam-white-links a {
  font-size: 14px;
  line-height: 28px;
  font-weight: 600;
  font-family: "Raleway";
  color: #364352;
  text-decoration: none;
}
.vamtam-white-links a:hover {
  color: #ffffff;
  text-decoration: none;
  transition: all .2s ease;
}
.wpv-scroll-to-top.wpv-circle {
  border-radius: 5000px;
  border: 1px solid #EDEDED;
  width: 45px;
  height: 45px;
  line-height: 45px;
  display: inline-block;
  text-align: center;
}
.ScrollSceneIndicators {
  z-index: 0 !important;
}
.vamtam-only-title {
  display: none;
}
.tparrows {
  background: rgba(0,0,0,0) !important;
  border-radius: 0;
  border: 1px solid rgba(255,255,255,0.3);
  transition: background .3s ease, border .3s ease;
}
.tparrows:hover {
  background: rgba(0,0,0,0.6) !important;
  border-color: rgba(0,0,0,0.2) !important;
}
.mfp-vamtam button.mfp-close {
  color: #ffffff;
  opacity: 1;
  margin-right: -26px;
  right: 50%;
  margin-top: 60px;
  position: fixed;
}
.mfp-vamtam button.mfp-close:before {
  content: '';
  width: 52px;
  height: 52px;
  border: 4px solid;
  position: absolute;
  left: 50%;
  top: 50%;
  margin-left: -26px;
  margin-top: -26px;
  border-radius: 50%;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.mfp-vamtam.mfp-bg {
  background: #7C8A8D;
}
.mfp-vamtam .mfp-arrow {
  color: #ffffff;
  width: 120px;
  height: 60px;
}
.mfp-vamtam .mfp-arrow:before {
  display: none;
}
.mfp-vamtam .mfp-arrow:after {
  position: absolute;
  font-family: theme;
  font-size: 60px;
  width: 60px;
  height: 60px;
  line-height: 60px;
  text-align: center;
  border: 0;
  margin: -30px 0 0 -30px;
  top: 50%;
  left: 50%;
}
.mfp-vamtam .mfp-arrow:hover {
  color: #F0542D;
}
.mfp-vamtam .mfp-arrow-left:after {
  content: "\e607";
}
.mfp-vamtam .mfp-arrow-right:after {
  content: "\e606";
}
ul,
ol {
  margin: 0.4em 0px 0.4em 1.3em;
}
ul li,
ol li {
  padding-bottom: 4px;
  padding-top: 4px;
}
.styled-list {
  padding: 0;
  margin-left: 0.3em;
  list-style: none;
}
.styled-list li {
  padding-left: 1.5em;
  text-indent: -1.5em;
}
.styled-list li:before {
  text-indent: 0;
}
.styled-list.icon-accent1 li:before {
  color: #F0542D;
}
.styled-list.icon-accent2 li:before {
  color: #364352;
}
.styled-list.icon-accent3 li:before {
  color: #7C8A8D;
}
.styled-list.icon-accent4 li:before {
  color: #D8D8D8;
}
.styled-list.icon-accent5 li:before {
  color: #ffffff;
}
.styled-list.icon-accent6 li:before {
  color: #2B2F34;
}
.styled-list.icon-accent7 li:before {
  color: #EDEDED;
}
.styled-list.icon-accent8 li:before {
  color: #ffffff;
}
.form-input {
  position: relative;
  margin: 0;
  background: #EDEDED;
}
input[type=text],
input[type=tel],
input[type=email],
input[type=password],
input[type=email],
input[type=search],
input[type=date],
input[type=range],
input[type=number],
input[type=button],
input[type=tel],
textarea,
select {
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  padding: 17px;
  width: 100%;
  position: relative;
  border: none;
  outline: none;
  border: solid 1px rgba(43,47,52,0.1);
  margin: 0;
  box-shadow: none !important;
  font-size: 18px;
  border-radius: 0px;
  margin-bottom: 15px;
  background: #ffffff;
  color: #2B2F34;
}
div.wpcf7 input[type=text],
div.wpcf7 input[type=tel],
div.wpcf7 input[type=email],
div.wpcf7 input[type=password],
div.wpcf7 input[type=email],
div.wpcf7 input[type=search],
div.wpcf7 input[type=date],
div.wpcf7 input[type=range],
div.wpcf7 input[type=number],
div.wpcf7 input[type=button],
div.wpcf7 input[type=tel],
div.wpcf7 textarea,
div.wpcf7 select {
  width: 100%;
  position: relative;
  outline: none;
  border-bottom: 1px solid transparent;
  margin: 0 0 20px 0;
  box-shadow: none !important;
  font-size: 14px;
  border-radius: 0px;
  background: #ffffff;
  color: #2B2F34;
  padding: 10px;
  font-weight: 200;
  transition: all .2s ease;
  border: solid 1px rgba(43,47,52,0.1);
  margin-top: 5px;
}
div.wpcf7 input[type=text]:hover,
div.wpcf7 input[type=tel]:hover,
div.wpcf7 input[type=email]:hover,
div.wpcf7 input[type=password]:hover,
div.wpcf7 input[type=email]:hover,
div.wpcf7 input[type=search]:hover,
div.wpcf7 input[type=date]:hover,
div.wpcf7 input[type=range]:hover,
div.wpcf7 input[type=number]:hover,
div.wpcf7 input[type=button]:hover,
div.wpcf7 input[type=tel]:hover,
div.wpcf7 textarea:hover,
div.wpcf7 select:hover {
  -moz-box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05) !important;
  box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05) !important;
  border: solid 1px rgba(0,0,0,0.2);
}
input[type=text]:focus,
input[type=tel]:focus,
input[type=email]:focus,
input[type=password]:focus,
input[type=email]:focus,
input[type=search]:focus,
input[type=date]:focus,
input[type=range]:focus,
input[type=number]:focus,
input[type=button]:focus,
input[type=tel]:focus,
textarea:focus,
select:focus {
  border: 1px solid #F0542D !important;
}
input[type=text].invalid,
input[type=tel].invalid,
input[type=email].invalid,
input[type=password].invalid,
input[type=email].invalid,
input[type=search].invalid,
input[type=date].invalid,
input[type=range].invalid,
input[type=number].invalid,
input[type=button].invalid,
input[type=tel].invalid,
textarea.invalid,
select.invalid {
  border-color: #D94729;
}
input[type=text]:-moz-ui-invalid,
input[type=tel]:-moz-ui-invalid,
input[type=email]:-moz-ui-invalid,
input[type=password]:-moz-ui-invalid,
input[type=email]:-moz-ui-invalid,
input[type=search]:-moz-ui-invalid,
input[type=date]:-moz-ui-invalid,
input[type=range]:-moz-ui-invalid,
input[type=number]:-moz-ui-invalid,
input[type=button]:-moz-ui-invalid,
input[type=tel]:-moz-ui-invalid,
textarea:-moz-ui-invalid,
select:-moz-ui-invalid {
  border-color: #D94729;
}
.wpv-main input[type=text],
.wpv-main input[type=tel],
.wpv-main input[type=email],
.wpv-main input[type=password],
.wpv-main input[type=email],
.wpv-main input[type=search],
.wpv-main input[type=date],
.wpv-main input[type=range],
.wpv-main input[type=number],
.wpv-main input[type=button],
.wpv-main input[type=tel],
.wpv-main textarea,
.wpv-main select {
  background-color: #ffffff;
  color: #808080;
}
.wpv-main input[type=text]::-webkit-input-placeholder,
.wpv-main input[type=tel]::-webkit-input-placeholder,
.wpv-main input[type=email]::-webkit-input-placeholder,
.wpv-main input[type=password]::-webkit-input-placeholder,
.wpv-main input[type=email]::-webkit-input-placeholder,
.wpv-main input[type=search]::-webkit-input-placeholder,
.wpv-main input[type=date]::-webkit-input-placeholder,
.wpv-main input[type=range]::-webkit-input-placeholder,
.wpv-main input[type=number]::-webkit-input-placeholder,
.wpv-main input[type=button]::-webkit-input-placeholder,
.wpv-main input[type=tel]::-webkit-input-placeholder,
.wpv-main textarea::-webkit-input-placeholder,
.wpv-main select::-webkit-input-placeholder {
  color: #b3b3b3;
}
.wpv-main input[type=text]:-ms-input-placeholder,
.wpv-main input[type=tel]:-ms-input-placeholder,
.wpv-main input[type=email]:-ms-input-placeholder,
.wpv-main input[type=password]:-ms-input-placeholder,
.wpv-main input[type=email]:-ms-input-placeholder,
.wpv-main input[type=search]:-ms-input-placeholder,
.wpv-main input[type=date]:-ms-input-placeholder,
.wpv-main input[type=range]:-ms-input-placeholder,
.wpv-main input[type=number]:-ms-input-placeholder,
.wpv-main input[type=button]:-ms-input-placeholder,
.wpv-main input[type=tel]:-ms-input-placeholder,
.wpv-main textarea:-ms-input-placeholder,
.wpv-main select:-ms-input-placeholder {
  color: #b3b3b3;
}
.wpv-main input[type=text]::placeholder,
.wpv-main input[type=tel]::placeholder,
.wpv-main input[type=email]::placeholder,
.wpv-main input[type=password]::placeholder,
.wpv-main input[type=email]::placeholder,
.wpv-main input[type=search]::placeholder,
.wpv-main input[type=date]::placeholder,
.wpv-main input[type=range]::placeholder,
.wpv-main input[type=number]::placeholder,
.wpv-main input[type=button]::placeholder,
.wpv-main input[type=tel]::placeholder,
.wpv-main textarea::placeholder,
.wpv-main select::placeholder {
  color: #b3b3b3;
}
footer.main-footer input[type=text],
footer.main-footer input[type=tel],
footer.main-footer input[type=email],
footer.main-footer input[type=password],
footer.main-footer input[type=email],
footer.main-footer input[type=search],
footer.main-footer input[type=date],
footer.main-footer input[type=range],
footer.main-footer input[type=number],
footer.main-footer input[type=button],
footer.main-footer input[type=tel],
footer.main-footer textarea,
footer.main-footer select {
  background-color: #474b52;
  color: #c8cbd0;
}
footer.main-footer input[type=text]::-webkit-input-placeholder,
footer.main-footer input[type=tel]::-webkit-input-placeholder,
footer.main-footer input[type=email]::-webkit-input-placeholder,
footer.main-footer input[type=password]::-webkit-input-placeholder,
footer.main-footer input[type=email]::-webkit-input-placeholder,
footer.main-footer input[type=search]::-webkit-input-placeholder,
footer.main-footer input[type=date]::-webkit-input-placeholder,
footer.main-footer input[type=range]::-webkit-input-placeholder,
footer.main-footer input[type=number]::-webkit-input-placeholder,
footer.main-footer input[type=button]::-webkit-input-placeholder,
footer.main-footer input[type=tel]::-webkit-input-placeholder,
footer.main-footer textarea::-webkit-input-placeholder,
footer.main-footer select::-webkit-input-placeholder {
  color: #9297a0;
}
footer.main-footer input[type=text]:-ms-input-placeholder,
footer.main-footer input[type=tel]:-ms-input-placeholder,
footer.main-footer input[type=email]:-ms-input-placeholder,
footer.main-footer input[type=password]:-ms-input-placeholder,
footer.main-footer input[type=email]:-ms-input-placeholder,
footer.main-footer input[type=search]:-ms-input-placeholder,
footer.main-footer input[type=date]:-ms-input-placeholder,
footer.main-footer input[type=range]:-ms-input-placeholder,
footer.main-footer input[type=number]:-ms-input-placeholder,
footer.main-footer input[type=button]:-ms-input-placeholder,
footer.main-footer input[type=tel]:-ms-input-placeholder,
footer.main-footer textarea:-ms-input-placeholder,
footer.main-footer select:-ms-input-placeholder {
  color: #9297a0;
}
footer.main-footer input[type=text]::placeholder,
footer.main-footer input[type=tel]::placeholder,
footer.main-footer input[type=email]::placeholder,
footer.main-footer input[type=password]::placeholder,
footer.main-footer input[type=email]::placeholder,
footer.main-footer input[type=search]::placeholder,
footer.main-footer input[type=date]::placeholder,
footer.main-footer input[type=range]::placeholder,
footer.main-footer input[type=number]::placeholder,
footer.main-footer input[type=button]::placeholder,
footer.main-footer input[type=tel]::placeholder,
footer.main-footer textarea::placeholder,
footer.main-footer select::placeholder {
  color: #9297a0;
}
.fixed-header-box input[type=text],
.fixed-header-box input[type=tel],
.fixed-header-box input[type=email],
.fixed-header-box input[type=password],
.fixed-header-box input[type=email],
.fixed-header-box input[type=search],
.fixed-header-box input[type=date],
.fixed-header-box input[type=range],
.fixed-header-box input[type=number],
.fixed-header-box input[type=button],
.fixed-header-box input[type=tel],
.fixed-header-box textarea,
.fixed-header-box select {
  background-color: #ffffff;
  color: #808080;
}
.fixed-header-box input[type=text]::-webkit-input-placeholder,
.fixed-header-box input[type=tel]::-webkit-input-placeholder,
.fixed-header-box input[type=email]::-webkit-input-placeholder,
.fixed-header-box input[type=password]::-webkit-input-placeholder,
.fixed-header-box input[type=email]::-webkit-input-placeholder,
.fixed-header-box input[type=search]::-webkit-input-placeholder,
.fixed-header-box input[type=date]::-webkit-input-placeholder,
.fixed-header-box input[type=range]::-webkit-input-placeholder,
.fixed-header-box input[type=number]::-webkit-input-placeholder,
.fixed-header-box input[type=button]::-webkit-input-placeholder,
.fixed-header-box input[type=tel]::-webkit-input-placeholder,
.fixed-header-box textarea::-webkit-input-placeholder,
.fixed-header-box select::-webkit-input-placeholder {
  color: #b3b3b3;
}
.fixed-header-box input[type=text]:-ms-input-placeholder,
.fixed-header-box input[type=tel]:-ms-input-placeholder,
.fixed-header-box input[type=email]:-ms-input-placeholder,
.fixed-header-box input[type=password]:-ms-input-placeholder,
.fixed-header-box input[type=email]:-ms-input-placeholder,
.fixed-header-box input[type=search]:-ms-input-placeholder,
.fixed-header-box input[type=date]:-ms-input-placeholder,
.fixed-header-box input[type=range]:-ms-input-placeholder,
.fixed-header-box input[type=number]:-ms-input-placeholder,
.fixed-header-box input[type=button]:-ms-input-placeholder,
.fixed-header-box input[type=tel]:-ms-input-placeholder,
.fixed-header-box textarea:-ms-input-placeholder,
.fixed-header-box select:-ms-input-placeholder {
  color: #b3b3b3;
}
.fixed-header-box input[type=text]::placeholder,
.fixed-header-box input[type=tel]::placeholder,
.fixed-header-box input[type=email]::placeholder,
.fixed-header-box input[type=password]::placeholder,
.fixed-header-box input[type=email]::placeholder,
.fixed-header-box input[type=search]::placeholder,
.fixed-header-box input[type=date]::placeholder,
.fixed-header-box input[type=range]::placeholder,
.fixed-header-box input[type=number]::placeholder,
.fixed-header-box input[type=button]::placeholder,
.fixed-header-box input[type=tel]::placeholder,
.fixed-header-box textarea::placeholder,
.fixed-header-box select::placeholder {
  color: #b3b3b3;
}
.form-input .required {
  display: none;
}
textarea {
  min-height: 6em;
  width: 100%;
  position: relative;
  resize: none;
  font-size: 18px;
}
html.placeholder .dgx-donate-form-section label[for],
html.placeholder form.wpcf7-form label[for] {
  display: inline-block;
}
.select2-container .select2-choice {
  background: #ffffff;
  font-size: 14px;
  height: 20px;
  border-radius: 0px;
  color: #2B2F34;
  border: solid 1px rgba(43,47,52,0.1);
  box-shadow: none;
  font: inherit;
  padding: 10px;
  transition: all .2s ease;
}
.select2-drop-active {
  border-color: rgba(43,47,52,0.1);
  border-radius: 0;
}
.select2-results {
  background-color: #ffffff;
}
.load-more,
.wp-pagenavi {
  clear: both;
  margin-top: 50px;
}
.products + .load-more,
.products + .wp-pagenavi {
  margin-top: 0;
}
.wp-pagenavi {
  text-align: center;
  border-top: 1px solid #EDEDED;
  z-index: 100;
  position: relative;
  text-align: right;
  padding: 20px 0 40px;
}
.wp-pagenavi:last-child {
  padding-bottom: 0;
}
article > .page-content > section.portfolios > .wp-pagenavi {
  margin: 0 10px 30px;
}
.wp-pagenavi a,
.wp-pagenavi span {
  margin: 1px !important;
  border: none !important;
  display: inline-block;
  padding: 2px 8px 3px 8px !important;
  font-size: 12px;
}
.wp-pagenavi .current {
  background-color: #F0542D;
  color: #ffffff;
  font-size: 12px;
  font-weight: normal !important;
  margin: 0px 0px 0px 5px !important;
}
.wp-pagenavi a {
  transition: all 0.3s;
  border: solid 1px #EDEDED !important;
  margin: 0px 0px 0px 5px !important;
}
.wp-pagenavi a:hover,
.wp-pagenavi .current {
  background-color: #F0542D;
  border: solid 1px #F0542D !important;
  color: #ffffff;
}
.wp-pagenavi .previouspostslink,
.wp-pagenavi .nextpostslink {
  color: transparent !important;
  background: #ffffff;
  width: 23px;
  height: 23px;
  text-align: center;
  line-height: 23px;
  padding: 0 !important;
}
.wp-pagenavi .previouspostslink:after,
.wp-pagenavi .nextpostslink:after {
  color: #F0542D;
  font-size: 11px;
  font-family: theme;
  left: -2px;
  position: relative;
  font-weight: normal !important;
}
.wp-pagenavi .previouspostslink:after:hover,
.wp-pagenavi .nextpostslink:after:hover {
  color: #5C6268;
}
.wp-pagenavi .previouspostslink:after {
  content: "\e006";
}
.wp-pagenavi .nextpostslink:after {
  content: "\e005";
}
.wp-pagenavi span.pages {
  float: left;
  font: normal 14px/20px "Raleway";
  font-size: 12px;
  padding: 0 !important;
}
.wp-pagenavi a.page {
  background: #ffffff;
  color: #F0542D;
  font-size: 12px;
}
.wp-pagenavi a.page:hover {
  color: #5C6268;
}
.wp-pagenavi a.page:visited {
  color: #142e91;
}
.wp-pagenavi a,
.wp-pagenavi span,
.wp-pagenavi span.pages,
.wp-pagenavi .current {
  font-size: 1.2em;
}
.comment-paging {
  border-top: 0;
  margin-top: -40px;
  margin-bottom: 40px;
  padding-top: 0;
}
.comment-paging a,
.comment-paging span {
  margin: 1px !important;
  border: none !important;
  display: inline-block;
  padding: 2px 8px 3px 8px !important;
  font-size: 12px;
}
.comment-paging .current {
  background-color: #EDEDED;
  color: #ffffff;
  font-size: 12px;
  font-weight: normal !important;
}
.comment-paging .prev,
.comment-paging .next {
  color: transparent !important;
  background: #ffffff;
  width: 23px;
  height: 23px;
  text-align: center;
  line-height: 22px;
  padding: 0 !important;
  text-indent: -200px;
}
.comment-paging .prev:after,
.comment-paging .next:after {
  color: #F0542D;
  font-size: 12px;
  font-family: theme;
  position: relative;
  font-weight: normal !important;
}
.comment-paging .prev:after:hover,
.comment-paging .next:after:hover {
  color: #5C6268;
}
.comment-paging .prev:after {
  content: "\e006";
  left: 70px;
}
.comment-paging .next:after {
  content: "\e005";
  left: 83px;
}
.comment-paging span.pages {
  float: left;
  font: normal 14px/20px "Raleway";
  padding: 0 !important;
}
.comment-paging a.page-numbers {
  background: #ffffff;
  color: #F0542D;
  font-size: 12px;
}
.comment-paging a.page-numbers:hover {
  color: #5C6268;
}
.comment-paging a.page-numbers:visited {
  color: #142e91;
}
.load-more {
  margin: 50px auto 50px auto;
  position: relative;
  text-align: center;
}
.load-more.loading {
  background: url(../wpv_theme/assets/images/loader.gif) center center no-repeat;
  background-image: url(../wpv_theme/assets/images/loader.gif), url(../wpv_theme/assets/images/loader_bg.png);
  background-position: center center, center center;
}
.load-more .button.lm-btn {
  border: 2px solid #d4d4d4;
  background: none;
  box-shadow: none;
  padding: 0;
  max-width: 380px;
  width: 100%;
  border-radius: 0px;
}
.load-more .button.lm-btn span {
  color: #d4d4d4;
  padding: 0.8em 0 !important;
  position: relative;
  z-index: 555;
  text-transform: uppercase;
  font: 500 1.4em/1 "Raleway";
}
.load-more .button.lm-btn span:hover {
  text-decoration: none;
}
.load-more .button.lm-btn:hover {
  border-color: #F0542D;
}
.load-more .button.lm-btn:hover span {
  color: #F0542D !important;
}
.load-more + .share-btns {
  margin-top: 30px;
}
.wpv-accordion {
  border: solid 1px #EDEDED;
  margin: 0;
  padding-top: 0px;
  list-style: none;
  background: #ffffff;
}
.wpv-accordion .tab {
  position: relative;
  font-size: inherit;
  margin: 0;
  padding: 0;
  color: inherit;
  outline: none;
  border-top: 1px solid #EDEDED;
}
.wpv-accordion .tab:first-child {
  border-top: 0px;
}
.wpv-accordion .tab.ui-state-hover,
.wpv-accordion .tab.ui-state-active,
.wpv-accordion .tab.ui-state-selected {
  background-color: #EDEDED;
  border-color: #EDEDED;
}
.wpv-accordion .tab.ui-state-hover .ui-icon:after,
.wpv-accordion .tab.ui-state-active .ui-icon:after,
.wpv-accordion .tab.ui-state-selected .ui-icon:after {
  content: "\e60f";
  color: #F0542D !important;
  font-family: theme;
}
.wpv-accordion .tab.ui-state-active.has-bg {
  background: #F0542D;
}
.wpv-accordion .tab.ui-state-active.has-bg .inner {
  opacity: 1;
}
.wpv-accordion .tab .inner {
  padding: 23px 55px 23px 20px;
  margin: 0;
  cursor: pointer;
  outline: none !important;
  display: block;
  font: 300 20px/26px "Raleway";
  color: #ffffff;
  background-color: #364352;
  transition: opacity .3s ease;
  font-size: 12px;
  font-weight: bold;
}
.wpv-accordion .tab .inner:hover {
  text-decoration: none;
}
.wpv-accordion .tab .ui-icon {
  width: 40px;
  font-style: normal;
  display: block;
  position: absolute;
  right: 10px;
  text-align: center;
  font-size: 12px;
  line-height: 74px;
}
.wpv-accordion .tab .ui-icon:after {
  content: "\e60e";
  color: #F0542D;
  font-family: theme;
}
.wpv-accordion .pane .inner {
  padding: 10px 20px;
  z-index: 1;
  position: relative;
  overflow: hidden;
}
.wpv-accordion .pane-wrapper {
  background-position: top center;
  background-size: cover;
  padding: 0;
  border-bottom: 1px solid #EDEDED;
}
.wpv-accordion .pane-wrapper:first-child,
.wpv-accordion .pane-wrapper:first-child .tab .inner {
  border-radius: 0;
}
.wpv-accordion .pane-wrapper:last-child {
  border-bottom: none;
}
.wpv-accordion .pane-wrapper:last-child,
.wpv-accordion .pane-wrapper:last-child .tab:not(.ui-state-active) .inner {
  border-radius: 0;
}
blockquote {
  position: relative;
  z-index: 1;
  overflow: hidden;
  margin: 30px 0;
  padding-left: 20px;
  border-left: 1px solid #D8D8D8;
  text-align: left;
  font-size: 1.2em;
  font-weight: 300;
}
blockquote p,
blockquote {
  font: normal 24px/30px "Raleway";
  font-size: 1.2em;
  font-weight: 300;
}
blockquote.small p,
blockquote.small {
  font: normal 14px/20px "Raleway";
  margin-bottom: 0;
}
blockquote.simple {
  overflow: auto;
  margin: 0;
  padding: 20px 0 10px 0;
  padding-left: 0;
  border-left: 0;
  text-align: left;
}
blockquote.simple .quote-thumbnail {
  height: 40px;
  float: left;
  margin-left: 10px;
}
blockquote.simple .quote-thumbnail img {
  display: inline-block;
  border-radius: 100%;
  margin: 0px;
  max-height: 100%;
  width: auto;
}
blockquote.simple .quote-title-wrapper {
  margin: 10px 0;
}
blockquote.simple .quote-title {
  width: auto;
  color: #7C8A8D;
  font-weight: normal;
  float: left;
  border: none;
  padding: 0px;
  border-radius: 0px;
}
blockquote.simple .quote-title,
blockquote.simple .quote-title a {
  color: #F0542D;
}
blockquote.simple .quote-title .the-title:not(:last-child) {
  padding-right: 3px;
}
blockquote.simple .quote-title .the-title {
  font-size: 12px;
}
blockquote.simple .quote-title .icon {
  font-size: 16px;
  vertical-align: middle;
  padding-bottom: 2px;
}
blockquote.simple .quote-text {
  font: normal 14px/20px "Raleway";
  overflow: hidden;
  font-weight: normal;
}
blockquote.simple .quote-text img {
  width: auto;
}
blockquote cite {
  display: block;
  margin: 10px 0 0 0;
}
blockquote cite,
blockquote cite a {
  font: 600 12px/14px "Raleway";
  color: #F0542D;
}
blockquote cite a {
  vertical-align: middle;
}
blockquote cite:before {
  display: inline-block;
  margin-right: 10px;
  width: 30px;
  height: 0;
  border-bottom: 1px solid #EDEDED;
  content: "";
  vertical-align: middle;
}
blockquote:last-child cite:empty {
  display: none;
}
.slide-wrapper blockquote {
  padding-top: 0;
  padding-bottom: 0;
}
blockquote p:first-child {
  margin-top: 0;
}
blockquote p:last-child {
  margin-bottom: 0;
}
.blockquote-slider .bx-controls {
  height: 22px;
}
.loop-wrapper .post-row {
  clear: both;
  transition: background .4s ease;
}
.loop-wrapper .post-row:before,
.loop-wrapper .post-row:after {
  content: " ";
  display: table;
}
.loop-wrapper .post-row:after {
  clear: both;
}
.loop-wrapper .post-row:before,
.loop-wrapper .post-row:after {
  content: " ";
  display: table;
}
.loop-wrapper .post-row:after {
  clear: both;
}
.loop-wrapper .post-row .media-inner {
  background-color: #ffffff;
}
.loop-wrapper .post-row .media-inner > img {
  -webkit-backface-visibility: hidden;
  transition: opacity .4s;
}
.loop-wrapper .sticky .post-row,
.loop-wrapper .post-row:hover {
  background: #f5f5f5;
}
.loop-wrapper .sticky .post-row .top-part,
.loop-wrapper .post-row:hover .top-part {
  color: #2B2F34;
}
.loop-wrapper .post-row:hover .media-inner > img {
  opacity: 0.8;
  -webkit-backface-visibility: hidden;
}
.loop-wrapper .post-row-left,
.loop-wrapper .post-row-center {
  float: left;
}
.loop-wrapper .post-row-left {
  width: 160px;
  vertical-align: top;
  padding-top: 30px;
  text-align: right;
  padding-right: 30px;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.loop-wrapper .post-row-left .post-left-actions {
  display: none;
}
.loop-wrapper .post-date {
  display: inline-block;
  margin-right: 10px;
}
.loop-wrapper .post-date a:hover {
  text-decoration: none;
}
.loop-wrapper .post-date .top-part,
.loop-wrapper .post-date .bottom-part {
  display: block;
  text-align: center;
  width: 75px;
  transition: color .3s ease;
}
.loop-wrapper .post-date .top-part {
  font: 800 26px/30px "Raleway";
  color: #7C8A8D;
  line-height: 1;
  font-size: 45px;
  border-bottom: 1px solid;
  border-color: #EDEDED;
  padding-bottom: 10px;
}
.loop-wrapper .post-date .bottom-part {
  font: 600 12px/14px "Raleway";
  color: #D8D8D8;
  padding-top: 10px;
  line-height: 1;
}
.loop-wrapper .post-row-center {
  width: calc(100% - 160px);
  padding: 30px 0 30px 0;
}
.loop-wrapper .list-item {
  border-bottom: 1px solid #EDEDED;
  margin-bottom: 0;
}
.loop-wrapper .list-item:last-child {
  border-bottom: 0;
}
.loop-wrapper .list-item .post-content-outer {
  padding: 0;
}
.loop-wrapper .list-item .post-content-outer .post-content > ol:last-child,
.loop-wrapper .list-item .post-content-outer .post-content > ul:last-child {
  margin-bottom: 1em;
}
.loop-wrapper .list-item .post-media {
  width: 280px;
  float: left;
}
.loop-wrapper .list-item .post-media + .post-content-outer {
  padding-left: 310px;
}
.loop-wrapper .list-item .post-media .media-inner {
  display: block;
}
.loop-wrapper .list-item .post-article {
  display: block;
}
.loop-wrapper .list-item header.single {
  padding-top: 10px;
}
.loop-wrapper header {
  position: relative;
}
.loop-wrapper .page-content {
  position: relative;
}
.loop-wrapper .post-article {
  display: inline-block;
  margin: 0;
  width: 100%;
}
.loop-wrapper .post-article p {
  font-size: inherit;
  padding-right: 20px;
}
.loop-wrapper .post-article .post-content-outer .post-meta {
  overflow: hidden;
  width: 100%;
  margin-top: 10px;
  font-size: 10px;
  font-style: italic;
  text-transform: uppercase;
  color: #D8D8D8;
}
.loop-wrapper .post-article .post-content-outer .post-meta a {
  font-size: 11px;
  font-style: italic;
  text-transform: uppercase;
  color: #D8D8D8;
}
.loop-wrapper .post-article .post-content-outer .post-meta a:hover {
  color: #F0542D;
}
.loop-wrapper .post-article .post-content-outer .post-meta nav > div:not(.post-actions),
.loop-wrapper .post-article .post-content-outer .post-meta .post-actions > div,
.loop-wrapper .post-article .post-content-outer .post-meta .post-edit-link {
  font: bold 10px/11px "Arial";
  float: left;
  padding-right: 20px;
  min-height: 20px;
  line-height: 19px;
}
.loop-wrapper .post-article .post-content-outer .post-meta nav > div:not(.post-actions) > span.icon,
.loop-wrapper .post-article .post-content-outer .post-meta .post-actions > div > span.icon,
.loop-wrapper .post-article .post-content-outer .post-meta .post-edit-link > span.icon {
  color: #D8D8D8;
}
.loop-wrapper .post-article .post-content-outer .post-meta nav > div:not(.post-actions).blog-buttons,
.loop-wrapper .post-article .post-content-outer .post-meta .post-actions > div.blog-buttons,
.loop-wrapper .post-article .post-content-outer .post-meta .post-edit-link.blog-buttons {
  padding-top: 24px;
  border-right: none !important;
}
.loop-wrapper .post-article .post-content-outer .post-meta nav > div:not(.post-actions).blog-buttons a,
.loop-wrapper .post-article .post-content-outer .post-meta .post-actions > div.blog-buttons a,
.loop-wrapper .post-article .post-content-outer .post-meta .post-edit-link.blog-buttons a {
  position: relative;
}
.loop-wrapper .post-article .post-content-outer .post-meta nav > div:not(.post-actions).blog-buttons a:after,
.loop-wrapper .post-article .post-content-outer .post-meta .post-actions > div.blog-buttons a:after,
.loop-wrapper .post-article .post-content-outer .post-meta .post-edit-link.blog-buttons a:after {
  position: absolute;
  top: -25px;
  right: -20px;
  width: 1px;
  height: 300%;
  border-right: 1px solid #EDEDED;
  content: "";
}
.loop-wrapper .post-article .post-content-outer .post-meta .comment-count a:hover {
  text-decoration: none !important;
}
.loop-wrapper .post-article .post-content-outer .post-meta .comment-count a:hover span {
  text-decoration: none;
}
.loop-wrapper .post-article .post-content-outer .post-meta span.icon {
  display: inline-block;
  overflow: hidden;
  margin-right: 10px;
  padding: 2px;
  width: 8px;
  vertical-align: middle;
  text-align: center;
  text-decoration: none !important;
  font-size: 12px;
  line-height: normal;
}
.loop-wrapper .post-article .post-content-outer .post-meta .post-actions {
  float: right;
}
.loop-wrapper .post-article .post-content-outer .post-meta .post-actions .comment-count a {
  font-weight: normal;
  font-size: 12px;
  color: #D8D8D8;
}
.loop-wrapper .post-article .post-content-outer .post-meta .post-actions .comment-count a:hover {
  color: #F0542D;
}
.page-content label[for|=pwbox] {
  position: relative;
  top: -3px;
  display: inline-block !important;
  font-size: 0 !important;
}
.page-content label[for|=pwbox] input {
  font-size: 14px !important;
}
.post-article header {
  margin-bottom: 5px !important;
}
.post-article header.sep-text.single .content {
  text-align: left;
  white-space: normal;
}
.post-article header.sep-text.single .sep-text-after {
  display: none;
}
.post-article header h3 {
  margin: 0;
}
.post-article header h3,
.post-article header h3 a {
  color: #F0542D;
  line-height: 1.3em !important;
}
.post-article header a {
  transition: color .3s ease;
}
.post-article header a:hover {
  text-decoration: none;
  color: #5C6268;
}
.post-article .post-subheader {
  display: table;
  width: 100%;
  font-size: 14px;
}
.post-article .post-subheader .post-date {
  display: table-cell;
  margin: 0;
  padding-right: 1em;
  text-transform: uppercase;
  white-space: nowrap;
  font-size: 11px;
  line-height: 1;
}
.post-article .post-subheader .post-date-after {
  display: table-cell;
  overflow: visible;
  width: 100%;
  vertical-align: top;
  white-space: nowrap;
}
.post-article .post-subheader .post-date-after:after {
  display: inline-block;
  width: 100%;
  height: 1ex;
  border-bottom: 1px solid #EDEDED;
  content: "";
  vertical-align: top;
}
.post-article .post-media {
  text-align: center;
}
.post-article .post-media .media-inner {
  position: relative;
  min-height: 21px;
  overflow: hidden;
}
.post-article .post-media .media-inner > div {
  max-width: none !important;
  width: auto !important;
}
.post-article .post-media .media-inner > img {
  -webkit-transition: all .3s;
  transition: all .3s;
  width: 100%;
}
.post-article .blog-buttons {
  text-align: center;
}
.post-article .blog-buttons:after {
  display: block;
  clear: both;
  content: "";
}
.post-article .blog-buttons a {
  display: inline-block;
  margin: 0 auto;
}
.post-article .blog-buttons a .icon {
  margin: 0 8px 0 0;
  padding: 0;
  color: #F0542D;
  font-size: 16px;
}
.post-article .standard-post-format .the-content .post-meta,
.post-article .image-post-format .the-content .post-meta,
.post-article .link-post-format .the-content .post-meta,
.post-article .audio-post-format .the-content .post-meta,
.post-article .video-post-format .the-content .post-meta,
.post-article .gallery-post-format .the-content .post-meta {
  display: inline-block;
  margin: 10px 0 0 0;
  width: 100%;
  border: 1px solid #EDEDED;
  background: #ffffff;
}
.post-article .standard-post-format .the-content .post-meta div,
.post-article .image-post-format .the-content .post-meta div,
.post-article .link-post-format .the-content .post-meta div,
.post-article .audio-post-format .the-content .post-meta div,
.post-article .video-post-format .the-content .post-meta div,
.post-article .gallery-post-format .the-content .post-meta div {
  display: inline-block;
  float: left;
  padding: 15px;
  border-right: 1px solid #EDEDED;
  text-transform: uppercase;
}
.single-post-wrapper .post-article .standard-post-format .post-content-outer,
.single-post-wrapper .post-article .standard-post-format .post-media,
.single-post-wrapper .post-article .standard-post-format .the-content,
.single-post-wrapper .post-article .image-post-format .post-content-outer,
.single-post-wrapper .post-article .image-post-format .post-media,
.single-post-wrapper .post-article .image-post-format .the-content,
.single-post-wrapper .post-article .link-post-format .post-content-outer,
.single-post-wrapper .post-article .link-post-format .post-media,
.single-post-wrapper .post-article .link-post-format .the-content,
.single-post-wrapper .post-article .audio-post-format .post-content-outer,
.single-post-wrapper .post-article .audio-post-format .post-media,
.single-post-wrapper .post-article .audio-post-format .the-content,
.single-post-wrapper .post-article .video-post-format .post-content-outer,
.single-post-wrapper .post-article .video-post-format .post-media,
.single-post-wrapper .post-article .video-post-format .the-content,
.single-post-wrapper .post-article .gallery-post-format .post-content-outer,
.single-post-wrapper .post-article .gallery-post-format .post-media,
.single-post-wrapper .post-article .gallery-post-format .the-content {
  display: block;
  width: auto;
}
.single-post-wrapper .post-article .standard-post-format .the-content,
.single-post-wrapper .post-article .image-post-format .the-content,
.single-post-wrapper .post-article .link-post-format .the-content,
.single-post-wrapper .post-article .audio-post-format .the-content,
.single-post-wrapper .post-article .video-post-format .the-content,
.single-post-wrapper .post-article .gallery-post-format .the-content {
  padding: 0;
}
.post-article .audio-post-format .post-media {
  float: none;
  width: auto;
  margin: 0 60px 10px 0;
}
.post-article .audio-post-format .post-media + .post-content-outer {
  padding-left: 0;
}
.post-article .audio-post-format .media-inner {
  display: block;
}
.post-article .quote-post-format blockquote.large {
  padding: 0;
  overflow: visible;
  text-align: left;
}
.post-article .quote-post-format blockquote.large .quote-text,
.post-article .quote-post-format blockquote.large .quote-text p {
  font: normal 24px/30px "Raleway";
}
.post-article .quote-post-format .cite img {
  border-bottom: 1px solid #EDEDED;
  padding-bottom: 10px;
  margin-bottom: 10px;
}
.post-article .quote-post-format .cite img + .quote-author {
  display: block;
}
.post-article .aside-post-format .post-content-outer {
  padding-top: 0;
}
.post-article .status-post-format .the-content {
  padding-right: 36px !important;
}
.post-article .gallery-post-format .post-media {
  position: relative;
  text-align: center;
}
.post-article .gallery-post-format .post-media .button {
  position: absolute;
  bottom: 30px;
  left: 50%;
  z-index: 5;
  margin-left: -30px;
  padding: 0.7em 0.7em 0.75em;
}
.post-article .gallery-post-format .post-media .button span:after {
  border: none !important;
}
.post-article .gallery-post-format .post-media .button:hover {
  text-decoration: none;
}
.post-article .gallery-post-format .post-media .media-inner {
  display: block;
}
.post-article .excerpt-more {
  float: left;
  margin-top: -0.6em;
}
.post-article .status-post-format .post-subheader,
.post-article .aside-post-format .post-subheader,
.post-article .link-post-format .post-subheader {
  margin-bottom: 0 !important;
}
.post-article .status-post-format .post-media,
.post-article .aside-post-format .post-media,
.post-article .link-post-format .post-media {
  margin-top: 20px;
}
.post-article .video-post-format .media-inner iframe {
  height: 360px;
}
body.single-post .single-post-wrapper .post-content-outer .meta-top {
  margin-bottom: 20px;
}
body.single-post .single-post-wrapper .post-content-outer .meta-top .author {
  margin-right: 20px;
}
body.single-post .single-post-wrapper .post-content-outer .meta-top .comment-count {
  float: right;
}
body.single-post .single-post-wrapper .post-content-outer .meta-top .comment-count .icon {
  position: relative;
  margin-right: 5px;
  top: 1px;
}
body.single-post .single-post-wrapper .post-content-outer .meta-top .comment-count a:not(.icon) {
  font-size: 13px;
  position: relative;
  top: -2px;
}
body.single-post .single-post-wrapper .post-content-outer .meta-bottom {
  margin-top: 20px;
}
body.single-post .single-post-wrapper .post-content-outer .meta-bottom .icon {
  margin-right: 5px;
}
body.single-post .related-posts {
  clear: both;
  position: relative;
  padding-top: 40px;
  padding-bottom: 60px;
  background: #ffffff;
}
body.single-post .related-posts .grid-1-1 {
  padding: 0;
}
body.single-post .related-posts .grid-1-1 .loop-wrapper.scroll-x.news {
  padding-top: 0;
}
body.single-post.single-format-aside .page-header .post-siblings {
  padding-top: 60px;
}
body.full .related-posts:before {
  position: absolute;
  top: 0;
  left: -100%;
  width: 300%;
  height: 100%;
  background: #ffffff;
  content: "";
}
.header-middle .limit-wrapper .news.scroll-x {
  padding-top: 10px !important;
}
.ie8 .loop-wrapper .page-content {
  margin-bottom: 30px;
}
.loop-wrapper.news .post-media-date {
  background: none;
  position: relative;
  overflow: hidden;
}
.loop-wrapper.news .post-media-date .thumbnail img {
  -webkit-transition: opacity 0.35s, -webkit-transform 0.35s;
  transition: opacity 0.35s, transform 0.35s;
  -webkit-transform: translate3d(0,0,300px);
  -ms-transform: translate3d(0,0,300px);
  transform: translate3d(0,0,300px);
}
.loop-wrapper.news .as-standard-post-format .post-media-date,
.loop-wrapper.news .aside-post-format .post-media-date,
.loop-wrapper.news .link-post-format .post-media-date,
.loop-wrapper.news .audio-post-format .post-media-date,
.loop-wrapper.news .quote-post-format .post-media-date {
  background: none;
  -webkit-transition: 0.35s, -webkit-transform 0.35s;
  transition: 0.35s, transform 0.35s;
}
.loop-wrapper.news .as-standard-post-format .post-media-date .post-actions-wrapper,
.loop-wrapper.news .aside-post-format .post-media-date .post-actions-wrapper,
.loop-wrapper.news .link-post-format .post-media-date .post-actions-wrapper,
.loop-wrapper.news .audio-post-format .post-media-date .post-actions-wrapper,
.loop-wrapper.news .quote-post-format .post-media-date .post-actions-wrapper {
  padding-bottom: 0px;
}
.loop-wrapper.news .post-article {
  overflow: hidden;
  margin: 0;
  border-bottom: 0px !important;
}
.loop-wrapper.news .post-article:hover .image-post-format .thumbnail img,
.loop-wrapper.news .post-article:hover .as-image .thumbnail img {
  -webkit-transform: scale(1.15);
  -ms-transform: scale(1.15);
  transform: scale(1.15);
  opacity: 1;
}
.loop-wrapper.news .post-article:hover .post-actions-wrapper {
  -webkit-transform: translate3d(0,0,0);
  -ms-transform: translate3d(0,0,0);
  transform: translate3d(0,0,0);
}
.loop-wrapper.news .post-article .post-content-outer,
.loop-wrapper.news .post-article .post-content-outer p {
  font: normal 14px/20px "Raleway";
  font-size: inherit;
  margin-bottom: 0.5em;
}
.loop-wrapper.news .page-content:not(.has-post-thumbnail) .post-article:hover .as-standard-post-format .post-media-date,
.loop-wrapper.news .page-content:not(.has-post-thumbnail) .post-article:hover .aside-post-format .post-media-date,
.loop-wrapper.news .page-content:not(.has-post-thumbnail) .post-article:hover .link-post-format .post-media-date,
.loop-wrapper.news .page-content:not(.has-post-thumbnail) .post-article:hover .audio-post-format .post-media-date,
.loop-wrapper.news .page-content:not(.has-post-thumbnail) .post-article:hover .quote-post-format .post-media-date {
  padding-bottom: 40px;
}
.loop-wrapper.news .post-content-wrapper {
  padding: 10px 20px 20px;
  background: #ffffff;
}
.loop-wrapper.news .post-content-wrapper h3 {
  font-weight: bold;
}
.loop-wrapper.news .post-content-wrapper h3,
.loop-wrapper.news .post-content-wrapper h3 a {
  color: #F0542D;
  font-weight: normal;
  font-size: 1.2em;
}
.loop-wrapper.news .post-content-wrapper h3:hover,
.loop-wrapper.news .post-content-wrapper h3 a:hover {
  color: #5C6268;
}
.loop-wrapper.news .comment-count {
  position: relative;
  display: inline-block;
  float: right;
  background: #F0542D;
  margin: 0;
  color: #ffffff;
}
.loop-wrapper.news .comment-count a {
  font-weight: normal;
  font-size: 12px;
  color: #ffffff;
  padding: 10px 15px;
  display: block;
}
.loop-wrapper.news .comment-count a:hover {
  color: #F0542D;
  background: #364352;
}
.loop-wrapper.news .post-actions-wrapper {
  position: absolute;
  left: 0;
  top: auto;
  height: auto;
  background: rgba(54,67,82,0.5);
  -webkit-transition: -webkit-transform 0.35s;
  transition: transform 0.35s;
  -webkit-transform: translate3d(0,100%,0);
  transform: translate3d(0,100%,0);
  width: 100%;
  bottom: 0;
}
html.touch .loop-wrapper.news .post-actions-wrapper {
  -webkit-transform: translate3d(0,0,0);
  -ms-transform: translate3d(0,0,0);
  transform: translate3d(0,0,0);
}
.loop-wrapper.news .post-actions-wrapper .icon {
  color: #ffffff;
  position: relative;
  display: inline-block;
  width: auto;
  height: auto;
  margin: inherit;
  opacity: 1;
  margin-right: 0.7em;
  vertical-align: top;
  font-size: 14px;
  text-align: left;
}
.loop-wrapper.news .post-actions-wrapper .post-date {
  position: relative;
  display: inline-block;
  float: left;
  font-size: 10px;
  font-style: normal;
  text-transform: uppercase;
  color: #ffffff;
  font-family: arial;
  font-weight: bold;
  padding: 10px 0px 10px 20px;
}
.loop-wrapper.news .post-actions-wrapper a:hover .icon {
  color: #F0542D;
}
.loop-wrapper.news .post-content-meta,
.loop-wrapper.news .author {
  margin: 0px;
  padding-top: 0px;
  border: none;
  text-align: left;
  font-size: 10px;
  font-style: normal;
  text-transform: uppercase;
  color: #D8D8D8;
}
.loop-wrapper.news .post-content-meta a,
.loop-wrapper.news .author a {
  font-size: 10px;
  font-style: normal;
  text-transform: uppercase;
  color: #F0542D;
}
.loop-wrapper.news .post-content-meta a:hover,
.loop-wrapper.news .author a:hover {
  color: #5C6268;
}
.loop-wrapper.news .list-item {
  padding-top: 15px;
  border-bottom: 0;
}
.loop-wrapper.news .list-item header.single {
  padding: 10px 0 0 0;
  position: relative;
  border-bottom: none;
}
.loop-wrapper.news .list-item header.single:after {
  display: none;
}
.loop-wrapper.news .list-item > div {
  position: relative;
  z-index: 1;
  overflow: hidden;
  background: transparent;
}
.loop-wrapper.news.wpv-isotope-loaded {
  padding-top: 2px;
  padding-bottom: 15px;
}
.loop-wrapper.news .thumbnail {
  position: relative;
  overflow: visible;
  width: 100%;
  text-align: center;
  background: none;
}
.loop-wrapper.news .thumbnail img {
  width: 100%;
  height: auto;
  transition: opacity .4s;
}
.loop-wrapper.news .thumbnail .icon {
  position: absolute;
  top: 50%;
  left: 50%;
  display: inline-block;
  width: 65px;
  height: 65px;
  color: #ffffff;
  font-size: 65px;
  margin: -32.5px 0 0 -32.5px;
  opacity: 0;
}
.loop-wrapper.news .post-edit-link,
.loop-wrapper.news .sep-text-after {
  display: none;
}
.loop-wrapper.news .image-post-format .thumbnail,
.loop-wrapper.news .video-post-format.as-image .thumbnail,
.loop-wrapper.news .standard-post-format.as-image .thumbnail {
  overflow: hidden;
  -webkit-transform: translateZ(0);
  -ms-transform: translateZ(0);
  transform: translateZ(0);
}
.loop-wrapper.news > .page-content {
  margin-bottom: 20px;
}
.loop-wrapper.news .post-article .quote-post-format .cite {
  float: none;
  padding: 20px 0 20px;
  width: auto;
  text-align: left;
}
.loop-wrapper.news .post-article .quote-post-format .cite img {
  display: inline-block;
  margin-bottom: 0;
  padding: 0 20px 0 0;
  max-width: 85px;
  border: 0;
  vertical-align: middle;
}
.loop-wrapper.news .post-article .quote-post-format .cite img + .quote-author {
  display: inline;
  vertical-align: middle;
}
.loop-wrapper.news .post-article .quote-post-format .cite + .quote-text {
  padding-left: 0;
}
.loop-wrapper.news .post-article .quote-post-format .quote-text {
  padding-bottom: 25px;
}
body.boxed .wpv-main .wpv-grid.grid-1-1.extended,
body.boxed .wpv-main .wpv-grid.grid-1-1.extended-content {
  padding-left: 60px !important;
  padding-right: 60px !important;
  margin-left: -45px;
  margin-right: -45px;
  width: auto;
  float: none;
}
body.boxed .wpv-main .wpv-grid.grid-1-1.extended.no-extended-padding,
body.boxed .wpv-main .wpv-grid.grid-1-1.extended-content.no-extended-padding {
  padding-left: 15px;
  padding-right: 15px;
}
body.boxed .wpv-main .wpv-grid.grid-1-1.extended .wpv-parallax-bg-img,
body.boxed .wpv-main .wpv-grid.grid-1-1.extended .wpv-video-bg,
body.boxed .wpv-main .wpv-grid.grid-1-1.extended-content .wpv-parallax-bg-img,
body.boxed .wpv-main .wpv-grid.grid-1-1.extended-content .wpv-video-bg {
  left: 0;
  right: 0;
}
.wpv-grid.has-background > .column-title:first-child,
.wpv-grid.has-background > .sep-text:first-child,
.wpv-grid.has-background > style:first-child + .column-title,
.wpv-grid.has-background > style:first-child + .sep-text,
.wpv-grid.has-background > .extended-column-inner > .column-title:first-child,
.wpv-grid.has-background > .extended-column-inner > .sep-text:first-child,
.wpv-grid.has-background > .extended-column-inner > style:first-child + .column-title,
.wpv-grid.has-background > .extended-column-inner > style:first-child + .sep-text {
  padding-top: 0;
}
html.csstransitions .wpv-grid.animated-active {
  opacity: 0;
}
html.csstransitions .wpv-grid.animated-active.animation-zoom-in {
  opacity: 0.2;
  -webkit-transform: scale(0.5);
  -ms-transform: scale(0.5);
  transform: scale(0.5);
}
html.csstransitions .wpv-grid.animated-active.animation-ended {
  opacity: 1;
}
html.csstransitions .wpv-grid.animated-active.animation-ended.animation-from-left {
  -webkit-animation: element-from-left 0.7s 1 ease-out;
  animation: element-from-left 0.7s 1 ease-out;
}
html.csstransitions .wpv-grid.animated-active.animation-ended.animation-from-right {
  -webkit-animation: element-from-right 0.7s 1 ease-out;
  animation: element-from-right 0.7s 1 ease-out;
}
html.csstransitions .wpv-grid.animated-active.animation-ended.animation-from-top {
  -webkit-animation: element-from-top 0.7s 1 ease-out;
  animation: element-from-top 0.7s 1 ease-out;
}
html.csstransitions .wpv-grid.animated-active.animation-ended.animation-from-bottom {
  -webkit-animation: element-from-bottom 0.7s 1 ease-out;
  animation: element-from-bottom 0.7s 1 ease-out;
}
html.csstransitions .wpv-grid.animated-active.animation-ended.animation-fade-in {
  transition: opacity .8s ease-out;
}
html.csstransitions .wpv-grid.animated-active.animation-ended.animation-zoom-in {
  -webkit-animation: element-zoom-in .4s 1 cubic-bezier(0.175,0.885,0.320,1.275);
  animation: element-zoom-in .4s 1 cubic-bezier(0.175,0.885,0.320,1.275);
  -webkit-transform: scale(1);
  -ms-transform: scale(1);
  transform: scale(1);
}
.wpv-grid.parallax-bg,
.wpv-grid.parallax-bg-suspended,
.wpv-grid.has-video-bg {
  z-index: 0;
}
.wpv-grid.has-video-bg {
  overflow: hidden;
}
.wpv-grid.parallax-bg,
.wpv-grid.has-video-bg {
  opacity: 0;
  transition: opacity .6s ease;
}
.wpv-grid.parallax-bg.parallax-loaded,
.wpv-grid.parallax-bg.parallax-bg-suspended,
.wpv-grid.parallax-bg.video-bg-loaded,
.wpv-grid.has-video-bg.parallax-loaded,
.wpv-grid.has-video-bg.parallax-bg-suspended,
.wpv-grid.has-video-bg.video-bg-loaded {
  opacity: 1;
}
.wpv-grid.parallax-bg-suspended > .wpv-parallax-bg-img {
  background-attachment: scroll !important;
}
.wpv-parallax-bg-img,
.wpv-video-bg {
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: -1;
}
.extended-content .wpv-parallax-bg-img,
.extended-content .wpv-video-bg {
  left: 15px;
  right: 15px;
}
.wpv-video-bg-content,
.wpv-parallax-bg-content {
  z-index: 0;
}
.wpv-video-bg .mejs__offscreen {
  display: none;
}
.wpv-background-video {
  width: 100% !important;
  height: auto !important;
}
.wpv-background-video .mejs-overlay-loading,
.wpv-background-video .mejs-overlay-play,
.wpv-background-video .mejs-controls {
  display: none !important;
}
@-webkit-keyframes element-from-left {
  0% {
    -webkit-transform: translate(-20%,0);
    opacity: 0;
  }
  100% {
    -webkit-transform: translate(0,0);
    opacity: 1;
  }
}
@-moz-keyframes element-from-left {
  0% {
    -moz-transform: translate(-20%,0);
    opacity: 0;
  }
  100% {
    -moz-transform: translate(0,0);
    opacity: 1;
  }
}
@-o-keyframes element-from-left {
  0% {
    -o-transform: translate(-20%,0);
    opacity: 0;
  }
  100% {
    -o-transform: translate(0,0);
    opacity: 1;
  }
}
@keyframes element-from-left {
  0% {
    transform: translate(-20%,0);
    opacity: 0;
  }
  100% {
    transform: translate(0,0);
    opacity: 1;
  }
}
@-webkit-keyframes element-from-right {
  0% {
    -webkit-transform: translate(20%,0);
    opacity: 0;
  }
  100% {
    -webkit-transform: translate(0,0);
    opacity: 1;
  }
}
@-moz-keyframes element-from-right {
  0% {
    -moz-transform: translate(20%,0);
    opacity: 0;
  }
  100% {
    -moz-transform: translate(0,0);
    opacity: 1;
  }
}
@-o-keyframes element-from-right {
  0% {
    -o-transform: translate(20%,0);
    opacity: 0;
  }
  100% {
    -o-transform: translate(0,0);
    opacity: 1;
  }
}
@keyframes element-from-right {
  0% {
    transform: translate(20%,0);
    opacity: 0;
  }
  100% {
    transform: translate(0,0);
    opacity: 1;
  }
}
@-webkit-keyframes element-from-bottom {
  0% {
    -webkit-transform: translate(0,30%);
    opacity: 0;
  }
  100% {
    -webkit-transform: translate(0,0);
    opacity: 1;
  }
}
@-moz-keyframes element-from-bottom {
  0% {
    -moz-transform: translate(0,30%);
    opacity: 0;
  }
  100% {
    -moz-transform: translate(0,0);
    opacity: 1;
  }
}
@-o-keyframes element-from-bottom {
  0% {
    -o-transform: translate(0,30%);
    opacity: 0;
  }
  100% {
    -o-transform: translate(0,0);
    opacity: 1;
  }
}
@keyframes element-from-bottom {
  0% {
    transform: translate(0,30%);
    opacity: 0;
  }
  100% {
    transform: translate(0,0);
    opacity: 1;
  }
}
@-webkit-keyframes element-from-top {
  0% {
    -webkit-transform: translate(0,-30%);
    opacity: 0;
  }
  100% {
    -webkit-transform: translate(0,0);
    opacity: 1;
  }
}
@-moz-keyframes element-from-top {
  0% {
    -moz-transform: translate(0,-30%);
    opacity: 0;
  }
  100% {
    -moz-transform: translate(0,0);
    opacity: 1;
  }
}
@-o-keyframes element-from-top {
  0% {
    -o-transform: translate(0,-30%);
    opacity: 0;
  }
  100% {
    -o-transform: translate(0,0);
    opacity: 1;
  }
}
@keyframes element-from-top {
  0% {
    transform: translate(0,-30%);
    opacity: 0;
  }
  100% {
    transform: translate(0,0);
    opacity: 1;
  }
}
@-webkit-keyframes element-zoom-in {
  0% {
    -webkit-transform: scale(0.3);
    opacity: .1;
  }
  100% {
    -webkit-transform: scale(1);
    opacity: 1;
  }
}
@-moz-keyframes element-zoom-in {
  0% {
    -moz-transform: scale(0.3);
    opacity: .1;
  }
  100% {
    -moz-transform: scale(1);
    opacity: 1;
  }
}
@-o-keyframes element-zoom-in {
  0% {
    -o-transform: scale(0.3);
    opacity: .1;
  }
  100% {
    -o-transform: scale(1);
    opacity: 1;
  }
}
@keyframes element-zoom-in {
  0% {
    transform: scale(0.3);
    opacity: .1;
  }
  100% {
    transform: scale(1);
    opacity: 1;
  }
}
.wpv-countdown.regular {
  text-align: center;
}
.wpv-countdown.regular .wpvc-block {
  display: inline-block;
  vertical-align: middle;
  padding: 40px 20px 20px;
  border: 1px solid #EDEDED;
  border-radius: 3px;
  width: 140px;
  text-align: center;
  margin-right: 10px;
  margin-left: 10px;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.wpv-countdown.regular .wpvc-block .value {
  font-family: "Raleway";
  font-size: 40px;
  font-weight: bold;
  color: #F0542D;
  padding-bottom: 40px;
}
.wpv-countdown.regular .wpvc-block .value-label {
  border-top: 1px dotted #EDEDED;
  padding-top: 20px;
  text-transform: uppercase;
}
.wpv-countdown.regular .wpvc-sep {
  display: inline-block;
  vertical-align: middle;
  font-size: 30px;
  color: #EDEDED;
}
.wpv-countdown.regular.lt300 .wpvc-block {
  margin: 10px 0;
}
.wpv-countdown.regular.lt350 .wpvc-sep {
  display: none;
}
.sep,
.sep-2,
.sep-3 {
  position: relative;
  display: block;
  clear: both;
  margin: 60px 0 30px 0;
  min-width: 100%;
  height: 1px;
  border-top: 1px solid;
  color: #EDEDED;
}
.sep.has-icon .icon,
.sep-2.has-icon .icon,
.sep-3.has-icon .icon {
  margin-top: -2px;
  font-size: 24px;
}
.sep-2 {
  border-bottom: 1px solid;
  height: 2px;
}
.sep-text {
  position: relative;
  margin: 60px 0 30px 0;
  text-align: center;
}
.sep-text + .frame-fl,
.sep-text + .frame > .google_map {
  margin-top: 15px;
}
.sep-text .content,
.sep-text .sep-text-more {
  display: table-cell;
  vertical-align: middle;
  white-space: nowrap;
}
.sep-text .content *,
.sep-text .sep-text-more * {
  margin: 0;
  line-height: 1;
}
.sep-text .content {
  padding-right: .8em;
}
.sep-text .sep-text-more {
  padding-left: .8em;
}
.sep-text .sep-text-before,
.sep-text .sep-text-after {
  display: table-cell;
  width: 100%;
  vertical-align: bottom;
}
.sep-text .sep-text-line {
  display: inline-block;
  padding-top: 2px;
  width: 100%;
  border-top: 0 solid;
  border-bottom: 1px solid;
  color: #EDEDED;
  vertical-align: baseline;
}
.sep-text.centered .sep-text-before,
.sep-text.centered .sep-text-after {
  width: 50%;
  font-size: 22px;
}
.sep-text.centered .content {
  padding-left: .8em;
}
.sep-text:last-child {
  margin-bottom: 20px;
}
.sep-text + .row {
  padding-top: 15px;
}
.column-title {
  text-align: center;
  margin: 60px 0 30px 0;
}
.column-title + .frame-fl,
.column-title + .frame > .google_map {
  margin-top: 15px;
}
.column-title + p {
  margin-top: 10px;
}
.text-divider-double {
  position: relative;
  margin: 60px 0 25px 0;
  text-align: center;
}
.text-divider-double .icon {
  display: block;
  padding-bottom: 20px;
}
.text-divider-double + .sep {
  margin: 0 0 30px 0;
  position: relative;
}
.text-divider-double + .sep + .frame-fl,
.text-divider-double + .sep + .frame > .google_map {
  margin-top: 15px;
}
.related-content-title {
  text-align: center;
  position: relative;
  margin-bottom: 30px;
  border-bottom: 1px solid #EDEDED;
  padding-bottom: 15px;
}
.dropcap1,
.dropcap2 {
  float: left;
  font-weight: 400 !important;
  overflow: visible;
  text-align: center;
  vertical-align: middle;
  font-family: "Raleway";
  color: #F0542D;
}
.dropcap1 {
  font-size: 30px !important;
  height: 30px;
  line-height: 1em;
  padding: 7px 8px;
  border: 2px solid #F0542D;
  width: auto;
  min-width: 1em;
  color: #F0542D;
  margin: -0.04em 15px -0.07em 0;
}
.dropcap2 {
  border: 0 none !important;
  font-size: 44px !important;
  height: 40px;
  line-height: 1em;
  margin: -0.05em 15px 0 -0.1em;
  padding: 0;
  width: 2ex;
}
.dropcap2.accent1 {
  color: #F0542D;
}
.dropcap2.accent2 {
  color: #364352;
}
.dropcap2.accent3 {
  color: #7C8A8D;
}
.dropcap2.accent4 {
  color: #D8D8D8;
}
.dropcap2.accent5 {
  color: #ffffff;
}
.dropcap2.accent6 {
  color: #2B2F34;
}
.dropcap-text {
  display: table-cell;
  vertical-align: middle;
  font: normal 24px/30px "Raleway";
  color: #4A4F55;
}
.dropcap-wrapper {
  display: table;
}
.dropcap-wrapper .dropcap1,
.dropcap-wrapper .dropcap2 {
  float: none;
  display: block;
}
.dropcap-wrapper .dropcap-left {
  display: table-cell;
  vertical-align: top;
}
.services.has-more {
  position: relative;
  padding: 0;
  z-index: 2000;
}
.services.has-more .title {
  margin: 20px 0 0 -20px;
  color: #ffffff !important;
}
.services.has-more .image-wrapper {
  padding: 20px;
  text-align: center;
}
.services.has-more .image-wrapper img {
  display: inline-block;
  vertical-align: bottom;
}
.services.has-more .image-wrapper:hover img {
  -webkit-transform: scale(1.2);
  -ms-transform: scale(1.2);
  transform: scale(1.2);
}
.services.has-more .services-content-wrapper > .row {
  margin: 0;
}
.services.has-more .open {
  width: 100%;
  position: absolute;
  top: 100%;
  padding: 0 20px 0 20px;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.services.has-more .open .services-content-wrapper {
  padding: 10px 0px;
}
.services.has-more .open p:first-child {
  margin-top: 0;
}
.services.has-more .open p:last-child {
  margin-bottom: 0;
}
.services.has-more .closed {
  padding: 20px;
  max-height: 100%;
  max-width: 100%;
}
.services.has-more .closed .services-content-wrapper {
  padding-bottom: 20px;
  text-align: center;
}
.services.has-more .closed .title {
  display: inline-block;
  position: relative;
  background: none;
  font-weight: 600;
  margin: 0px;
  width: 90%;
  padding: 0px 5% 15px 5%;
}
.services.has-more.expandable-animation-3d .open {
  transform-origin: top;
  transform: translate(0,0) scaleY(0);
  transform-style: preserve-3d;
  -webkit-backface-visibility: hidden;
  will-change: transform;
}
.services.has-more.expandable-animation-3d .closed {
  -webkit-backface-visibility: hidden;
  will-change: transform;
}
html.touch .services.has-more .open {
  transform: none;
  position: relative;
  top: 0;
}
.highlight {
  padding: 0 5px;
  color: #000;
  vertical-align: baseline;
  line-height: 125%;
  margin-right: 5px;
  display: inline-block;
  position: relative;
}
.highlight.light,
.highlight.light:before {
  background: #afb4ba;
}
.highlight.dark {
  color: #eee;
}
.highlight.dark,
.highlight.dark:before {
  background: #90321b;
}
.highlight .highlight-content {
  position: relative;
  z-index: 1;
}
.icon.shortcode {
  line-height: 1.15;
}
.icon.shortcode.inverted-colors {
  border-radius: 1000px;
  padding: .4em !important;
  width: 1.15em;
  height: 1.15em;
  text-align: center;
}
.icon.shortcode.box,
.icon.shortcode.border {
  padding: .6em;
  position: relative;
  min-height: 1em;
  min-width: 1em;
  -webkit-transition: all 0.5s;
  transition: all 0.5s;
}
.icon.shortcode.box svg,
.icon.shortcode.border svg {
  position: absolute;
  width: 100%;
  height: 100%;
  top: 0;
  left: 0;
}
.icon.shortcode.box .char,
.icon.shortcode.border .char {
  position: relative;
}
h1 .icon.shortcode,
h2 .icon.shortcode,
h3 .icon.shortcode,
h4 .icon.shortcode,
h5 .icon.shortcode,
h6 .icon.shortcode {
  vertical-align: bottom;
}
.post-article .gallery-post-format  .post-media,
.portfolio-image-wrapper {
  padding: 0;
  border: 0;
  box-shadow: none;
}
.thumbnail.partner {
  display: block;
  position: relative;
  opacity: 0.8;
  padding-bottom: .5em;
  -webkit-transition: all .3s ease;
  transition: all .3s ease;
}
.thumbnail.partner:after {
  color: #aeaeae !important;
  content: attr(title);
  display: block;
  border-top: 1px solid;
  text-align: center;
  position: absolute;
  bottom: -1em;
  left: 0;
  right: 0;
  height: 1.5em;
  opacity: 0;
  -webkit-transition: all .3s ease;
  transition: all .3s ease;
}
.thumbnail.partner:hover {
  opacity: 1;
}
.thumbnail.partner:hover:after {
  opacity: 1;
}
.linkarea {
  padding: 20px;
  cursor: pointer;
  border: 1px solid transparent;
  min-height: 50px;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-background-clip: border-box;
  -moz-background-clip: border;
  background-clip: border-box;
  -webkit-transition: all .5s;
  transition: all .5s;
}
.linkarea.background-accent1 {
  background-color: #F0542D;
}
.linkarea.background-accent1:not(:hover) a,
.linkarea.background-accent1:not(:hover) p,
.linkarea.background-accent1:not(:hover) h1,
.linkarea.background-accent1:not(:hover) h2,
.linkarea.background-accent1:not(:hover) h3,
.linkarea.background-accent1:not(:hover) h4,
.linkarea.background-accent1:not(:hover) h5,
.linkarea.background-accent1:not(:hover) h6 {
  color: #ffffff;
}
.linkarea.background-accent2 {
  background-color: #364352;
}
.linkarea.background-accent2:not(:hover) a,
.linkarea.background-accent2:not(:hover) p,
.linkarea.background-accent2:not(:hover) h1,
.linkarea.background-accent2:not(:hover) h2,
.linkarea.background-accent2:not(:hover) h3,
.linkarea.background-accent2:not(:hover) h4,
.linkarea.background-accent2:not(:hover) h5,
.linkarea.background-accent2:not(:hover) h6 {
  color: #b7c3d0;
}
.linkarea.background-accent3 {
  background-color: #7C8A8D;
}
.linkarea.background-accent3:not(:hover) a,
.linkarea.background-accent3:not(:hover) p,
.linkarea.background-accent3:not(:hover) h1,
.linkarea.background-accent3:not(:hover) h2,
.linkarea.background-accent3:not(:hover) h3,
.linkarea.background-accent3:not(:hover) h4,
.linkarea.background-accent3:not(:hover) h5,
.linkarea.background-accent3:not(:hover) h6 {
  color: #ffffff;
}
.linkarea.background-accent4 {
  background-color: #D8D8D8;
}
.linkarea.background-accent4:not(:hover) a,
.linkarea.background-accent4:not(:hover) p,
.linkarea.background-accent4:not(:hover) h1,
.linkarea.background-accent4:not(:hover) h2,
.linkarea.background-accent4:not(:hover) h3,
.linkarea.background-accent4:not(:hover) h4,
.linkarea.background-accent4:not(:hover) h5,
.linkarea.background-accent4:not(:hover) h6 {
  color: #595959;
}
.linkarea.background-accent5 {
  background-color: #ffffff;
}
.linkarea.background-accent5:not(:hover) a,
.linkarea.background-accent5:not(:hover) p,
.linkarea.background-accent5:not(:hover) h1,
.linkarea.background-accent5:not(:hover) h2,
.linkarea.background-accent5:not(:hover) h3,
.linkarea.background-accent5:not(:hover) h4,
.linkarea.background-accent5:not(:hover) h5,
.linkarea.background-accent5:not(:hover) h6 {
  color: #808080;
}
.linkarea.background-accent6 {
  background-color: #2B2F34;
}
.linkarea.background-accent6:not(:hover) a,
.linkarea.background-accent6:not(:hover) p,
.linkarea.background-accent6:not(:hover) h1,
.linkarea.background-accent6:not(:hover) h2,
.linkarea.background-accent6:not(:hover) h3,
.linkarea.background-accent6:not(:hover) h4,
.linkarea.background-accent6:not(:hover) h5,
.linkarea.background-accent6:not(:hover) h6 {
  color: #a7aeb7;
}
.linkarea.background-accent7 {
  background-color: #EDEDED;
}
.linkarea.background-accent7:not(:hover) a,
.linkarea.background-accent7:not(:hover) p,
.linkarea.background-accent7:not(:hover) h1,
.linkarea.background-accent7:not(:hover) h2,
.linkarea.background-accent7:not(:hover) h3,
.linkarea.background-accent7:not(:hover) h4,
.linkarea.background-accent7:not(:hover) h5,
.linkarea.background-accent7:not(:hover) h6 {
  color: #6e6e6e;
}
.linkarea.background-accent8 {
  background-color: #ffffff;
}
.linkarea.background-accent8:not(:hover) a,
.linkarea.background-accent8:not(:hover) p,
.linkarea.background-accent8:not(:hover) h1,
.linkarea.background-accent8:not(:hover) h2,
.linkarea.background-accent8:not(:hover) h3,
.linkarea.background-accent8:not(:hover) h4,
.linkarea.background-accent8:not(:hover) h5,
.linkarea.background-accent8:not(:hover) h6 {
  color: #808080;
}
.linkarea.accent1.background-transparent {
  background-color: transparent;
  background-color: rgba(240,84,45,0);
  border: solid 1px #EDEDED;
}
.linkarea.accent1:hover,
.linkarea.accent1:focus {
  background-color: #F0542D;
  box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05);
}
.linkarea.accent1:hover a,
.linkarea.accent1:focus a {
  text-decoration: none;
}
.linkarea.accent1:active {
  background-color: #ee4115;
}
.linkarea.accent1:focus {
  border: 1px solid #c3320e;
  outline: none;
}
.linkarea.accent2.background-transparent {
  background-color: transparent;
  background-color: rgba(54,67,82,0);
  border: solid 1px #EDEDED;
}
.linkarea.accent2:hover,
.linkarea.accent2:focus {
  background-color: #364352;
  box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05);
}
.linkarea.accent2:hover a,
.linkarea.accent2:focus a {
  text-decoration: none;
}
.linkarea.accent2:active {
  background-color: #2c3643;
}
.linkarea.accent2:focus {
  border: 1px solid #181d24;
  outline: none;
}
.linkarea.accent3.background-transparent {
  background-color: transparent;
  background-color: rgba(124,138,141,0);
  border: solid 1px #EDEDED;
}
.linkarea.accent3:hover,
.linkarea.accent3:focus {
  background-color: #7C8A8D;
  box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05);
}
.linkarea.accent3:hover a,
.linkarea.accent3:focus a {
  text-decoration: none;
}
.linkarea.accent3:active {
  background-color: #6f7d80;
}
.linkarea.accent3:focus {
  border: 1px solid #586265;
  outline: none;
}
.linkarea.accent4.background-transparent {
  background-color: transparent;
  background-color: rgba(216,216,216,0);
  border: solid 1px #EDEDED;
}
.linkarea.accent4:hover,
.linkarea.accent4:focus {
  background-color: #D8D8D8;
  box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05);
}
.linkarea.accent4:hover a,
.linkarea.accent4:focus a {
  text-decoration: none;
}
.linkarea.accent4:active {
  background-color: #cbcbcb;
}
.linkarea.accent4:focus {
  border: 1px solid #b2b2b2;
  outline: none;
}
.linkarea.accent5.background-transparent {
  background-color: transparent;
  background-color: rgba(255,255,255,0);
  border: solid 1px #EDEDED;
}
.linkarea.accent5:hover,
.linkarea.accent5:focus {
  background-color: #ffffff;
  box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05);
}
.linkarea.accent5:hover a,
.linkarea.accent5:focus a {
  text-decoration: none;
}
.linkarea.accent5:active {
  background-color: #f2f2f2;
}
.linkarea.accent5:focus {
  border: 1px solid #d9d9d9;
  outline: none;
}
.linkarea.accent6.background-transparent {
  background-color: transparent;
  background-color: rgba(43,47,52,0);
  border: solid 1px #EDEDED;
}
.linkarea.accent6:hover,
.linkarea.accent6:focus {
  background-color: #2B2F34;
  box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05);
}
.linkarea.accent6:hover a,
.linkarea.accent6:focus a {
  text-decoration: none;
}
.linkarea.accent6:active {
  background-color: #1f2226;
}
.linkarea.accent6:focus {
  border: 1px solid #08090a;
  outline: none;
}
.linkarea.accent7.background-transparent {
  background-color: transparent;
  background-color: rgba(237,237,237,0);
  border: solid 1px #EDEDED;
}
.linkarea.accent7:hover,
.linkarea.accent7:focus {
  background-color: #EDEDED;
  box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05);
}
.linkarea.accent7:hover a,
.linkarea.accent7:focus a {
  text-decoration: none;
}
.linkarea.accent7:active {
  background-color: #e0e0e0;
}
.linkarea.accent7:focus {
  border: 1px solid #c7c7c7;
  outline: none;
}
.linkarea.accent8.background-transparent {
  background-color: transparent;
  background-color: rgba(255,255,255,0);
  border: solid 1px #EDEDED;
}
.linkarea.accent8:hover,
.linkarea.accent8:focus {
  background-color: #ffffff;
  box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05);
}
.linkarea.accent8:hover a,
.linkarea.accent8:focus a {
  text-decoration: none;
}
.linkarea.accent8:active {
  background-color: #f2f2f2;
}
.linkarea.accent8:focus {
  border: 1px solid #d9d9d9;
  outline: none;
}
.linkarea .first {
  text-align: center;
  padding-bottom: 10px;
}
.linkarea .first img {
  display: inline-block;
  vertical-align: bottom;
}
.linkarea .first:last-child {
  padding-bottom: 0;
}
.linkarea:hover h3 {
  text-decoration: none;
  color: #F0542D !important;
  transition: color 0.4s;
}
body.single-portfolio .layout-full aside.right {
  margin-top: 0 !important;
}
body.single-portfolio .related-portfolios {
  position: relative;
  padding-top: 10px;
  padding-bottom: 50px;
  clear: both;
}
body.single-portfolio .related-portfolios .grid-1-1 {
  padding: 0;
}
body.single-portfolio .related-portfolios .portfolios .portfolio_details {
  padding: 10px 20px 0px 20px;
}
.scrollable-wrapper .portfolios li {
  padding: 0px;
  margin: 0px !important;
}
.portfolios {
  position: relative;
  padding: 0px;
  margin: 0px;
}
.portfolios .wp-pagenavi {
  margin-top: 30px !important;
}
.portfolios.normal > ul > li {
  margin: 0px;
  padding: 0px;
}
.portfolios.normal > ul > li:last-child {
  padding-right: 0;
}
.portfolios > ul {
  overflow: visible;
  padding: 0;
  margin: 0;
}
.portfolios > ul > li {
  position: relative;
  float: left;
  list-style: none outside none;
}
.portfolios > ul.animated > li {
  box-shadow: none !important;
}
.portfolios > ul.transitionable > li {
  overflow: hidden;
}
.portfolios .portfolio-item-wrapper {
  overflow: hidden;
  border: 0;
  border: none;
  background: #ffffff;
  background-clip: content-box;
  text-align: left;
}
.portfolios .portfolio-item-wrapper .excerpt p {
  margin: 5% 0 0;
  padding: 5%;
  font-size: 14px;
  line-height: 16px;
  line-height: 18px;
  font-weight: 500;
  color: #ffffff !important;
  border: 1px solid #fff;
  opacity: 0;
  -webkit-transition: opacity 0.35s, transform 0.35s;
  transition: opacity 0.35s, transform 0.35s;
  -webkit-transform: translate3d(0,20px,0) scale(1.1);
  -ms-transform: translate3d(0,20px,0) scale(1.1);
  transform: translate3d(0,20px,0) scale(1.1);
}
.portfolios .portfolio-item-wrapper h3 {
  -webkit-transition: -webkit-transform 0.35s;
  transition: transform 0.35s;
  -webkit-transform: translate3d(0,20px,0);
  -ms-transform: translate3d(0,20px,0);
  transform: translate3d(0,20px,0);
  opacity: 0;
  margin-top: 15%;
  color: #ffffff !important;
  font-weight: 700;
}
.portfolios .portfolio-item-wrapper .portfolio_details {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  padding: 5%;
  color: #ffffff;
  text-transform: uppercase;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  text-align: center;
}
.portfolios .portfolio-item-wrapper .portfolio_details > a {
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  padding: 5%;
}
.portfolios .no-title.no-description .portfolio-item-wrapper {
  border: 0;
}
.portfolios .no-title.no-description .portfolio-item-wrapper .thumbnail {
  -webkit-transform: translateZ(0);
  -ms-transform: translateZ(0);
  transform: translateZ(0);
  overflow: hidden;
}
.portfolios .state-open .portfolio-item-wrapper h3 {
  -webkit-transform: translate3d(0,0,0);
  -ms-transform: translate3d(0,0,0);
  transform: translate3d(0,0,0);
  opacity: 1;
}
.portfolios .state-open .portfolio-item-wrapper .excerpt p {
  opacity: 1;
  -webkit-transform: translate3d(0,0,0) scale(1);
  -ms-transform: translate3d(0,0,0) scale(1);
  transform: translate3d(0,0,0) scale(1);
}
.portfolios .state-open .portfolio-image .thumbnail img {
  opacity: 0.2;
}
.portfolios .state-open .portfolio-image .thumbnail > img,
.portfolios .state-open .portfolio-image .thumbnail > a > img {
  transform: scale(1.15);
}
.portfolios .state-open .portfolio-image .bxslider-container > li {
  overflow: hidden;
}
.portfolios .portfolio-image {
  position: relative;
  overflow: hidden;
}
.portfolios .portfolio-image .thumbnail {
  display: block;
  max-height: none !important;
  background: #F0542D;
  position: relative;
  overflow: hidden;
}
.portfolios .portfolio-image .thumbnail a.button.accent2 {
  display: none;
}
.portfolios .portfolio-image .thumbnail > a {
  position: relative;
  display: block;
}
.portfolios .portfolio-image .thumbnail img {
  transition: opacity 0.35s;
}
.portfolios .portfolio-image .thumbnail > a img,
.portfolios .portfolio-image .thumbnail > img {
  width: 100%;
  transition: opacity 0.35s, transform 0.35s;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
}
.portfolios .portfolio_details {
  padding: 10px 10px 0px 10px;
}
.portfolios .portfolio_details .title {
  color: #F0542D;
  font-size: 20px;
  line-height: 20px;
  width: 100%;
}
.portfolios .portfolio_details .title:hover {
  color: #5C6268;
}
.portfolios .portfolio_details .title:last-child {
  margin-bottom: 20px;
}
.portfolios .portfolio_details .excerpt {
  margin: 0;
}
.portfolios .portfolio_details .button {
  margin-top: 10px;
}
.portfolios.isotope {
  overflow: hidden;
  margin-bottom: -30px !important;
  padding: 0;
  height: 0;
}
.portfolios.isotope > ul {
  clear: both;
}
.portfolios .style-1.featured {
  margin: 0;
  padding: 0;
  box-shadow: none;
}
body.full .related-portfolios:before {
  position: absolute;
  top: 0;
  left: -100%;
  width: 300%;
  height: 100%;
  background: #fafafa;
  content: "";
}
.portfolio_details .row {
  margin-bottom: 3%;
}
.portfolio-filters {
  z-index: 6;
  text-align: center;
  margin-bottom: 30px;
  padding-top: 10px;
}
.portfolio-filters .inner-wrapper {
  display: inline-block;
  text-align: center;
  line-height: 35px;
  margin-bottom: -1px;
}
.portfolio-filters .inner-wrapper .cbp-filter-item {
  display: inline-block;
  margin: 0 .6em;
  color: #767676;
  transition: all .3s;
  line-height: normal;
  text-transform: uppercase;
  cursor: pointer;
  letter-spacing: 1px;
  font-size: 11px;
  font-weight: 600;
  border-top: 0;
  padding: 0;
  text-align: center;
}
.portfolio-filters .inner-wrapper .cbp-filter-item:hover,
.portfolio-filters .inner-wrapper .cbp-filter-item.cbp-filter-item-active {
  color: #5C6268;
}
.portfolio-filters .inner-wrapper .cbp-filter-item:hover:after,
.portfolio-filters .inner-wrapper .cbp-filter-item.cbp-filter-item-active:after {
  width: 40%;
  opacity: 1;
}
.portfolio-filters .inner-wrapper .cbp-filter-item:after {
  content: " ";
  display: block;
  width: 0%;
  height: 1px;
  background: #F0542D;
  margin: auto;
  margin-top: 5px;
  transition: all .4s;
  opacity: 0;
}
header.page-header .portfolio-filters {
  padding-bottom: 10px;
}
header.page-header .portfolio-filters.portfolio-filters {
  padding: 0px;
}
header.page-header .portfolio-filters .cbp-filter-item:first-child {
  margin-left: 0;
  padding-left: 0;
}
.portfolio-filters .cbp-search {
  display: inline-block;
  margin-top: 15px;
}
.portfolio-filters .cbp-search:hover .cbp-search-icon {
  opacity: 1;
}
.portfolio-filters .cbp-search .cbp-search-icon {
  opacity: 0;
  transition: opacity .5s ease-out;
}
.portfolio-filters .cbp-search .cbp-search-input {
  font-size: 12px;
  margin: 0px;
  font-family: #767676;
  border-color: transparent;
  transition: all .5s ease-out;
  text-align: center;
  padding: 5px;
}
.portfolio-filters .cbp-search .cbp-search-input:hover {
  border-color: rgba(0,0,0,0.1);
  color: #2B2F34;
}
.portfolio-filters .cbp-filter-counter {
  background-color: #2B2F34;
}
.portfolio-filters .cbp-filter-counter:after {
  border-top-color: #2B2F34;
}
.portfolios.scroll-x > ul > li.has-title.no-description {
  margin-bottom: 20px !important;
}
article.type-portfolio {
  margin-bottom: 40px;
  padding-bottom: 0 !important;
}
article.type-portfolio.left-right .portfolio-text-content .portfolio-content > .grid-1-5,
article.type-portfolio.right-only .portfolio-text-content .portfolio-content > .grid-1-5 {
  margin-top: 0;
}
article.type-portfolio .portfolio-text-content .portfolio-content {
  margin-bottom: 0;
  padding-top: 20px;
}
article.type-portfolio .portfolio-text-content .portfolio-content > .grid-1-5 {
  padding-bottom: 20px;
  padding-left: 10px;
}
article.type-portfolio .portfolio-text-content .portfolio-content > .grid-1-5 .cell {
  padding: 10px;
  border-bottom: 1px solid #EDEDED;
}
article.type-portfolio .portfolio-text-content .portfolio-content > .grid-1-5 .cell p {
  margin: 0;
  color: #bababa;
}
article.type-portfolio .portfolio-text-content .portfolio-content > .grid-1-5 .cell p a {
  color: #F0542D;
}
article.type-portfolio .portfolio-text-content .portfolio-content > .grid-1-5 .cell p a:hover,
article.type-portfolio .portfolio-text-content .portfolio-content > .grid-1-5 .cell p a.active {
  color: #5C6268;
  text-decoration: none;
}
article.type-portfolio .portfolio-text-content img {
  display: inline-block;
  max-width: 100%;
}
article.type-portfolio .portfolio-text-content .row-1 .left {
  min-width: 0;
}
article.type-portfolio .portfolio-text-content .row-1 .right {
  float: right;
}
article.type-portfolio .portfolio-image-wrapper {
  position: relative;
  overflow: hidden;
  width: auto !important;
  text-align: center;
}
article.type-portfolio .portfolio-image-wrapper > img {
  width: 100%;
  height: auto;
}
html.touch .portfolios .portfolio-item-wrapper .portfolio_details {
  position: static;
  padding: 30px 15px;
}
html.touch .portfolios .portfolio-item-wrapper .portfolio_details > a {
  position: static;
  padding: 0;
}
html.touch .portfolios .portfolio-item-wrapper h3.title,
html.touch .portfolios .portfolio-item-wrapper .excerpt p {
  opacity: 1;
  transform: none;
  color: #767676 !important;
  margin: 5px 0;
}
.row.has-price {
  margin-right: -10px;
  margin-left: -10px;
  padding-top: 10px;
}
.price-wrapper {
  transition: .3s;
}
.price-wrapper:hover {
  box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05);
  padding-bottom: 0px !important;
}
.price-wrapper .price-title {
  margin: 0;
  font-weight: normal;
  text-align: center;
  line-height: 1;
  background: none;
  padding: 1.3em 1em;
  border: solid 1px #EDEDED;
  border-bottom: none;
}
.price-wrapper .price .content-box {
  color: #6e6e6e;
  border: 1px solid #EDEDED;
  border-width: 0 1px;
  padding: 15px 30px;
}
.price-wrapper .price .content-box ul {
  margin: 0;
  list-style: none;
}
.price-wrapper .price .content-box ul li {
  border-color: #6e6e6e;
  border-bottom: 1px solid #EDEDED;
  text-align: center;
  color: #2B2F34;
  line-height: 1em;
  padding: 18px 0;
}
.price-wrapper .price .meta-box {
  padding: 10px 10px 25px;
  text-align: center;
  border: 1px solid #EDEDED;
  border-top: 0;
}
.price-wrapper .price .meta-box .description {
  padding: 0px;
}
.price-wrapper .price .meta-box a.button-border {
  margin: 15px auto 0;
}
.price-wrapper .price .meta-box a.button-border .btext {
  font-style: normal;
  text-transform: none;
  font-size: 0.9em;
}
.price-wrapper .price .meta-box a.button-border:first-child {
  margin-top: 0;
}
.price-wrapper .value-box {
  color: #ffffff;
  height: 200px;
  background: #7C8A8D;
  text-align: center;
  line-height: 200px;
  cursor: default;
}
.price-wrapper .value-box .value-box-content {
  display: inline-block;
  vertical-align: bottom;
  line-height: 1;
}
.price-wrapper .value-box .value {
  position: relative;
  display: inline-block;
  vertical-align: top;
  font-size: 60px;
  font-family: "Raleway";
  line-height: 38px;
}
.price-wrapper .value-box .meta {
  display: block;
  color: #F0542D;
  text-transform: uppercase;
  font-size: 11px;
  font-family: "Raleway";
  line-height: 1em;
  background: #ffffff;
  height: auto;
  margin: 50px auto 0px auto;
  border-radius: 0;
  padding: 0.8em 0.5em;
  font-weight: bold;
  letter-spacing: 1px;
  min-height: 10px;
}
.price-wrapper.featured {
  margin: 0px 0;
}
.price-wrapper.featured .price-title {
  position: relative;
  font-weight: normal;
  background: none;
  padding: 1.3em 1em;
  border: solid 1px #EDEDED;
  border-bottom: none;
}
.price-wrapper.featured .value-box {
  background: #F0542D;
  position: relative;
}
.price-wrapper.featured .value-box .meta {
  background: #ffffff;
  color: #2B2F34;
}
.price-wrapper.featured .value-box:before {
  position: absolute;
  top: 25px;
  left: 50%;
  margin-left: -17px;
  z-index: 1;
  color: #ffffff;
  content: "\e169";
  font-style: normal;
  font-size: 34px;
  font-family: icomoon;
  line-height: normal;
}
.price-wrapper.featured .value {
  margin-top: 0px;
  font-size: 60px;
  line-height: 38px;
  color: #ffffff;
}
.price-wrapper.featured .meta-box {
  padding: 10px 10px 25px;
}
.wpv-progress {
  position: relative;
  text-align: center;
  width: 130px;
  height: auto;
  line-height: normal;
  font-weight: 300;
  font-size: 1.2em;
  margin: auto;
  margin-top: 20px;
  margin-bottom: 20px;
}
.wpv-progress canvas {
  position: absolute;
  top: 0;
  left: 0;
}
.wpv-progress span:not(.icon) {
  font: normal 24px/30px "Raleway";
  font-size: 40px;
  color: #F0542D;
}
.wpv-progress + .wpv-progress-content {
  color: #2B2F34;
  font-size: 12px;
  line-height: 16px;
}
.wpv-progress.number {
  width: auto;
  font-size: 30px;
}
.wpv-progress.number .icon {
  font-size: 36px;
  display: block;
  margin-bottom: 20px;
  color: #2B2F34;
  font-weight: 100;
}
.wpv-progress.number + .wpv-progress-content {
  padding-top: 20px;
  border-top: 1px solid #EDEDED;
}
.wpv-progress.pie {
  padding-top: 47px;
  min-height: 85px;
  font-size: 1.8em;
  margin-top: 5px;
}
.wpv-progress.pie span:not(.icon) {
  font-size: 2em;
}
.wpv-progress + .wpv-progress-content {
  text-align: center;
}
.services .services-title:empty {
  display: none;
}
.services.has-icon:hover .thumbnail .icon.shortcode,
.services.has-icon:hover .thumbnail img {
  -webkit-transform: scale(1);
  -ms-transform: scale(1);
  transform: scale(1);
  border-color: #ffffff;
}
.services .thumbnail {
  display: block;
  max-height: none !important;
  text-align: inherit;
}
.services .thumbnail img {
  margin: 0px;
  border-radius: 0px;
  padding: 0px;
  border: none;
  transition: border-color .3s, background .3s;
}
.services .thumbnail a {
  display: block;
  position: relative;
}
.services .thumbnail a.has-border {
  padding-bottom: 10px;
}
.services .thumbnail a.has-border:before,
.services .thumbnail a.has-border:after {
  content: "";
  display: none;
  width: 0;
  height: 0;
  border: 10px solid transparent;
  border-top-color: #EDEDED;
  border-bottom: 0;
  position: absolute;
  bottom: 1px;
  left: 50%;
  margin-left: -10px;
  transition: color .3s;
}
.services .thumbnail a.has-border:after {
  border-width: 8px;
  border-top-color: #ffffff;
  border-bottom: 0;
  bottom: 2px;
  margin-left: -8px;
}
.services .thumbnail .icon {
  background: #F0542D;
  color: #ffffff;
  padding: 20px;
  border-radius: 100%;
  text-align: center;
  min-height: inherit;
  min-width: inherit;
  position: relative;
  line-height: 100%;
  -webkit-transform: scale(0.9);
  -ms-transform: scale(0.9);
  transform: scale(0.9);
  margin-bottom: 10px;
  border: solid 5px #F0542D;
}
.services .thumbnail .icon:after {
  left: 50%;
  border: solid transparent;
  content: " ";
  height: 0;
  width: 0;
  position: absolute;
  border-top-color: #F0542D;
  border-width: 0.4em;
  margin-left: -0.4em;
  bottom: -0.6em;
  z-index: -1;
}
.services .services-inside {
  margin: 0;
  padding: 0;
  display: block;
}
.services .services-inside .services-title {
  margin: 17px 0 0 0;
  line-height: 1;
}
.services .services-inside .sep-2 {
  margin: 10px 0 20px;
  padding: 0;
  display: none;
}
.services .services-content {
  padding: 5px 0 10px 0;
}
.services .services-content ul {
  padding: 0;
}
.ie8 .services .services-content ul {
  list-style-position: inside;
}
.services .services-content:last-child,
.services .services-content:last-child {
  padding-bottom: 0 !important;
  margin-bottom: 0;
}
.services .services-content:empty {
  display: none;
}
.services .thumbnail .icon,
.services .services-title a,
.services .services-button-wrap a {
  -webkit-transition: color .2s;
  transition: color .2s;
}
.services:hover .thumbnail .icon,
.services:hover .services-title a,
.services:hover .sep-2,
.services:hover .services-button-wrap a {
  border-color: #F0542D;
  color: #F0542D;
}
.services:hover .thumbnail a {
  font-size: 120% !important;
}
.services:hover .thumbnail a:before,
.services:hover .thumbnail a:after {
  border-top-color: #F0542D;
}
.services.smallimage .services-inside {
  box-shadow: 0 0 0 transparent;
  margin: 0;
  padding: 0;
}
.services.smallimage .services-content {
  display: none;
  padding: 8px 6px 0 6px;
}
html.touch .services.smallimage .services-content {
  display: block;
}
html.touch .services.smallimage .services-inside,
.services.smallimage.transitionable.state-hover .services-inside {
  margin: -13px !important;
  background: #ffffff;
  box-shadow: 0 0 4px rgba(0,0,0,0.2);
  padding: 13px;
}
html.touch .services.smallimage a,
.services.smallimage.transitionable.state-hover a {
  text-decoration: none;
  color: #5C6268;
}
html.touch .services.smallimage .services-content,
.services.smallimage.transitionable.state-hover .services-content {
  opacity: 1;
}
.services.smallimage.transitionable,
.services.smallimage.transitionable .services-inside {
  -webkit-transition: all .2s ease;
  transition: all .2s ease;
}
.services.smallimage .shrinking {
  position: relative;
  background: #F0542D;
  text-align: center;
  height: 0;
  overflow: hidden;
}
.services.smallimage .shrinking .icon {
  padding: 0;
  font-size: 60px;
  transition: none;
  -webkit-font-smoothing: subpixel-antialiased;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  transform: translateZ(0);
  -webkit-transform: translateZ(0);
}
.sitemap ul {
  list-style-type: none;
}
.sitemap ul li {
  padding-left: 1.5em;
  text-indent: -1.5em;
}
.sitemap ul li:before {
  text-indent: 0;
  font-family: theme;
  padding-right: .5em;
  font-size: 8px;
  vertical-align: middle;
}
.sitemap ul > li:before {
  content: "\e003";
}
.sitemap ul > li li {
  font-size: .9em;
}
.sitemap ul > li li:before {
  content: "\e005";
}
.sitemap .top + h2 {
  margin-top: 20px;
}
.slogan {
  position: relative;
}
.slogan em {
  font-size: 12px;
  line-height: 0.8em;
}
.slogan .title {
  font-size: 24px;
  margin-bottom: 18px;
}
.slogan .description {
  font-size: 16px !important;
  line-height: 1.4em !important;
  font-weight: normal;
}
.slogan h3 {
  line-height: 1;
}
.slogan .slogan-content,
.slogan .button-wrp {
  vertical-align: middle;
}
.slogan.has-button .slogan-content,
.slogan .button-wrp {
  display: table-cell;
}
.slogan .button-wrp {
  padding-left: 30px;
  text-align: center;
  white-space: nowrap;
}
.slogan .slogan-content {
  width: 100%;
}
.slogan .button-wrp .button {
  border: none;
  font-size: 18px !important;
  line-height: 1 !important;
  padding: 0 !important;
  margin: auto !important;
  vertical-align: middle;
  white-space: nowrap;
}
.slogan .vamtam-button.button-filled span.icon {
  font-size: 20px;
}
.has-background > .slogan,
.has-background > div > .slogan {
  padding: 30px 15px;
}
table.vamtam-styled {
  width: 100%;
  border-collapse: collapse;
  border-spacing: 0;
  border: none;
  padding-right: 10px;
}
table.vamtam-styled th,
table.vamtam-styled td,
table.vamtam-styled caption {
  padding: 5px;
  border: 1px solid #EDEDED;
}
table.vamtam-styled caption {
  border-bottom: none;
}
table.vamtam-styled thead th {
  padding: 10px;
  vertical-align: bottom;
  text-align: left;
  padding: 10px 5px 5px 5px;
  border-right: 1px solid #d4d4d4;
  font-size: 18px;
  font-weight: normal;
  background-color: #fafafa;
  color: #a7a7a7;
}
table.vamtam-styled thead th:last-child,
table.vamtam-styled thead th .last-child {
  border-right: 0px;
}
table.vamtam-styled tbody tr:nth-child(even) td {
  background: #ffffff;
  color: inherit;
}
table.vamtam-styled tbody tr:last-child td {
  border-bottom: 0;
}
table.vamtam-styled td {
  border: none;
  padding: 8px 0px;
}
table.vamtam-styled td:last-child {
  border: none;
}
table.vamtam-styled tfoot {
  font-size: 12px;
  font-style: normal;
  color: #adadad;
}
.wpv-tabs {
  border: 0;
}
.wpv-tabs > .ui-tabs-nav {
  margin: 0;
  padding: 0;
  border: 0;
  border-radius: 0;
  list-style: none;
  -webkit-transform: none;
}
.wpv-tabs > .ui-tabs-nav li {
  position: relative;
  z-index: 2;
  display: block;
  float: left;
  background: none;
  top: 0;
  margin: 0;
  border: 0;
  border-radius: 0;
}
.wpv-tabs > .ui-tabs-nav li a {
  font: 300 20px/26px "Raleway";
  position: relative;
  display: block;
  padding: 25px;
  outline: none;
  line-height: 1;
  cursor: pointer;
}
.wpv-tabs > .ui-tabs-nav li.has-icon {
  display: table;
}
.wpv-tabs > .ui-tabs-nav li.has-icon .icon.shortcode,
.wpv-tabs > .ui-tabs-nav li.has-icon .title-text {
  display: table-cell;
}
.wpv-tabs > .ui-tabs-nav li .icon.shortcode {
  font-size: 22px;
  padding: 0 15px 0 5px;
}
.wpv-tabs > .ui-tabs-nav li.ui-state-default a {
  color: #F0542D;
}
.wpv-tabs > .ui-tabs-nav li.ui-state-hover a,
.wpv-tabs > .ui-tabs-nav li.ui-state-active a,
.wpv-tabs > .ui-tabs-nav li.ui-state-selected a {
  text-decoration: none;
  color: #F0542D;
}
.wpv-tabs .pane {
  clear: both;
  padding: 10px 30px 20px 30px;
  -webkit-transform: none;
}
.wpv-tabs .pane p {
  padding-top: 0;
  padding-bottom: 0;
}
.wpv-tabs,
.wpv-tabs:after {
  display: block;
  clear: both;
  content: "";
}
.wpv-tabs.horizontal .ui-tabs-nav {
  border-radius: 1px 1px 0 0;
}
.wpv-tabs.horizontal .ui-tabs-nav li {
  float: none;
  display: table-cell;
  transition: all .3s;
  padding: 0;
}
.wpv-tabs.horizontal .ui-tabs-nav li:first-child {
  border-top-left-radius: 1px;
}
.wpv-tabs.horizontal .ui-tabs-nav li:last-child {
  border-top-right-radius: 1px;
}
.wpv-tabs.horizontal .pane {
  border-radius: 0 0 1px 1px;
  background: #ffffff;
}
.wpv-tabs.vertical {
  position: relative;
  margin: 0 -60px;
  padding: 0;
}
.wpv-tabs.vertical:before {
  position: absolute;
  right: -199%;
  z-index: 5;
  width: 200%;
  height: 100%;
  content: "";
}
.wpv-tabs.vertical .ui-tabs-nav {
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  float: left;
  margin-top: 0;
  width: 20%;
  border: none;
}
body.layout-full .wpv-tabs.vertical .ui-tabs-nav,
body.layout-right-only .wpv-tabs.vertical .ui-tabs-nav {
  padding-left: 60px;
}
body.layout-left-right .wpv-tabs.vertical .ui-tabs-nav,
body.layout-left-only .wpv-tabs.vertical .ui-tabs-nav {
  padding-left: 15px;
}
.wpv-tabs.vertical .ui-tabs-nav:before {
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  position: absolute;
  left: -200%;
  z-index: 2;
  width: 200%;
  height: 100%;
  content: "";
}
.wpv-tabs.vertical .ui-tabs-nav li {
  -webkit-transition: background .5s;
  transition: background .5s;
  float: none;
  margin: 0;
  border: 0;
  border-bottom: 0px solid;
  padding: 0;
  white-space: normal;
  opacity: 1;
}
.wpv-tabs.vertical .ui-tabs-nav li a {
  font: 600 12px/14px "Raleway";
  display: table;
  padding: 11px 0;
  min-height: 44px;
  width: 100%;
  font-size: 16px;
}
.wpv-tabs.vertical .ui-tabs-nav li a .icon.shortcode {
  padding-right: 20px;
  vertical-align: middle;
  font-size: 44px;
  line-height: 49px;
  display: table-cell;
}
.wpv-tabs.vertical .ui-tabs-nav li a .title-text {
  width: 100%;
  font-weight: normal;
  vertical-align: middle;
  display: table-cell;
  line-height: 1.1;
}
.wpv-tabs.vertical .ui-tabs-nav li a .title-text:first-child {
  padding-left: 1em;
}
.wpv-tabs.vertical .ui-tabs-nav li:first-child {
  margin-left: 0;
  margin-top: 0;
}
.wpv-tabs.vertical .ui-tabs-nav li:last-child {
  margin-bottom: 60px;
}
.wpv-tabs.vertical .ui-tabs-nav li.ui-state-active,
.wpv-tabs.vertical .ui-tabs-nav li.ui-state-selected,
.wpv-tabs.vertical .ui-tabs-nav li.ui-state-hover {
  border-right: 0;
  border-left: 0;
  text-decoration: none;
  opacity: 1;
}
.wpv-tabs.vertical .ui-tabs-nav li.ui-state-active a,
.wpv-tabs.vertical .ui-tabs-nav li.ui-state-selected a,
.wpv-tabs.vertical .ui-tabs-nav li.ui-state-hover a {
  border: none;
}
.wpv-tabs.vertical .ui-tabs-nav li.inactive-block-title {
  padding: 45px 0;
  border: none;
  opacity: 1;
}
.wpv-tabs.vertical .ui-tabs-nav li.inactive-block-title > h1,
.wpv-tabs.vertical .ui-tabs-nav li.inactive-block-title > h2,
.wpv-tabs.vertical .ui-tabs-nav li.inactive-block-title > h3,
.wpv-tabs.vertical .ui-tabs-nav li.inactive-block-title > h4,
.wpv-tabs.vertical .ui-tabs-nav li.inactive-block-title > h5,
.wpv-tabs.vertical .ui-tabs-nav li.inactive-block-title > h6 {
  font: 800 26px/30px "Raleway";
  word-wrap: break-word;
}
.wpv-tabs.vertical .pane {
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  float: right;
  clear: none;
  padding: 0 60px;
  width: 80%;
  background: transparent;
}
.wpv-tabs.vertical .pane:before {
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  position: absolute;
  top: 30px;
  left: 0;
  z-index: 1;
  margin-top: -30px;
  width: 20%;
  height: 100%;
  content: "";
}
.wpv-tabs .pane.ui-accordion-content {
  float: none;
  width: 100%;
  padding: 0;
}
body.boxed .wpv-tabs.vertical:before,
body.boxed .wpv-tabs.vertical .ui-tabs-nav:before {
  display: none;
}
body.full.layout-left-right .wpv-tabs.vertical .ui-tabs-nav:before,
body.full.layout-left-only .wpv-tabs.vertical .ui-tabs-nav:before {
  display: none;
}
body.full.layout-left-right .wpv-tabs.vertical:before,
body.full.layout-right-only .wpv-tabs.vertical:before {
  display: none;
}
.team-member-row {
  position: relative;
  z-index: 60;
}
.team-member-row > div {
  position: static;
}
@media all and (-webkit-min-device-pixel-ratio: 0) {
  .team-member-row {
    display: inline-table;
    width: 100%;
    table-layout: fixed;
  }
}
.team-member {
  text-align: left;
  border: solid 1px rgba(43,47,52,0.1);
  padding-top: 0 !important;
  padding-bottom: 0 !important;
  margin: 10px 0;
}
.team-member .thumbnail {
  overflow: hidden;
  background: #2B2F34;
  position: relative;
}
.team-member img {
  -webkit-backface-visibility: hidden;
  -webkit-transition: opacity 0.35s, -webkit-transform 0.35s;
  transition: opacity 0.35s, transform 0.35s;
  -webkit-transform: translate3d(0,0,300px);
  -ms-transform: translate3d(0,0,300px);
  transform: translate3d(0,0,300px);
  width: 100%;
}
html.no-touch .team-member:hover {
  box-shadow: 0px 2px 4px 0px rgba(0,0,0,0.05);
}
html.no-touch .team-member:hover img {
  opacity: 0.6;
  -webkit-transform: scale(1.15);
  -ms-transform: scale(1.15);
  transform: scale(1.15);
}
html.touch .team-member .share-icons,
.team-member:hover .share-icons {
  -webkit-transform: translate3d(0,0,0);
  -ms-transform: translate3d(0,0,0);
  transform: translate3d(0,0,0);
  opacity: 1;
  bottom: 40%;
  white-space: normal;
}
html.touch .team-member .share-icons .icon,
.team-member:hover .share-icons .icon {
  margin: 10px 5px 0px 5px;
}
.team-member .sep-text {
  margin: 0 0 20px 0;
}
.team-member .team-member-info {
  background: #ffffff;
  margin-top: 0px;
  padding: 15px 20px 25px 20px;
}
.team-member .team-member-info h3 {
  margin-top: 5px;
  margin-bottom: 0;
  font-style: normal;
  font-size: 20px;
}
.team-member .team-member-info h3 a {
  font-size: inherit;
  font-style: normal;
  color: #4A4F55;
  font-weight: normal;
}
.team-member .team-member-info h3 a:hover {
  color: #F0542D;
}
.team-member .team-member-info h5 {
  margin-top: 0;
  padding-bottom: 15px;
  color: #364352 !important;
  font-weight: normal;
  margin-top: 5px;
  border-bottom: none;
  font-weight: inherit;
  margin-bottom: 0px;
}
.team-member .team-member-info a[href^="mailto:"] {
  word-wrap: break-word;
}
.team-member .team-member-position {
  text-transform: uppercase;
  font-size: 11px;
}
.team-member .team-member-phone {
  padding-bottom: 5px;
}
.team-member .description {
  padding: 0 20px;
}
.team-member .share-icons {
  margin-top: 10px;
  white-space: nowrap;
  position: absolute;
  left: 0;
  top: auto;
  height: auto;
  -webkit-transition: -webkit-transform 0.35s;
  transition: transform 0.35s;
  -webkit-transform: translate3d( 0, 100%, 0 );
  -ms-transform: translate3d( 0, 100%, 0 );
  transform: translate3d( 0, 100%, 0 );
  bottom: 30%;
  width: 100%;
  margin: 0px;
  padding: 0px;
  text-align: center;
  opacity: 0;
  background: none;
}
.team-member .share-icons a:hover .icon.shortcode.use-hover {
  background: #ffffff;
  color: #F0542D !important;
}
html.touch .team-member .share-icons {
  -webkit-transform: translate3d( 0, 0, 0 );
  -ms-transform: translate3d( 0, 0, 0 );
  transform: translate3d( 0, 0, 0 );
}
.team-member .share-icons .icon {
  margin: 0px 5px 0px 5px;
  width: 16px;
  height: 16px;
  color: #ffffff;
  text-align: center;
  font-size: 16px !important;
  line-height: 1;
  display: inline-block;
  padding: 10px;
  border-radius: 100%;
  border: solid 1px rgba(255,255,255,0.5);
  background: transparent;
}
.team-member .share-icons .icon:hover {
  -webkit-transition: color .5s ease 0s;
  transition: color .5s ease 0s;
  color: #F0542D;
}
.team-member .description {
  display: none;
}
.team-member .team-member-bio {
  border: none;
  padding: 0px 20px 25px 20px;
  margin-top: 0px;
}
.single-tweet {
  text-align: center;
}
.single-tweet .tweet-text {
  color: #a9a9a9;
}
.single-tweet .tweet-text p {
  margin: 1em 0 .5em 0;
}
.single-tweet .tweet-time {
  text-transform: uppercase;
  color: #a9a9a9;
  font-size: 10px;
}
.single-tweet + .tweet-divider {
  margin: 16px auto;
  max-width: 250px;
  height: 1px;
  background: #EDEDED;
}
.shortcode-tooltip {
  position: relative;
  border-bottom: 1px dotted;
}
.shortcode-tooltip .tooltip {
  display: none;
  position: absolute;
  left: 50%;
  bottom: 35px;
  background: #fff;
  color: #000;
  padding: 10px;
  min-width: 200px;
  z-index: 5000;
  overflow: visible;
  text-indent: 0;
  border-radius: 2px;
  box-shadow: 0 1px 3px rgba(0,0,0,0.5);
}
.shortcode-tooltip .tooltip:before {
  content: "";
  position: absolute;
  top: 100%;
  left: 50%;
  width: 0;
  height: 0;
  border-top: 10px solid rgba(0,0,0,0.5);
  border-left: 10px inset transparent;
  border-right: 10px inset transparent;
  margin: 1px auto auto -5px;
}
.shortcode-tooltip .tooltip:after {
  content: "";
  position: absolute;
  top: 100%;
  left: 50%;
  width: 0;
  height: 0;
  border-top: 10px solid #FFF;
  border-left: 10px inset transparent;
  border-right: 10px inset transparent;
  margin: 0 auto auto -5px;
}
.no-boxshadow .shortcode-tooltip .tooltip {
  border: 1px solid #ddd;
}
.no-boxshadow .shortcode-tooltip .tooltip:before,
.no-boxshadow .shortcode-tooltip .tooltip:after {
  display: none;
}
.shortcode-tooltip .tooltip .tooltip-arrow {
  display: none;
}
div.wpcf7-response-output,
div.wpcf7-validation-errors {
  margin: 1em 0 0 !important;
  position: relative;
  z-index: 8;
  background: #ffffff;
}
.wpcf7-not-valid,
input.wpcf7-not-valid {
  border-color: #D94729;
}
.wpcf7-not-valid-tip {
  display: none !important;
}
div.wpcf7 .wpcf7-form {
  display: block;
  margin: 0;
}
div.wpcf7 .wpcf7-form .wpcf7-submit {
  margin-top: 0;
  margin-right: 10px;
  font-size: 1em;
  font-weight: normal;
  display: inline-block;
  text-align: center;
  cursor: pointer;
  position: relative;
  z-index: 0;
  vertical-align: middle;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
  text-decoration: none;
  text-shadow: none;
  line-height: 1.15em;
  border-widht: 2px;
  padding: 0;
  text-align: center !important;
  background: #F0542D;
  color: #ffffff;
  padding: 0.8em 1.6em;
  color: #F0542D;
  border: solid 2px #F0542D;
  background: transparent;
  letter-spacing: 2px;
  padding: 0.6em 1.4em;
}
div.wpcf7 .wpcf7-form .wpcf7-submit,
div.wpcf7 .wpcf7-form .wpcf7-submit span {
  transition: color .3s ease, border .3s ease, background .3s ease;
}
div.wpcf7 .wpcf7-form .wpcf7-submit span {
  display: inline-block;
  font-size: 1em;
  line-height: inherit;
  padding: .3em .4em;
  margin: 0 0;
  vertical-align: baseline;
}
div.wpcf7 .wpcf7-form .wpcf7-submit span.icon {
  font-size: 100%;
  vertical-align: bottom !important;
}
div.wpcf7 .wpcf7-form .wpcf7-submit span.icon.shortcode.inverted-colors {
  font-size: 100%;
  box-shadow: 0 1px 1px rgba(0,0,0,0.1) inset, 0 1px 1px rgba(255,255,255,0.2);
  text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}
div.wpcf7 .wpcf7-form .wpcf7-submit span.icon:first-child,
div.wpcf7 .wpcf7-form .wpcf7-submit span.icon:last-child {
  vertical-align: top;
  background: none;
}
div.wpcf7 .wpcf7-form .wpcf7-submit span.icon:first-child {
  padding: .5em 0 .5em .8em !important;
}
div.wpcf7 .wpcf7-form .wpcf7-submit span.icon:last-child {
  padding: .5em .8em .5em 0 !important;
}
div.wpcf7 .wpcf7-form .wpcf7-submit span.btext {
  position: relative;
  font-weight: 500;
  vertical-align: middle;
  padding: 0.7em 1.2em;
  letter-spacing: 1px;
}
div.wpcf7 .wpcf7-form .wpcf7-submit:hover,
div.wpcf7 .wpcf7-form .wpcf7-submit:hover span {
  text-decoration: none;
}
div.wpcf7 .wpcf7-form .wpcf7-submit span {
  color: #ffffff;
}
div.wpcf7 .wpcf7-form .wpcf7-submit:hover,
div.wpcf7 .wpcf7-form .wpcf7-submit:focus,
div.wpcf7 .wpcf7-form .wpcf7-submit:active {
  background: #7C8A8D;
}
div.wpcf7 .wpcf7-form .wpcf7-submit:hover,
div.wpcf7 .wpcf7-form .wpcf7-submit:hover span,
div.wpcf7 .wpcf7-form .wpcf7-submit:focus,
div.wpcf7 .wpcf7-form .wpcf7-submit:focus span,
div.wpcf7 .wpcf7-form .wpcf7-submit:active,
div.wpcf7 .wpcf7-form .wpcf7-submit:active span {
  color: #ffffff;
}
div.wpcf7 .wpcf7-form .wpcf7-submit:hover {
  background: #F0542D !important;
  color: #ffffff;
}
.email-offers {
  display: inline-block;
  vertical-align: top;
  margin: 0px;
}
.email-offers input {
  margin: 0px !important;
}
.wpcf7-file {
  background: #fff;
  padding: 10px;
  border: 1px solid #EDEDED;
  margin: 0 0 20px 0;
  font-size: 14px;
  -moz-box-shadow: 0px 2px 2px 0px rgba(0,0,0,0.1) !important;
  box-shadow: 0px 2px 2px 0px rgba(0,0,0,0.1) !important;
}
.vamtam-rsvp-form label {
  font-size: 12px;
  color: #364352;
}
.vamtam-rsvp-form input[type="text"],
.vamtam-rsvp-form input[type="number"],
.vamtam-rsvp-form select {
  font-size: 20px;
  padding: 17px;
  background: #ffffff !important;
  color: #F0542D;
}
.vamtam-rsvp-form select {
  -webkit-appearance: none;
  -moz-appearance: none;
  appearance: none;
}
.vamtam-rsvp-form .wpcf7-form-control-wrap.dropdown {
  position: relative;
  display: block;
}
.vamtam-rsvp-form .wpcf7-form-control-wrap.dropdown::after {
  content: '';
  display: block;
  position: absolute;
  top: 24px;
  right: 18px;
  border: 5px solid transparent;
  border-top-color: #364352;
  pointer-events: none;
}
.vamtam-rsvp-form .wpcf7-form-control-wrap.your-name {
  width: 100%;
}
.vamtam-rsvp-form .ajax-loader {
  display: none;
}
.wpcf7-form-control.wpcf7-submit:disabled {
  cursor: not-allowed !important;
}
.wpv-wysija-newsletter,
#main .wpv-wysija-newsletter {
  text-align: center;
  font-size: 14px;
}
.wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija,
#main .wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija {
  display: inline-block;
  position: relative;
}
.wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija label,
#main .wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija label {
  display: none;
}
.wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija input[name="wysija[user][email]"],
#main .wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija input[name="wysija[user][email]"] {
  width: 210px;
  height: 50px;
  border: 0;
  background: #ffffff;
  border-radius: 0;
  margin: 0 20px;
}
.wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija .wysija-submit,
.wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija .wysija-paragraph,
.wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija input[name="wysija[user][email]"],
#main .wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija .wysija-submit,
#main .wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija .wysija-paragraph,
#main .wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija input[name="wysija[user][email]"] {
  display: inline-block;
  vertical-align: middle;
}
.wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija .wysija-submit,
#main .wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija .wysija-submit {
  background: none;
  color: #F0542D;
  border: 1px solid #F0542D;
  margin-top: 0;
  padding: 10px 30px 10px 30px;
  font-size: 19px;
  border-radius: 0;
}
.wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija .wysija-submit:hover,
#main .wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija .wysija-submit:hover {
  color: #ffffff !important;
  transition: color .3s ease;
  background: #F0542D;
  border-color: #F0542D;
}
.wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija .formError,
#main .wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija .formError {
  left: 20px !important;
  width: 210px !important;
  top: auto !important;
  bottom: 100% !important;
  opacity: 1 !important;
}
.wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija .formError .formErrorContent,
#main .wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija .formError .formErrorContent {
  width: 190px !important;
  border: 0;
  background: #ffffff;
  color: #2B2F34;
}
.wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija .allmsgs > div,
#main .wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija .allmsgs > div {
  margin: 0 0 0 20px;
  display: inline-block;
  vertical-align: middle;
}
.wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija .allmsgs > div ul,
#main .wpv-wysija-newsletter .widget_wysija_cont.shortcode_wysija .allmsgs > div ul {
  margin-left: 0;
}
.widget {
  margin: 0 auto 30px;
  padding: 0;
}
.widget .widget-title {
  position: relative;
  overflow: hidden;
  margin: 0;
  padding: 0 5px 5px 0;
  border-bottom: 1px solid #EDEDED;
  margin-bottom: 10px;
}
.widget .widget-title,
.widget .widget-title a {
  word-wrap: break-word;
  line-height: 1.7em !important;
}
.widget .widget-title > .icon {
  margin-right: 10px;
  vertical-align: baseline;
}
.widget:last-child {
  margin-bottom: 0;
  padding-bottom: 0;
  border-bottom: 0;
  background: transparent;
}
.widget.last-child {
  margin-bottom: 0;
  padding-bottom: 0;
  border-bottom: 0;
  background: transparent;
}
.widget ul,
.widget ol {
  margin: 0;
  padding: 0;
  list-style: none;
}
.widget li {
  position: relative;
  overflow: hidden;
  margin: 0;
  padding: 10px 0;
  transition: all .2s ease;
  border-bottom: 1px solid #EDEDED;
  text-overflow: ellipsis;
  word-wrap: break-word;
  font: normal 14px/20px "Raleway" !important;
}
.widget li:first-child {
  padding-top: 0;
}
.widget select {
  max-width: 100%;
}
.widget .lang_sel_click li {
  overflow: visible;
}
.widget .lang_sel_click li a {
  transition: none;
}
.widget-box {
  padding: 6px 0 0 0;
}
.widget-box:after {
  position: relative;
  top: 10px;
  display: block;
  clear: both;
  margin: 0 -10px;
  height: 1px;
  content: "";
}
aside.left .widget,
aside.right .widget,
#header-sidebars .widget {
  margin: 0 0 60px 0;
  padding: 0;
}
aside.left .widget .widget-title,
aside.right .widget .widget-title,
#header-sidebars .widget .widget-title {
  background: transparent;
}
aside.left .widget .widget-title > .icon,
aside.right .widget .widget-title > .icon,
#header-sidebars .widget .widget-title > .icon {
  margin-top: -3px;
}
aside.left .widget .widget-title > .icon.shortcode,
aside.right .widget .widget-title > .icon.shortcode,
#header-sidebars .widget .widget-title > .icon.shortcode {
  color: #EDEDED;
}
aside.left .widget .widget-title + ul,
aside.left .widget .widget-title + ol,
aside.left .widget .widget-title + div,
aside.left .widget .widget-title + form,
aside.right .widget .widget-title + ul,
aside.right .widget .widget-title + ol,
aside.right .widget .widget-title + div,
aside.right .widget .widget-title + form,
#header-sidebars .widget .widget-title + ul,
#header-sidebars .widget .widget-title + ol,
#header-sidebars .widget .widget-title + div,
#header-sidebars .widget .widget-title + form {
  border: none;
}
aside.left .widget > ul,
aside.left .widget > ol,
aside.left .widget > div,
aside.left .widget > h4+form,
aside.right .widget > ul,
aside.right .widget > ol,
aside.right .widget > div,
aside.right .widget > h4+form,
#header-sidebars .widget > ul,
#header-sidebars .widget > ol,
#header-sidebars .widget > div,
#header-sidebars .widget > h4+form {
  padding: 6px 0 0 0;
}
aside.left .widget > ul:after,
aside.left .widget > ol:after,
aside.left .widget > div:after,
aside.left .widget > h4+form:after,
aside.right .widget > ul:after,
aside.right .widget > ol:after,
aside.right .widget > div:after,
aside.right .widget > h4+form:after,
#header-sidebars .widget > ul:after,
#header-sidebars .widget > ol:after,
#header-sidebars .widget > div:after,
#header-sidebars .widget > h4+form:after {
  position: relative;
  top: 10px;
  display: block;
  clear: both;
  margin: 0 -10px;
  height: 1px;
  content: "";
}
#footer-sidebars .widget .widget-title {
  white-space: normal;
}
.wpv_authors .authors_list > li {
  padding: 0 0;
  border-bottom: 0 solid #EDEDED;
  position: relative;
  overflow: hidden;
  margin: 0;
  text-overflow: ellipsis;
}
.wpv_authors .authors_list > li:first-child {
  padding-top: 0;
}
.wpv_authors .authors_list > li:last-child {
  padding-bottom: 0;
  border-bottom: 0;
}
.wpv_authors .gravatar {
  float: left;
}
.wpv_authors .author_name  h6 {
  margin-bottom: 5px;
}
.wpv_authors .author_name  h6 a {
  font-size: 16px !important;
}
.wpv_authors .author_info:not(:first-child) {
  padding-left: 50px;
}
.wpv_authors .author_desc {
  padding-bottom: 10px;
}
.wpv_authors .post-count {
  font-size: .8em;
}
.widget_calendar {
  max-width: 100%;
}
.widget_calendar #wp-calendar {
  width: 100%;
}
.widget_calendar #wp-calendar caption {
  font: 300 20px/26px "Raleway";
  color: #F0542D;
  padding: 0 0 10px 0;
}
.widget_calendar #wp-calendar thead {
  border-top: 1px solid #EDEDED;
  border-bottom: 1px solid #EDEDED;
}
.widget_calendar #wp-calendar tbody {
  padding: 10px 0;
}
.widget_calendar #wp-calendar tbody tr:first-child td {
  padding-top: 10px;
}
.widget_calendar #wp-calendar tbody tr:last-child td {
  padding-bottom: 10px;
}
.widget_calendar #wp-calendar tfoot {
  border-top: 1px solid #EDEDED;
}
.widget_calendar #wp-calendar tfoot td {
  padding-top: 10px;
  margin-top: 5px;
}
.widget_calendar #wp-calendar tfoot td:first-child {
  text-align: left;
}
.widget_calendar #wp-calendar tfoot td:last-child {
  text-align: right;
}
.widget_calendar #wp-calendar tfoot td a {
  font-weight: bold;
}
.widget_calendar #wp-calendar td#today {
  background: #F0542D;
  color: #ffffff;
  border-radius: 3px;
}
.widget_calendar th,
.widget_calendar td {
  padding: 2px;
  text-align: center;
}
.widget_calendar th {
  font-size: 100%;
}
.contact_info_wrap .icon {
  padding-right: 8px;
}
.contact_info_wrap li {
  padding: 4px 0 4px 24px;
}
.contact_info_wrap li > .icon {
  margin-left: -24px;
}
.contact_info_wrap > p:first-child {
  margin-top: 0;
}
.flickr_wrap {
  padding: 5px 5px 5px 0 !important;
}
.flickr_badge_image {
  float: left;
  padding: 5px;
  position: relative;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.flickr_badge_image img {
  width: 60px;
  display: block;
}
.ie8 .flickr_badge_image {
  width: 83px;
}
aside .flickr_badge_image {
  max-width: 50%;
}
aside .flickr_badge_image img {
  width: 100%;
  height: auto;
}
.wpv_icon_link li {
  padding: 10px 0;
}
.wpv_icon_link li:first-child {
  padding-top: 0;
}
.wpv_icon_link a {
  color: inherit;
  display: block;
  height: 32px;
  line-height: 32px;
  position: relative;
}
.wpv_icon_link a span {
  line-height: 32px;
  height: 32px;
  display: block;
  position: absolute;
}
.wpv_icon_link .content {
  left: 0;
  top: 0;
  padding-left: 40px;
}
.wpv_icon_link .before {
  left: 0;
  top: 2px;
  font-size: 25px;
}
.wpv_icon_link .after {
  right: 0;
  top: 0;
  font-size: 1.5em;
  opacity: 0.6;
  display: none;
}
.wpv_icon_link [data-icon-type="facebook"] {
  color: #39599f;
}
.wpv_icon_link [data-icon-type="twitter"] {
  color: #45b0e3;
}
.wpv_icon_link [data-icon-type="googleplus"] {
  color: #d04f40;
}
.wpv_icon_link [data-icon-type="pinterest1"] {
  color: #cb2027;
}
.wpv_icon_link [data-icon-type="flickr"] {
  color: #e956a2;
}
.wpv_icon_link [data-icon-type="vimeo"] {
  color: #1ab7ea;
}
.wpv_icon_link [data-icon-type="youtube"] {
  color: #f33;
}
.wpv_icon_link [data-icon-type="linkedin"] {
  color: #4875B4;
}
.wpv_icon_link [data-icon-type="wordpress"] {
  color: #464646;
}
#top-nav-sidebar .wpv_icon_link {
  margin-top: -6.25px;
  margin-bottom: -6.25px;
}
.wpv_posts .wpv-tabs.horizontal .ui-tabs-nav {
  display: block;
}
.wpv_posts .wpv-tabs.horizontal .ui-tabs-nav li {
  display: block;
  float: left;
  background: #ffffff;
  border: 1px solid #EDEDED;
  padding: 10px;
  border-radius: 1px 1px 0 0;
  margin-bottom: -1px;
  margin-right: -1px;
}
.wpv_posts .wpv-tabs.horizontal .ui-tabs-nav li .icon {
  color: #2B2F34;
}
.wpv_posts .wpv-tabs.horizontal .ui-tabs-nav li:hover .icon,
.wpv_posts .wpv-tabs.horizontal .ui-tabs-nav li.ui-state-active .icon,
.wpv_posts .wpv-tabs.horizontal .ui-tabs-nav li.ui-state-selected .icon {
  color: #F0542D;
}
.wpv_posts .wpv-tabs.horizontal .ui-tabs-nav li.ui-state-active {
  border-bottom-color: #ffffff;
}
.wpv_posts .wpv-tabs.horizontal .ui-tabs-nav li a {
  padding: 5px;
}
.wpv_posts .wpv-tabs.horizontal .ui-tabs-nav li a:hover {
  text-decoration: none;
}
.wpv_posts .wpv-tabs.horizontal .ui-tabs-nav li a:hover .icon {
  color: #F0542D !important;
  font-size: 20px;
}
.wpv_posts .wpv-tabs.horizontal .ui-tabs-nav li a .icon {
  color: #2B2F34;
  text-align: center;
  font-size: 20px;
  padding: 0;
}
.wpv_posts .wpv-tabs.horizontal .ui-tabs-nav li .icon {
  display: block;
  text-transform: none;
  font-size: 17px;
  line-height: 22px;
}
.wpv_posts [data-single] .icon {
  color: #F0542D;
}
.wpv_posts .ui-tabs-panel {
  background: transparent;
  padding: 0;
}
.wpv_posts .ui-tabs-panel .tagcloud {
  margin-bottom: -5px;
  padding-top: 10px !important;
}
.wpv_posts .wpv-tabs.horizontal .pane {
  background: #ffffff;
  color: #2B2F34;
  border: 1px solid #EDEDED;
  border-top-right-radius: 1px;
}
.wpv_posts .wpv-tabs.horizontal .pane.tab-comments .title a:last-child {
  font-size: 11px;
  color: #7C8A8D;
}
.wpv_posts .posts_list {
  padding: 0;
  background: transparent;
}
.wpv_posts .posts_list li {
  padding: 10px;
  display: table;
  width: 100%;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.wpv_posts .posts_list li .thumbnail {
  position: relative;
  display: table-cell;
  width: 70px;
  vertical-align: top;
}
.wpv_posts .posts_list li .thumbnail img {
  width: 70px;
  height: auto;
  padding-right: 10px;
}
.wpv_posts .posts_list li .post_extra_info {
  display: table-cell;
  vertical-align: text-top;
  padding-left: 0;
  font-size: 11px;
  font-color: #EDEDED;
  font-style: italic;
}
.wpv_posts .posts_list li .post_extra_info .title {
  margin: 0;
}
.wpv_posts .posts_list li .post_extra_info .title a {
  font-weight: normal;
  font-size: 15px;
  line-height: 20px;
}
.wpv_posts .posts_list li .post_extra_info .title + div {
  color: #7C8A8D;
}
.wpv_posts .posts_list li .post_extra_info .nothumb .title a {
  padding-top: 0;
  font-weight: normal;
  font-size: 11px;
  line-height: 20px;
}
.wpv_posts .posts_list li .post_extra_info .comments {
  display: none;
}
.widget_nav_menu > div {
  padding: 0 !important;
}
.widget_nav_menu > div:after {
  top: 0 !important;
  margin: 0 !important;
}
.widget_nav_menu.widget .menu-pagepost-options-container {
  border-right: none !important;
  border-bottom: none !important;
  border-left: none !important;
}
.widget_nav_menu .menu li {
  background-color: #ffffff;
  margin: 0;
  padding: 0;
  border-bottom: 1px solid #EDEDED;
}
.widget_nav_menu .menu li:last-child {
  border-bottom: none;
}
.widget_nav_menu .menu li.last-child {
  border-bottom: none;
}
.widget_nav_menu .menu li.current_page_item a,
.widget_nav_menu .menu li:hover a {
  color: #5C6268;
  transition: all .5s;
  transition: none;
}
.widget_nav_menu .menu li.current_page_item a {
  font-weight: normal;
}
.widget_nav_menu .menu li a {
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  display: block;
  padding: 10px 10px 10px 5px;
  min-width: 100%;
  border: 0 !important;
  color: #F0542D;
}
.widget_post_formats .post-format-pad {
  position: relative;
  left: auto;
  float: left;
  margin: 5px;
  padding: 0px !important;
  width: 30px;
  height: 30px;
  border: none;
}
.widget_post_formats .post-format-pad * {
  margin-top: 0px !important;
  margin-left: 1px !important;
}
.widget_post_formats .post-format-pad a {
  width: 28px;
  height: 28px;
  display: block;
  font-size: 18px;
  line-height: 28px;
  text-align: center;
  padding: 0 !important;
}
.widget_post_formats .post-format-pad a:hover {
  text-decoration: none !important;
}
.widget_post_formats .post-format-pad .icon {
  color: #2B2F34;
}
.widget_post_formats .post-format-pad .icon:hover {
  color: #5C6268;
}
.widget_post_formats .post-format-pad .icon:visited {
  color: #142e91;
}
.widget_post_formats .post-format-pad .icon.standard {
  padding-top: 2px !important;
}
.widget_post_formats .post-format-pad .icon.standard span.icon {
  vertical-align: inherit;
}
.widget_search .searchform,
.widget_product_search  .woocommerce-product-search {
  position: relative;
  display: block;
  padding: 0 !important;
  max-width: 100% !important;
  width: 100%;
  white-space: nowrap;
}
.widget_search .searchform input[name="s"],
.widget_product_search  .woocommerce-product-search input[name="s"] {
  width: 100% !important;
  height: 45px;
  border-right-width: 45px;
  border-color: #EDEDED;
}
.widget_search .searchform input[name="s"]:focus,
.widget_product_search  .woocommerce-product-search input[name="s"]:focus {
  border-color: #EDEDED;
}
.widget_search .searchform [type="submit"],
.widget_product_search  .woocommerce-product-search [type="submit"] {
  position: absolute;
  z-index: 5;
  padding: 0;
  width: 46px;
  height: 45px;
  background: transparent;
  box-shadow: none;
  text-indent: -200px;
  font-size: inherit !important;
  border: 1px solid #EDEDED;
  top: 0px;
  right: 0px;
  bottom: 0px;
  color: transparent;
}
.widget_search .searchform [type="submit"]:hover,
.widget_product_search  .woocommerce-product-search [type="submit"]:hover {
  border: 1px solid #F0542D;
}
.widget_search .searchform:before,
.widget_product_search  .woocommerce-product-search:before {
  position: absolute;
  right: 0;
  top: 0;
  z-index: 4;
  margin: 0;
  width: 45px;
  height: 44px;
  background: #ffffff;
  color: #F0542D;
  content: "\e12d";
  font: normal 26px/48px icomoon;
  cursor: pointer;
  text-align: center;
  border: none;
}
.wpv_social a,
.wpv_social a img,
.wpv_social img {
  border: 0px !important;
  min-width: 20px;
  min-height: 16px;
  display: block;
}
.wpv_social a {
  zoom: 1;
  filter: none;
  opacity: 1;
  -webkit-transition: opacity 0.3s ease !important;
  -moz-transition: opacity 0.3s ease !important;
  -o-transition: opacity 0.3s ease !important;
  transition: opacity 0.3s ease !important;
  float: left;
}
.wpv_social a:hover {
  zoom: 1;
  opacity: 0.7;
  filter: alpha(opacity=70);
}
.social_wrap a,
.wpv_social .vamtam_full a {
  clear: both;
  margin-bottom: 3px;
}
.wpv_social .vamtam_full a img {
  padding: 0px 0px 7px 0px;
}
aside .social_wrap a {
  float: left;
  clear: none;
}
aside .social_wrap:after {
  content: "";
  display: block;
  clear: both;
}
.tagcloud {
  padding-bottom: 5px !important;
}
.tagcloud a {
  display: inline-block;
  position: relative;
  text-transform: lowercase;
  color: #364352;
  background: #ffffff;
  border-color: #b7c3d0;
  font: 600 46px/48px "Raleway";
  font-weight: normal;
  border-radius: 0px;
  margin: 0px;
  padding: 5px 10px;
  line-height: 1em;
}
.tagcloud a:hover {
  background: #F0542D;
  text-decoration: none;
  color: #ffffff !important;
}
.widget_rss .widget-title a.rsswidget {
  color: #4A4F55 !important;
}
.widget_rss .widget-title a.rsswidget img {
  display: none;
}
.page-404 {
  position: relative;
  padding: 0 30px 0.035px;
  text-align: center;
}
.page-404 .searchform {
  position: relative;
  display: block;
  margin: 0 auto 100px auto;
  max-width: 812px;
}
.page-404 input[name=s] {
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  z-index: 1;
  padding: 5px 122px 5px 10px;
  width: 100%;
  height: 45px;
  font-style: italic;
  font-size: 15px;
}
.page-404 input[name=s]:focus {
  font-style: normal;
}
.page-404 input[type=submit] {
  position: absolute;
  top: 3px;
  right: 3px;
  bottom: 3px;
  z-index: 3;
  padding: 0 1em;
  height: 40px;
  font-size: 16px;
}
#header-404 {
  display: block;
  margin: 0 auto;
  padding-top: 100px;
  padding: 30px;
  height: 324px;
  width: auto;
  max-width: 812px;
  background: url("https://construction.vamtam.com/wp-content/themes/construction/wpv_theme/assets/images/404_bg.png") no-repeat bottom right;
  color: #D8D8D8;
  text-align: left;
}
#header-404 .line-1 {
  font: 800 70px/1 "Raleway";
  color: #F0542D;
}
#header-404 .line-2 {
  font: 800 50px/1.1 "Raleway";
  color: #2B2F34;
  line-height: 0.8em;
  padding-bottom: 20px;
}
#header-404 .line-3 {
  font: 800 20px/1 "Raleway";
  color: #2B2F34;
}
#header-404 .line-4 {
  margin-top: 80px;
  color: #2B2F34;
}
footer.main-footer {
  position: relative;
  background: url(https://construction.vamtam.com//wp-content/uploads/2014/12/footer-bg.jpg) no-repeat center bottom scroll;
  background-color: #34373c;
  -webkit-background-size: auto;
  -moz-background-size: auto;
  background-size: auto;
}
footer.main-footer div.wpcf7 input,
footer.main-footer div.wpcf7 textarea,
footer.main-footer div.wpcf7 select {
  background: none !important;
  color: #D8D8D8;
  border: 1px solid rgba(255,255,255,0.15);
}
footer.main-footer div.wpcf7 input:hover,
footer.main-footer div.wpcf7 textarea:hover,
footer.main-footer div.wpcf7 select:hover {
  border-color: rgba(255,255,255,0.3);
}
footer.main-footer div.wpcf7 select {
  height: 30px;
}
footer.main-footer div.wpcf7 input.wpcf7-submit:hover {
  border-color: #F0542D;
}
footer.main-footer .sep-3 {
  margin: 0px;
  opacity: 0.2;
}
footer.main-footer,
footer.main-footer p,
footer.main-footer a,
footer.main-footer th,
footer.main-footer td {
  font: normal 13px/20px "Raleway";
  color: #AFAFAF;
}
footer.main-footer p {
  line-height: 170%;
}
footer.main-footer .widget li {
  background: transparent;
  border-bottom: none !important;
}
footer.main-footer .widget.widget_nav_menu #menu-horizontal-footer {
  text-align: center;
}
footer.main-footer .widget.widget_nav_menu #menu-horizontal-footer li {
  display: inline-block;
  vertical-align: top;
}
footer.main-footer .widget.widget_nav_menu #menu-horizontal-footer li:hover a,
footer.main-footer .widget.widget_nav_menu #menu-horizontal-footer li.current-menu-item a {
  background: none;
  color: #F0542D !important;
}
footer.main-footer .widget.widget_nav_menu #menu-horizontal-footer li a {
  padding: 5px 20px;
  color: #ffffff;
  font-size: 14px;
}
footer.main-footer .widget.widget_nav_menu .menu li:last-child,
footer.main-footer .widget.widget_nav_menu .menu li.last-child {
  border-bottom: none;
}
footer.main-footer .widget.widget_nav_menu .menu li a {
  color: #F0542D;
  padding: 5px 8px 8px 3px;
}
footer.main-footer .widget.widget_nav_menu .menu li a:visited {
  color: #F0542D !important;
}
footer.main-footer .widget.widget_nav_menu .menu li a:hover {
  color: #fff !important;
  text-decoration: none !important;
  background: none;
}
footer.main-footer .widget.widget_nav_menu .menu li:hover,
footer.main-footer .widget.widget_nav_menu .menu li.current_page_item {
  position: relative;
}
footer.main-footer .widget.widget_nav_menu .menu li:hover a,
footer.main-footer .widget.widget_nav_menu .menu li.current_page_item a {
  color: #F0542D;
  background: none;
}
footer.main-footer .widget .widget-title {
  border: none;
  text-align: left;
  padding: 0;
  margin: 0 0 10px;
  font: 300 14px/16px "Raleway" !important;
  color: #ffffff !important;
}
footer.main-footer .widget .widget-title > .icon {
  margin-bottom: 17px;
}
footer.main-footer a {
  color: #F0542D;
  -webkit-transition: all .3s ease;
  transition: all .3s ease;
}
footer.main-footer a:visited {
  color: #F0542D;
}
footer.main-footer a h4 {
  color: #ffffff !important;
}
footer.main-footer a:hover {
  color: #fff;
  text-decoration: none;
}
footer.main-footer a:hover .icon.shortcode {
  color: #fff !important;
}
#footer-sidebars {
  max-width: 1140px;
  margin: 0 auto;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  position: relative;
}
#footer-sidebars .row:first-child:not(:last-child) {
  border-bottom: solid 1px rgba(237,237,237,0.2);
  margin-bottom: 30px;
}
#footer-sidebars > .row aside {
  border-right: 0;
  padding: 10px 0 30px;
  float: left;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
#footer-sidebars > .row aside.full {
  width: 100%;
}
#footer-sidebars > .row aside.cell-1-2 {
  width: 50%;
}
#footer-sidebars > .row aside.cell-1-3 {
  width: 33.333333333333%;
}
#footer-sidebars > .row aside.cell-1-4 {
  width: 25%;
}
#footer-sidebars > .row aside.cell-1-5 {
  width: 20%;
}
#footer-sidebars > .row aside.cell-1-6 {
  width: 16.666666666667%;
}
#footer-sidebars > .row aside.cell-2-3 {
  width: 66.666666666667%;
}
#footer-sidebars > .row aside.cell-2-4 {
  width: 50%;
}
#footer-sidebars > .row aside.cell-2-5 {
  width: 40%;
}
#footer-sidebars > .row aside.cell-2-6 {
  width: 33.333333333333%;
}
#footer-sidebars > .row aside.cell-3-4 {
  width: 75%;
}
#footer-sidebars > .row aside.cell-3-5 {
  width: 60%;
}
#footer-sidebars > .row aside.cell-3-6 {
  width: 50%;
}
#footer-sidebars > .row aside.cell-4-5 {
  width: 80%;
}
#footer-sidebars > .row aside.cell-4-6 {
  width: 66.666666666667%;
}
#footer-sidebars > .row aside.cell-5-6 {
  width: 83.333333333333%;
}
#footer-sidebars > .row aside.last {
  border-right: 0;
}
#footer-sidebars > .row .widget {
  padding-left: 30px;
  padding-right: 30px;
}
#footer-sidebars > .row .widget,
#footer-sidebars > .row .widget:last-child {
  margin-bottom: 0;
  padding-bottom: 0px;
}
#footer-sidebars > .row .widget .widget-title {
  text-align: left;
  padding-top: 0px;
  padding-bottom: 5px;
  letter-spacing: 2px;
}
#footer-sidebars .wpv_icon_link li {
  padding: 5px;
}
#footer-sidebars .wpv_icon_link li:first-child {
  padding-top: 0;
}
#footer-sidebars .wpv_posts .wpv-tabs > ul {
  border-bottom-color: #282a2e;
  background-color: #34373c;
}
#footer-sidebars .wpv_posts .wpv-tabs > ul li {
  border-bottom: 1px solid transparent !important;
}
#footer-sidebars .wpv_posts .wpv-tabs > ul li.ui-state-hover,
#footer-sidebars .wpv_posts .wpv-tabs > ul li.ui-state-selected,
#footer-sidebars .wpv_posts .wpv-tabs > ul li.ui-state-active {
  border-color: #282a2e;
  background: transparent;
  border-bottom-color: #34373c !important;
}
#footer-sidebars .wpv_posts .ui-tabs-panel {
  border-color: #282a2e;
}
#footer-sidebars .wpv_posts .posts_list li {
  border-top-color: #282a2e;
  padding: 0 0 10px 0;
}
.copyrights {
  background-repeat: repeat;
  background-position: center top;
  background-attachment: scroll;
  background-color: #ffffff;
  -webkit-background-size: auto;
  -moz-background-size: auto;
  background-size: auto;
  padding: 25px 30px;
  margin: 0;
  position: relative;
  z-index: 5;
}
.copyrights .alignright,
.copyrights .alignleft {
  margin: 0px !important;
}
.copyrights a {
  color: #F0542D;
  -webkit-transition: all .3s ease;
  transition: all .3s ease;
}
.copyrights a:visited {
  color: #F0542D;
}
.copyrights a:hover {
  color: #2B2F34;
  text-decoration: none;
}
.copyrights a:hover .icon.shortcode {
  color: #2B2F34 !important;
}
.copyrights .aligncenter {
  margin-top: 0;
  margin-bottom: 0;
}
.copyrights > .row {
  padding: 0;
  margin: 0 auto;
}
.copyrights .wpv-grid {
  min-height: 1px;
}
.copyrights,
.copyrights * {
  font: 300 12px/14px "Raleway";
  color: #898989;
}
#sub-footer-menu ul {
  margin: 0;
}
#sub-footer-menu li {
  list-style: none;
  float: left;
  padding: 0 5px;
  border-left: 1px solid #ffffff;
}
#sub-footer-menu li a {
  color: #F0542D;
  font: 300 12px/14px "Raleway";
}
#sub-footer-menu li:first-child {
  padding-left: 0;
  border-left: 0;
}
#scroll-to-top,
#feedback,
#toggle-style-switcher {
  display: block;
  width: 25px !important;
  height: 22px !important;
  line-height: 22px !important;
  font-size: 20px !important;
  padding: 4px;
  margin-left: 2px;
  font-family: "icomoon";
  text-align: center;
  cursor: pointer;
  z-index: 9998;
  border: none !important;
  position: relative;
  background: #F0542D;
  text-shadow: 0 -1px 0 #da3810;
  color: #ffffff !important;
  border-radius: 1px 0 0 1px;
  background-clip: padding-box;
}
#scroll-to-top:hover,
#feedback:hover,
#toggle-style-switcher:hover {
  padding-right: 6px;
  text-decoration: none;
  margin-left: 0;
  color: #ffffff !important;
}
#style-switcher {
  position: fixed !important;
  z-index: 900000 !important;
  top: 210px;
  left: 0;
  right: auto;
}
#style-switcher #toggle-style-switcher {
  position: absolute;
  top: 0;
  right: -35px !important;
  border-radius: 0 1px 1px 0;
  margin-left: 0;
  margin-right: 2px;
}
#style-switcher #toggle-style-switcher:after {
  border-right-color: #F0542D !important;
}
#style-switcher #toggle-style-switcher:before {
  content: "\e035";
  font-family: theme;
}
#style-switcher #toggle-style-switcher:hover {
  padding-right: 4px;
}
#style-switcher.open #toggle-style-switcher,
#style-switcher:hover #toggle-style-switcher {
  padding-left: 6px !important;
  margin-right: 0 !important;
  opacity: 1;
}
body.admin-bar #style-switcher {
  top: 243px;
}
#ss-teaser .close {
  content: "\e255";
}
#scroll-to-top {
  position: fixed;
  bottom: 69px;
  right: 0px;
  z-index: -1;
  border-radius: 1px 0 0;
  background-clip: padding-box;
  opacity: 0;
}
#scroll-to-top:hover {
  opacity: 0;
}
#scroll-to-top.visible {
  opacity: 1;
  z-index: 200;
}
#scroll-to-top.visible:hover {
  opacity: 1;
}
#feedback-wrapper {
  position: fixed;
  bottom: 105px;
  right: -250px;
  z-index: 999900;
  background: #364352;
  width: 250px;
  min-height: 84px;
  color: #ffffff !important;
  border-radius: 1px 0 0 0;
  background-clip: padding-box;
  -webkit-transition: right .4s;
  transition: right .4s;
}
#feedback-wrapper #feedback {
  position: absolute;
  bottom: 0;
  right: 250px;
}
#feedback-wrapper.expanded {
  right: 0;
}
#feedback-wrapper.expanded #feedback {
  opacity: 1;
  padding-right: 6px;
}
#feedback-wrapper h4,
#feedback-wrapper h4 a {
  color: #ffffff !important;
  margin-bottom: 0px;
}
#feedback-wrapper h4 {
  border: none;
  padding: 10px 30px;
}
#feedback-wrapper section {
  margin: 10px;
}
#feedback-wrapper .widget {
  padding: 0;
  border: none !important;
}
.woocommerce input[type=text],
.woocommerce input[type=tel],
.woocommerce input[type=email],
.woocommerce input[type=password],
.woocommerce input[type=email],
.woocommerce input[type=search],
.woocommerce input[type=date],
.woocommerce input[type=range],
.woocommerce input[type=number],
.woocommerce input[name="apply_coupon"],
.woocommerce textarea,
.woocommerce select {
  padding: 14px;
  margin-bottom: 0 !important;
  font-size: 14px;
  box-shadow: none;
  text-shadow: none;
  font-weight: normal;
  border-radius: 0px;
}
.woocommerce input[type=submit],
.woocommerce input[type=button] {
  border: 0;
}
.woocommerce input[name="apply_coupon"] {
  margin-top: 10px;
}
.woocommerce a.remove,
.woocommerce ul.product_list_widget li a.remove {
  font-size: 18px !important;
  height: 20px;
  width: 20px;
  padding: 0px;
  font-weight: 100;
  line-height: 1em !important;
}
.woocommerce a.remove:hover,
.woocommerce ul.product_list_widget li a.remove:hover {
  background: #F0542D !important;
}
.woocommerce .ul.socialcount {
  margin: 0.4em 0px 0.4em 0 !important;
}
.woocommerce .lost_reset_password .button {
  font-size: 1em;
  font-weight: normal;
  display: inline-block;
  text-align: center;
  cursor: pointer;
  position: relative;
  z-index: 0;
  vertical-align: middle;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
  text-decoration: none;
  text-shadow: none;
  line-height: 1.15em;
  border-widht: 2px;
  padding: 0;
  text-align: center !important;
  background: #F0542D;
  color: #ffffff;
  padding: 0.8em 1.6em;
  border-radius: 0;
}
.woocommerce .lost_reset_password .button,
.woocommerce .lost_reset_password .button span {
  transition: color .3s ease, border .3s ease, background .3s ease;
}
.woocommerce .lost_reset_password .button span {
  display: inline-block;
  font-size: 1em;
  line-height: inherit;
  padding: .3em .4em;
  margin: 0 0;
  vertical-align: baseline;
}
.woocommerce .lost_reset_password .button span.icon {
  font-size: 100%;
  vertical-align: bottom !important;
}
.woocommerce .lost_reset_password .button span.icon.shortcode.inverted-colors {
  font-size: 100%;
  box-shadow: 0 1px 1px rgba(0,0,0,0.1) inset, 0 1px 1px rgba(255,255,255,0.2);
  text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}
.woocommerce .lost_reset_password .button span.icon:first-child,
.woocommerce .lost_reset_password .button span.icon:last-child {
  vertical-align: top;
  background: none;
}
.woocommerce .lost_reset_password .button span.icon:first-child {
  padding: .5em 0 .5em .8em !important;
}
.woocommerce .lost_reset_password .button span.icon:last-child {
  padding: .5em .8em .5em 0 !important;
}
.woocommerce .lost_reset_password .button span.btext {
  position: relative;
  font-weight: 500;
  vertical-align: middle;
  padding: 0.7em 1.2em;
  letter-spacing: 1px;
}
.woocommerce .lost_reset_password .button:hover,
.woocommerce .lost_reset_password .button:hover span {
  text-decoration: none;
}
.woocommerce .lost_reset_password .button span {
  color: #ffffff;
}
.woocommerce .lost_reset_password .button:hover,
.woocommerce .lost_reset_password .button:focus,
.woocommerce .lost_reset_password .button:active {
  background: #364352;
}
.woocommerce .lost_reset_password .button:hover,
.woocommerce .lost_reset_password .button:hover span,
.woocommerce .lost_reset_password .button:focus,
.woocommerce .lost_reset_password .button:focus span,
.woocommerce .lost_reset_password .button:active,
.woocommerce .lost_reset_password .button:active span {
  color: #b7c3d0;
}
.woocommerce .checkout-breadcrumb .icon.shortcode {
  line-height: 1.15;
  font-size: 20px;
  padding: 0 20px;
  vertical-align: middle !important;
  color: #EDEDED;
}
.woocommerce .checkout-breadcrumb .title-part-inactive {
  color: #EDEDED;
}
.woocommerce #payment {
  background: none;
}
.woocommerce #payment #place_order {
  float: left;
  padding: 1em 1.8em;
}
.submit-button-style
			.woocommerce #payment #place_order:hover {
  background: #364352;
  color: #ffffff !important;
}
.woocommerce #payment ul.payment_methods {
  border-bottom: 0;
}
.woocommerce #payment ul.payment_methods li input {
  vertical-align: middle;
  border: 0;
}
.woocommerce #payment .payment_box {
  background: #EDEDED;
}
.woocommerce #payment .payment_box p {
  margin: 0;
}
.woocommerce h1.page-title,
.woocommerce div.product .product_title {
  display: none;
}
.woocommerce .star-rating {
  float: none;
  color: #F0542D;
  font-style: normal;
}
.woocommerce .star-rating:before {
  color: #F0542D;
  font-style: normal;
}
.woocommerce .woocommerce-result-count {
  margin-top: 20px;
  line-height: 15px;
}
.woocommerce .woocommerce-ordering {
  margin-bottom: 30px;
}
.woocommerce .woocommerce-ordering select {
  padding: 10px;
  box-shadow: 0 1px 2px rgba(0,0,0,0.16) !important;
  font-size: 12px;
  line-height: 22px;
}
.woocommerce form.login {
  border-radius: 1px;
  border: 3px solid #F0542D;
}
.woocommerce form.checkout_coupon {
  border-radius: 1px;
  border: 3px solid #F0542D;
}
.woocommerce .woocommerce-message,
.woocommerce .woocommerce-error,
.woocommerce .woocommerce-info {
  margin-bottom: 2em;
  border-top: 0;
  background: transparent;
  box-shadow: none;
  padding: 10px !important;
  text-shadow: none;
  border-radius: 1px;
}
.woocommerce .woocommerce-message:before,
.woocommerce .woocommerce-error:before,
.woocommerce .woocommerce-info:before {
  display: none;
}
.woocommerce .button.wc-forward:after,
.woocommerce .button.wc-forward:before,
.woocommerce .button.wc-forward a:after,
.woocommerce .button.wc-forward a:before,
.woocommerce .button.wc-backward:after,
.woocommerce .button.wc-backward:before,
.woocommerce .button.wc-backward a:after,
.woocommerce .button.wc-backward a:before {
  display: none;
}
.woocommerce .woocommerce-info,
.woocommerce .woocommerce-message {
  background-color: transparent;
  border: solid 1px #EDEDED;
  border-radius: 0px;
}
.woocommerce .woocommerce-error {
  background-color: rgba(240,84,45,0.1);
  color: rgba(240,84,45,0.8);
  text-shadow: none;
}
.woocommerce span.onsale,
.woocommerce .products.vamtam-wc .product span.onsale {
  top: 0;
  right: 0;
  left: auto;
  z-index: 5;
  margin: 0;
  border-radius: 1px;
  background: transparent;
  box-shadow: none;
  color: #D55000;
  text-transform: uppercase;
  text-shadow: none;
  font-weight: bold;
  font-style: normal;
  font-size: .75em;
  line-height: 1;
  min-width: 0;
  min-height: 0;
  font-family: "Arial", sans-serif;
  background: #FCEA00;
  padding: 10px;
}
.woocommerce .products.vamtam-wc .product .stock,
.woocommerce div.product .summary .stock {
  font-size: 12px;
  margin: 0;
  overflow: hidden;
}
.woocommerce .products.vamtam-wc .product .stock small,
.woocommerce div.product .summary .stock small {
  position: relative;
  color: #767676;
  line-height: 1;
  padding-right: 5px;
}
.woocommerce .products.vamtam-wc .product .stock small:after,
.woocommerce div.product .summary .stock small:after {
  content: "";
  position: absolute;
  left: 100%;
  bottom: 3px;
  width: 800px;
  height: 1px;
  background: #EDEDED;
}
.woocommerce .products.vamtam-wc {
  position: relative;
}
.woocommerce .products.vamtam-wc .product-category mark.count {
  display: none;
}
.woocommerce .products.vamtam-wc .product {
  padding: 0;
}
.woocommerce .products.vamtam-wc .product span.amount {
  font-weight: normal;
  font-size: 0.6em;
  background: #F0542D;
  color: #ffffff;
  padding: 10px 15px;
}
.woocommerce .products.vamtam-wc .product .add_to_cart_button,
.woocommerce .products.vamtam-wc .product .vamtam-button.product_type_simple {
  margin-top: 10px;
}
.woocommerce .products.vamtam-wc .product.first {
  clear: both;
}
.woocommerce .products.vamtam-wc .product.last {
  margin-right: 0;
}
.woocommerce .products.vamtam-wc .product .wc-new-badge {
  margin: 0;
  position: absolute;
  top: 0;
  left: 0;
  border-radius: 0;
  padding: 5px 10px;
  background: #F0542D;
}
.woocommerce .products.vamtam-wc .product .categories {
  margin: 0;
}
.woocommerce .products.vamtam-wc .product .categories a {
  color: #767676;
  font-size: 12px;
}
.woocommerce .products.vamtam-wc .product .price {
  display: block;
  font: normal 24px/30px "Raleway";
  color: #7C8A8D;
  margin-top: -36px;
  position: relative;
  margin-bottom: 15px;
}
.woocommerce .products.vamtam-wc .product .price del {
  margin: 0px;
  font-size: inherit;
  display: inline-block;
  opacity: 1;
}
.woocommerce .products.vamtam-wc .product .price del span {
  background: #000;
  color: #fff;
}
.woocommerce .products.vamtam-wc .product .price ins span {
  color: #D55000;
  background: #FCEA00;
}
.woocommerce .products.vamtam-wc .product h5 {
  margin-bottom: 0px;
}
.woocommerce .products.vamtam-wc .product .woocommerce-loop-product__title {
  font: 300 20px/26px "Raleway";
  font-size: 18px;
  font-weight: normal;
  color: #F0542D;
  padding-bottom: .1em;
}
.woocommerce .products.vamtam-wc .product a .product-thumbnail {
  position: relative;
  display: block;
  max-height: none !important;
  border: 1px solid #EDEDED;
  margin-bottom: 0px;
  overflow: hidden;
  -webkit-transform: translateZ(0);
  -ms-transform: translateZ(0);
  transform: translateZ(0);
}
.woocommerce .products.vamtam-wc .product a img {
  display: block;
  border: 0;
  box-shadow: none;
  margin: 0;
  -webkit-transition: all .3s;
  transition: all .3s;
}
html.no-touch .woocommerce .products.vamtam-wc .product a:hover img {
  box-shadow: none !important;
  -webkit-transform: scale(1.1);
  -ms-transform: scale(1.1);
  transform: scale(1.1);
}
.woocommerce .products.vamtam-wc .product a:hover .woocommerce-loop-product__title {
  color: #5C6268;
  box-shadow: none;
  -webkit-box-shadow: none;
}
.woocommerce .products.vamtam-wc .product .aggregateRating {
  margin: 10px 0 20px 0;
  min-height: 1.4em;
}
.woocommerce .products.vamtam-wc .product .aggregateRating .star-rating {
  position: relative;
  top: 2px;
  float: left;
  margin-right: 10px;
  margin-bottom: 0;
  width: 7em;
  color: #F0542D;
  letter-spacing: 5px;
  font-size: 14px;
}
.woocommerce .products.vamtam-wc .product .aggregateRating .star-rating span {
  display: inline-block;
}
.woocommerce .products.vamtam-wc .product .aggregateRating .star-rating span strong,
.woocommerce .products.vamtam-wc .product .aggregateRating .star-rating span span.visualhidden {
  display: none;
}
.woocommerce .products.vamtam-wc .product .aggregateRating .star-rating span:before {
  font-size: 14px !important;
}
.woocommerce .products.vamtam-wc .product .aggregateRating a.count {
  position: relative;
  top: -3px;
  margin: 0 0 0 5px;
  color: #2B2F34;
}
.woocommerce .products.vamtam-wc .product .aggregateRating a.count span.number {
  color: #364352;
}
.woocommerce .products.vamtam-wc .product .aggregateRating + .vamtam-button {
  margin-top: 0;
}
.woocommerce .products.vamtam-wc .product span.price span.from {
  font: italic 14px/18px "Raleway";
  color: #898989;
}
.woocommerce .products.vamtam-wc .product .add_to_cart_button .btext {
  padding-left: 1.5em;
  padding-right: 1.5em;
}
.woocommerce .products.vamtam-wc div[itemprop="description"] {
  margin: 0 0 5px 0;
}
.woocommerce .products.vamtam-wc div[itemprop="description"] > p:first-child {
  margin-top: 0;
}
.woocommerce .related.products,
.woocommerce .upsells.products {
  clear: both;
  margin-top: 100px;
}
.woocommerce .related.products h2,
.woocommerce .upsells.products h2 {
  font: 800 26px/30px "Raleway";
  position: relative;
  margin: 0;
  margin-bottom: 30px;
  padding: 0 5px 15px 0;
  padding-bottom: 20px;
  border-bottom: 1px solid #EDEDED;
  color: #4A4F55;
  text-align: center;
  text-transform: uppercase;
}
.woocommerce .related.products ul .product,
.woocommerce .related.products .products.vamtam-wc .product,
.woocommerce .upsells.products ul .product,
.woocommerce .upsells.products .products.vamtam-wc .product {
  margin-bottom: 60px;
  width: 22.15%;
}
.woocommerce .upsells.products ul .product,
.woocommerce .upsells.products .products.vamtam-wc .product {
  margin-bottom: 0;
}
.woocommerce .quantity input.qty,
.woocommerce #quantity input.qty {
  border: 1px solid #EDEDED;
  border-radius: 1px;
  font-weight: normal;
  padding: 0;
  font-size: 14px;
  height: 45px;
}
.woocommerce div.product span.onsale {
  right: 52%;
}
.woocommerce div.product p.price {
  margin-bottom: 30px;
}
.woocommerce div.product p.price span.from {
  font: italic 14px/18px "Raleway";
  color: #898989;
}
.woocommerce div.product .woocommerce-tabs {
  position: relative;
}
.woocommerce div.product .woocommerce-tabs > ul.tabs {
  overflow: visible;
  margin: 0;
  margin-top: 10px;
  padding: 0;
  border: 0;
  background: #ffffff;
  list-style: none;
}
.woocommerce div.product .woocommerce-tabs > ul.tabs li {
  position: relative;
  z-index: 2;
  display: block;
  float: left;
  margin: 0;
  padding: 0;
  border: 0;
  box-shadow: none;
  white-space: nowrap;
  border-radius: 0;
  background: none;
  color: #2B2F34;
}
.woocommerce div.product .woocommerce-tabs > ul.tabs li:before,
.woocommerce div.product .woocommerce-tabs > ul.tabs li:after {
  display: none !important;
}
.woocommerce div.product .woocommerce-tabs > ul.tabs li a {
  position: relative;
  display: block;
  padding: 25px 16px;
  outline: none;
  color: #2B2F34;
  text-shadow: none;
  font-weight: normal;
  font-size: 18px;
  line-height: 1;
  cursor: pointer;
  border-bottom: solid 3px transparent;
  transition: all 0.3s;
}
.woocommerce div.product .woocommerce-tabs > ul.tabs li a .icon {
  color: #ffffff;
  font-style: normal;
}
.woocommerce div.product .woocommerce-tabs > ul.tabs li a:hover {
  border: 0;
  border-radius: 1px;
  box-shadow: none;
  color: #2B2F34;
  text-decoration: none;
  border-bottom: solid 3px #F0542D;
  background: none;
}
.woocommerce div.product .woocommerce-tabs > ul.tabs li a:hover .icon {
  color: #ffffff !important;
}
.woocommerce div.product .woocommerce-tabs > ul.tabs li.active {
  padding: 0 !important;
  border: 0;
  box-shadow: none;
  color: #ffffff;
  text-decoration: none;
  white-space: nowrap;
  border-radius: 0px;
  background: none;
}
.woocommerce div.product .woocommerce-tabs > ul.tabs li.active a {
  border-bottom: solid 3px #F0542D;
  background: none;
  color: #2B2F34;
}
.woocommerce div.product .woocommerce-tabs .panel {
  clear: both;
  margin-bottom: 0 !important;
  padding: 10px 12px 0 12px;
}
.woocommerce div.product .woocommerce-tabs,
.woocommerce div.product .woocommerce-tabs:after,
.woocommerce div.product .woocommerce-tabs > ul:after {
  display: block;
  clear: both;
  content: "";
}
.woocommerce div.product .woocommerce-tabs #tab-description > h2,
.woocommerce div.product .woocommerce-tabs #tab-reviews h2 {
  display: none;
}
.woocommerce div.product .woocommerce-tabs #tab-reviews #comments > div .star-rating {
  display: none;
}
.woocommerce div.product form.cart {
  margin: 20px 0px;
}
.woocommerce div.product form.cart .group_table td {
  padding-bottom: 1em;
}
.woocommerce div.product form.cart > .single_add_to_cart_button {
  padding: .7em 2em;
  border: 2px solid #F0542D;
  border-radius: 1px;
  background: transparent;
  box-shadow: none;
  color: #F0542D;
  text-transform: uppercase;
  text-shadow: none;
  font-style: normal;
  font-size: 15px;
}
.woocommerce div.product form.cart > .single_add_to_cart_button:hover,
.woocommerce div.product form.cart > .single_add_to_cart_button:hover span {
  border-color: #F0542D;
  background: #F0542D;
  color: #ffffff;
  transition: color 0.3s;
}
.woocommerce div.product form.cart + .share-btns {
  text-align: left;
  padding: 20px 0;
}
.woocommerce div.product form.cart + .share-btns > ul {
  margin-left: 0;
}
.woocommerce div.product form.cart + .share-btns .sep:first-child,
.woocommerce div.product form.cart + .share-btns .sep-2:first-child,
.woocommerce div.product form.cart + .share-btns .sep-3:first-child {
  display: none;
}
.woocommerce div.product .product_meta .posted_in,
.woocommerce div.product .product_meta .tagged_as {
  display: block;
}
.woocommerce div.product div.images {
  position: relative;
  margin-bottom: 120px;
}
.woocommerce div.product div.images .bx-wrapper {
  margin-bottom: 0;
}
.woocommerce div.product div.images ul.thumbnails {
  padding-top: 0;
  list-style-type: none;
  margin: 0;
}
.woocommerce div.product div.images ul.thumbnails li {
  display: inline-block;
  margin-top: 4%;
  margin-right: 4%;
  width: 22%;
}
.woocommerce div.product div.images ul.thumbnails li:nth-child(4n) {
  margin-right: 0;
}
.woocommerce.woocommerce-cart .cart_totals table {
  float: left;
  text-align: left;
}
.woocommerce.woocommerce-checkout .product-subtotal .amount,
.woocommerce.woocommerce-checkout .cart-subtotal .amount,
.woocommerce.woocommerce-checkout .order-total .amount {
  font: 600 12px/14px "Raleway";
  color: inherit;
  font-weight: bold;
  font-size: 1.3em;
}
.woocommerce.woocommerce-checkout .customer_details dt,
.woocommerce.woocommerce-checkout .customer_details dd {
  display: inline;
}
.woocommerce.woocommerce-checkout .customer_details dt:before {
  display: block;
  content: "";
}
.woocommerce.woocommerce-checkout .addresses {
  margin-top: 30px;
}
.woocommerce.woocommerce-checkout table.shop_table,
.woocommerce.woocommerce-checkout table.shop_table th,
.woocommerce.woocommerce-checkout table.shop_table td {
  border: 0;
  font-weight: normal;
  padding: 3px;
}
.woocommerce.woocommerce-checkout h3 {
  margin-bottom: .8em;
  font: 300 20px/26px "Raleway";
}
.woocommerce.woocommerce-checkout #payment div.payment_box {
  background: #EDEDED;
  box-shadow: none;
  text-shadow: none;
}
.woocommerce.woocommerce-checkout #payment div.payment_box:after {
  border-bottom-color: #EDEDED;
}
.woocommerce.woocommerce-checkout #shiptobilling {
  line-height: 2.7em;
}
.woocommerce.woocommerce-checkout .amount {
  color: #7C8A8D;
}
.woocommerce.woocommerce-checkout #place_order {
  font-size: 1em;
  font-weight: normal;
  display: inline-block;
  text-align: center;
  cursor: pointer;
  position: relative;
  z-index: 0;
  vertical-align: middle;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
  text-decoration: none;
  text-shadow: none;
  line-height: 1.15em;
  border-widht: 2px;
  padding: 0;
  text-align: center !important;
  background: #F0542D;
  color: #ffffff;
}
.woocommerce.woocommerce-checkout #place_order,
.woocommerce.woocommerce-checkout #place_order span {
  transition: color .3s ease, border .3s ease, background .3s ease;
}
.woocommerce.woocommerce-checkout #place_order span {
  display: inline-block;
  font-size: 1em;
  line-height: inherit;
  padding: .3em .4em;
  margin: 0 0;
  vertical-align: baseline;
}
.woocommerce.woocommerce-checkout #place_order span.icon {
  font-size: 100%;
  vertical-align: bottom !important;
}
.woocommerce.woocommerce-checkout #place_order span.icon.shortcode.inverted-colors {
  font-size: 100%;
  box-shadow: 0 1px 1px rgba(0,0,0,0.1) inset, 0 1px 1px rgba(255,255,255,0.2);
  text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}
.woocommerce.woocommerce-checkout #place_order span.icon:first-child,
.woocommerce.woocommerce-checkout #place_order span.icon:last-child {
  vertical-align: top;
  background: none;
}
.woocommerce.woocommerce-checkout #place_order span.icon:first-child {
  padding: .5em 0 .5em .8em !important;
}
.woocommerce.woocommerce-checkout #place_order span.icon:last-child {
  padding: .5em .8em .5em 0 !important;
}
.woocommerce.woocommerce-checkout #place_order span.btext {
  position: relative;
  font-weight: 500;
  vertical-align: middle;
  padding: 0.7em 1.2em;
  letter-spacing: 1px;
}
.woocommerce.woocommerce-checkout #place_order:hover,
.woocommerce.woocommerce-checkout #place_order:hover span {
  text-decoration: none;
}
.woocommerce.woocommerce-checkout #place_order span {
  color: #ffffff;
}
.woocommerce.woocommerce-checkout #place_order:hover,
.woocommerce.woocommerce-checkout #place_order:focus,
.woocommerce.woocommerce-checkout #place_order:active {
  background: #364352;
}
.woocommerce.woocommerce-checkout #place_order:hover,
.woocommerce.woocommerce-checkout #place_order:hover span,
.woocommerce.woocommerce-checkout #place_order:focus,
.woocommerce.woocommerce-checkout #place_order:focus span,
.woocommerce.woocommerce-checkout #place_order:active,
.woocommerce.woocommerce-checkout #place_order:active span {
  color: #b7c3d0;
}
.woocommerce #reviews h3 {
  margin: 0 0 20px;
  font-size: 16px;
}
.woocommerce #reviews #comments ol {
  margin: 0px;
}
.woocommerce #reviews #comments li {
  position: relative;
  min-height: 70px;
  border-bottom: solid 1px #EDEDED;
  padding: 15px;
}
.woocommerce #reviews #comments li.has-children {
  padding-bottom: 0;
}
.woocommerce #reviews #comments ol li {
  clear: both;
  margin-top: -1px;
  list-style: none;
}
.woocommerce #reviews #comments > ol > li:first-child {
  margin-top: 0px;
}
.woocommerce #reviews #comments .children {
  border-top: 0;
  margin: 0px;
}
.woocommerce #reviews #comments .children li {
  clear: both;
  margin-left: 80px;
  padding-left: 10px;
}
.woocommerce #reviews #comments .children li:last-child {
  padding-bottom: 15px;
  border-bottom: none;
}
.woocommerce #reviews #comments .avatar {
  max-width: 70px !important;
  max-height: 70px;
  background-color: #EDEDED;
}
.woocommerce #reviews #comments .comment-author {
  position: absolute;
  top: 0;
  bottom: 0;
  padding: 10px;
  min-height: 70px;
  width: 70px;
}
.woocommerce #reviews #comments .bypostauthor {
  position: relative;
  z-index: 1;
  transition: .3s;
}
.woocommerce #reviews #comments .bypostauthor:hover {
  background: #f5f5f5;
}
.woocommerce #reviews #comments .bypostauthor:hover .comment-author:after {
  border-right-color: #ffffff;
}
.woocommerce #reviews #comments .comment-author-link {
  display: inline;
}
.woocommerce #reviews #comments .comment-time {
  display: inline;
  font-size: 10px !important;
}
.woocommerce #reviews #comments .comment-time:before {
  margin: auto 5px;
  content: " | ";
}
.woocommerce #reviews #comments .comment-content {
  position: relative;
  margin-left: 100px;
  min-height: 50px;
}
.woocommerce #reviews #comments .comment-content:hover h6.comment-reply-link {
  display: block;
}
.woocommerce #reviews #comments .comment-meta {
  margin-top: -3px;
  margin-bottom: 6px;
}
.woocommerce #reviews #comments .comment-meta > .comment-author-link {
  font: 300 20px/26px "Raleway";
}
.woocommerce #reviews #comments h6.comment-reply-link {
  position: absolute;
  top: 0px;
  right: 0px;
  display: none;
  padding: 0 0 0 5px;
}
.woocommerce #reviews #comments h6.comment-reply-link a {
  margin: 0 0 0 5px;
  color: #F0542D;
  font-size: 12px;
}
.woocommerce #reviews #comments h6.comment-reply-link a:hover {
  color: #5C6268;
}
.woocommerce #reviews #comments h6.comment-reply-link:before {
  position: relative;
  top: 5px;
  color: #7C8A8D;
  content: "\e03a";
  font-size: 18px;
  font-family: theme;
  line-height: 18px;
}
.woocommerce #reviews #comments #reply-title {
  margin-bottom: 0px !important;
}
.woocommerce #reviews #comments #cancel-comment-reply-link {
  position: relative;
}
.woocommerce #reviews #comments .comment-notes {
  margin-bottom: 14px;
}
.woocommerce #reviews #comments ol.commentlist li {
  margin-bottom: 0;
  padding: 15px 0;
  border-top: 1px dotted #EDEDED;
}
.woocommerce #reviews #comments ol.commentlist li img.avatar {
  position: relative;
  float: none;
  width: 60px;
}
.woocommerce #reviews #comments ol.commentlist li .comment-meta {
  color: #767676;
}
.woocommerce #reviews #comments ol.commentlist li .comment-meta div.star-rating {
  width: 7em !important;
  letter-spacing: 5px;
  font-size: 14px !important;
}
.woocommerce #reviews #comments ol.commentlist li .comment-meta div.star-rating span {
  color: #F0542D !important;
  font-size: 14px !important;
}
.woocommerce #reviews #comments ol.commentlist li .comment-meta div.star-rating span:before {
  font-size: 14px !important;
}
.woocommerce #reviews #comments .add_review {
  margin-top: 30px;
}
.woocommerce #commentform .form-submit {
  position: static;
}
.woocommerce #commentform .form-submit input {
  font-size: 1em;
  font-weight: normal;
  display: inline-block;
  text-align: center;
  cursor: pointer;
  position: relative;
  z-index: 0;
  vertical-align: middle;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
  text-decoration: none;
  text-shadow: none;
  line-height: 1.15em;
  border-widht: 2px;
  padding: 0;
  text-align: center !important;
  background: #F0542D;
  color: #ffffff;
  padding: 0.8em 1.6em;
}
.woocommerce #commentform .form-submit input,
.woocommerce #commentform .form-submit input span {
  transition: color .3s ease, border .3s ease, background .3s ease;
}
.woocommerce #commentform .form-submit input span {
  display: inline-block;
  font-size: 1em;
  line-height: inherit;
  padding: .3em .4em;
  margin: 0 0;
  vertical-align: baseline;
}
.woocommerce #commentform .form-submit input span.icon {
  font-size: 100%;
  vertical-align: bottom !important;
}
.woocommerce #commentform .form-submit input span.icon.shortcode.inverted-colors {
  font-size: 100%;
  box-shadow: 0 1px 1px rgba(0,0,0,0.1) inset, 0 1px 1px rgba(255,255,255,0.2);
  text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}
.woocommerce #commentform .form-submit input span.icon:first-child,
.woocommerce #commentform .form-submit input span.icon:last-child {
  vertical-align: top;
  background: none;
}
.woocommerce #commentform .form-submit input span.icon:first-child {
  padding: .5em 0 .5em .8em !important;
}
.woocommerce #commentform .form-submit input span.icon:last-child {
  padding: .5em .8em .5em 0 !important;
}
.woocommerce #commentform .form-submit input span.btext {
  position: relative;
  font-weight: 500;
  vertical-align: middle;
  padding: 0.7em 1.2em;
  letter-spacing: 1px;
}
.woocommerce #commentform .form-submit input:hover,
.woocommerce #commentform .form-submit input:hover span {
  text-decoration: none;
}
.woocommerce #commentform .form-submit input span {
  color: #ffffff;
}
.woocommerce #commentform .form-submit input:hover,
.woocommerce #commentform .form-submit input:focus,
.woocommerce #commentform .form-submit input:active {
  background: #7C8A8D;
}
.woocommerce #commentform .form-submit input:hover,
.woocommerce #commentform .form-submit input:hover span,
.woocommerce #commentform .form-submit input:focus,
.woocommerce #commentform .form-submit input:focus span,
.woocommerce #commentform .form-submit input:active,
.woocommerce #commentform .form-submit input:active span {
  color: #ffffff;
}
html.placeholder .woocommerce label[for] {
  display: inline;
}
html.placeholder .woocommerce form .form-row label[for] {
  display: block;
  padding-bottom: 5px;
}
html.placeholder .woocommerce form .form-row label[for].checkbox {
  display: inline;
}
.woocommerce article img {
  display: inline-block;
}
.woocommerce div.product .summary form.cart {
  padding-left: 20px;
}
.woocommerce div.product .summary > div {
  padding-left: 20px;
}
.woocommerce div.product .summary .star-rating {
  margin: 13px 8px 15px 0;
  width: 7em;
  color: #F0542D;
  letter-spacing: 5px;
  font-size: 14px;
}
.woocommerce div.product .summary .star-rating span:before {
  font-size: 14px !important;
}
.woocommerce div.product .summary a.count {
  display: inline-block;
  margin: 10px 5px 15px 0;
  color: #2B2F34;
  font-size: 10px;
}
.woocommerce div.product .summary a.count span.number {
  color: #364352;
}
.woocommerce div.product .summary form.variations_form table.variations td {
  display: block;
  padding-bottom: 5px;
}
.woocommerce div.product .summary form.variations_form table.variations td select {
  margin: 0 0 5px 0;
}
.woocommerce div.product .summary form.variations_form .single_add_to_cart_button {
  font: normal 14px/20px "Raleway";
  border-radius: 1px;
  background: #F0542D;
  color: #ffffff;
  text-transform: uppercase;
  font-weight: normal;
}
.woocommerce div.product .summary form.variations_form .single_add_to_cart_button:hover,
.woocommerce div.product .summary form.variations_form .single_add_to_cart_button:before,
.woocommerce div.product .summary form.variations_form .single_add_to_cart_button:after {
  color: #7C8A8D !important;
  text-decoration: none;
}
.woocommerce div.product .summary form.variations_form .single_add_to_cart_button:after {
  top: 2.2em;
  border-top: 1px solid #7C8A8D;
}
.woocommerce div.product .summary .share-btns {
  margin: 0 0 0 20px;
  padding: 0 0 20px 0;
}
.woocommerce div.product .summary .product_meta {
  margin: 0 0 0 20px;
  padding-left: 0;
}
.woocommerce div.product .summary .price .amount,
.woocommerce div.product .summary .price ins .amount,
.woocommerce div.product .summary .price del .amount {
  font: 800 26px/30px "Raleway";
}
.woocommerce div.product .summary .price del {
  opacity: 1;
  display: inline-block;
  margin-right: .5em;
}
.woocommerce div.product .summary .price del,
.woocommerce div.product .summary .price del .amount {
  color: #EDEDED;
}
.woocommerce div.product .summary .stock {
  margin-left: 20px;
}
.woocommerce div.product .summary .stock.out-of-stock {
  border-top: 1px solid #EDEDED;
  padding: 25px 0 0 0;
}
.woocommerce div.product .summary .stock.out-of-stock small {
  font-size: 2em !important;
}
.woocommerce div.product .summary .stock.out-of-stock small:after {
  display: none;
}
.woocommerce .price .amount,
.woocommerce .price ins .amount {
  font: normal 24px/30px "Raleway";
  font-style: normal;
  color: #2B2F34;
  text-decoration: none !important;
}
.woocommerce .price del .amount {
  font: 600 12px/14px "Raleway";
  color: #2B2F34;
  text-decoration: line-through;
}
.woocommerce .images a img {
  box-shadow: none !important;
}
.woocommerce .product_meta {
  padding: 15px 0 0 0;
  border-top: 1px solid #EDEDED;
}
.woocommerce .product_meta span {
  line-height: 25px;
}
.woocommerce .product_meta a {
  color: #F0542D;
}
.woocommerce .product_meta a:hover {
  color: #5C6268;
}
.woocommerce .product_meta a:visited {
  color: #142e91;
}
.woocommerce table.shop_table th,
.woocommerce table.shop_table tfoot th td {
  font-weight: normal;
}
.woocommerce.woocommerce-cart .button {
  padding: 0.6em 1em !important;
  text-shadow: none !important;
}
.woocommerce.woocommerce-cart .cart-collaterals .button {
  margin: 10px 10px 0 0;
  font-size: 1em;
  font-weight: normal;
  display: inline-block;
  text-align: center;
  cursor: pointer;
  position: relative;
  z-index: 0;
  vertical-align: middle;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
  text-decoration: none;
  text-shadow: none;
  line-height: 1.15em;
  border-widht: 2px;
  padding: 0;
  text-align: center !important;
  background: #EDEDED;
  color: #3b3b3b;
}
.woocommerce.woocommerce-cart .cart-collaterals .button,
.woocommerce.woocommerce-cart .cart-collaterals .button span {
  transition: color .3s ease, border .3s ease, background .3s ease;
}
.woocommerce.woocommerce-cart .cart-collaterals .button span {
  display: inline-block;
  font-size: 1em;
  line-height: inherit;
  padding: .3em .4em;
  margin: 0 0;
  vertical-align: baseline;
}
.woocommerce.woocommerce-cart .cart-collaterals .button span.icon {
  font-size: 100%;
  vertical-align: bottom !important;
}
.woocommerce.woocommerce-cart .cart-collaterals .button span.icon.shortcode.inverted-colors {
  font-size: 100%;
  box-shadow: 0 1px 1px rgba(0,0,0,0.1) inset, 0 1px 1px rgba(255,255,255,0.2);
  text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}
.woocommerce.woocommerce-cart .cart-collaterals .button span.icon:first-child,
.woocommerce.woocommerce-cart .cart-collaterals .button span.icon:last-child {
  vertical-align: top;
  background: none;
}
.woocommerce.woocommerce-cart .cart-collaterals .button span.icon:first-child {
  padding: .5em 0 .5em .8em !important;
}
.woocommerce.woocommerce-cart .cart-collaterals .button span.icon:last-child {
  padding: .5em .8em .5em 0 !important;
}
.woocommerce.woocommerce-cart .cart-collaterals .button span.btext {
  position: relative;
  font-weight: 500;
  vertical-align: middle;
  padding: 0.7em 1.2em;
  letter-spacing: 1px;
}
.woocommerce.woocommerce-cart .cart-collaterals .button:hover,
.woocommerce.woocommerce-cart .cart-collaterals .button:hover span {
  text-decoration: none;
}
.woocommerce.woocommerce-cart .cart-collaterals .button span {
  color: #3b3b3b;
}
.woocommerce.woocommerce-cart .cart-collaterals .button:hover,
.woocommerce.woocommerce-cart .cart-collaterals .button:focus,
.woocommerce.woocommerce-cart .cart-collaterals .button:active {
  background: #364352;
}
.woocommerce.woocommerce-cart .cart-collaterals .button:hover,
.woocommerce.woocommerce-cart .cart-collaterals .button:hover span,
.woocommerce.woocommerce-cart .cart-collaterals .button:focus,
.woocommerce.woocommerce-cart .cart-collaterals .button:focus span,
.woocommerce.woocommerce-cart .cart-collaterals .button:active,
.woocommerce.woocommerce-cart .cart-collaterals .button:active span {
  color: #b7c3d0;
}
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button {
  font-size: 1em;
  font-weight: normal;
  display: inline-block;
  text-align: center;
  cursor: pointer;
  position: relative;
  z-index: 0;
  vertical-align: middle;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
  text-decoration: none;
  text-shadow: none;
  line-height: 1.15em;
  border-widht: 2px;
  padding: 0;
  text-align: center !important;
  background: #F0542D;
  color: #ffffff;
  padding: 0.5em 1.4em;
}
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button,
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button span {
  transition: color .3s ease, border .3s ease, background .3s ease;
}
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button span {
  display: inline-block;
  font-size: 1em;
  line-height: inherit;
  padding: .3em .4em;
  margin: 0 0;
  vertical-align: baseline;
}
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button span.icon {
  font-size: 100%;
  vertical-align: bottom !important;
}
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button span.icon.shortcode.inverted-colors {
  font-size: 100%;
  box-shadow: 0 1px 1px rgba(0,0,0,0.1) inset, 0 1px 1px rgba(255,255,255,0.2);
  text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button span.icon:first-child,
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button span.icon:last-child {
  vertical-align: top;
  background: none;
}
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button span.icon:first-child {
  padding: .5em 0 .5em .8em !important;
}
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button span.icon:last-child {
  padding: .5em .8em .5em 0 !important;
}
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button span.btext {
  position: relative;
  font-weight: 500;
  vertical-align: middle;
  padding: 0.7em 1.2em;
  letter-spacing: 1px;
}
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button:hover,
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button:hover span {
  text-decoration: none;
}
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button span {
  color: #ffffff;
}
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button:hover,
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button:focus,
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button:active {
  background: #364352;
}
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button:hover,
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button:hover span,
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button:focus,
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button:focus span,
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button:active,
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button:active span {
  color: #b7c3d0;
}
.woocommerce.woocommerce-cart .cart-collaterals .checkout-button:hover {
  color: #ffffff;
}
.woocommerce.woocommerce-cart .coupon {
  margin-top: 30px;
  text-transform: uppercase;
  font-size: 16;
}
.woocommerce.woocommerce-cart table.shop_table,
.woocommerce.woocommerce-cart table.shop_table th,
.woocommerce.woocommerce-cart table.shop_table td {
  border: 0;
}
.woocommerce.woocommerce-cart table.shop_table .product-thumbnail img {
  width: 50px;
}
.woocommerce.woocommerce-cart table.shop_table td {
  border-top: 1px solid #EDEDED;
  border-bottom: 0;
}
.woocommerce.woocommerce-cart table.shop_table td.product-name a {
  font-size: 15px;
}
.woocommerce.woocommerce-cart table.shop_table a.remove:hover {
  background: none;
  color: red;
}
.woocommerce.woocommerce-cart .product-subtotal .amount,
.woocommerce.woocommerce-cart .cart-subtotal .amount,
.woocommerce.woocommerce-cart .order-total .amount {
  font: 600 12px/14px "Raleway";
  color: #242323;
  font-weight: bold;
  font-size: 1.3em;
}
.woocommerce.woocommerce-cart .cart_totals th,
.woocommerce.woocommerce-cart .cart_totals th strong {
  font-weight: normal;
  padding: 0;
  text-transform: none !important;
}
.woocommerce.woocommerce-cart .cart_totals table.shop_table th,
.woocommerce.woocommerce-cart .cart_totals table.shop_table td {
  border-top: 1px solid #EDEDED;
  width: 50%;
}
.woocommerce.woocommerce-cart .cart_totals,
.woocommerce.woocommerce-cart .shipping_calculator {
  width: auto;
  float: none;
}
.woocommerce.woocommerce-cart .shipping-calculator-form .button {
  font-size: 1em;
  font-weight: normal;
  display: inline-block;
  text-align: center;
  cursor: pointer;
  position: relative;
  z-index: 0;
  vertical-align: middle;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
  text-decoration: none;
  text-shadow: none;
  line-height: 1.15em;
  border-widht: 2px;
  padding: 0;
  text-align: center !important;
  background: #EDEDED;
  color: #3b3b3b;
  margin: 0;
}
.woocommerce.woocommerce-cart .shipping-calculator-form .button,
.woocommerce.woocommerce-cart .shipping-calculator-form .button span {
  transition: color .3s ease, border .3s ease, background .3s ease;
}
.woocommerce.woocommerce-cart .shipping-calculator-form .button span {
  display: inline-block;
  font-size: 1em;
  line-height: inherit;
  padding: .3em .4em;
  margin: 0 0;
  vertical-align: baseline;
}
.woocommerce.woocommerce-cart .shipping-calculator-form .button span.icon {
  font-size: 100%;
  vertical-align: bottom !important;
}
.woocommerce.woocommerce-cart .shipping-calculator-form .button span.icon.shortcode.inverted-colors {
  font-size: 100%;
  box-shadow: 0 1px 1px rgba(0,0,0,0.1) inset, 0 1px 1px rgba(255,255,255,0.2);
  text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}
.woocommerce.woocommerce-cart .shipping-calculator-form .button span.icon:first-child,
.woocommerce.woocommerce-cart .shipping-calculator-form .button span.icon:last-child {
  vertical-align: top;
  background: none;
}
.woocommerce.woocommerce-cart .shipping-calculator-form .button span.icon:first-child {
  padding: .5em 0 .5em .8em !important;
}
.woocommerce.woocommerce-cart .shipping-calculator-form .button span.icon:last-child {
  padding: .5em .8em .5em 0 !important;
}
.woocommerce.woocommerce-cart .shipping-calculator-form .button span.btext {
  position: relative;
  font-weight: 500;
  vertical-align: middle;
  padding: 0.7em 1.2em;
  letter-spacing: 1px;
}
.woocommerce.woocommerce-cart .shipping-calculator-form .button:hover,
.woocommerce.woocommerce-cart .shipping-calculator-form .button:hover span {
  text-decoration: none;
}
.woocommerce.woocommerce-cart .shipping-calculator-form .button span {
  color: #3b3b3b;
}
.woocommerce.woocommerce-cart .shipping-calculator-form .button:hover,
.woocommerce.woocommerce-cart .shipping-calculator-form .button:focus,
.woocommerce.woocommerce-cart .shipping-calculator-form .button:active {
  background: #364352;
}
.woocommerce.woocommerce-cart .shipping-calculator-form .button:hover,
.woocommerce.woocommerce-cart .shipping-calculator-form .button:hover span,
.woocommerce.woocommerce-cart .shipping-calculator-form .button:focus,
.woocommerce.woocommerce-cart .shipping-calculator-form .button:focus span,
.woocommerce.woocommerce-cart .shipping-calculator-form .button:active,
.woocommerce.woocommerce-cart .shipping-calculator-form .button:active span {
  color: #b7c3d0;
}
.woocommerce.woocommerce-cart .shipping-calculator-form .form-row {
  padding: 0;
}
.woocommerce.woocommerce-cart .shipping-calculator-form .form-row input {
  margin: 0 !important;
}
.woocommerce.woocommerce-cart .shipping-calculator-form .form-row .calc_shipping_country_field {
  margin-bottom: 10px;
}
.woocommerce.woocommerce-cart .cart_totals > h2,
.woocommerce.woocommerce-cart .shipping_calculator > h2 {
  font: 300 20px/26px "Raleway";
  text-align: left;
}
.woocommerce.woocommerce-cart .cart_totals > h2 {
  margin-top: 0;
}
.woocommerce.woocommerce-cart .shipping-calculator-button:hover {
  text-decoration: none;
}
.woocommerce.woocommerce-cart .shipping-calculator-button:after {
  display: none;
}
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"] {
  font-size: 1em;
  font-weight: normal;
  display: inline-block;
  text-align: center;
  cursor: pointer;
  position: relative;
  z-index: 0;
  vertical-align: middle;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
  text-decoration: none;
  text-shadow: none;
  line-height: 1.15em;
  border-widht: 2px;
  padding: 0;
  text-align: center !important;
  background: #F0542D;
  color: #ffffff;
  padding: 0.8em 1.6em;
  border: none !important;
  box-shadow: none !important;
}
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"],
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"] span {
  transition: color .3s ease, border .3s ease, background .3s ease;
}
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"] span {
  display: inline-block;
  font-size: 1em;
  line-height: inherit;
  padding: .3em .4em;
  margin: 0 0;
  vertical-align: baseline;
}
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"] span.icon {
  font-size: 100%;
  vertical-align: bottom !important;
}
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"] span.icon.shortcode.inverted-colors {
  font-size: 100%;
  box-shadow: 0 1px 1px rgba(0,0,0,0.1) inset, 0 1px 1px rgba(255,255,255,0.2);
  text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"] span.icon:first-child,
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"] span.icon:last-child {
  vertical-align: top;
  background: none;
}
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"] span.icon:first-child {
  padding: .5em 0 .5em .8em !important;
}
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"] span.icon:last-child {
  padding: .5em .8em .5em 0 !important;
}
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"] span.btext {
  position: relative;
  font-weight: 500;
  vertical-align: middle;
  padding: 0.7em 1.2em;
  letter-spacing: 1px;
}
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"]:hover,
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"]:hover span {
  text-decoration: none;
}
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"] span {
  color: #ffffff;
}
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"]:hover,
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"]:focus,
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"]:active {
  background: #7C8A8D;
}
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"]:hover,
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"]:hover span,
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"]:focus,
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"]:focus span,
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"]:active,
.woocommerce .pp_content_container #respond #commentform .form-submit input[type="submit"]:active span {
  color: #ffffff;
}
.woocommerce .add_review a.button {
  font-size: 1em;
  font-weight: normal;
  display: inline-block;
  text-align: center;
  cursor: pointer;
  position: relative;
  z-index: 0;
  vertical-align: middle;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
  text-decoration: none;
  text-shadow: none;
  line-height: 1.15em;
  border-widht: 2px;
  padding: 0;
  text-align: center !important;
  background: #F0542D;
  color: #ffffff;
  padding-right: .8em;
  padding-left: .8em;
  box-shadow: none;
}
.woocommerce .add_review a.button,
.woocommerce .add_review a.button span {
  transition: color .3s ease, border .3s ease, background .3s ease;
}
.woocommerce .add_review a.button span {
  display: inline-block;
  font-size: 1em;
  line-height: inherit;
  padding: .3em .4em;
  margin: 0 0;
  vertical-align: baseline;
}
.woocommerce .add_review a.button span.icon {
  font-size: 100%;
  vertical-align: bottom !important;
}
.woocommerce .add_review a.button span.icon.shortcode.inverted-colors {
  font-size: 100%;
  box-shadow: 0 1px 1px rgba(0,0,0,0.1) inset, 0 1px 1px rgba(255,255,255,0.2);
  text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}
.woocommerce .add_review a.button span.icon:first-child,
.woocommerce .add_review a.button span.icon:last-child {
  vertical-align: top;
  background: none;
}
.woocommerce .add_review a.button span.icon:first-child {
  padding: .5em 0 .5em .8em !important;
}
.woocommerce .add_review a.button span.icon:last-child {
  padding: .5em .8em .5em 0 !important;
}
.woocommerce .add_review a.button span.btext {
  position: relative;
  font-weight: 500;
  vertical-align: middle;
  padding: 0.7em 1.2em;
  letter-spacing: 1px;
}
.woocommerce .add_review a.button:hover,
.woocommerce .add_review a.button:hover span {
  text-decoration: none;
}
.woocommerce .add_review a.button span {
  color: #ffffff;
}
.woocommerce .add_review a.button:hover,
.woocommerce .add_review a.button:focus,
.woocommerce .add_review a.button:active {
  background: #364352;
}
.woocommerce .add_review a.button:hover,
.woocommerce .add_review a.button:hover span,
.woocommerce .add_review a.button:focus,
.woocommerce .add_review a.button:focus span,
.woocommerce .add_review a.button:active,
.woocommerce .add_review a.button:active span {
  color: #b7c3d0;
}
.woocommerce ul.cart_list a {
  font: 600 12px/14px "Raleway";
  padding: 5px 0 10px 0;
  font-size: 14px;
}
.woocommerce ul.product-categories li.current-cat a {
  color: #5C6268;
}
.woocommerce .myaccount_user {
  padding-bottom: 70px;
}
.woocommerce .myaccount_address {
  padding-bottom: 30px;
}
.woocommerce #customer_login .lost_password {
  margin-left: 20px;
}
body.woocommerce-checkout form.login {
  margin-bottom: 5em;
}
body.woocommerce-checkout .col-2 {
  border: 3px solid #F0542D;
  padding: 20px;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.cart-collaterals {
  width: auto !important;
  padding: 20px;
  border: solid 3px #F0542D;
}
.cart-collaterals .cart_totals table tr:first-child th {
  width: 69%;
}
.cart-collaterals .cart_totals tr td {
  border: 0;
  padding: 3px !important;
}
.woocommerce .page-wrapper #review_form #respond .form-submit input,
.woocommerce .page-wrapper #submit,
.woocommerce .page-wrapper a.button,
.woocommerce .page-wrapper input.button,
.woocommerce .page-wrapper input[type=button],
.woocommerce .page-wrapper button.button,
.woocommerce .products #review_form #respond .form-submit input,
.woocommerce .products #submit,
.woocommerce .products a.button,
.woocommerce .products input.button,
.woocommerce .products input[type=button],
.woocommerce .products button.button {
  font-size: 1em;
  font-weight: normal;
  display: inline-block;
  text-align: center;
  cursor: pointer;
  position: relative;
  z-index: 0;
  vertical-align: middle;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
  text-decoration: none;
  text-shadow: none;
  line-height: 1.15em;
  border-widht: 2px;
  padding: 0;
  text-align: center !important;
  background: #F0542D;
  color: #ffffff;
  font: normal 14px/20px "Raleway";
  box-shadow: none;
  padding: 0.8em 1.6em;
  border: none;
  border-radius: 0;
}
.woocommerce .page-wrapper #review_form #respond .form-submit input,
.woocommerce .page-wrapper #review_form #respond .form-submit input span,
.woocommerce .page-wrapper #submit,
.woocommerce .page-wrapper #submit span,
.woocommerce .page-wrapper a.button,
.woocommerce .page-wrapper a.button span,
.woocommerce .page-wrapper input.button,
.woocommerce .page-wrapper input.button span,
.woocommerce .page-wrapper input[type=button],
.woocommerce .page-wrapper input[type=button] span,
.woocommerce .page-wrapper button.button,
.woocommerce .page-wrapper button.button span,
.woocommerce .products #review_form #respond .form-submit input,
.woocommerce .products #review_form #respond .form-submit input span,
.woocommerce .products #submit,
.woocommerce .products #submit span,
.woocommerce .products a.button,
.woocommerce .products a.button span,
.woocommerce .products input.button,
.woocommerce .products input.button span,
.woocommerce .products input[type=button],
.woocommerce .products input[type=button] span,
.woocommerce .products button.button,
.woocommerce .products button.button span {
  transition: color .3s ease, border .3s ease, background .3s ease;
}
.woocommerce .page-wrapper #review_form #respond .form-submit input span,
.woocommerce .page-wrapper #submit span,
.woocommerce .page-wrapper a.button span,
.woocommerce .page-wrapper input.button span,
.woocommerce .page-wrapper input[type=button] span,
.woocommerce .page-wrapper button.button span,
.woocommerce .products #review_form #respond .form-submit input span,
.woocommerce .products #submit span,
.woocommerce .products a.button span,
.woocommerce .products input.button span,
.woocommerce .products input[type=button] span,
.woocommerce .products button.button span {
  display: inline-block;
  font-size: 1em;
  line-height: inherit;
  padding: .3em .4em;
  margin: 0 0;
  vertical-align: baseline;
}
.woocommerce .page-wrapper #review_form #respond .form-submit input span.icon,
.woocommerce .page-wrapper #submit span.icon,
.woocommerce .page-wrapper a.button span.icon,
.woocommerce .page-wrapper input.button span.icon,
.woocommerce .page-wrapper input[type=button] span.icon,
.woocommerce .page-wrapper button.button span.icon,
.woocommerce .products #review_form #respond .form-submit input span.icon,
.woocommerce .products #submit span.icon,
.woocommerce .products a.button span.icon,
.woocommerce .products input.button span.icon,
.woocommerce .products input[type=button] span.icon,
.woocommerce .products button.button span.icon {
  font-size: 100%;
  vertical-align: bottom !important;
}
.woocommerce .page-wrapper #review_form #respond .form-submit input span.icon.shortcode.inverted-colors,
.woocommerce .page-wrapper #submit span.icon.shortcode.inverted-colors,
.woocommerce .page-wrapper a.button span.icon.shortcode.inverted-colors,
.woocommerce .page-wrapper input.button span.icon.shortcode.inverted-colors,
.woocommerce .page-wrapper input[type=button] span.icon.shortcode.inverted-colors,
.woocommerce .page-wrapper button.button span.icon.shortcode.inverted-colors,
.woocommerce .products #review_form #respond .form-submit input span.icon.shortcode.inverted-colors,
.woocommerce .products #submit span.icon.shortcode.inverted-colors,
.woocommerce .products a.button span.icon.shortcode.inverted-colors,
.woocommerce .products input.button span.icon.shortcode.inverted-colors,
.woocommerce .products input[type=button] span.icon.shortcode.inverted-colors,
.woocommerce .products button.button span.icon.shortcode.inverted-colors {
  font-size: 100%;
  box-shadow: 0 1px 1px rgba(0,0,0,0.1) inset, 0 1px 1px rgba(255,255,255,0.2);
  text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}
.woocommerce .page-wrapper #review_form #respond .form-submit input span.icon:first-child,
.woocommerce .page-wrapper #review_form #respond .form-submit input span.icon:last-child,
.woocommerce .page-wrapper #submit span.icon:first-child,
.woocommerce .page-wrapper #submit span.icon:last-child,
.woocommerce .page-wrapper a.button span.icon:first-child,
.woocommerce .page-wrapper a.button span.icon:last-child,
.woocommerce .page-wrapper input.button span.icon:first-child,
.woocommerce .page-wrapper input.button span.icon:last-child,
.woocommerce .page-wrapper input[type=button] span.icon:first-child,
.woocommerce .page-wrapper input[type=button] span.icon:last-child,
.woocommerce .page-wrapper button.button span.icon:first-child,
.woocommerce .page-wrapper button.button span.icon:last-child,
.woocommerce .products #review_form #respond .form-submit input span.icon:first-child,
.woocommerce .products #review_form #respond .form-submit input span.icon:last-child,
.woocommerce .products #submit span.icon:first-child,
.woocommerce .products #submit span.icon:last-child,
.woocommerce .products a.button span.icon:first-child,
.woocommerce .products a.button span.icon:last-child,
.woocommerce .products input.button span.icon:first-child,
.woocommerce .products input.button span.icon:last-child,
.woocommerce .products input[type=button] span.icon:first-child,
.woocommerce .products input[type=button] span.icon:last-child,
.woocommerce .products button.button span.icon:first-child,
.woocommerce .products button.button span.icon:last-child {
  vertical-align: top;
  background: none;
}
.woocommerce .page-wrapper #review_form #respond .form-submit input span.icon:first-child,
.woocommerce .page-wrapper #submit span.icon:first-child,
.woocommerce .page-wrapper a.button span.icon:first-child,
.woocommerce .page-wrapper input.button span.icon:first-child,
.woocommerce .page-wrapper input[type=button] span.icon:first-child,
.woocommerce .page-wrapper button.button span.icon:first-child,
.woocommerce .products #review_form #respond .form-submit input span.icon:first-child,
.woocommerce .products #submit span.icon:first-child,
.woocommerce .products a.button span.icon:first-child,
.woocommerce .products input.button span.icon:first-child,
.woocommerce .products input[type=button] span.icon:first-child,
.woocommerce .products button.button span.icon:first-child {
  padding: .5em 0 .5em .8em !important;
}
.woocommerce .page-wrapper #review_form #respond .form-submit input span.icon:last-child,
.woocommerce .page-wrapper #submit span.icon:last-child,
.woocommerce .page-wrapper a.button span.icon:last-child,
.woocommerce .page-wrapper input.button span.icon:last-child,
.woocommerce .page-wrapper input[type=button] span.icon:last-child,
.woocommerce .page-wrapper button.button span.icon:last-child,
.woocommerce .products #review_form #respond .form-submit input span.icon:last-child,
.woocommerce .products #submit span.icon:last-child,
.woocommerce .products a.button span.icon:last-child,
.woocommerce .products input.button span.icon:last-child,
.woocommerce .products input[type=button] span.icon:last-child,
.woocommerce .products button.button span.icon:last-child {
  padding: .5em .8em .5em 0 !important;
}
.woocommerce .page-wrapper #review_form #respond .form-submit input span.btext,
.woocommerce .page-wrapper #submit span.btext,
.woocommerce .page-wrapper a.button span.btext,
.woocommerce .page-wrapper input.button span.btext,
.woocommerce .page-wrapper input[type=button] span.btext,
.woocommerce .page-wrapper button.button span.btext,
.woocommerce .products #review_form #respond .form-submit input span.btext,
.woocommerce .products #submit span.btext,
.woocommerce .products a.button span.btext,
.woocommerce .products input.button span.btext,
.woocommerce .products input[type=button] span.btext,
.woocommerce .products button.button span.btext {
  position: relative;
  font-weight: 500;
  vertical-align: middle;
  padding: 0.7em 1.2em;
  letter-spacing: 1px;
}
.woocommerce .page-wrapper #review_form #respond .form-submit input:hover,
.woocommerce .page-wrapper #review_form #respond .form-submit input:hover span,
.woocommerce .page-wrapper #submit:hover,
.woocommerce .page-wrapper #submit:hover span,
.woocommerce .page-wrapper a.button:hover,
.woocommerce .page-wrapper a.button:hover span,
.woocommerce .page-wrapper input.button:hover,
.woocommerce .page-wrapper input.button:hover span,
.woocommerce .page-wrapper input[type=button]:hover,
.woocommerce .page-wrapper input[type=button]:hover span,
.woocommerce .page-wrapper button.button:hover,
.woocommerce .page-wrapper button.button:hover span,
.woocommerce .products #review_form #respond .form-submit input:hover,
.woocommerce .products #review_form #respond .form-submit input:hover span,
.woocommerce .products #submit:hover,
.woocommerce .products #submit:hover span,
.woocommerce .products a.button:hover,
.woocommerce .products a.button:hover span,
.woocommerce .products input.button:hover,
.woocommerce .products input.button:hover span,
.woocommerce .products input[type=button]:hover,
.woocommerce .products input[type=button]:hover span,
.woocommerce .products button.button:hover,
.woocommerce .products button.button:hover span {
  text-decoration: none;
}
.woocommerce .page-wrapper #review_form #respond .form-submit input span,
.woocommerce .page-wrapper #submit span,
.woocommerce .page-wrapper a.button span,
.woocommerce .page-wrapper input.button span,
.woocommerce .page-wrapper input[type=button] span,
.woocommerce .page-wrapper button.button span,
.woocommerce .products #review_form #respond .form-submit input span,
.woocommerce .products #submit span,
.woocommerce .products a.button span,
.woocommerce .products input.button span,
.woocommerce .products input[type=button] span,
.woocommerce .products button.button span {
  color: #ffffff;
}
.woocommerce .page-wrapper #review_form #respond .form-submit input:hover,
.woocommerce .page-wrapper #review_form #respond .form-submit input:focus,
.woocommerce .page-wrapper #review_form #respond .form-submit input:active,
.woocommerce .page-wrapper #submit:hover,
.woocommerce .page-wrapper #submit:focus,
.woocommerce .page-wrapper #submit:active,
.woocommerce .page-wrapper a.button:hover,
.woocommerce .page-wrapper a.button:focus,
.woocommerce .page-wrapper a.button:active,
.woocommerce .page-wrapper input.button:hover,
.woocommerce .page-wrapper input.button:focus,
.woocommerce .page-wrapper input.button:active,
.woocommerce .page-wrapper input[type=button]:hover,
.woocommerce .page-wrapper input[type=button]:focus,
.woocommerce .page-wrapper input[type=button]:active,
.woocommerce .page-wrapper button.button:hover,
.woocommerce .page-wrapper button.button:focus,
.woocommerce .page-wrapper button.button:active,
.woocommerce .products #review_form #respond .form-submit input:hover,
.woocommerce .products #review_form #respond .form-submit input:focus,
.woocommerce .products #review_form #respond .form-submit input:active,
.woocommerce .products #submit:hover,
.woocommerce .products #submit:focus,
.woocommerce .products #submit:active,
.woocommerce .products a.button:hover,
.woocommerce .products a.button:focus,
.woocommerce .products a.button:active,
.woocommerce .products input.button:hover,
.woocommerce .products input.button:focus,
.woocommerce .products input.button:active,
.woocommerce .products input[type=button]:hover,
.woocommerce .products input[type=button]:focus,
.woocommerce .products input[type=button]:active,
.woocommerce .products button.button:hover,
.woocommerce .products button.button:focus,
.woocommerce .products button.button:active {
  background: #364352;
}
.woocommerce .page-wrapper #review_form #respond .form-submit input:hover,
.woocommerce .page-wrapper #review_form #respond .form-submit input:hover span,
.woocommerce .page-wrapper #review_form #respond .form-submit input:focus,
.woocommerce .page-wrapper #review_form #respond .form-submit input:focus span,
.woocommerce .page-wrapper #review_form #respond .form-submit input:active,
.woocommerce .page-wrapper #review_form #respond .form-submit input:active span,
.woocommerce .page-wrapper #submit:hover,
.woocommerce .page-wrapper #submit:hover span,
.woocommerce .page-wrapper #submit:focus,
.woocommerce .page-wrapper #submit:focus span,
.woocommerce .page-wrapper #submit:active,
.woocommerce .page-wrapper #submit:active span,
.woocommerce .page-wrapper a.button:hover,
.woocommerce .page-wrapper a.button:hover span,
.woocommerce .page-wrapper a.button:focus,
.woocommerce .page-wrapper a.button:focus span,
.woocommerce .page-wrapper a.button:active,
.woocommerce .page-wrapper a.button:active span,
.woocommerce .page-wrapper input.button:hover,
.woocommerce .page-wrapper input.button:hover span,
.woocommerce .page-wrapper input.button:focus,
.woocommerce .page-wrapper input.button:focus span,
.woocommerce .page-wrapper input.button:active,
.woocommerce .page-wrapper input.button:active span,
.woocommerce .page-wrapper input[type=button]:hover,
.woocommerce .page-wrapper input[type=button]:hover span,
.woocommerce .page-wrapper input[type=button]:focus,
.woocommerce .page-wrapper input[type=button]:focus span,
.woocommerce .page-wrapper input[type=button]:active,
.woocommerce .page-wrapper input[type=button]:active span,
.woocommerce .page-wrapper button.button:hover,
.woocommerce .page-wrapper button.button:hover span,
.woocommerce .page-wrapper button.button:focus,
.woocommerce .page-wrapper button.button:focus span,
.woocommerce .page-wrapper button.button:active,
.woocommerce .page-wrapper button.button:active span,
.woocommerce .products #review_form #respond .form-submit input:hover,
.woocommerce .products #review_form #respond .form-submit input:hover span,
.woocommerce .products #review_form #respond .form-submit input:focus,
.woocommerce .products #review_form #respond .form-submit input:focus span,
.woocommerce .products #review_form #respond .form-submit input:active,
.woocommerce .products #review_form #respond .form-submit input:active span,
.woocommerce .products #submit:hover,
.woocommerce .products #submit:hover span,
.woocommerce .products #submit:focus,
.woocommerce .products #submit:focus span,
.woocommerce .products #submit:active,
.woocommerce .products #submit:active span,
.woocommerce .products a.button:hover,
.woocommerce .products a.button:hover span,
.woocommerce .products a.button:focus,
.woocommerce .products a.button:focus span,
.woocommerce .products a.button:active,
.woocommerce .products a.button:active span,
.woocommerce .products input.button:hover,
.woocommerce .products input.button:hover span,
.woocommerce .products input.button:focus,
.woocommerce .products input.button:focus span,
.woocommerce .products input.button:active,
.woocommerce .products input.button:active span,
.woocommerce .products input[type=button]:hover,
.woocommerce .products input[type=button]:hover span,
.woocommerce .products input[type=button]:focus,
.woocommerce .products input[type=button]:focus span,
.woocommerce .products input[type=button]:active,
.woocommerce .products input[type=button]:active span,
.woocommerce .products button.button:hover,
.woocommerce .products button.button:hover span,
.woocommerce .products button.button:focus,
.woocommerce .products button.button:focus span,
.woocommerce .products button.button:active,
.woocommerce .products button.button:active span {
  color: #b7c3d0;
}
.woocommerce .page-wrapper .quantity,
.woocommerce .products .quantity {
  margin: 0 10px 0 0 !important;
  padding-top: 0;
}
.woocommerce-page #review_form #respond p {
  margin: 0 0 10px;
}
.vamtam-cart-dropdown-link {
  position: relative;
  display: block;
  margin-top: -1px;
  margin-left: 2px;
  padding: 4px 0 4px 8px;
  width: 40px;
  height: 43px;
  background: transparent;
  color: #2B2F34;
  text-align: center;
  font-size: 35px;
  line-height: 40px;
  cursor: pointer;
  transition: color .4s;
}
body.sticky-header-type-over.sticky-header.wpv-not-scrolled .vamtam-cart-dropdown-link,
body.sticky-header-type-half-over.sticky-header.wpv-not-scrolled .layout-standard .vamtam-cart-dropdown-link,
body.sticky-header-type-half-over.sticky-header.wpv-not-scrolled .layout-logo-text-menu .vamtam-cart-dropdown-link {
  color: #ffffff;
}
.vamtam-cart-dropdown-link .products {
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  position: absolute;
  top: 5px;
  right: 0px;
  z-index: 1;
  display: block;
  padding: 5px;
  width: 20px;
  height: 20px;
  border-radius: 100px;
  background: #F0542D;
  color: #ffffff;
  text-align: center;
  font-style: normal;
  font-size: 10px;
  font-family: "Raleway";
  line-height: 8px;
  font-weight: 900;
}
.vamtam-cart-dropdown-link .products.cart-empty {
  background: #EDEDED;
  color: #6e6e6e;
}
.vamtam-cart-dropdown-link .icon {
  position: relative;
  top: 5px;
  float: left;
  font-size: 21px;
  color: #D8D8D8;
}
.vamtam-cart-dropdown-link:hover {
  text-decoration: none;
  color: #F0542D;
}
.fixed-header-box .cart-dropdown {
  display: table-cell;
  min-width: 50px;
  vertical-align: middle;
}
.fixed-header-box .cart-dropdown.hidden {
  display: none;
}
.fixed-header-box .cart-dropdown:hover .vamtam-cart-dropdown-link {
  z-index: 9999;
}
.fixed-header-box .cart-dropdown:not(:last-child) .cart-dropdown-inner {
  width: 62px;
}
.fixed-header-box .cart-dropdown:not(:last-child) .vamtam-cart-dropdown-link {
  padding-right: 5px;
  padding-left: 15px;
}
.fixed-header-box .cart-dropdown:not(:last-child) .vamtam-cart-dropdown-link .products {
  right: 5px;
}
.fixed-header-box .cart-dropdown:not(:last-child) .widget {
  width: 262px;
}
.fixed-header-box .cart-dropdown .cart-dropdown-inner {
  width: 50px;
  height: 50px;
}
.fixed-header-box .cart-dropdown .widget {
  position: absolute;
  display: none;
  margin-left: -230px;
  padding: 15px;
  width: 250px;
  background-color: #ffffff;
  box-shadow: 0 2px 4px 2px rgba(0,0,0,0.09);
}
.fixed-header-box .cart-dropdown .widget img {
  box-shadow: none;
}
.woocommerce.widget span.amount {
  color: #F0542D;
}
.woocommerce ul.product_list_widget li a {
  font: 600 12px/14px "Raleway";
  padding: 5px 0 5px 0;
  font-size: 14px;
}
.woocommerce ul.product_list_widget li img {
  box-shadow: none;
}
.woocommerce ul.product_list_widget .star-rating {
  display: none;
  margin: .7em 0;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content li {
  overflow: visible;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content li.empty {
  border-bottom: 0;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content li a {
  font-size: inherit !important;
  font-weight: normal !important;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content li:last-child {
  border: none;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .total {
  padding: 20px 0px 10px 0px;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .total strong,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .total .amount {
  font: 600 12px/14px "Raleway";
  color: #242323;
  font-size: 1.1em;
  font-weight: normal;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .total .amount {
  font-weight: bold;
  font-size: 1.4em;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .quantity .amount {
  font: normal 14px/20px "Raleway";
  color: #767676;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content p:last-child {
  margin-bottom: 0;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button {
  margin-right: 10px;
  font-size: 1em;
  font-weight: normal;
  display: inline-block;
  text-align: center;
  cursor: pointer;
  position: relative;
  z-index: 0;
  vertical-align: middle;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
  text-decoration: none;
  text-shadow: none;
  line-height: 1.15em;
  border-widht: 2px;
  padding: 0;
  text-align: center !important;
  background: #EDEDED;
  color: #3b3b3b;
  padding: 0.5em 1.4em;
  box-shadow: none;
  border: none;
  border-radius: 0;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button span {
  transition: color .3s ease, border .3s ease, background .3s ease;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button span {
  display: inline-block;
  font-size: 1em;
  line-height: inherit;
  padding: .3em .4em;
  margin: 0 0;
  vertical-align: baseline;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button span.icon {
  font-size: 100%;
  vertical-align: bottom !important;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button span.icon.shortcode.inverted-colors {
  font-size: 100%;
  box-shadow: 0 1px 1px rgba(0,0,0,0.1) inset, 0 1px 1px rgba(255,255,255,0.2);
  text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button span.icon:first-child,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button span.icon:last-child {
  vertical-align: top;
  background: none;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button span.icon:first-child {
  padding: .5em 0 .5em .8em !important;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button span.icon:last-child {
  padding: .5em .8em .5em 0 !important;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button span.btext {
  position: relative;
  font-weight: 500;
  vertical-align: middle;
  padding: 0.7em 1.2em;
  letter-spacing: 1px;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button:hover,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button:hover span {
  text-decoration: none;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button span {
  color: #3b3b3b;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button:hover,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button:focus,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button:active {
  background: #7C8A8D;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button:hover,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button:hover span,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button:focus,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button:focus span,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button:active,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button:active span {
  color: #ffffff;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.button:hover {
  background: #364352;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout {
  font-size: 1em;
  font-weight: normal;
  display: inline-block;
  text-align: center;
  cursor: pointer;
  position: relative;
  z-index: 0;
  vertical-align: middle;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
  text-decoration: none;
  text-shadow: none;
  line-height: 1.15em;
  border-widht: 2px;
  padding: 0;
  text-align: center !important;
  background: #F0542D;
  color: #ffffff;
  padding: 0.5em 1em;
  box-shadow: none;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout span {
  transition: color .3s ease, border .3s ease, background .3s ease;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout span {
  display: inline-block;
  font-size: 1em;
  line-height: inherit;
  padding: .3em .4em;
  margin: 0 0;
  vertical-align: baseline;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout span.icon {
  font-size: 100%;
  vertical-align: bottom !important;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout span.icon.shortcode.inverted-colors {
  font-size: 100%;
  box-shadow: 0 1px 1px rgba(0,0,0,0.1) inset, 0 1px 1px rgba(255,255,255,0.2);
  text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout span.icon:first-child,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout span.icon:last-child {
  vertical-align: top;
  background: none;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout span.icon:first-child {
  padding: .5em 0 .5em .8em !important;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout span.icon:last-child {
  padding: .5em .8em .5em 0 !important;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout span.btext {
  position: relative;
  font-weight: 500;
  vertical-align: middle;
  padding: 0.7em 1.2em;
  letter-spacing: 1px;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout:hover,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout:hover span {
  text-decoration: none;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout span {
  color: #ffffff;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout:hover,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout:focus,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout:active {
  background: #364352;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout:hover,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout:hover span,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout:focus,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout:focus span,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout:active,
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout:active span {
  color: #b7c3d0;
}
.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a.checkout:hover {
  color: #ffffff;
}
.woocommerce.widget_product_search #searchform label {
  display: none !important;
}
.woocommerce.widget_price_filter .price_slider {
  height: 0.8em;
  background: #ffffff !important;
  border: solid 1px #EDEDED;
}
.woocommerce.widget_price_filter .price_slider > div.ui-slider-range {
  background: #7C8A8D;
  box-shadow: none !important;
}
.woocommerce.widget_price_filter .price_slider > .ui-slider-handle {
  width: 1em;
  height: 1em;
  border: 0.3em solid #ffffff !important;
  background: #F0542D;
  box-shadow: none !important;
  top: -0.4em;
}
.woocommerce.widget_price_filter .price_slider_amount .button {
  font-size: 1em;
  font-weight: normal;
  display: inline-block;
  text-align: center;
  cursor: pointer;
  position: relative;
  z-index: 0;
  vertical-align: middle;
  -moz-user-select: none;
  -webkit-user-select: none;
  user-select: none;
  text-decoration: none;
  text-shadow: none;
  line-height: 1.15em;
  border-widht: 2px;
  padding: 0;
  text-align: center !important;
  background: #F0542D;
  color: #ffffff;
  margin-top: 15px;
  padding: 0.5em 1.1em;
  box-shadow: none;
  font-style: normal;
  font-size: 1.1em;
  border-radius: 0;
}
.woocommerce.widget_price_filter .price_slider_amount .button,
.woocommerce.widget_price_filter .price_slider_amount .button span {
  transition: color .3s ease, border .3s ease, background .3s ease;
}
.woocommerce.widget_price_filter .price_slider_amount .button span {
  display: inline-block;
  font-size: 1em;
  line-height: inherit;
  padding: .3em .4em;
  margin: 0 0;
  vertical-align: baseline;
}
.woocommerce.widget_price_filter .price_slider_amount .button span.icon {
  font-size: 100%;
  vertical-align: bottom !important;
}
.woocommerce.widget_price_filter .price_slider_amount .button span.icon.shortcode.inverted-colors {
  font-size: 100%;
  box-shadow: 0 1px 1px rgba(0,0,0,0.1) inset, 0 1px 1px rgba(255,255,255,0.2);
  text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}
.woocommerce.widget_price_filter .price_slider_amount .button span.icon:first-child,
.woocommerce.widget_price_filter .price_slider_amount .button span.icon:last-child {
  vertical-align: top;
  background: none;
}
.woocommerce.widget_price_filter .price_slider_amount .button span.icon:first-child {
  padding: .5em 0 .5em .8em !important;
}
.woocommerce.widget_price_filter .price_slider_amount .button span.icon:last-child {
  padding: .5em .8em .5em 0 !important;
}
.woocommerce.widget_price_filter .price_slider_amount .button span.btext {
  position: relative;
  font-weight: 500;
  vertical-align: middle;
  padding: 0.7em 1.2em;
  letter-spacing: 1px;
}
.woocommerce.widget_price_filter .price_slider_amount .button:hover,
.woocommerce.widget_price_filter .price_slider_amount .button:hover span {
  text-decoration: none;
}
.woocommerce.widget_price_filter .price_slider_amount .button span {
  color: #ffffff;
}
.woocommerce.widget_price_filter .price_slider_amount .button:hover,
.woocommerce.widget_price_filter .price_slider_amount .button:focus,
.woocommerce.widget_price_filter .price_slider_amount .button:active {
  background: #364352;
}
.woocommerce.widget_price_filter .price_slider_amount .button:hover,
.woocommerce.widget_price_filter .price_slider_amount .button:hover span,
.woocommerce.widget_price_filter .price_slider_amount .button:focus,
.woocommerce.widget_price_filter .price_slider_amount .button:focus span,
.woocommerce.widget_price_filter .price_slider_amount .button:active,
.woocommerce.widget_price_filter .price_slider_amount .button:active span {
  color: #b7c3d0;
}
.woocommerce.widget_price_filter .price_slider_amount .button:hover {
  color: #ffffff;
  background: #364352;
}
.woocommerce.widget_price_filter .price_label {
  padding-top: 10px;
}
.woocommerce.widget_price_filter .from,
.woocommerce.widget_price_filter .to {
  color: #F0542D;
  font-size: 1.3em;
}
.woocommerce.widget_layered_nav_filters ul li {
  border: none;
}
.woocommerce.widget_layered_nav_filters ul li a {
  border-color: transparent;
  border-radius: 0px;
  background: none;
  color: #364352 !important;
  padding: 4px 10px;
}
.woocommerce.widget_layered_nav ul li {
  padding: 10px 0;
}
.woocommerce.widget_layered_nav ul li:first-child {
  padding-top: 0;
}
.contact_info_wrap,
.flickr_wrap,
.portfolios,
.price-outer-wrapper,
.services,
.slogan,
.team-member,
.toggle,
.unapproved,
.wpv-tabs {
  padding-top: 15px;
  padding-bottom: 15px;
}
.loop-wrapper.page-content {
  padding-top: 0;
  padding-bottom: 0;
}
.page-content > .frame > .google_map,
.page-content > .row > .grid-1-1 > .frame > .google_map {
  margin: 0 -60px;
}
.wpv-grid > .linkarea,
.wpv-grid > .services.has-more {
  margin-left: -15px;
  margin-right: -15px;
}
.alignnone {
  float: none !important;
}
.textcenter {
  text-align: center;
}
.textright {
  text-align: right;
}
.alignright {
  float: right;
  margin: 1em 0 1em 1.5em;
}
.alignleft {
  float: left;
  margin: 1em 1.5em 1em 0;
}
.aligncenter {
  display: block;
  margin: 1em auto;
}
a img.alignright {
  float: right;
  margin: 0 0 20px 25px;
}
a img.alignnone {
  margin: 0px;
}
a img.alignleft {
  float: left;
  margin: 0 25px 20px 0;
}
a img.aligncenter {
  display: block;
  margin-left: auto;
  margin-right: auto;
}
img.alignleft {
  margin: 0 25px 20px 0;
}
.wp-caption.alignleft {
  margin: 5px 10px 5px 0;
}
img.alignright {
  margin: 0 0 20px 25px;
}
.wp-caption.alignright {
  margin: 5px 0 5px 10px;
}
img.aligncenter {
  margin: 0 auto;
}
img.alignnone {
  margin: 5px 0;
}
.wp-caption {
  max-width: 100%;
}
.wp-caption.alignleft {
  margin: 5px 10px 5px 0;
}
.wp-caption.alignright {
  margin: 5px 0 5px 10px;
}
.wp-caption .wp-caption-text,
.entry-caption,
.gallery-caption {
  margin-top: 0;
  font: italic 14px/18px "Raleway";
  color: #898989;
}
.wp-smiley,
.wp-smiley * {
  border: 0px !important;
}
.sticky,
.gallery-caption,
.bypostauthor {
  outline: none;
}
table {
  border-collapse: collapse;
  border-spacing: 0;
  line-height: 2;
  width: 100%;
}
caption,
th,
td {
  font-weight: normal;
  text-align: left;
}
caption {
  font-size: 16px;
  margin: 20px 0;
}
th {
  font-weight: bold;
  text-transform: uppercase;
}
td {
  border: none;
  padding: 6px 10px 6px 0;
}
dl {
  margin: 0 20px;
}
dt {
  font-weight: bold;
}
dd {
  margin: 0 0 10px;
}
address {
  font-style: italic;
  margin: 0 0 24px;
}
var,
cite {
  font-style: italic;
}
[class*="gallery-columns-"] {
  margin: 0 -15px;
}
[class*="gallery-columns-"].gallery-columns-1 .gallery-item {
  width: 100%;
}
[class*="gallery-columns-"].gallery-columns-2 .gallery-item {
  width: 50%;
}
[class*="gallery-columns-"].gallery-columns-3 .gallery-item {
  width: 33.333333333333%;
}
[class*="gallery-columns-"].gallery-columns-4 .gallery-item {
  width: 25%;
}
[class*="gallery-columns-"].gallery-columns-5 .gallery-item {
  width: 20%;
}
[class*="gallery-columns-"].gallery-columns-6 .gallery-item {
  width: 16.666666666667%;
}
[class*="gallery-columns-"].gallery-columns-7 .gallery-item {
  width: 14.285714285714%;
}
[class*="gallery-columns-"].gallery-columns-8 .gallery-item {
  width: 12.5%;
}
[class*="gallery-columns-"].gallery-columns-9 .gallery-item {
  width: 11.111111111111%;
}
[class*="gallery-columns-"] figure.gallery-item {
  padding: 0 15px;
  display: inline-block;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
[class*="gallery-columns-"] figure.gallery-item img {
  display: inline-block;
}
.me-cannotplay span {
  padding: 5px;
}
.post-password-required {
  text-align: center;
}
@media (min-width: 959px) {
  .add-border {
    border: solid 1px #EDEDED;
  }
  header.main-header {
    overflow: visible;
  }
  header.main-header .mobile-top-bar,
  header.main-header .mobile-logo-additions {
    display: none;
  }
  .top-nav > .top-nav-inner > .row > .row:not(.single-cell) {
    display: table;
  }
  .top-nav > .top-nav-inner > .row > .row:not(.single-cell) > .grid-1-2 {
    display: table-cell;
    float: none;
    width: 100%;
    vertical-align: middle;
  }
  #sub-header {
    position: relative;
    z-index: 2;
  }
  #sub-header header.page-header {
    padding: 0 60px;
  }
  .portfolio-filters .cbp-l-filters-dropdown {
    margin-bottom: 0;
  }
  .portfolio-filters .cbp-l-filters-dropdownWrap {
    position: relative;
    background: none;
    width: auto;
  }
  .portfolio-filters .cbp-l-filters-dropdownList {
    display: block;
  }
  .portfolio-filters .cbp-l-filters-dropdownList .cbp-filter-item {
    width: auto;
  }
  .portfolio-filters .cbp-l-filters-dropdownHeader {
    display: none;
  }
  .portfolio-filters .cbp-search {
    margin-bottom: 0;
  }
  .wpv-grid.left-border:before {
    position: absolute;
    top: 0%;
    bottom: 0%;
    left: 0;
    width: 1px;
    height: 100%;
    content: "";
  }
  .wpv-grid.has-more-button,
  .wpv-grid.has-more-button.grid-1-1,
  .wpv-grid.has-more-button.extended.grid-1-1 {
    position: relative;
    padding-right: 77px;
  }
  .wpv-grid.has-more-button .column-read-more-btn {
    position: absolute;
    top: 50%;
    right: 0;
    z-index: 44444444444;
    margin-top: -28px;
    padding: 20px 20px 20px 10px;
    background: #ffffff;
    box-shadow: 0 1px 1px #e3e3e3;
    color: #F0542D;
    text-align: center;
    font-size: 16px;
  }
  .wpv-grid.has-more-button .column-read-more-btn:hover {
    color: #5C6268;
  }
  .move-into-slider,
  .move-into-slider-2 {
    z-index: 10;
  }
  .move-into-slider .wpv-tabs,
  .move-into-slider-2 .wpv-tabs {
    padding-top: 0;
    margin: 0 -20px;
  }
  .move-into-slider {
    margin-top: -60px;
  }
  .move-into-slider-2 {
    margin-top: -20px;
  }
  .page-template-guestbook-php #sub-header header.page-header {
    padding-bottom: 90px;
  }
  .page-template-guestbook-php #comments:first-child {
    margin-top: -90px;
    position: relative;
    z-index: 10;
  }
  body.woocommerce-checkout .col-1 {
    width: 58% !important;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    padding-right: 30px;
  }
  body.woocommerce-checkout .col-2 {
    width: 42% !important;
  }
}
@media (min-width: 1281px) {
  .loop-wrapper.news > .grid-1-4:nth-child(4n+1),
  .loop-wrapper.news > .grid-1-3:nth-child(3n+1),
  .loop-wrapper.news > .grid-1-2:nth-child(2n+1),
  .portfolios > ul > .grid-1-4:nth-child(4n+1),
  .portfolios > ul > .grid-1-3:nth-child(3n+1),
  .portfolios > ul > .grid-1-2:nth-child(2n+1) {
    clear: both;
  }
}
@media (min-width: 959px) and (max-width: 1280px) {
  .responsive-layout #ss-teaser,
  .responsive-layout #style-switcher,
  .responsive-layout #feedback-wrapper {
    display: none !important;
    height: 0 !important;
    width: 0 !important;
    right: auto !important;
    left: -10000px !important;
  }
  .responsive-layout .loop-wrapper.news > .grid-1-4,
  .responsive-layout .portfolios > ul > .grid-1-4 {
    width: 33.333333333333%;
  }
  .responsive-layout .loop-wrapper.news > .grid-1-4:nth-child(3n+1),
  .responsive-layout .portfolios > ul > .grid-1-4:nth-child(3n+1) {
    clear: both;
  }
  .responsive-layout .loop-wrapper.news > .grid-1-3:nth-child(3n+1),
  .responsive-layout .loop-wrapper.news > .grid-1-2:nth-child(2n+1),
  .responsive-layout .portfolios > ul > .grid-1-3:nth-child(3n+1),
  .responsive-layout .portfolios > ul > .grid-1-2:nth-child(2n+1) {
    clear: both;
  }
  .responsive-layout header.main-header {
    position: relative;
    top: 0;
    right: 0;
    left: 0;
    margin: 0;
  }
  .responsive-layout header.main-header .header-left {
    border-radius: 0;
    background-clip: padding-box;
    display: none;
  }
  .responsive-layout header.main-header #header-text {
    display: none;
  }
  .responsive-layout header.main-header .header-right {
    display: none;
  }
  .responsive-layout header.main-header .second-row .second-row-columns {
    display: block;
  }
  .responsive-layout .page-wrapper aside.left,
  .responsive-layout .page-wrapper aside.right {
    padding-left: 20px;
    padding-right: 20px;
  }
  .responsive-layout #footer-sidebars > .row .widget {
    padding-left: 20px;
    padding-right: 20px;
  }
  .responsive-layout .vamtam-booking-form .wpv-grid .wpv-grid:first-child {
    width: 100%;
  }
  .responsive-layout .vamtam-booking-form .wpv-grid .wpv-grid:last-child {
    width: 200%;
    margin-left: -100%;
    margin-top: 5px;
  }
}
@media (min-width: 959px) and (max-width: 1140px) {
  .responsive-layout .page-content > .limit-wrapper {
    padding-left: 30px;
    padding-right: 30px;
  }
}
@media (max-width: 1260px) {
  header.main-header .first-row {
    box-sizing: border-box;
  }
}
@media (max-width: 958px) {
  .responsive-layout #scroll-to-top {
    bottom: 50px;
  }
  .responsive-layout .comments .children li {
    margin-left: 10px;
  }
  .responsive-layout .error-message {
    display: none;
  }
  .responsive-layout html {
    background-image: none;
  }
  .responsive-layout.page-header .title {
    padding: 30px 0 0 0 !important;
  }
  .responsive-layout.no-header-sidebars.no-page-header .page-wrapper {
    padding-top: 20px;
  }
  .responsive-layout .wpv-accordion {
    margin-bottom: 30px;
  }
  .responsive-layout .move-into-slider .icon.shortcode.box {
    padding: 0.1em;
  }
  .responsive-layout .move-into-slider {
    margin-top: 0px;
  }
  .responsive-layout #ss-teaser,
  .responsive-layout #style-switcher,
  .responsive-layout #feedback-wrapper {
    right: auto !important;
    left: -10000px !important;
    display: none !important;
    width: 0 !important;
    height: 0 !important;
  }
  .responsive-layout.boxed .boxed-layout {
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    margin: 0 !important;
    padding: 0 !important;
  }
  .responsive-layout .alignleft,
  .responsive-layout .alignright {
    float: none;
  }
  .responsive-layout .grid-1-2,
  .responsive-layout .grid-1-3,
  .responsive-layout .grid-1-4,
  .responsive-layout .grid-1-5,
  .responsive-layout .grid-1-6,
  .responsive-layout .grid-2-3,
  .responsive-layout .grid-2-5,
  .responsive-layout .grid-3-4,
  .responsive-layout .grid-3-5,
  .responsive-layout .grid-4-5,
  .responsive-layout .grid-5-6,
  .responsive-layout aside.left,
  .responsive-layout aside.right,
  .responsive-layout .left-only,
  .responsive-layout .right-only,
  .responsive-layout .left-right {
    float: none !important;
    clear: both !important;
    margin-bottom: 0;
    width: 100% !important;
  }
  .responsive-layout .grid-1-2:last-child,
  .responsive-layout .grid-1-3:last-child,
  .responsive-layout .grid-1-4:last-child,
  .responsive-layout .grid-1-5:last-child,
  .responsive-layout .grid-1-6:last-child,
  .responsive-layout .grid-2-3:last-child,
  .responsive-layout .grid-2-5:last-child,
  .responsive-layout .grid-3-4:last-child,
  .responsive-layout .grid-3-5:last-child,
  .responsive-layout .grid-4-5:last-child,
  .responsive-layout .grid-5-6:last-child,
  .responsive-layout aside.left:last-child,
  .responsive-layout aside.right:last-child,
  .responsive-layout .left-only:last-child,
  .responsive-layout .right-only:last-child,
  .responsive-layout .left-right:last-child {
    margin-bottom: 0;
  }
  .responsive-layout .grid-1-1 {
    margin-bottom: 0;
    float: none;
    clear: both;
  }
  .responsive-layout .grid-1-1:before,
  .responsive-layout .grid-1-1:after {
    content: " ";
    display: table;
  }
  .responsive-layout .grid-1-1:after {
    clear: both;
  }
  .responsive-layout .grid-1-1:before,
  .responsive-layout .grid-1-1:after {
    content: " ";
    display: table;
  }
  .responsive-layout .grid-1-1:after {
    clear: both;
  }
  .responsive-layout .grid-1-1:last-child {
    margin-bottom: 0;
  }
  .responsive-layout #header-sidebars aside,
  .responsive-layout #footer-sidebars aside {
    display: block !important;
    clear: both !important;
    margin: 0 0 15px 0 !important;
    width: 100% !important;
  }
  .responsive-layout #header-sidebars aside section,
  .responsive-layout #footer-sidebars aside section {
    margin: 0;
  }
  .responsive-layout #footer-sidebars aside {
    padding: 0 !important;
  }
  .responsive-layout .row {
    margin-bottom: 0;
  }
  .responsive-layout .row:last-child {
    margin-bottom: 0;
  }
  .responsive-layout #wpadminbar {
    overflow: hidden;
    min-width: 0;
  }
  .responsive-layout aside.left,
  .responsive-layout aside.right {
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    margin-right: 0;
    margin-left: 0;
    padding: 0 30px;
  }
  .responsive-layout aside .menu-item > .sub-menu {
    display: none !important;
  }
  .responsive-layout .copyrights {
    padding: 10px 0;
  }
  .responsive-layout .copyrights,
  .responsive-layout .copyrights * {
    text-align: center !important;
  }
  .responsive-layout .copyrights img.alignleft,
  .responsive-layout .copyrights img.alignright {
    display: inline-block;
    float: none;
  }
  .responsive-layout .copyrights .wpv-grid {
    margin-bottom: 0;
  }
  .responsive-layout .price-wrapper.featured {
    margin-top: 0;
  }
  .responsive-layout .meta-header-inside {
    width: 100%;
  }
  .responsive-layout.fast-slider .fast-slider-caption {
    height: auto;
  }
  .responsive-layout.fast-slider .fast-slider-navbar {
    right: auto;
    left: 0;
    width: 100%;
  }
  .responsive-layout .slogan.has-button .slogan-content,
  .responsive-layout .slogan.has-button .button-wrp {
    display: block;
  }
  .responsive-layout .slogan.has-button .button-wrp {
    padding-top: 30px;
    padding-left: 0;
  }
  .responsive-layout #sub-footer-menu li {
    display: inline-block;
    float: none;
  }
  .responsive-layout .portfolio-viewer-wrap {
    padding: 0 30px;
  }
  .responsive-layout .portfolio-viewer-wrap .content .share-btns {
    margin-bottom: 20px;
  }
  .responsive-layout .woocommerce.woocommerce-scrollable .products.vamtam-wc .product {
    clear: none;
  }
  .responsive-layout.post-type-archive-product .products.vamtam-wc .product,
  .responsive-layout.tax-product_cat .products.vamtam-wc .product {
    margin-bottom: 20px;
  }
  html.csstransforms .responsive-layout.post-type-archive-product .products.vamtam-wc .product span.onsale:before,
  html.csstransforms .responsive-layout.tax-product_cat .products.vamtam-wc .product span.onsale:before {
    border-width: 0 65px 65px 65px;
    left: -28px;
  }
  .responsive-layout.woocommerce table.cart {
    max-width: 100%;
  }
  .responsive-layout.woocommerce table.cart td.product-thumbnail,
  .responsive-layout.woocommerce table.cart th.product-thumbnail {
    display: none;
  }
  .responsive-layout.woocommerce table.cart td.actions {
    text-align: left;
  }
  .responsive-layout.woocommerce table.cart td.actions div.coupon {
    margin-bottom: 1em;
  }
  .responsive-layout.woocommerce table.cart td.actions > input[type="submit"] {
    display: block;
    float: none !important;
    margin-bottom: 1em !important;
    margin-left: 0 !important;
  }
  .responsive-layout.woocommerce .cart-collaterals .shipping_calculator,
  .responsive-layout.woocommerce .cart-collaterals .cart_totals {
    float: none;
    width: 100%;
  }
  .responsive-layout.woocommerce .cart-collaterals .shipping_calculator {
    padding-top: 30px;
  }
  .responsive-layout.woocommerce div.product span.onsale {
    right: 0;
  }
  .responsive-layout.woocommerce div.product div.summary,
  .responsive-layout.woocommerce div.product div.images {
    float: none;
    width: 100%;
  }
  .responsive-layout.woocommerce div.product div.images {
    margin-bottom: 30px;
  }
  .responsive-layout.woocommerce div.product .woocommerce-tabs > ul.tabs li {
    float: none !important;
    border: none !important;
    text-align: center;
  }
  .responsive-layout.woocommerce div.product .woocommerce-tabs > ul.tabs li:first-child {
    margin-left: 0;
  }
  .responsive-layout.woocommerce .summary form.cart,
  .responsive-layout.woocommerce .summary > div,
  .responsive-layout.woocommerce .summary .product_meta {
    padding-left: 0;
  }
  .responsive-layout.woocommerce .summary .share-btns {
    margin-left: 0;
  }
  .responsive-layout.woocommerce .summary .product_meta {
    margin: 0;
  }
  .responsive-layout.woocommerce .woocommerce-result-count {
    float: none;
    margin-top: 0;
  }
  .responsive-layout.woocommerce .woocommerce-ordering {
    float: none;
    margin-bottom: 40px;
  }
  .responsive-layout.woocommerce .related.products .products.vamtam-wc .product,
  .responsive-layout.woocommerce .upsells.products .products.vamtam-wc .product {
    width: 45%;
    margin: 5% 2%;
    display: inline-block;
    vertical-align: top;
  }
  .responsive-layout.woocommerce .type-featured .limit-wrapper .row {
    margin-left: -5px;
    margin-right: -5px;
  }
  .responsive-layout.woocommerce .email-offers input {
    margin-bottom: 1em !important;
  }
  .responsive-layout .woocommerce.columns-3 .products.vamtam-wc .product {
    width: 48%;
  }
  .responsive-layout .woocommerce.columns-3 .products.vamtam-wc .product:nth-child(2n+1) {
    clear: both;
  }
  .responsive-layout .woocommerce .widget_shopping_cart .widget_shopping_cart_content .buttons a.button {
    float: left;
    clear: both;
  }
  .responsive-layout.single-product aside.left {
    display: none;
  }
  .responsive-layout.single-portfolio .portfolios > ul > li.has-description {
    margin-bottom: 30px !important;
  }
  .responsive-layout .portfolios .portfolio-filters {
    margin-bottom: 0px;
  }
  .responsive-layout .portfolios .portfolio-filters .cbp-l-filters-dropdownWrap {
    background: #ffffff;
    border: 1px solid #EDEDED;
  }
  .responsive-layout .portfolios .portfolio-filters .cbp-l-filters-dropdownHeader {
    color: #767676;
    text-transform: uppercase;
  }
  .responsive-layout .portfolios .portfolio-filters .cbp-l-filters-dropdownHeader:after {
    border-color: #767676 transparent;
  }
  .responsive-layout .portfolios .portfolio-filters .cbp-l-filters-dropdownWrap .cbp-filter-item {
    margin: 0;
  }
  .responsive-layout .portfolios .portfolio-filters .cbp-l-filters-dropdown,
  .responsive-layout .portfolios .portfolio-filters .cbp-l-filters-dropdownWrap,
  .responsive-layout .portfolios .portfolio-filters .cbp-search {
    width: 100%;
    max-width: 300px;
    display: inline-block;
    float: none;
  }
  .responsive-layout .portfolios .portfolio-filters .cbp-search {
    margin-top: 0px;
  }
  .responsive-layout .portfolios .portfolio_details .excerpt {
    display: none;
  }
  .responsive-layout .portfolios .portfolio_details .title,
  .responsive-layout .portfolios .portfolio_details .title a {
    font-size: 1em;
    line-height: 1em;
  }
  .responsive-layout .page-content .load-more {
    margin-bottom: 30px;
  }
  .responsive-layout .page-content .load-more a {
    padding: 0;
  }
  .responsive-layout #footer-sidebars {
    overflow: hidden;
  }
  .responsive-layout #footer-sidebars .widget {
    padding: 0 30px !important;
  }
  .responsive-layout footer.main-footer {
    padding-top: 30px;
    padding-bottom: 30px;
  }
  .responsive-layout article .loop-wrapper {
    padding: 0 0 20px 0 !important;
  }
  .responsive-layout article .loop-wrapper .list-item header.single {
    padding-top: 20px;
  }
  .responsive-layout .post-article .post-media .media-inner {
    position: relative;
    display: block;
    min-height: 21px;
  }
  .responsive-layout .post-article a.single-post-format {
    display: none;
  }
  .responsive-layout #header-breadcrumbs {
    display: none;
  }
  .responsive-layout #sub-header {
    position: relative;
    z-index: 2;
  }
  .responsive-layout #sub-header header.page-header {
    padding: 0 30px;
  }
  .responsive-layout #sub-header header.page-header .title {
    padding: 30px 0 0 0;
  }
  .responsive-layout #sub-header header.page-header .post-siblings {
    margin-bottom: -20px;
  }
  .responsive-layout #sub-header .meta-header-inside {
    position: relative;
    padding: 0 0 30px 0;
    width: 100%;
  }
  .responsive-layout .row > .has-more-button {
    padding-right: 15px !important;
  }
  .responsive-layout .column-read-more-btn {
    display: none;
  }
  .responsive-layout #commentform .form-submit {
    float: none;
    text-align: center;
  }
  .responsive-layout .respond-box {
    margin-top: 30px;
  }
  .responsive-layout .page-wrapper > div,
  .responsive-layout .page-wrapper > article {
    padding-right: 15px !important;
    padding-left: 15px !important;
  }
  .responsive-layout .header-middle {
    margin-bottom: 0;
  }
  .responsive-layout .header-middle > .limit-wrapper,
  .responsive-layout .header-middle > .row .limit-wrapper > .extended-column-inner,
  .responsive-layout .header-middle .header-middle-content {
    padding-right: 30px;
    padding-left: 30px;
  }
  .responsive-layout.boxed .row > div.extended.grid-1-1 {
    margin-right: -15px;
    margin-left: -15px;
    padding-right: 30px;
    padding-left: 30px;
  }
  .responsive-layout .services.smallimage {
    margin: 0 60px;
  }
  .responsive-layout #page {
    overflow: hidden;
  }
  .responsive-layout .meta-header-inside {
    padding: 0 0 30px 0;
  }
  .responsive-layout #header-breadcrumbs {
    padding: 10px 0 0 60px;
    color: #ffffff;
    text-align: left;
  }
  .responsive-layout #header-breadcrumbs a {
    color: #F0542D;
  }
  .responsive-layout #header-breadcrumbs:after {
    position: absolute;
    top: 34px;
    left: 60px;
    width: 70px;
    height: 1px;
    border-bottom: 1px solid #EDEDED;
    content: "";
  }
  .responsive-layout.single-post .meta-header-inside {
    padding: 0 0 20px 0 !important;
  }
  .responsive-layout .wpv-grid.has-more-button .column-read-more-btn {
    display: none;
  }
  .responsive-layout .loop-wrapper.regular .post-row-left {
    display: none;
  }
  .responsive-layout .loop-wrapper.regular .post-row-center {
    padding-left: 0;
    padding-right: 0;
    padding-top: 0;
    width: 100%;
  }
  .responsive-layout .loop-wrapper.regular .post-article .post-media {
    float: none;
    max-width: 100%;
    width: 100%;
  }
  .responsive-layout .loop-wrapper.regular .post-article .post-media img {
    width: 100%;
  }
  .responsive-layout .loop-wrapper.regular .post-article .post-content-outer {
    padding-left: 5px;
    padding-right: 5px;
  }
  .responsive-layout .loop-wrapper.regular .post-article .post-content-outer.single-post {
    padding-left: 0;
  }
  .responsive-layout .loop-wrapper.regular .post-article .post-content-outer .post-meta div {
    border: none;
  }
  .responsive-layout .loop-wrapper.regular .post-article .post-content-outer .post-meta div.blog-buttons a:after {
    display: none;
  }
  .responsive-layout .loop-wrapper.regular .post-article .quote-post-format .cite {
    float: none;
    padding-bottom: 25px;
    width: auto;
    text-align: left;
  }
  .responsive-layout .loop-wrapper.regular .post-article .quote-post-format .cite img {
    display: inline-block;
    margin-bottom: 0;
    padding: 0 20px 0 0;
    max-width: 85px;
    border: 0;
    vertical-align: middle;
  }
  .responsive-layout .loop-wrapper.regular .post-article .quote-post-format .cite img + .quote-author {
    display: inline;
    vertical-align: middle;
  }
  .responsive-layout .loop-wrapper.regular .post-article .quote-post-format .cite + .quote-text {
    padding-left: 0;
  }
  .responsive-layout .loop-wrapper.regular .post-article .quote-post-format .quote-text {
    padding-bottom: 25px;
  }
  .responsive-layout .loop-wrapper.news .post-content-wrapper {
    padding: 0px;
    background: none;
  }
  .responsive-layout .team-member {
    text-align: center;
  }
  .responsive-layout .team-member img {
    display: inline-block;
  }
  .responsive-layout .team-member .share-icons .icon {
    float: none;
  }
  .responsive-layout .wpv-tabs .ui-tabs-nav li {
    display: block;
    float: none;
    margin-left: 0 !important;
  }
  .responsive-layout .wpv-tabs.vertical {
    overflow: hidden;
    margin: 0 -30px;
  }
  .responsive-layout .wpv-tabs.vertical:before {
    display: none;
  }
  .responsive-layout .wpv-tabs.vertical .ui-tabs-nav {
    position: relative;
    padding: 0 30px !important;
    width: 100%;
  }
  .responsive-layout .wpv-tabs.vertical .ui-tabs-nav:before {
    display: none;
  }
  .responsive-layout .wpv-tabs.vertical .ui-tabs-nav li {
    width: 100%;
    text-align: center;
  }
  .responsive-layout .wpv-tabs.vertical .ui-tabs-nav li.inactive-block-title {
    padding: 30px 0;
  }
  .responsive-layout .wpv-tabs.vertical .ui-tabs-nav li:last-child {
    margin-bottom: 30px;
  }
  .responsive-layout .wpv-tabs.vertical .ui-tabs-nav li:not(.has-icon) a .title-text {
    width: auto;
  }
  .responsive-layout .wpv-tabs.vertical .pane {
    float: none;
    clear: both;
    padding: 30px;
    width: 100%;
  }
  .responsive-layout .wpv-tabs.vertical .pane:before {
    display: none;
  }
  .responsive-layout .wpv-tabs.horizontal .ui-tabs-nav li:first-child {
    border-top-right-radius: 5px;
  }
  .responsive-layout .wpv-tabs.horizontal .ui-tabs-nav li:last-child {
    border-top-right-radius: 0;
  }
  .responsive-layout .comments .children {
    margin-left: 0;
    border-top: 0;
  }
  .responsive-layout .ls-bottom-nav-wrapper {
    display: none;
  }
  .responsive-layout .sep-text:not(.keep-always) .content {
    display: block;
    white-space: normal;
  }
  .responsive-layout .sep-text:not(.keep-always) .sep-text-before,
  .responsive-layout .sep-text:not(.keep-always) .sep-text-after {
    display: none;
  }
  .responsive-layout .sep-text-more {
    display: none;
  }
  .responsive-layout .sep,
  .responsive-layout .sep-2,
  .responsive-layout .sep-3 {
    margin-top: 30px;
  }
  .responsive-layout blockquote.simple .quote-thumbnail {
    float: none;
    width: auto;
    text-align: left;
    margin: 0;
  }
  .responsive-layout blockquote.simple .quote-thumbnail img {
    display: none;
  }
  .responsive-layout .vamtam-rsvp-form {
    padding: 0;
  }
  .responsive-layout .vamtam-rsvp-form .wpcf7-file {
    width: 92%;
    padding: 4%;
  }
  .responsive-layout .wpv-grid.hide-bg-lowres,
  .responsive-layout .wpv-grid.hide-bg-lowres > .wpv-parallax-bg-img {
    background-image: none !important;
  }
  .responsive-layout .wpv-grid.extended-content.has-horizontal-padding {
    padding-left: 5px !important;
    padding-right: 5px !important;
  }
  .responsive-layout .wpv-grid.extended-content.has-extended-padding {
    padding-left: 0px;
    padding-right: 0px;
  }
  .responsive-layout .wpv-grid.extended-content .extended-column-inner {
    padding: 0 10px;
  }
  .responsive-layout .wpv-hide-lowres {
    display: none;
  }
  .responsive-layout .wpv-restrict-mobile-map {
    height: 180px;
  }
  .responsive-layout .extended-column-inner {
    padding: 0;
  }
}
@media (min-width: 700px) and (max-width: 958px) {
  .responsive-layout.boxed .page-wrapper > div,
  .responsive-layout.boxed .page-wrapper > article,
  .responsive-layout.boxed .page-wrapper .ajax-result > div,
  .responsive-layout.boxed .page-wrapper .ajax-result > article {
    padding-left: 120px;
    padding-right: 120px;
  }
  .responsive-layout.boxed .row > div.grid-1-1.extended,
  .responsive-layout.boxed .row > div.grid-1-1.extended-content {
    padding-left: 120px !important;
    padding-right: 120px !important;
    margin-left: -105px;
    margin-right: -105px;
  }
  .responsive-layout.boxed aside.left,
  .responsive-layout.boxed aside.right,
  .responsive-layout.boxed #footer-sidebars .widget,
  .responsive-layout.boxed .header-middle .header-middle-content {
    padding: 0 120px !important;
  }
}
@media (max-width: 479px) {
  .responsive-layout .comment .comment-content {
    margin-left: 10px;
  }
  .responsive-layout .comment .comment-author {
    display: none;
  }
  .responsive-layout .socialcount > li {
    min-width: 60px;
  }
  .responsive-layout .socialcount .count {
    display: none;
  }
  .responsive-layout .page-header h1 {
    line-height: 1.2em;
    font-size: 24px;
  }
  .responsive-layout .post-article header h3,
  .responsive-layout .post-article header h3 a {
    font-size: 1.3em;
    padding-top: 0;
  }
  .responsive-layout .loop-wrapper.news .post-actions-wrapper {
    bottom: -4px;
  }
  .responsive-layout .loop-wrapper.news .post-actions-wrapper .icon {
    margin-right: 4px;
    font-size: 11px;
  }
  .responsive-layout .loop-wrapper.news .post-actions-wrapper .post-date {
    text-transform: none;
    margin-right: 0;
    width: 68%;
    padding: 5px;
    line-height: 2em;
    font-size: 0.6em;
  }
  .responsive-layout .loop-wrapper.news .comment-count {
    width: 25%;
  }
  .responsive-layout .loop-wrapper.news .comment-count a {
    padding: 5px;
    text-align: center;
  }
  .responsive-layout .loop-wrapper .list-item .post-content-outer {
    padding: 0;
    margin-bottom: 0;
  }
  .responsive-layout .post-content-wrapper {
    background: none;
  }
  .responsive-layout .post-content-wrapper h3,
  .responsive-layout .post-content-wrapper h3 a {
    font-size: 15px;
  }
  .responsive-layout article .loop-wrapper .list-item header.single {
    padding-top: 20px;
  }
  .responsive-layout header.main-header.layout-logo-menu .first-row .logo-wrapper .logo img {
    max-width: 120px;
  }
  .responsive-layout header.main-header.layout-logo-text-menu .first-row-left .logo-wrapper .logo img {
    max-width: 120px !important;
  }
  .responsive-layout.woocommerce table.cart td,
  .responsive-layout.woocommerce table.cart th {
    font-size: 10px;
  }
  .responsive-layout.woocommerce table.cart td.product-price,
  .responsive-layout.woocommerce table.cart th.product-price {
    display: none;
  }
  .responsive-layout.woocommerce table.cart td.product-name a {
    font-size: 13px;
  }
  .responsive-layout.single-post .related-posts {
    padding-top: 0px;
  }
  .responsive-layout #commentform .form-submit {
    margin: 0px;
  }
  .responsive-layout h3 .vamtam-button {
    margin-top: 20px;
  }
  .responsive-layout .linkarea table td {
    display: block;
  }
}
@media (max-width: 959px) {
  .responsive-layout .fixed-header-box .cart-dropdown {
    display: none !important;
  }
  .responsive-layout header.main-header {
    position: relative;
    top: 0;
    right: 0;
    left: 0;
    margin: 0;
  }
  .responsive-layout header.main-header .header-padding {
    padding: 0;
  }
  .responsive-layout header.main-header .mobile-top-bar {
    display: block;
    padding: 5px 20px;
    box-sizing: border-box;
    max-width: 100%;
  }
  .responsive-layout header.main-header .logo-wrapper .logo {
    min-width: 0 !important;
    width: 100%;
    display: table-cell;
    vertical-align: middle;
  }
  .responsive-layout header.main-header .logo-wrapper .logo img {
    top: 0;
    display: block;
    opacity: 1 !important;
    height: auto;
    max-width: 100%;
  }
  .responsive-layout header.main-header .logo-wrapper .logo img.alternative-logo {
    display: none;
  }
  .responsive-layout header.main-header .logo-wrapper .mobile-logo-additions {
    display: table-cell;
    vertical-align: middle;
    text-align: right;
    white-space: nowrap;
  }
  .responsive-layout header.main-header .logo-wrapper .mobile-logo-additions .vamtam-cart-dropdown-link {
    display: inline-block;
    padding: 0;
    margin: 0 10px 0 0;
    vertical-align: middle;
  }
  .responsive-layout header.main-header .logo-wrapper .mobile-logo-additions .header-search {
    vertical-align: middle;
  }
  .responsive-layout header.main-header .header-left {
    border-radius: 0;
    background-clip: padding-box;
    display: none;
  }
  .responsive-layout header.main-header #header-text {
    display: none;
  }
  .responsive-layout header.main-header .header-right {
    display: none;
  }
  .responsive-layout header.main-header .second-row .second-row-columns {
    display: block;
  }
  .responsive-layout header.main-header .second-row .second-row-columns .header-center {
    display: block;
  }
  .responsive-layout header.main-header .search-wrapper {
    display: none;
  }
  .responsive-layout .fixed-header-box .logo-wrapper {
    padding-right: 20px;
  }
  .responsive-layout.sticky-header-type-over.sticky-header.wpv-not-scrolled header.main-header.layout-logo-menu .first-row {
    border-radius: 0;
  }
  .responsive-layout header.main-header.layout-logo-text-menu .first-row {
    display: block;
    min-height: 0;
    height: auto;
  }
  .responsive-layout header.main-header.layout-logo-text-menu .first-row-wrapper {
    padding: 0;
    height: auto;
  }
  .responsive-layout header.main-header.layout-logo-text-menu .first-row-right {
    display: none;
  }
  .responsive-layout header.main-header.layout-logo-text-menu .first-row-left {
    display: block;
    margin-bottom: 0;
    min-height: 0;
    height: auto;
  }
  .responsive-layout header.main-header.layout-logo-text-menu .first-row-left .logo-wrapper {
    display: block;
    min-height: 0;
  }
  .responsive-layout header.main-header.layout-logo-text-menu .first-row-left .logo-wrapper .logo {
    top: 0;
  }
  .responsive-layout header.main-header.layout-logo-text-menu .first-row-left .logo-wrapper .logo img {
    padding: 10px 0 !important;
    top: 0 !important;
    max-width: 200px;
  }
  .responsive-layout header.main-header.layout-logo-menu .header-contents {
    display: block;
    padding: 0;
    margin: 0;
  }
  .responsive-layout header.main-header.layout-logo-menu .first-row {
    display: block;
    padding: 0;
  }
  .responsive-layout header.main-header.layout-logo-menu .first-row .logo-wrapper {
    min-height: 0;
  }
  .responsive-layout header.main-header.layout-logo-menu .first-row .logo-wrapper .logo {
    top: 0;
  }
  .responsive-layout header.main-header.layout-logo-menu .first-row .logo-wrapper .logo img {
    padding: 0 !important;
  }
  .responsive-layout header.main-header.layout-standard .first-row {
    height: auto;
    display: block;
  }
  .responsive-layout header.main-header.layout-standard .first-row .logo-wrapper {
    display: block;
  }
  .responsive-layout header.main-header.layout-standard .first-row .logo {
    display: table-cell;
  }
  .responsive-layout header.main-header.layout-standard .first-row .logo img {
    padding: 0 !important;
  }
  .responsive-layout header.main-header .top-nav,
  .responsive-layout header.main-header .second-row {
    display: none !important;
  }
  .responsive-layout header.main-header .logo {
    padding: 10px 0;
  }
  .responsive-layout header.main-header .logo img {
    max-height: 65px;
  }
  .responsive-layout header.main-header .logo-wrapper {
    padding-left: 70px;
    clear: both;
  }
  .responsive-layout header.main-header .logo-wrapper:before,
  .responsive-layout header.main-header .logo-wrapper:after {
    content: " ";
    display: table;
  }
  .responsive-layout header.main-header .logo-wrapper:after {
    clear: both;
  }
  .responsive-layout header.main-header .logo-wrapper:before,
  .responsive-layout header.main-header .logo-wrapper:after {
    content: " ";
    display: table;
  }
  .responsive-layout header.main-header .logo-wrapper:after {
    clear: both;
  }
  .responsive-layout .fixed-header-box {
    padding: 0;
  }
  .responsive-layout #menus {
    float: none;
    display: inline-block;
  }
  .responsive-layout #mp-menu-trigger {
    position: absolute;
    top: 50%;
    left: 0;
    z-index: 600;
    display: block;
    margin-top: -17.5px;
    padding-left: 20px;
    padding-right: 20px;
    width: 35px;
    height: 35px;
    text-indent: -100000px;
    cursor: pointer;
    visibility: hidden;
  }
  .responsive-layout #mp-menu-trigger:before {
    position: absolute;
    top: 0;
    left: 20px;
    padding: 0;
    width: 35px;
    height: 35px;
    color: #F0542D;
    text-indent: 0;
    font-size: 35px;
    line-height: .9;
  }
  .responsive-layout .mp-pusher {
    position: relative;
    left: 0;
    height: 100%;
  }
  .responsive-layout .mp-menu {
    position: fixed;
    top: 0;
    left: -270px;
    z-index: 110 !important;
    display: block;
    width: 270px;
    height: 100%;
    background-color: #EDEDED;
  }
  .responsive-layout .mp-menu ul {
    margin: 0;
    padding: 0;
    list-style: none;
  }
  .responsive-layout .mp-menu ul li {
    padding-bottom: 0;
  }
  .responsive-layout .mp-menu ul li li:first-child {
    padding-top: 0;
  }
  .responsive-layout .mp-menu ul li > a {
    font: 600 13px/30px "Raleway";
    -webkit-transition: background 0.3s ease-out, box-shadow 0.3s ease-out;
    transition: background 0.3s ease-out, box-shadow 0.3s ease-out;
    display: block;
    padding: 10px 20px;
    outline: none;
    box-shadow: inset 0 -1px rgba(255,255,255,0.2);
    color: #000000;
  }
  .responsive-layout .mp-menu ul li > a.has-children::after {
    float: right;
    margin-right: -10px;
    color: #000000;
    content: "\e005";
    font-size: 15px;
    font-family: 'theme';
    font-style: normal;
  }
  .responsive-layout .mp-menu ul li > a:hover {
    text-decoration: none;
  }
  .responsive-layout .mp-menu ul li::before {
    position: absolute;
    left: 10px;
    z-index: -1;
    color: rgba(0,0,0,0.2);
    line-height: 3.5;
  }
  .responsive-layout .mp-menu h2 {
    font: 600 13px/30px "Raleway";
    margin: 0;
    padding: 1em;
    color: #000000;
    text-transform: uppercase;
    letter-spacing: 1px;
    font-weight: 700;
    font-size: 1em;
  }
  .responsive-layout .mp-menu .mp-level .mp-level:not(.mp-level-open),
  .responsive-layout .mp-menu .mp-level.mp-level-open .mp-level:not(.mp-level-open) {
    display: none;
  }
  .responsive-layout .mp-level {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    background: #EDEDED;
  }
  .responsive-layout .mp-level::after {
    z-index: -1;
  }
  .responsive-layout .mp-level.mp-level-overlay {
    cursor: pointer;
  }
  .responsive-layout .mp-level.mp-level-overlay.mp-level::before {
    width: 100%;
    height: 100%;
    background: transparent;
    opacity: 1;
  }
  .responsive-layout .mp-level .mp-level {
    position: relative;
  }
  .responsive-layout .mp-level .mp-back + ul {
    box-shadow: inset 0 1px rgba(255,255,255,0.1);
  }
  .responsive-layout .mp-pusher::after,
  .responsive-layout .mp-level::after,
  .responsive-layout .mp-level::before {
    position: absolute;
    top: 0;
    right: 0;
    width: 0;
    height: 0;
    content: '';
    opacity: 0;
  }
  .responsive-layout .mp-pusher.mp-pushed::after,
  .responsive-layout .mp-level.mp-level-overlay::after {
    -webkit-transition: opacity .5s ease-out;
    transition: opacity .5s ease-out;
    width: 100%;
    height: 100%;
    opacity: 1;
  }
  .responsive-layout .mp-pusher::after {
    -webkit-transition: opacity 0.3s ease-out, width 0.1s 0.3s ease-out, height 0.1s 0.3s ease-out;
    transition: opacity 0.3s ease-out, width 0.1s 0.3s ease-out, height 0.1s 0.3s ease-out;
    background: rgba(255,255,255,0.8);
    z-index: 100;
  }
  .responsive-layout .mp-menu ul li a:not(.mp-back):hover {
    background: transparent;
    color: #F0542D;
  }
  .responsive-layout .mp-menu .mp-level.mp-level-overlay > ul > li > a,
  .responsive-layout .mp-level.mp-level-overlay > ul > li:first-child > a {
    box-shadow: inset 0 -1px rgba(255,255,255,0);
  }
  .responsive-layout .mp-back {
    -webkit-transition: background 0.3s ease-out;
    transition: background 0.3s ease-out;
    position: relative;
    display: block;
    padding: 1em;
    outline: none;
    background: #2B2F34;
    box-shadow: inset 0 1px rgba(255,255,255,0.1);
    color: #ffffff;
    text-transform: uppercase;
    letter-spacing: 1px;
    font: normal 14px/20px "Raleway";
    font-weight: bold;
  }
  .responsive-layout .mp-back::after {
    position: absolute;
    right: 10px;
    color: #ffffff;
    content: "\e006";
    font-size: 15px;
    font-family: 'theme';
    font-weight: normal;
    font-style: normal;
  }
}
@media print {
  * {
    background: transparent !important;
    color: black !important;
    text-shadow: none !important;
    filter: none !important;
    -ms-filter: none !important;
  }
  a,
  a:visited {
    color: #444 !important;
    text-decoration: underline;
  }
  a[href]:after {
    content: " (" attr(href) ")";
  }
  abbr[title]:after {
    content: " (" attr(title) ")";
  }
  .ir a:after,
  a[href^="javascript:"]:after,
  a[href^="#"]:after {
    content: "";
  }
  pre,
  blockquote {
    border: 1px solid #999;
    page-break-inside: avoid;
  }
  thead {
    display: table-header-group;
  }
  tr,
  img {
    page-break-inside: avoid;
  }
  @page {
    margin: 0.5cm;
  }
  p,
  h2,
  h3 {
    orphans: 3;
    widows: 3;
  }
  h2,
  h3 {
    page-break-after: avoid;
  }
}
